<?xml version="1.0" encoding="UTF-8" standalone="yes"?>
<xsl:stylesheet xmlns:xs="http://www.w3.org/2001/XMLSchema"
                xmlns:xsd="http://www.w3.org/2001/XMLSchema"
                xmlns:saxon="http://saxon.sf.net/"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
                xmlns:schold="http://www.ascc.net/xml/schematron"
                xmlns:iso="http://purl.oclc.org/dsdl/schematron"
                xmlns:xhtml="http://www.w3.org/1999/xhtml"
                xmlns:hl7="urn:hl7-org:v3"
                xmlns:cda="urn:hl7-org:v3"
                xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                xmlns:hl7v2="urn:hl7-org:v2xml"
                xmlns:lab="urn:oid:1.3.6.1.4.1.19376.1.3.2"
                xmlns:sdtc="urn:hl7-org:sdtc"
                xmlns:hl7nl="urn:hl7-nl:v3"
                xmlns:nfu="urn:urn:nictiz-nl:v3/nfu"
                xmlns:pharm="urn:ihe:pharm:medication"
                version="2.0"><!--Implementers: please note that overriding process-prolog or process-root is 
    the preferred method for meta-stylesheets to use where possible. -->
   <xsl:param name="archiveDirParameter"/>
   <xsl:param name="archiveNameParameter"/>
   <xsl:param name="fileNameParameter"/>
   <xsl:param name="fileDirParameter"/>
   <xsl:variable name="document-uri">
      <xsl:value-of select="document-uri(/)"/>
   </xsl:variable>

   <!--PHASES-->


   <!--PROLOG-->
   <xsl:output method="text"/>

   <!--XSD TYPES FOR XSLT2-->


   <!--KEYS AND FUNCTIONS-->


   <!--DEFAULT RULES-->


   <!--MODE: SCHEMATRON-SELECT-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-select-full-path">
      <xsl:apply-templates select="." mode="schematron-get-full-path"/>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-->
   <!--This mode can be used to generate an ugly though full XPath for locators-->
   <xsl:template match="*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">
            <xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>*:</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>[namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="preceding"
                    select="count(preceding-sibling::*[local-name()=local-name(current())                                   and namespace-uri() = namespace-uri(current())])"/>
      <xsl:text>[</xsl:text>
      <xsl:value-of select="1+ $preceding"/>
      <xsl:text>]</xsl:text>
   </xsl:template>
   <xsl:template match="@*" mode="schematron-get-full-path">
      <xsl:apply-templates select="parent::*" mode="schematron-get-full-path"/>
      <xsl:text>/</xsl:text>
      <xsl:choose>
         <xsl:when test="namespace-uri()=''">@<xsl:value-of select="name()"/>
         </xsl:when>
         <xsl:otherwise>
            <xsl:text>@*[local-name()='</xsl:text>
            <xsl:value-of select="local-name()"/>
            <xsl:text>' and namespace-uri()='</xsl:text>
            <xsl:value-of select="namespace-uri()"/>
            <xsl:text>']</xsl:text>
         </xsl:otherwise>
      </xsl:choose>
   </xsl:template>

   <!--MODE: SCHEMATRON-FULL-PATH-2-->
   <!--This mode can be used to generate prefixed XPath for humans-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-2">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="preceding-sibling::*[name(.)=name(current())]">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>
   <!--MODE: SCHEMATRON-FULL-PATH-3-->
   <!--This mode can be used to generate prefixed XPath for humans 
	(Top-level element has index)-->
   <xsl:template match="node() | @*" mode="schematron-get-full-path-3">
      <xsl:for-each select="ancestor-or-self::*">
         <xsl:text>/</xsl:text>
         <xsl:value-of select="name(.)"/>
         <xsl:if test="parent::*">
            <xsl:text>[</xsl:text>
            <xsl:value-of select="count(preceding-sibling::*[name(.)=name(current())])+1"/>
            <xsl:text>]</xsl:text>
         </xsl:if>
      </xsl:for-each>
      <xsl:if test="not(self::*)">
         <xsl:text/>/@<xsl:value-of select="name(.)"/>
      </xsl:if>
   </xsl:template>

   <!--MODE: GENERATE-ID-FROM-PATH -->
   <xsl:template match="/" mode="generate-id-from-path"/>
   <xsl:template match="text()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.text-', 1+count(preceding-sibling::text()), '-')"/>
   </xsl:template>
   <xsl:template match="comment()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.comment-', 1+count(preceding-sibling::comment()), '-')"/>
   </xsl:template>
   <xsl:template match="processing-instruction()" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.processing-instruction-', 1+count(preceding-sibling::processing-instruction()), '-')"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-from-path">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:value-of select="concat('.@', name())"/>
   </xsl:template>
   <xsl:template match="*" mode="generate-id-from-path" priority="-0.5">
      <xsl:apply-templates select="parent::*" mode="generate-id-from-path"/>
      <xsl:text>.</xsl:text>
      <xsl:value-of select="concat('.',name(),'-',1+count(preceding-sibling::*[name()=name(current())]),'-')"/>
   </xsl:template>

   <!--MODE: GENERATE-ID-2 -->
   <xsl:template match="/" mode="generate-id-2">U</xsl:template>
   <xsl:template match="*" mode="generate-id-2" priority="2">
      <xsl:text>U</xsl:text>
      <xsl:number level="multiple" count="*"/>
   </xsl:template>
   <xsl:template match="node()" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>n</xsl:text>
      <xsl:number count="node()"/>
   </xsl:template>
   <xsl:template match="@*" mode="generate-id-2">
      <xsl:text>U.</xsl:text>
      <xsl:number level="multiple" count="*"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="string-length(local-name(.))"/>
      <xsl:text>_</xsl:text>
      <xsl:value-of select="translate(name(),':','.')"/>
   </xsl:template>
   <!--Strip characters-->
   <xsl:template match="text()" priority="-1"/>

   <!--SCHEMA SETUP-->
   <xsl:template match="/">
      <xsl:apply-templates select="/" mode="M12"/>
      <xsl:apply-templates select="/" mode="M13"/>
      <xsl:apply-templates select="/" mode="M14"/>
      <xsl:apply-templates select="/" mode="M15"/>
   </xsl:template>

   <!--SCHEMATRON PATTERNS-->


   <!--PATTERN -->
   <xsl:template match="text()" priority="-1" mode="M12"/>
   <xsl:template match="@*|node()" priority="-2" mode="M12">
      <xsl:apply-templates select="*" mode="M12"/>
   </xsl:template>

   <!--PATTERN OML_O21_Lab2Lab-->


	  <!--RULE -->
   <xsl:template match="/" priority="1000" mode="M13">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:SFT | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:OML_O21.PATIENT | descendant-or-self::hl7v2:OML_O21.ORDER"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): In de instance werd tenminste één van de volgende elementen verwacht: descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:SFT | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:OML_O21.PATIENT | descendant-or-self::hl7v2:OML_O21.ORDER (descendant-or-self::hl7v2:MSH | descendant-or-self::hl7v2:SFT | descendant-or-self::hl7v2:NTE | descendant-or-self::hl7v2:OML_O21.PATIENT | descendant-or-self::hl7v2:OML_O21.ORDER / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M13"/>
   <xsl:template match="@*|node()" priority="-2" mode="M13">
      <xsl:apply-templates select="*" mode="M13"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502Lab2Lab Aanvraagbericht (OML^O21)-->


	  <!--RULE d20e3426-false-d5727e0-->
   <xsl:template match="/hl7v2:OML_O21" priority="18713" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:MSH is required [min 1x]. (count(hl7v2:MSH) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:MSH komt te vaak voor [max 1x]. (count(hl7v2:MSH) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT is required [min 1x]. (count(hl7v2:OML_O21.PATIENT) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.ORDER) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.ORDER is required [min 1x]. (count(hl7v2:OML_O21.ORDER) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH" priority="18712" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.1 is required [min 1x]. (count(hl7v2:MSH.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.1 komt te vaak voor [max 1x]. (count(hl7v2:MSH.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.2 is required [min 1x]. (count(hl7v2:MSH.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.2 komt te vaak voor [max 1x]. (count(hl7v2:MSH.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.3 is required [min 1x]. (count(hl7v2:MSH.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.3 komt te vaak voor [max 1x]. (count(hl7v2:MSH.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.4 komt te vaak voor [max 1x]. (count(hl7v2:MSH.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.5 is required [min 1x]. (count(hl7v2:MSH.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.5 komt te vaak voor [max 1x]. (count(hl7v2:MSH.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.6 is required [min 1x]. (count(hl7v2:MSH.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.6 komt te vaak voor [max 1x]. (count(hl7v2:MSH.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.7 is required [min 1x]. (count(hl7v2:MSH.7) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.7 komt te vaak voor [max 1x]. (count(hl7v2:MSH.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.8 komt te vaak voor [max 1x]. (count(hl7v2:MSH.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.9 is required [min 1x]. (count(hl7v2:MSH.9) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.9 komt te vaak voor [max 1x]. (count(hl7v2:MSH.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.10 is required [min 1x]. (count(hl7v2:MSH.10) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.10 komt te vaak voor [max 1x]. (count(hl7v2:MSH.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.11 is required [min 1x]. (count(hl7v2:MSH.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.11 komt te vaak voor [max 1x]. (count(hl7v2:MSH.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.12 is required [min 1x]. (count(hl7v2:MSH.12) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.12 komt te vaak voor [max 1x]. (count(hl7v2:MSH.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.13 komt te vaak voor [max 1x]. (count(hl7v2:MSH.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.14 komt te vaak voor [max 1x]. (count(hl7v2:MSH.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.15 komt te vaak voor [max 1x]. (count(hl7v2:MSH.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.16 komt te vaak voor [max 1x]. (count(hl7v2:MSH.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.17 komt te vaak voor [max 1x]. (count(hl7v2:MSH.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.18 komt te vaak voor [max 1x]. (count(hl7v2:MSH.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.19 komt te vaak voor [max 1x]. (count(hl7v2:MSH.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.20 komt te vaak voor [max 1x]. (count(hl7v2:MSH.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSH.21) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): element hl7v2:MSH.21 is mandatory [min 1x]. (count(hl7v2:MSH.21) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.1"
                 priority="18711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Field Separator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Field Separator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Field Separator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.2"
                 priority="18710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('2') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('2') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Encoding Characters') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Encoding Characters' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Encoding Characters') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3"
                 priority="18709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('3') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '3' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('3') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70361') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Application') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sending Application' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sending Application') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.1"
                 priority="18707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.2"
                 priority="18706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/hl7v2:HD.3"
                 priority="18705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4"
                 priority="18703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('4') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '4' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('4') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70362') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sending Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sending Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sending Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.1"
                 priority="18701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.2"
                 priority="18700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/hl7v2:HD.3"
                 priority="18699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5"
                 priority="18697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('5') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '5' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('5') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70361') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70361' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70361') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Application') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Receiving Application' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Receiving Application') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.1"
                 priority="18695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.2"
                 priority="18694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/hl7v2:HD.3"
                 priority="18693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6"
                 priority="18691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('6') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '6' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('6') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70362') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70362' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70362') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Receiving Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Receiving Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Receiving Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.1"
                 priority="18689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.2"
                 priority="18688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/hl7v2:HD.3"
                 priority="18687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7"
                 priority="18685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('7') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '7' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('7') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time Of Message' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time Of Message') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.1"
                 priority="18683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7/hl7v2:TS.2"
                 priority="18682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.8"
                 priority="18680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('8') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '8' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('8') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Security') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Security' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Security') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9"
                 priority="18679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.1 komt te vaak voor [max 1x]. (count(hl7v2:MSG.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.2 komt te vaak voor [max 1x]. (count(hl7v2:MSG.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MSG.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): element hl7v2:MSG.3 komt te vaak voor [max 1x]. (count(hl7v2:MSG.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('9') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '9' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('9') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MSG') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'MSG' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MSG') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Message Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.1"
                 priority="18677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70076') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van Table MOET 'HL70076' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70076') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van LongName MOET 'Message Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Message Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.2"
                 priority="18675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70003') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van Table MOET 'HL70003' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70003') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Trigger Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van LongName MOET 'Trigger Event' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Trigger Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/hl7v2:MSG.3"
                 priority="18673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70354') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van Table MOET 'HL70354' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70354') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Structure') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSG_datatype): de waarde van LongName MOET 'Message Structure' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Message Structure') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.36-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.10"
                 priority="18671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('10') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '10' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('10') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Control ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Control ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Message Control ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11"
                 priority="18670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): element hl7v2:PT.1 komt te vaak voor [max 1x]. (count(hl7v2:PT.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PT.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): element hl7v2:PT.2 komt te vaak voor [max 1x]. (count(hl7v2:PT.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('11') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '11' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('11') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'PT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Processing ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.1"
                 priority="18668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70103') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van Table MOET 'HL70103' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70103') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van LongName MOET 'Processing ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Processing ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11/hl7v2:PT.2"
                 priority="18666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70207') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van Table MOET 'HL70207' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70207') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Processing Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PT_datatype): de waarde van LongName MOET 'Processing Mode' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Processing Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12"
                 priority="18664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='2.5'"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de elementinhoud van hl7v2:MSH.12 MOET ''2.5'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='2.5' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.1 komt te vaak voor [max 1x]. (count(hl7v2:VID.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.2 komt te vaak voor [max 1x]. (count(hl7v2:VID.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:VID.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): element hl7v2:VID.3 komt te vaak voor [max 1x]. (count(hl7v2:VID.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('12') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '12' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('12') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('VID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'VID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('VID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.1"
                 priority="18662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70104') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van Table MOET 'HL70104' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70104') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van LongName MOET 'Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2"
                 priority="18660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Internationalization Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van LongName MOET 'Internationalization Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Internationalization Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.1"
                 priority="18658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.2"
                 priority="18657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.3"
                 priority="18656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.4"
                 priority="18654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.5"
                 priority="18653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/hl7v2:CE.6"
                 priority="18652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3"
                 priority="18650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('International Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(VID_datatype): de waarde van LongName MOET 'International Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('International Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.69-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.1"
                 priority="18648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.2"
                 priority="18647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.3"
                 priority="18646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.4"
                 priority="18644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.5"
                 priority="18643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/hl7v2:CE.6"
                 priority="18642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.13"
                 priority="18640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('13') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '13' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('13') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Sequence Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.14"
                 priority="18639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('14') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '14' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('14') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Continuation Pointer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Continuation Pointer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Continuation Pointer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.15"
                 priority="18638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('15') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '15' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('15') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70155') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Accept Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Accept Acknowledgment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.16"
                 priority="18636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('16') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '16' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('16') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70155') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70155' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70155') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Application Acknowledgment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Application Acknowledgment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Application Acknowledgment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.17"
                 priority="18634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NLD'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:MSH.17 MOET ''NLD'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='NLD' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('17') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '17' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('17') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.18"
                 priority="18632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('692') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '692' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('692') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70211') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70211' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70211') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Character Set') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Character Set' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Character Set') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19"
                 priority="18630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('693') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '693' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('693') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Language Of Message') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Principal Language Of Message' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Principal Language Of Message') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.1"
                 priority="18628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.2"
                 priority="18627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.3"
                 priority="18626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.4"
                 priority="18624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.5"
                 priority="18623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/hl7v2:CE.6"
                 priority="18622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.20"
                 priority="18620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1317') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1317' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1317') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70356') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Table MOET 'HL70356' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70356') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Alternate Character Set Handling Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Character Set Handling Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21"
                 priority="18618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1598') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Item MOET '1598' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1598') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Message Profile Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MSH_segment_Lab_algemeen): de waarde van LongName MOET 'Message Profile Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Message Profile Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.56-2018-11-30T100013.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.1"
                 priority="18616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.2"
                 priority="18615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.3"
                 priority="18614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/hl7v2:EI.4"
                 priority="18613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT" priority="18611" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.1 is required [min 1x]. (count(hl7v2:SFT.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.1 komt te vaak voor [max 1x]. (count(hl7v2:SFT.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.2 is required [min 1x]. (count(hl7v2:SFT.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.2 komt te vaak voor [max 1x]. (count(hl7v2:SFT.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.3 is required [min 1x]. (count(hl7v2:SFT.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.3 komt te vaak voor [max 1x]. (count(hl7v2:SFT.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.4 is required [min 1x]. (count(hl7v2:SFT.4) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.4 komt te vaak voor [max 1x]. (count(hl7v2:SFT.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.5 komt te vaak voor [max 1x]. (count(hl7v2:SFT.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SFT.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): element hl7v2:SFT.6 komt te vaak voor [max 1x]. (count(hl7v2:SFT.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1"
                 priority="18610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1834') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Item MOET '1834' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1834') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Vendor Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van LongName MOET 'Software Vendor Organization' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Software Vendor Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.1"
                 priority="18608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.2"
                 priority="18607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.3"
                 priority="18606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.4"
                 priority="18605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.5"
                 priority="18604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6"
                 priority="18602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.1"
                 priority="18600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.2"
                 priority="18599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/hl7v2:HD.3"
                 priority="18598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.7"
                 priority="18596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8"
                 priority="18594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.1"
                 priority="18592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.2"
                 priority="18591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/hl7v2:HD.3"
                 priority="18590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.9"
                 priority="18588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.10"
                 priority="18586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.2"
                 priority="18585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1835') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Item MOET '1835' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1835') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Certified Version or Release Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van LongName MOET 'Software Certified Version or Release Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Software Certified Version or Release Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.3"
                 priority="18584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1836') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Item MOET '1836' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1836') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Product Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van LongName MOET 'Software Product Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Software Product Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.4"
                 priority="18583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1837') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Item MOET '1837' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1837') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Binary ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van LongName MOET 'Software Binary ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Software Binary ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5"
                 priority="18582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1838') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Item MOET '1838' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1838') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Product Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van LongName MOET 'Software Product Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Software Product Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape"
                 priority="18581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape"
                 priority="18580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="18579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6"
                 priority="18578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1839') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Item MOET '1839' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1839') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Software Install Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SFT_segment): de waarde van LongName MOET 'Software Install Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Software Install Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.135-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.1"
                 priority="18576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6/hl7v2:TS.2"
                 priority="18575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE" priority="18573" mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.1"
                 priority="18572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.2"
                 priority="18571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3"
                 priority="18569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="18568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="18567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="18566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4"
                 priority="18565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="18563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="18562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="18561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="18559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="18558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="18557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3695-false-d9243e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT"
                 priority="18555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID is required [min 1x]. (count(hl7v2:PID) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID komt te vaak voor [max 1x]. (count(hl7v2:PID) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PD1 komt te vaak voor [max 1x]. (count(hl7v2:PD1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT_VISIT) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT_VISIT komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT_VISIT) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:GT1 komt te vaak voor [max 1x]. (count(hl7v2:GT1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID"
                 priority="18554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.1 komt te vaak voor [max 1x]. (count(hl7v2:PID.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.2 komt te vaak voor [max 1x]. (count(hl7v2:PID.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.3 is required [min 1x]. (count(hl7v2:PID.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.5 is required [min 1x]. (count(hl7v2:PID.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.7 komt te vaak voor [max 1x]. (count(hl7v2:PID.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.8 komt te vaak voor [max 1x]. (count(hl7v2:PID.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.12 komt te vaak voor [max 1x]. (count(hl7v2:PID.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.15 komt te vaak voor [max 1x]. (count(hl7v2:PID.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.16 komt te vaak voor [max 1x]. (count(hl7v2:PID.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.17 komt te vaak voor [max 1x]. (count(hl7v2:PID.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.18 komt te vaak voor [max 1x]. (count(hl7v2:PID.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.19 komt te vaak voor [max 1x]. (count(hl7v2:PID.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.20 komt te vaak voor [max 1x]. (count(hl7v2:PID.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.23 komt te vaak voor [max 1x]. (count(hl7v2:PID.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.24 komt te vaak voor [max 1x]. (count(hl7v2:PID.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.25 komt te vaak voor [max 1x]. (count(hl7v2:PID.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.27 komt te vaak voor [max 1x]. (count(hl7v2:PID.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.28 komt te vaak voor [max 1x]. (count(hl7v2:PID.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.29 komt te vaak voor [max 1x]. (count(hl7v2:PID.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.30 komt te vaak voor [max 1x]. (count(hl7v2:PID.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.31 komt te vaak voor [max 1x]. (count(hl7v2:PID.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.33 komt te vaak voor [max 1x]. (count(hl7v2:PID.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.34 komt te vaak voor [max 1x]. (count(hl7v2:PID.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.35 komt te vaak voor [max 1x]. (count(hl7v2:PID.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.36 komt te vaak voor [max 1x]. (count(hl7v2:PID.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.37 komt te vaak voor [max 1x]. (count(hl7v2:PID.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38) &lt;= 2"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.38 komt te vaak voor [max 2x]. (count(hl7v2:PID.38) &lt;= 2 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.1"
                 priority="18553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('104') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '104' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('104') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Set ID - PID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2"
                 priority="18552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('105') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('105') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="18550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="18549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="18548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="18546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="18540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="18538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="18532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="18531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="18530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="18517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3"
                 priority="18504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('106') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '106' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('106') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Identifier List' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Identifier List') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="18502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="18501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="18500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="18498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="18492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="18490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="18484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="18483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="18482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="18469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4"
                 priority="18456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('107') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '107' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('107') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Alternate Patient ID - PID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="18454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="18453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="18452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="18450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="18444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="18442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="18436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="18435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="18434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="18421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5"
                 priority="18408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('108') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '108' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('108') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="18406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="18404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="18403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="18402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="18401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="18400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="18399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="18398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="18397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="18396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="18395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="18394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="18392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="18390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="18388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="18387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="18386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="18384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="18383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="18382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="18380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="18378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="18373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="18368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="18366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="18364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="18363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="18361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="18359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="18358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="18356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6"
                 priority="18355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="18353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="18351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="18350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="18349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="18348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="18347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="18346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="18345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="18344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="18343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="18342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="18341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="18339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="18337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="18335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="18334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="18333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="18331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="18330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="18329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="18327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="18325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="18320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="18315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="18313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="18311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="18310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="18308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="18306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="18305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="18303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7"
                 priority="18302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '110' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time of Birth' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="18300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="18299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.8"
                 priority="18297"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '111' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Administrative Sex' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9"
                 priority="18295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('112') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '112' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('112') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Alias' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Alias') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="18293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="18291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="18290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="18289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="18288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="18287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="18286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="18285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="18284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="18283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="18282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="18281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="18279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="18277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="18275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="18274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="18273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="18271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="18270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="18269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="18267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="18265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="18260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="18255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="18253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="18251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="18250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="18248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="18246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="18245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="18243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10"
                 priority="18242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Race' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="18240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="18239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="18238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="18236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="18235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="18234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11"
                 priority="18232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('114') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '114' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('114') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="18230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="18228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="18227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="18226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="18225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="18224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="18223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="18222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="18221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="18219"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="18217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="18216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="18215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="18214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="18212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="18210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="18208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="18207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="18205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="18203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="18202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="18200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="18198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="18197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="18195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="18193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="18192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.12"
                 priority="18190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('115') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '115' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('115') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'County Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13"
                 priority="18189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('116') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '116' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('116') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Phone Number - Home' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="18187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="18186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="18184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="18182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="18181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="18180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="18179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="18178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="18177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="18176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="18175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="18174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14"
                 priority="18173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('117') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '117' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('117') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Phone Number - Business' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phone Number - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="18171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="18170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="18168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="18166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="18165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="18164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="18163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="18162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="18161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="18160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="18159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="18158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15"
                 priority="18157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="18155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="18154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="18153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="18151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="18150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="18149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16"
                 priority="18147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '119' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Marital Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="18145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="18144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="18143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="18141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="18140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="18139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17"
                 priority="18137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="18135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="18134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="18133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="18131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="18130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="18129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18"
                 priority="18127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('121') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '121' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('121') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Account Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Account Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="18125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="18124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="18123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="18121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="18115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="18113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="18107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="18106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="18105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="18092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.19"
                 priority="18079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('122') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '122' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('122') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'SSN Number - Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('SSN Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20"
                 priority="18078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x]. (count(hl7v2:DLN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x]. (count(hl7v2:DLN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x]. (count(hl7v2:DLN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('123') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '123' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('123') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'DLN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Driver''s License Number - Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="18076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van LongName MOET 'License Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('License Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="18075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Table MOET 'HL70333' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70333') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van LongName MOET 'Issuing State, Province, Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Issuing State, Province, Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="18074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21"
                 priority="18073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('124') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '124' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('124') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Mother''s Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="18071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="18070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="18069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="18067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="18065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="18064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="18063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="18061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="18059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="18057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="18056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="18055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="18053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="18052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="18051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="18049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="18048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="18047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="18045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="18044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="18043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="18041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="18040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="18039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="18038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="18036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="18035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="18034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="18032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="18031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="18030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="18028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="18027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="18026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22"
                 priority="18025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="18023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="18022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="18021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="18019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="18018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="18017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.23"
                 priority="18015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('126') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '126' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('126') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Birth Place' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.24"
                 priority="18014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('127') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '127' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('127') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Multiple Birth Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Multiple Birth Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.25"
                 priority="18012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('128') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '128' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('128') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Birth Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Birth Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26"
                 priority="18011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="18009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="18008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="18007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="18005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="18004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="18003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27"
                 priority="18001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('130') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '130' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('130') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70172' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70172') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Veterans Military Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Veterans Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="17999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="17998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="17997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="17995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="17994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="17993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28"
                 priority="17991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="17989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="17988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="17987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="17985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="17984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="17983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29"
                 priority="17981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('740') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '740' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('740') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Death Date and Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Death Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="17979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="17978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.30"
                 priority="17976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('741') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '741' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('741') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Death Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Death Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.31"
                 priority="17974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1535') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1535' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1535') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Identity Unknown Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identity Unknown Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.32"
                 priority="17972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1536') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1536' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1536') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70445' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70445') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Identity Reliability Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identity Reliability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33"
                 priority="17971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1537') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1537' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1537') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Last Update Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Last Update Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="17969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="17968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34"
                 priority="17966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1538') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1538' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1538') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Last Update Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Last Update Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="17964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="17963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="17962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35"
                 priority="17960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1539') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1539' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1539') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70446' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70446') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Species Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Species Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="17958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="17957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="17956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="17954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="17953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="17952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36"
                 priority="17950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1540') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1540' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1540') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70447' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70447') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Breed Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Breed Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="17948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="17947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="17946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="17944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="17943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="17942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.37"
                 priority="17940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1541') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1541' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1541') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Strain' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Strain') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38"
                 priority="17939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1542') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1542' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1542') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70429' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70429') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Production Class Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Production Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="17937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="17936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="17935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="17933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="17932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="17931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39"
                 priority="17929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1840') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1840' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1840') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Tribal Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Tribal Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="17927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="17926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="17925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="17923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="17922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="17921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="17919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="17918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="17917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1"
                 priority="17916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x]. (count(hl7v2:PD1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x]. (count(hl7v2:PD1.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x]. (count(hl7v2:PD1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x]. (count(hl7v2:PD1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x]. (count(hl7v2:PD1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x]. (count(hl7v2:PD1.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x]. (count(hl7v2:PD1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x]. (count(hl7v2:PD1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x]. (count(hl7v2:PD1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x]. (count(hl7v2:PD1.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x]. (count(hl7v2:PD1.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x]. (count(hl7v2:PD1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x]. (count(hl7v2:PD1.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x]. (count(hl7v2:PD1.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x]. (count(hl7v2:PD1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.1"
                 priority="17915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '755' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Living Dependency' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.2"
                 priority="17914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '742' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Living Arrangement' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3"
                 priority="17913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '756' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Patient Primary Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Primary Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="17911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="17910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="17909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="17908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="17907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="17905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="17903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="17902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="17901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="17899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="17897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="17895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="17894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="17893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="17891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="17889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4"
                 priority="17888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '757' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="17886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="17885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="17883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="17882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="17881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="17880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="17879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="17878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="17877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="17876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="17875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="17874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="17873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="17872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="17870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="17869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="17868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="17866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="17864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="17863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="17861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="17859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="17857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="17856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="17855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="17853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="17851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="17849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="17848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="17847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="17845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="17844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="17843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="17841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="17839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="17834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="17829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="17827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="17825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="17824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="17822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="17820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="17819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="17817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="17816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="17814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="17813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="17812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="17810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="17809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="17808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="17806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="17805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="17804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="17803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="17801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="17800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="17799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="17797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="17796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="17795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="17793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="17792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="17791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.5"
                 priority="17790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '745' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Student Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.6"
                 priority="17789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '753' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70295' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Handicap' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.7"
                 priority="17788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '759' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70315' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Living Will Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.8"
                 priority="17787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '760' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Organ Donor Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.9"
                 priority="17786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '761' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Separate Bill' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separate Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10"
                 priority="17784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '762' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Duplicate Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Duplicate Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="17782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="17781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="17780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="17778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="17772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="17770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="17764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="17763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="17762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="17749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11"
                 priority="17736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '743' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="17734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="17733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="17732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="17730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="17729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="17728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.12"
                 priority="17726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '744' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.13"
                 priority="17724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1566') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1566' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1566') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Protection Indicator Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14"
                 priority="17723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1567') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1567' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1567') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Place of Worship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Place of Worship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="17721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="17720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="17719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="17718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="17717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="17715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="17713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="17712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="17711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="17709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="17707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="17705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="17704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="17703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="17701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="17699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15"
                 priority="17698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1568') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1568' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1568') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70435' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Advance Directive Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="17696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="17695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="17694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="17692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="17691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="17690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.16"
                 priority="17688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70441' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70441') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Immunization Registry Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Immunization Registry Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.17"
                 priority="17687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Immunization Registry Status Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Immunization Registry Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.18"
                 priority="17686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Publicity Code Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.19"
                 priority="17685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70140' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Military Branch' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Branch') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.20"
                 priority="17684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '486' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70141' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Military Rank/Grade' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.21"
                 priority="17683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70142' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Military Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE"
                 priority="17682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.1"
                 priority="17681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.2"
                 priority="17680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3"
                 priority="17678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="17677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="17676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="17675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4"
                 priority="17674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="17672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="17671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="17670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="17668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="17667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="17666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1"
                 priority="17664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.1 is required [min 1x]. (count(hl7v2:NK1.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.1 komt te vaak voor [max 1x]. (count(hl7v2:NK1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.3 komt te vaak voor [max 1x]. (count(hl7v2:NK1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.7 komt te vaak voor [max 1x]. (count(hl7v2:NK1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.8 komt te vaak voor [max 1x]. (count(hl7v2:NK1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.9 komt te vaak voor [max 1x]. (count(hl7v2:NK1.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.10 komt te vaak voor [max 1x]. (count(hl7v2:NK1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.11 komt te vaak voor [max 1x]. (count(hl7v2:NK1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.12 komt te vaak voor [max 1x]. (count(hl7v2:NK1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.14 komt te vaak voor [max 1x]. (count(hl7v2:NK1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.15 komt te vaak voor [max 1x]. (count(hl7v2:NK1.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.16 komt te vaak voor [max 1x]. (count(hl7v2:NK1.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.20 komt te vaak voor [max 1x]. (count(hl7v2:NK1.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.21 komt te vaak voor [max 1x]. (count(hl7v2:NK1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.22 komt te vaak voor [max 1x]. (count(hl7v2:NK1.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.23 komt te vaak voor [max 1x]. (count(hl7v2:NK1.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.24 komt te vaak voor [max 1x]. (count(hl7v2:NK1.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.25 komt te vaak voor [max 1x]. (count(hl7v2:NK1.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.27 komt te vaak voor [max 1x]. (count(hl7v2:NK1.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.34 komt te vaak voor [max 1x]. (count(hl7v2:NK1.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.36 komt te vaak voor [max 1x]. (count(hl7v2:NK1.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.37 komt te vaak voor [max 1x]. (count(hl7v2:NK1.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.38 komt te vaak voor [max 1x]. (count(hl7v2:NK1.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NK1.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): element hl7v2:NK1.39 komt te vaak voor [max 1x]. (count(hl7v2:NK1.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.1"
                 priority="17663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('190') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('190') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NK1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Set ID - NK1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NK1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2"
                 priority="17662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('191') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '191' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('191') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1"
                 priority="17660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="17658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="17657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="17656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="17655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="17654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.2"
                 priority="17653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.3"
                 priority="17652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.4"
                 priority="17651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.5"
                 priority="17650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.6"
                 priority="17649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.7"
                 priority="17648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.8"
                 priority="17646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9"
                 priority="17644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="17642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="17641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="17640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="17638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="17637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="17636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10"
                 priority="17634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="17632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="17627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.11"
                 priority="17622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12"
                 priority="17620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="17618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="17617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13"
                 priority="17615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="17613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="17612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.14"
                 priority="17610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3"
                 priority="17609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('192') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '192' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('192') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70063' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Relationship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.1"
                 priority="17607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.2"
                 priority="17606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.3"
                 priority="17605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.4"
                 priority="17603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.5"
                 priority="17602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/hl7v2:CE.6"
                 priority="17601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4"
                 priority="17599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('193') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '193' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('193') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1"
                 priority="17597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="17595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="17594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="17593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.2"
                 priority="17592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.3"
                 priority="17591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.4"
                 priority="17590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.5"
                 priority="17589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.6"
                 priority="17588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.7"
                 priority="17586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.8"
                 priority="17584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.9"
                 priority="17583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.10"
                 priority="17582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.11"
                 priority="17581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12"
                 priority="17579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="17577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="17572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13"
                 priority="17567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="17565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="17564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14"
                 priority="17562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="17560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="17559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5"
                 priority="17557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('194') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '194' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('194') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.1"
                 priority="17555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.2"
                 priority="17554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.3"
                 priority="17552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.4"
                 priority="17550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.5"
                 priority="17549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.6"
                 priority="17548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.7"
                 priority="17547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.8"
                 priority="17546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.9"
                 priority="17545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.10"
                 priority="17544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.11"
                 priority="17543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/hl7v2:XTN.12"
                 priority="17542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6"
                 priority="17541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('195') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '195' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('195') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Business Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Business Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Business Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.1"
                 priority="17539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.2"
                 priority="17538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.3"
                 priority="17536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.4"
                 priority="17534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.5"
                 priority="17533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.6"
                 priority="17532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.7"
                 priority="17531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.8"
                 priority="17530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.9"
                 priority="17529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.10"
                 priority="17528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.11"
                 priority="17527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/hl7v2:XTN.12"
                 priority="17526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7"
                 priority="17525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('196') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '196' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('196') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70131') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70131' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70131') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Contact Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.1"
                 priority="17523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.2"
                 priority="17522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.3"
                 priority="17521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.4"
                 priority="17519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.5"
                 priority="17518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/hl7v2:CE.6"
                 priority="17517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.8"
                 priority="17515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('197') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '197' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('197') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Start Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.9"
                 priority="17514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('198') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '198' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('198') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'End Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.10"
                 priority="17513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('199') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '199' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('199') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Next of Kin / Associated Parties Job Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Next of Kin / Associated Parties Job Title' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Next of Kin / Associated Parties Job Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11"
                 priority="17512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.1 komt te vaak voor [max 1x]. (count(hl7v2:JCC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.2 komt te vaak voor [max 1x]. (count(hl7v2:JCC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.3 komt te vaak voor [max 1x]. (count(hl7v2:JCC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('200') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('200') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('JCC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'JCC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('JCC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Next of Kin / Associated Parties Job Code/Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Next of Kin / Associated Parties Job Code/Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Next of Kin / Associated Parties Job Code/Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.1"
                 priority="17510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70327') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Table MOET 'HL70327' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70327') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.2"
                 priority="17509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70328') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Table MOET 'HL70328' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70328') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3"
                 priority="17508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Description Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Description Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Description Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape"
                 priority="17507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape"
                 priority="17506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="17505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12"
                 priority="17504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('201') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('201') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Next of Kin / Associated Parties Employee Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Next of Kin / Associated Parties Employee Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Next of Kin / Associated Parties Employee Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.1"
                 priority="17502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.2"
                 priority="17501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.3"
                 priority="17500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4"
                 priority="17498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.5"
                 priority="17492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6"
                 priority="17490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.7"
                 priority="17484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.8"
                 priority="17483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9"
                 priority="17482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10"
                 priority="17469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13"
                 priority="17456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('202') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('202') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name - NK1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Organization Name - NK1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name - NK1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.1"
                 priority="17454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.2"
                 priority="17453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.3"
                 priority="17452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.4"
                 priority="17451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.5"
                 priority="17450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6"
                 priority="17448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/hl7v2:HD.1"
                 priority="17446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/hl7v2:HD.2"
                 priority="17445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/hl7v2:HD.3"
                 priority="17444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.7"
                 priority="17442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8"
                 priority="17440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/hl7v2:HD.1"
                 priority="17438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/hl7v2:HD.2"
                 priority="17437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/hl7v2:HD.3"
                 priority="17436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.9"
                 priority="17434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.10"
                 priority="17432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14"
                 priority="17431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '119' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Marital Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.1"
                 priority="17429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.2"
                 priority="17428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.3"
                 priority="17427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.4"
                 priority="17425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.5"
                 priority="17424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/hl7v2:CE.6"
                 priority="17423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.15"
                 priority="17421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '111' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Administrative Sex' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16"
                 priority="17420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '110' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Date/Time of Birth' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16/hl7v2:TS.1"
                 priority="17418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16/hl7v2:TS.2"
                 priority="17417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.17"
                 priority="17415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '755' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Living Dependency' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.18"
                 priority="17414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '145' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70009' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Ambulatory Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19"
                 priority="17413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.1"
                 priority="17411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.2"
                 priority="17410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.3"
                 priority="17409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.4"
                 priority="17407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.5"
                 priority="17406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/hl7v2:CE.6"
                 priority="17405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20"
                 priority="17403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.1"
                 priority="17401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.2"
                 priority="17400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.3"
                 priority="17399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.4"
                 priority="17397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.5"
                 priority="17396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/hl7v2:CE.6"
                 priority="17395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.21"
                 priority="17393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '742' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Living Arrangement' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22"
                 priority="17392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '743' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.1"
                 priority="17390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.2"
                 priority="17389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.3"
                 priority="17388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.4"
                 priority="17386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.5"
                 priority="17385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/hl7v2:CE.6"
                 priority="17384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.23"
                 priority="17382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '744' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.24"
                 priority="17380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '745' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Student Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25"
                 priority="17379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.1"
                 priority="17377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.2"
                 priority="17376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.3"
                 priority="17375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.4"
                 priority="17373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.5"
                 priority="17372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/hl7v2:CE.6"
                 priority="17371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26"
                 priority="17369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1"
                 priority="17367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="17365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="17364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="17363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="17362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="17361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.2"
                 priority="17360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.3"
                 priority="17359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.4"
                 priority="17358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.5"
                 priority="17357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.6"
                 priority="17356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.7"
                 priority="17355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.8"
                 priority="17353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9"
                 priority="17351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="17349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="17348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="17347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="17345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="17344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="17343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10"
                 priority="17341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="17339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="17334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.11"
                 priority="17329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12"
                 priority="17327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="17325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="17324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13"
                 priority="17322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="17320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="17319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.14"
                 priority="17317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27"
                 priority="17316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.1"
                 priority="17314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.2"
                 priority="17313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.3"
                 priority="17312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.4"
                 priority="17310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.5"
                 priority="17309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/hl7v2:CE.6"
                 priority="17308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28"
                 priority="17306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.1"
                 priority="17304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.2"
                 priority="17303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.3"
                 priority="17302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.4"
                 priority="17300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.5"
                 priority="17299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/hl7v2:CE.6"
                 priority="17298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29"
                 priority="17296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('747') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '747' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('747') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70222' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Contact Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.1"
                 priority="17294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.2"
                 priority="17293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.3"
                 priority="17292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.4"
                 priority="17290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.5"
                 priority="17289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/hl7v2:CE.6"
                 priority="17288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30"
                 priority="17286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('748') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '748' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('748') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Person''s Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Contact Person''s Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Person''s Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1"
                 priority="17284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="17282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="17281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="17280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="17279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="17278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.2"
                 priority="17277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.3"
                 priority="17276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.4"
                 priority="17275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.5"
                 priority="17274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.6"
                 priority="17273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.7"
                 priority="17272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.8"
                 priority="17270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9"
                 priority="17268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="17266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="17265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="17264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="17262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="17261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="17260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10"
                 priority="17258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="17256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="17251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.11"
                 priority="17246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12"
                 priority="17244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="17242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="17241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13"
                 priority="17239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="17237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="17236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.14"
                 priority="17234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31"
                 priority="17233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('749') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '749' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('749') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Person''s Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Contact Person''s Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Person''s Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.1"
                 priority="17231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.2"
                 priority="17230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.3"
                 priority="17228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.4"
                 priority="17226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.5"
                 priority="17225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.6"
                 priority="17224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.7"
                 priority="17223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.8"
                 priority="17222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.9"
                 priority="17221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.10"
                 priority="17220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.11"
                 priority="17219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/hl7v2:XTN.12"
                 priority="17218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32"
                 priority="17217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('750') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '750' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('750') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Person''s Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Contact Person''s Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Person''s Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1"
                 priority="17215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="17213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="17212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="17211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.2"
                 priority="17210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.3"
                 priority="17209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.4"
                 priority="17208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.5"
                 priority="17207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.6"
                 priority="17206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.7"
                 priority="17204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.8"
                 priority="17202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.9"
                 priority="17201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.10"
                 priority="17200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.11"
                 priority="17199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12"
                 priority="17197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="17195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="17193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="17192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="17190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="17188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="17187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13"
                 priority="17185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="17183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="17182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14"
                 priority="17180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="17178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="17177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33"
                 priority="17175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('751') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '751' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('751') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Next of Kin/Associated Party''s Identifiers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Next of Kin/Associated Party''s Identifiers' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Next of Kin/Associated Party''s Identifiers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.1"
                 priority="17173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.2"
                 priority="17172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.3"
                 priority="17171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4"
                 priority="17169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.5"
                 priority="17163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6"
                 priority="17161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.7"
                 priority="17155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.8"
                 priority="17154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9"
                 priority="17153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10"
                 priority="17140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.34"
                 priority="17127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('752') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '752' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('752') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70311') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70311' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70311') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Job Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35"
                 priority="17126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Race' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.1"
                 priority="17124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.2"
                 priority="17123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.3"
                 priority="17122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.4"
                 priority="17120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.5"
                 priority="17119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/hl7v2:CE.6"
                 priority="17118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.36"
                 priority="17116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '753' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70295' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Handicap' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.37"
                 priority="17115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('754') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '754' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('754') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Person Social Security Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Contact Person Social Security Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Person Social Security Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.38"
                 priority="17114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1905') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '1905' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1905') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Next of Kin Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'Next of Kin Birth Place' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Next of Kin Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.39"
                 priority="17113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Item MOET '146' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van Table MOET 'HL70099' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NK1_segment): de waarde van LongName MOET 'VIP Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3705-false-d41240e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT"
                 priority="17112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 is required [min 1x]. (count(hl7v2:PV1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 komt te vaak voor [max 1x]. (count(hl7v2:PV1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV2 komt te vaak voor [max 1x]. (count(hl7v2:PV2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1"
                 priority="17111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.1 komt te vaak voor [max 1x]. (count(hl7v2:PV1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.2 is required [min 1x]. (count(hl7v2:PV1.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.2 komt te vaak voor [max 1x]. (count(hl7v2:PV1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.3 is required [min 1x]. (count(hl7v2:PV1.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.3 komt te vaak voor [max 1x]. (count(hl7v2:PV1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.4 komt te vaak voor [max 1x]. (count(hl7v2:PV1.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.5 komt te vaak voor [max 1x]. (count(hl7v2:PV1.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.6 komt te vaak voor [max 1x]. (count(hl7v2:PV1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.10 is required [min 1x]. (count(hl7v2:PV1.10) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.10 komt te vaak voor [max 1x]. (count(hl7v2:PV1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.11 komt te vaak voor [max 1x]. (count(hl7v2:PV1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.12 komt te vaak voor [max 1x]. (count(hl7v2:PV1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.13 komt te vaak voor [max 1x]. (count(hl7v2:PV1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.14 komt te vaak voor [max 1x]. (count(hl7v2:PV1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.16 komt te vaak voor [max 1x]. (count(hl7v2:PV1.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.18 komt te vaak voor [max 1x]. (count(hl7v2:PV1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.19 komt te vaak voor [max 1x]. (count(hl7v2:PV1.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.21 komt te vaak voor [max 1x]. (count(hl7v2:PV1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.22 komt te vaak voor [max 1x]. (count(hl7v2:PV1.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.23 komt te vaak voor [max 1x]. (count(hl7v2:PV1.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.28 komt te vaak voor [max 1x]. (count(hl7v2:PV1.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.29 komt te vaak voor [max 1x]. (count(hl7v2:PV1.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.30 komt te vaak voor [max 1x]. (count(hl7v2:PV1.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.31 komt te vaak voor [max 1x]. (count(hl7v2:PV1.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.32 komt te vaak voor [max 1x]. (count(hl7v2:PV1.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.33 komt te vaak voor [max 1x]. (count(hl7v2:PV1.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.34 komt te vaak voor [max 1x]. (count(hl7v2:PV1.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.35 komt te vaak voor [max 1x]. (count(hl7v2:PV1.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.36 komt te vaak voor [max 1x]. (count(hl7v2:PV1.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.37 komt te vaak voor [max 1x]. (count(hl7v2:PV1.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.38 komt te vaak voor [max 1x]. (count(hl7v2:PV1.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.39 is required [min 1x]. (count(hl7v2:PV1.39) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.39 komt te vaak voor [max 1x]. (count(hl7v2:PV1.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.40 komt te vaak voor [max 1x]. (count(hl7v2:PV1.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.41 komt te vaak voor [max 1x]. (count(hl7v2:PV1.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.42 komt te vaak voor [max 1x]. (count(hl7v2:PV1.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.43 komt te vaak voor [max 1x]. (count(hl7v2:PV1.43) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.44 komt te vaak voor [max 1x]. (count(hl7v2:PV1.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.46 komt te vaak voor [max 1x]. (count(hl7v2:PV1.46) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.47 komt te vaak voor [max 1x]. (count(hl7v2:PV1.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.48 komt te vaak voor [max 1x]. (count(hl7v2:PV1.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.49 komt te vaak voor [max 1x]. (count(hl7v2:PV1.49) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.50 komt te vaak voor [max 1x]. (count(hl7v2:PV1.50) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): element hl7v2:PV1.51 komt te vaak voor [max 1x]. (count(hl7v2:PV1.51) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.1"
                 priority="17110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('131') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '131' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('131') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Set ID - PV1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - PV1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.2"
                 priority="17109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('132') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '132' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('132') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70004' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70004') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3"
                 priority="17108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--REPORT warning-->
      <xsl:if test="count(hl7v2:PL.6) &lt; 1">
         <xsl:message>(PL_datatype_NL): element hl7v2:PL.6 is gecodeerd met bindingssterkte 'extensible' en bevat een code buiten de gespecificeerde set. (count(hl7v2:PL.6) &lt; 1 / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
      </xsl:if>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '133' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Assigned Patient Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="17106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="17105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="17104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="17103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="17101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="17100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="17099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="17097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="17096"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.410-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.410 Person location type NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.410-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="17094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="17093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="17092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="17091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="17089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="17088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="17087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="17086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="17084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype_NL): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.42-2017-05-13T200604.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="17082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="17081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="17080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.4"
                 priority="17078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('134') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '134' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('134') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70007' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70007') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Admission Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admission Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5"
                 priority="17077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('135') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '135' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('135') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Preadmit Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Preadmit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="17075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="17074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="17073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="17071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="17069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="17068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="17067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="17065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="17063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="17061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="17060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="17059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="17057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="17056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="17055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="17053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="17052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="17051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="17049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="17048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="17047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="17045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="17044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="17043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="17042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="17040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="17039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="17038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="17036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="17035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="17034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="17032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="17031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="17030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6"
                 priority="17029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('136') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('136') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Prior Patient Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="17027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="17026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="17025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="17024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="17022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="17021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="17020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="17018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="17017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="17016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="17015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="17014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="17013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="17011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="17010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="17009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="17008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="17006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="17004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="17003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="17002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7"
                 priority="17000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('137') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '137' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('137') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Attending Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Attending Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="16998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="16997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="16990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="16989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="16988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="16987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="16986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="16985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="16984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="16978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="16976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="16975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="16973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="16971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="16965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="16963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="16953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="16941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="16939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="16934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="16929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="16928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="16915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8"
                 priority="16902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('138') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '138' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('138') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Referring Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Referring Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="16900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="16899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="16892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="16891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="16890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="16889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="16888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="16887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="16886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="16880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="16878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="16877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="16875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="16873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="16867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="16865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="16855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="16843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="16841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="16836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="16831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="16830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="16817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9"
                 priority="16804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('139') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '139' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('139') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Consulting Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Consulting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="16802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="16801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="16794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="16793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="16792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="16791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="16790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="16789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="16788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="16782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="16780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="16779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="16777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="16775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="16769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="16767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="16757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="16745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="16743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="16738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="16733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="16732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="16719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.10"
                 priority="16706"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.1.11.2 RoleCodeNL - zorgverlenertype (personen) (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.1.11.2-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('140') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '140' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('140') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70069' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70069') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Hospital Service' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Hospital Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11"
                 priority="16704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('141') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '141' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('141') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Temporary Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="16702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="16701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="16700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="16699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="16693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="16692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="16691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="16690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="16689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="16688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="16681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.12"
                 priority="16675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('142') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '142' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('142') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70087' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70087') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Preadmit Test Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Preadmit Test Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.13"
                 priority="16674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('143') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '143' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('143') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70092' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70092') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Re-admission Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Re-admission Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.14"
                 priority="16673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('144') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '144' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('144') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70023' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70023') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Admit Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admit Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.15"
                 priority="16672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '145' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70009' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Ambulatory Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.16"
                 priority="16671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '146' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70099' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'VIP Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17"
                 priority="16670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('147') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '147' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('147') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Admitting Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admitting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="16668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="16667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="16660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="16659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="16658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="16657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="16656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="16655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="16654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="16648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="16646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="16645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="16643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="16641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="16635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="16633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="16623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="16611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="16609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="16604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="16599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="16598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="16585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.18"
                 priority="16572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '148' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70018' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19"
                 priority="16571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('149') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '149' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('149') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Visit Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="16569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="16568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="16567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="16565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="16563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="16562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="16561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="16559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="16557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="16555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="16554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="16553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="16551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="16550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="16549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="16547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="16546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="16545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="16543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="16542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="16541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="16539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="16538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="16537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="16536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="16534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="16533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="16532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="16530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="16529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="16528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="16526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="16525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="16524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20"
                 priority="16523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('150') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '150' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('150') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'FC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Financial Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="16521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van LongName MOET 'Financial Class Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="16520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="16518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="16517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.21"
                 priority="16515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('151') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '151' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('151') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70032' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70032') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Charge Price Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge Price Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.22"
                 priority="16514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('152') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '152' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('152') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70045' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70045') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Courtesy Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Courtesy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.23"
                 priority="16513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('153') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '153' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('153') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70046' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70046') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Credit Rating' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Credit Rating') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.24"
                 priority="16512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('154') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '154' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('154') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70044' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70044') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Contract Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.25"
                 priority="16511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('155') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '155' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('155') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Contract Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.26"
                 priority="16510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('156') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '156' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('156') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Contract Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.27"
                 priority="16509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('157') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '157' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('157') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Contract Period' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Period') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.28"
                 priority="16508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('158') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '158' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('158') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70073' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70073') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Interest Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Interest Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.29"
                 priority="16507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('159') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '159' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('159') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70110' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70110') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Transfer to Bad Debt Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transfer to Bad Debt Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.30"
                 priority="16506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('160') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '160' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('160') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Transfer to Bad Debt Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transfer to Bad Debt Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.31"
                 priority="16505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('161') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '161' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('161') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70021' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70021') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Bad Debt Agency Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bad Debt Agency Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.32"
                 priority="16504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('162') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '162' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('162') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Bad Debt Transfer Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bad Debt Transfer Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.33"
                 priority="16503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('163') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '163' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('163') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Bad Debt Recovery Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bad Debt Recovery Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.34"
                 priority="16502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('164') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '164' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('164') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70111' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70111') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Delete Account Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Delete Account Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.35"
                 priority="16501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '165' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Delete Account Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Delete Account Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.36"
                 priority="16500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '166' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70112' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Discharge Disposition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37"
                 priority="16499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x]. (count(hl7v2:DLD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x]. (count(hl7v2:DLD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '167' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'DLD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DLD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Discharged to Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharged to Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="16497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van Table MOET 'HL70113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van LongName MOET 'Discharge Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharge Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="16496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="16494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="16493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38"
                 priority="16491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '168' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70114' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70114') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Diet Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diet Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="16489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="16488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="16487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="16485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="16484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="16483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.39"
                 priority="16481"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.412 RIVM ISIS-AR Instellingstypen (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.412-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('169') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '169' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('169') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70115' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70115') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Servicing Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Servicing Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.40"
                 priority="16479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('170') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '170' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('170') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70116' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70116') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Bed Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.41"
                 priority="16478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70117' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70117') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Account Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Account Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42"
                 priority="16477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('172') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '172' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('172') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Pending Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="16475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="16474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="16473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="16472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="16466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="16465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="16464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="16463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="16462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="16461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="16454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43"
                 priority="16448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('173') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '173' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('173') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Prior Temporary Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="16446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="16445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="16444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="16443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="16437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="16436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="16435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="16434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="16433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="16432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="16425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44"
                 priority="16419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('174') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '174' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('174') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Admit Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="16417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="16416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45"
                 priority="16414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('175') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '175' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('175') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Discharge Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="16412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="16411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.46"
                 priority="16409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('176') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '176' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('176') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Current Patient Balance' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Current Patient Balance') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.47"
                 priority="16408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('177') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '177' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('177') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Total Charges' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Charges') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.48"
                 priority="16407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('178') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '178' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('178') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Total Adjustments' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Adjustments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.49"
                 priority="16406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('179') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '179' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('179') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Total Payments' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Payments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50"
                 priority="16405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('180') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '180' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('180') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Alternate Visit ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Visit ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="16403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="16402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="16401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="16399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="16397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="16396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="16395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="16393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="16391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="16389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="16388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="16387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="16385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="16384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="16383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="16381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="16380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="16379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="16377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="16376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="16375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="16373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="16372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="16371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="16370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="16368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="16367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="16366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="16364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="16363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="16362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="16360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="16359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="16358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.51"
                 priority="16357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '1226' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70326' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70326') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Visit Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52"
                 priority="16356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1274') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Item MOET '1274' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1274') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment_Lab_algemeen): de waarde van LongName MOET 'Other Healthcare Provider' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Healthcare Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.47-2017-05-13T193935.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="16354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="16353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="16346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="16345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="16344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="16343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="16342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="16341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="16340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="16334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="16332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="16331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="16329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="16327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="16321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="16319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="16309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="16297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="16295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="16290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="16285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="16284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="16271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2"
                 priority="16258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x]. (count(hl7v2:PV2.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x]. (count(hl7v2:PV2.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x]. (count(hl7v2:PV2.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x]. (count(hl7v2:PV2.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x]. (count(hl7v2:PV2.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x]. (count(hl7v2:PV2.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x]. (count(hl7v2:PV2.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x]. (count(hl7v2:PV2.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x]. (count(hl7v2:PV2.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x]. (count(hl7v2:PV2.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x]. (count(hl7v2:PV2.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x]. (count(hl7v2:PV2.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x]. (count(hl7v2:PV2.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x]. (count(hl7v2:PV2.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x]. (count(hl7v2:PV2.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x]. (count(hl7v2:PV2.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x]. (count(hl7v2:PV2.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x]. (count(hl7v2:PV2.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x]. (count(hl7v2:PV2.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x]. (count(hl7v2:PV2.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x]. (count(hl7v2:PV2.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x]. (count(hl7v2:PV2.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x]. (count(hl7v2:PV2.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x]. (count(hl7v2:PV2.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x]. (count(hl7v2:PV2.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x]. (count(hl7v2:PV2.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x]. (count(hl7v2:PV2.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x]. (count(hl7v2:PV2.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x]. (count(hl7v2:PV2.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x]. (count(hl7v2:PV2.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x]. (count(hl7v2:PV2.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x]. (count(hl7v2:PV2.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x]. (count(hl7v2:PV2.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x]. (count(hl7v2:PV2.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x]. (count(hl7v2:PV2.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x]. (count(hl7v2:PV2.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x]. (count(hl7v2:PV2.43) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x]. (count(hl7v2:PV2.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x]. (count(hl7v2:PV2.46) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x]. (count(hl7v2:PV2.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x]. (count(hl7v2:PV2.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1"
                 priority="16257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('181') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '181' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('181') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Prior Pending Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="16255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="16254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="16253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="16252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="16250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="16249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="16248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="16246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="16245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="16244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="16243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="16242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="16241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="16239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="16238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="16237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="16236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="16234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="16232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="16231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="16230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2"
                 priority="16228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('182') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '182' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('182') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70129') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Accommodation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Accommodation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="16226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="16225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="16224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="16222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="16221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="16220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3"
                 priority="16218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('183') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '183' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('183') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Admit Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admit Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="16216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="16215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="16214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="16212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="16211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="16210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4"
                 priority="16208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('184') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '184' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('184') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Transfer Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transfer Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="16206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="16205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="16204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="16202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="16201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="16200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.5"
                 priority="16198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('185') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '185' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('185') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Valuables' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Valuables') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.6"
                 priority="16197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('186') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '186' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('186') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Valuables Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Valuables Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.7"
                 priority="16196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('187') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '187' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('187') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70130' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70130') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit User Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit User Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8"
                 priority="16195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('188') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '188' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('188') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Admit Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="16193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="16192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9"
                 priority="16190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('189') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('189') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Discharge Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="16188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="16187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.10"
                 priority="16185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('711') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '711' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('711') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Estimated Length of Inpatient Stay' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Estimated Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.11"
                 priority="16184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('712') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '712' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('712') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Actual Length of Inpatient Stay' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Actual Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.12"
                 priority="16183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('713') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '713' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('713') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13"
                 priority="16182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('714') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '714' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('714') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Referral Source Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Referral Source Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="16180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="16179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="16177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="16176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="16175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="16174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="16173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="16172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="16171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="16170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="16169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="16168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="16167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="16166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="16164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="16163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="16162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="16160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="16158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="16157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="16155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="16153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="16151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="16150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="16149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="16147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="16145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="16143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="16142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="16141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="16139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="16138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="16137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="16135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="16133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="16131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="16130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="16128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="16126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="16125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="16123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="16121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="16119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="16118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="16116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="16114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="16113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="16111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="16110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="16108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="16107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="16106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="16104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="16103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="16102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="16100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="16099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="16098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="16097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="16095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="16094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="16093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="16091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="16090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="16089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="16087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="16086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="16085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.14"
                 priority="16084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('715') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '715' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('715') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Previous Service Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Previous Service Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.15"
                 priority="16083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('716') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '716' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('716') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Employment Illness Related Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employment Illness Related Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.16"
                 priority="16081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('717') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '717' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('717') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70213' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70213') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Purge Status Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Purge Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.17"
                 priority="16080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('718') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '718' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('718') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Purge Status Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Purge Status Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.18"
                 priority="16079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('719') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '719' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('719') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70214' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70214') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Special Program Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Program Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.19"
                 priority="16078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('720') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '720' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('720') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Retention Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Retention Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.20"
                 priority="16076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('721') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '721' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('721') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Number of Insurance Plans' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Number of Insurance Plans') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.21"
                 priority="16075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('722') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '722' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('722') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.22"
                 priority="16074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('723') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '723' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('723') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23"
                 priority="16072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('724') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '724' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('724') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Clinic Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Clinic Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="16070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="16069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="16068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="16067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="16066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="16064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="16062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="16061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="16060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="16058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="16056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="16054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="16053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="16052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="16050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="16048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.24"
                 priority="16047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('725') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '725' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('725') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70216' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70216') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Status Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.25"
                 priority="16046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('726') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '726' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('726') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70217') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Priority Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Priority Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.26"
                 priority="16045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('727') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '727' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('727') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Previous Treatment Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Previous Treatment Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.27"
                 priority="16044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('728') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '728' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('728') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70112' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Discharge Disposition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.28"
                 priority="16043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('729') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '729' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('729') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Signature on File Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Signature on File Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.29"
                 priority="16042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('730') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '730' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('730') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'First Similar Illness Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('First Similar Illness Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30"
                 priority="16041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('731') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '731' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('731') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70218' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Charge Adjustment Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="16039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="16038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="16037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="16035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="16034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="16033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.31"
                 priority="16031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('732') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '732' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('732') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70219' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70219') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Recurring Service Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Recurring Service Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.32"
                 priority="16030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('733') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '733' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('733') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Billing Media Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Billing Media Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33"
                 priority="16028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('734') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '734' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('734') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Surgery Date and Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Surgery Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="16026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="16025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.34"
                 priority="16023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('735') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '735' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('735') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Military Partnership Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Partnership Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.35"
                 priority="16021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('736') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '736' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('736') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Military Non-Availability Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Non-Availability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.36"
                 priority="16019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('737') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '737' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('737') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Newborn Baby Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Newborn Baby Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.37"
                 priority="16017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('738') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '738' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('738') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Baby Detained Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Baby Detained Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38"
                 priority="16015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1543') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1543' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1543') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70430' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70430') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Mode of Arrival Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mode of Arrival Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="16013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="16012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="16011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="16009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="16008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="16007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39"
                 priority="16005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1544') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1544' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1544') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70431' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70431') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Recreational Drug Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Recreational Drug Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="16003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="16002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="16001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="15999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="15998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="15997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40"
                 priority="15995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1545') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1545' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1545') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70432' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70432') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Admission Level of Care Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admission Level of Care Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="15993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="15992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="15991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="15989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="15988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="15987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41"
                 priority="15985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1546') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1546' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1546') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70433' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70433') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Precaution Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Precaution Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="15983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="15982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="15981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="15979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="15978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="15977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42"
                 priority="15975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1547') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1547' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1547') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70434' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70434') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Condition Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="15973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="15972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="15971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="15969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="15968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="15967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.43"
                 priority="15965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '759' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70315' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Living Will Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.44"
                 priority="15964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '760' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Organ Donor Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45"
                 priority="15963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1548') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1548' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1548') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70435' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Advance Directive Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="15961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="15960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="15959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="15957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="15956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="15955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.46"
                 priority="15953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1549') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1549' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1549') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Status Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47"
                 priority="15952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1550') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1550' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1550') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected LOA Return Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected LOA Return Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="15950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="15949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48"
                 priority="15947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1841') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1841' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1841') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Pre-admission Testing Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Pre-admission Testing Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="15945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="15944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.49"
                 priority="15942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1842') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1842' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1842') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70534' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70534') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Notify Clergy Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Notify Clergy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3713-false-d67790e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE"
                 priority="15941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN1 is required [min 1x]. (count(hl7v2:IN1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN1 komt te vaak voor [max 1x]. (count(hl7v2:IN1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN2 komt te vaak voor [max 1x]. (count(hl7v2:IN2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:IN3 komt te vaak voor [max 1x]. (count(hl7v2:IN3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1"
                 priority="15940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.1 is required [min 1x]. (count(hl7v2:IN1.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.1 komt te vaak voor [max 1x]. (count(hl7v2:IN1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.2 is required [min 1x]. (count(hl7v2:IN1.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.2 komt te vaak voor [max 1x]. (count(hl7v2:IN1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.3 is required [min 1x]. (count(hl7v2:IN1.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.8 komt te vaak voor [max 1x]. (count(hl7v2:IN1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.12 komt te vaak voor [max 1x]. (count(hl7v2:IN1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.13 komt te vaak voor [max 1x]. (count(hl7v2:IN1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.14 komt te vaak voor [max 1x]. (count(hl7v2:IN1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.15 komt te vaak voor [max 1x]. (count(hl7v2:IN1.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.17 komt te vaak voor [max 1x]. (count(hl7v2:IN1.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.18 komt te vaak voor [max 1x]. (count(hl7v2:IN1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.20 komt te vaak voor [max 1x]. (count(hl7v2:IN1.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.21 komt te vaak voor [max 1x]. (count(hl7v2:IN1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.22 komt te vaak voor [max 1x]. (count(hl7v2:IN1.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.23 komt te vaak voor [max 1x]. (count(hl7v2:IN1.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.24 komt te vaak voor [max 1x]. (count(hl7v2:IN1.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.25 komt te vaak voor [max 1x]. (count(hl7v2:IN1.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.26 komt te vaak voor [max 1x]. (count(hl7v2:IN1.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.27 komt te vaak voor [max 1x]. (count(hl7v2:IN1.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.28 komt te vaak voor [max 1x]. (count(hl7v2:IN1.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.29 komt te vaak voor [max 1x]. (count(hl7v2:IN1.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.31 komt te vaak voor [max 1x]. (count(hl7v2:IN1.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.32 komt te vaak voor [max 1x]. (count(hl7v2:IN1.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.33 komt te vaak voor [max 1x]. (count(hl7v2:IN1.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.34 komt te vaak voor [max 1x]. (count(hl7v2:IN1.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.35 komt te vaak voor [max 1x]. (count(hl7v2:IN1.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.36 komt te vaak voor [max 1x]. (count(hl7v2:IN1.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.37 komt te vaak voor [max 1x]. (count(hl7v2:IN1.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.38 komt te vaak voor [max 1x]. (count(hl7v2:IN1.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.39 komt te vaak voor [max 1x]. (count(hl7v2:IN1.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.40 komt te vaak voor [max 1x]. (count(hl7v2:IN1.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.41 komt te vaak voor [max 1x]. (count(hl7v2:IN1.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.42 komt te vaak voor [max 1x]. (count(hl7v2:IN1.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.43) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.43 komt te vaak voor [max 1x]. (count(hl7v2:IN1.43) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.45) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.45 komt te vaak voor [max 1x]. (count(hl7v2:IN1.45) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.46) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.46 komt te vaak voor [max 1x]. (count(hl7v2:IN1.46) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.47 komt te vaak voor [max 1x]. (count(hl7v2:IN1.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.48 komt te vaak voor [max 1x]. (count(hl7v2:IN1.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.50) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.50 komt te vaak voor [max 1x]. (count(hl7v2:IN1.50) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.51) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.51 komt te vaak voor [max 1x]. (count(hl7v2:IN1.51) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.52) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.52 komt te vaak voor [max 1x]. (count(hl7v2:IN1.52) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN1.53) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): element hl7v2:IN1.53 komt te vaak voor [max 1x]. (count(hl7v2:IN1.53) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.1"
                 priority="15939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('426') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '426' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('426') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - IN1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Set ID - IN1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - IN1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2"
                 priority="15938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '368' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70072') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70072' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70072') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Plan ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insurance Plan ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Plan ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.1"
                 priority="15936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.2"
                 priority="15935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.3"
                 priority="15934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.4"
                 priority="15932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.5"
                 priority="15931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/hl7v2:CE.6"
                 priority="15930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3"
                 priority="15928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('428') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '428' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('428') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Company ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insurance Company ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Company ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.1"
                 priority="15926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.2"
                 priority="15925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.3"
                 priority="15924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4"
                 priority="15922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.5"
                 priority="15916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6"
                 priority="15914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.7"
                 priority="15908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.8"
                 priority="15907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9"
                 priority="15906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10"
                 priority="15893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4"
                 priority="15880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('429') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '429' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('429') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Company Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insurance Company Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Company Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.1"
                 priority="15878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.2"
                 priority="15877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.3"
                 priority="15876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.4"
                 priority="15875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.5"
                 priority="15874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6"
                 priority="15872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/hl7v2:HD.1"
                 priority="15870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/hl7v2:HD.2"
                 priority="15869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/hl7v2:HD.3"
                 priority="15868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.7"
                 priority="15866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8"
                 priority="15864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/hl7v2:HD.1"
                 priority="15862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/hl7v2:HD.2"
                 priority="15861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/hl7v2:HD.3"
                 priority="15860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.9"
                 priority="15858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.10"
                 priority="15856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5"
                 priority="15855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('430') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '430' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('430') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Company Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insurance Company Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Company Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1"
                 priority="15853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="15851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="15850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="15849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.2"
                 priority="15848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.3"
                 priority="15847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.4"
                 priority="15846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.5"
                 priority="15845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.6"
                 priority="15844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.7"
                 priority="15842"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.8"
                 priority="15840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.9"
                 priority="15839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.10"
                 priority="15838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.11"
                 priority="15837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12"
                 priority="15835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="15833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="15828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13"
                 priority="15823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="15821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="15820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14"
                 priority="15818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="15816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="15815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6"
                 priority="15813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('431') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '431' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('431') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Co Contact Person') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insurance Co Contact Person' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Co Contact Person') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1"
                 priority="15811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.2"
                 priority="15804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.3"
                 priority="15803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.4"
                 priority="15802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.5"
                 priority="15801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.6"
                 priority="15800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.7"
                 priority="15799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.8"
                 priority="15797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9"
                 priority="15795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10"
                 priority="15785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.11"
                 priority="15773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12"
                 priority="15771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13"
                 priority="15766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.14"
                 priority="15761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7"
                 priority="15760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('432') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '432' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('432') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Co Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insurance Co Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Co Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.1"
                 priority="15758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.2"
                 priority="15757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.3"
                 priority="15755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.4"
                 priority="15753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.5"
                 priority="15752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.6"
                 priority="15751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.7"
                 priority="15750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.8"
                 priority="15749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.9"
                 priority="15748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.10"
                 priority="15747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.11"
                 priority="15746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/hl7v2:XTN.12"
                 priority="15745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.8"
                 priority="15744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('433') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '433' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('433') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Group Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9"
                 priority="15743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('434') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '434' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('434') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Group Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Group Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Group Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.1"
                 priority="15741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.2"
                 priority="15740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.3"
                 priority="15739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.4"
                 priority="15738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.5"
                 priority="15737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6"
                 priority="15735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/hl7v2:HD.1"
                 priority="15733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/hl7v2:HD.2"
                 priority="15732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/hl7v2:HD.3"
                 priority="15731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.7"
                 priority="15729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8"
                 priority="15727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/hl7v2:HD.1"
                 priority="15725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/hl7v2:HD.2"
                 priority="15724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/hl7v2:HD.3"
                 priority="15723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.9"
                 priority="15721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.10"
                 priority="15719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10"
                 priority="15718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('435') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '435' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('435') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Group Emp ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Group Emp ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Group Emp ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.1"
                 priority="15716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.2"
                 priority="15715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.3"
                 priority="15714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4"
                 priority="15712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.5"
                 priority="15706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6"
                 priority="15704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.7"
                 priority="15698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.8"
                 priority="15697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9"
                 priority="15696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10"
                 priority="15683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11"
                 priority="15670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('436') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '436' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('436') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Group Emp Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Group Emp Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Group Emp Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.1"
                 priority="15668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.2"
                 priority="15667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.3"
                 priority="15666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.4"
                 priority="15665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.5"
                 priority="15664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6"
                 priority="15662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/hl7v2:HD.1"
                 priority="15660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/hl7v2:HD.2"
                 priority="15659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/hl7v2:HD.3"
                 priority="15658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.7"
                 priority="15656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8"
                 priority="15654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/hl7v2:HD.1"
                 priority="15652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/hl7v2:HD.2"
                 priority="15651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/hl7v2:HD.3"
                 priority="15650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.9"
                 priority="15648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.10"
                 priority="15646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.12"
                 priority="15645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('437') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '437' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('437') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Plan Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Plan Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Plan Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.13"
                 priority="15644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('438') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '438' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('438') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Plan Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Plan Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Plan Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14"
                 priority="15643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AUI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): element hl7v2:AUI.1 komt te vaak voor [max 1x]. (count(hl7v2:AUI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AUI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): element hl7v2:AUI.2 komt te vaak voor [max 1x]. (count(hl7v2:AUI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AUI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): element hl7v2:AUI.3 komt te vaak voor [max 1x]. (count(hl7v2:AUI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('439') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '439' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('439') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('AUI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'AUI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('AUI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Authorization Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Authorization Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Authorization Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/hl7v2:AUI.1"
                 priority="15641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Authorization Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van LongName MOET 'Authorization Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Authorization Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/hl7v2:AUI.2"
                 priority="15640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van LongName MOET 'Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/hl7v2:AUI.3"
                 priority="15639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AUI_datatype): de waarde van LongName MOET 'Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.2-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.15"
                 priority="15638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('440') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '440' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('440') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70086') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70086' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70086') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Plan Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Plan Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Plan Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16"
                 priority="15637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('441') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '441' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('441') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Of Insured') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Name Of Insured' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Of Insured') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1"
                 priority="15635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.2"
                 priority="15628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.3"
                 priority="15627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.4"
                 priority="15626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.5"
                 priority="15625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.6"
                 priority="15624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.7"
                 priority="15623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.8"
                 priority="15621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9"
                 priority="15619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10"
                 priority="15609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.11"
                 priority="15597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12"
                 priority="15595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13"
                 priority="15590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.14"
                 priority="15585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17"
                 priority="15584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('442') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '442' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('442') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70063' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Relationship To Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Relationship To Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Relationship To Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.1"
                 priority="15582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.2"
                 priority="15581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.3"
                 priority="15580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.4"
                 priority="15578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.5"
                 priority="15577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/hl7v2:CE.6"
                 priority="15576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18"
                 priority="15574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('443') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '443' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('443') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Date Of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Date Of Birth' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Date Of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18/hl7v2:TS.1"
                 priority="15572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18/hl7v2:TS.2"
                 priority="15571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19"
                 priority="15569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('444') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('444') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1"
                 priority="15567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="15565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="15564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="15563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.2"
                 priority="15562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.3"
                 priority="15561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.4"
                 priority="15560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.5"
                 priority="15559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.6"
                 priority="15558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.7"
                 priority="15556"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.8"
                 priority="15554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.9"
                 priority="15553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.10"
                 priority="15552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.11"
                 priority="15551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12"
                 priority="15549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="15547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="15542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13"
                 priority="15537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="15535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="15534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14"
                 priority="15532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="15530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="15529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.20"
                 priority="15527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('445') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '445' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('445') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70135') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70135' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70135') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assignment Of Benefits') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Assignment Of Benefits' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assignment Of Benefits') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.21"
                 priority="15526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('446') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '446' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('446') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70173') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70173' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70173') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coordination Of Benefits') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Coordination Of Benefits' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coordination Of Benefits') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.22"
                 priority="15525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('447') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '447' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('447') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coord Of Ben. Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Coord Of Ben. Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coord Of Ben. Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.23"
                 priority="15524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('448') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('448') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Notice Of Admission Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Notice Of Admission Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Notice Of Admission Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.24"
                 priority="15522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('449') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '449' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('449') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Notice Of Admission Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Notice Of Admission Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Notice Of Admission Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.25"
                 priority="15521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('450') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '450' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('450') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Report Of Eligibility Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Report Of Eligibility Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Report Of Eligibility Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.26"
                 priority="15519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('451') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '451' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('451') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Report Of Eligibility Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Report Of Eligibility Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Report Of Eligibility Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.27"
                 priority="15518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('452') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '452' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('452') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70093') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70093' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70093') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Release Information Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Release Information Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Release Information Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.28"
                 priority="15517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('453') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '453' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('453') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pre-Admit Cert (PAC)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Pre-Admit Cert (PAC)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Pre-Admit Cert (PAC)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29"
                 priority="15516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('454') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '454' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('454') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verification Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Verification Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Verification Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29/hl7v2:TS.1"
                 priority="15514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29/hl7v2:TS.2"
                 priority="15513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30"
                 priority="15511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('455') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '455' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('455') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verification By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Verification By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Verification By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.1"
                 priority="15509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2"
                 priority="15508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="15506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="15505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="15504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="15503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="15502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.3"
                 priority="15501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.4"
                 priority="15500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.5"
                 priority="15499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.6"
                 priority="15498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.7"
                 priority="15497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.8"
                 priority="15496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9"
                 priority="15495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="15493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="15492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="15491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.10"
                 priority="15489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.11"
                 priority="15487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.12"
                 priority="15486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.13"
                 priority="15484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14"
                 priority="15482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="15480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="15479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="15478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.15"
                 priority="15476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16"
                 priority="15474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="15472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="15471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="15470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="15468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="15467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="15466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17"
                 priority="15464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="15462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="15457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.18"
                 priority="15452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19"
                 priority="15450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="15448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="15447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20"
                 priority="15445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="15443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="15442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.21"
                 priority="15440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22"
                 priority="15439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="15437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="15436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="15435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="15433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="15432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="15431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="15429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="15428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="15427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23"
                 priority="15426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="15424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="15423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="15422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="15420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="15419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="15418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="15416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="15415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="15414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.31"
                 priority="15413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('456') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '456' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('456') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70098') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70098' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70098') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Type Of Agreement Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Type Of Agreement Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Type Of Agreement Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.32"
                 priority="15412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('457') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '457' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('457') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70022') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70022' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70022') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Billing Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Billing Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Billing Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.33"
                 priority="15411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('458') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '458' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('458') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lifetime Reserve Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Lifetime Reserve Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Lifetime Reserve Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.34"
                 priority="15410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('459') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '459' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('459') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delay Before L.R. Day') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Delay Before L.R. Day' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Delay Before L.R. Day') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.35"
                 priority="15409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('460') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '460' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('460') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70042') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70042' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70042') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Company Plan Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Company Plan Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Company Plan Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.36"
                 priority="15408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('461') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '461' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('461') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Policy Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37"
                 priority="15407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('462') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '462' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('462') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Deductible') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Policy Deductible' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Deductible') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1"
                 priority="15405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.2"
                 priority="15400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.3"
                 priority="15398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.4"
                 priority="15397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5"
                 priority="15396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.6"
                 priority="15386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38"
                 priority="15384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('463') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '463' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('463') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Limit - Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Policy Limit - Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Limit - Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1"
                 priority="15382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.2"
                 priority="15377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.3"
                 priority="15375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.4"
                 priority="15374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5"
                 priority="15373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.6"
                 priority="15363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.39"
                 priority="15361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('464') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '464' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('464') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Limit - Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Policy Limit - Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Limit - Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40"
                 priority="15360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('465') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('465') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room Rate - Semi-Private') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Room Rate - Semi-Private' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room Rate - Semi-Private') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1"
                 priority="15358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.2"
                 priority="15353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.3"
                 priority="15351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.4"
                 priority="15350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5"
                 priority="15349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.6"
                 priority="15339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41"
                 priority="15337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('466') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '466' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('466') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room Rate - Private') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Room Rate - Private' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room Rate - Private') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1"
                 priority="15335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1/hl7v2:MO.1"
                 priority="15333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1/hl7v2:MO.2"
                 priority="15332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.2"
                 priority="15330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.3"
                 priority="15328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.4"
                 priority="15327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5"
                 priority="15326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.1"
                 priority="15324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.2"
                 priority="15323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.3"
                 priority="15322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.4"
                 priority="15320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.5"
                 priority="15319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/hl7v2:CE.6"
                 priority="15318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.6"
                 priority="15316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42"
                 priority="15314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('467') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '467' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('467') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70066') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70066' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70066') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Employment Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Employment Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Employment Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.1"
                 priority="15312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.2"
                 priority="15311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.3"
                 priority="15310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.4"
                 priority="15308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.5"
                 priority="15307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/hl7v2:CE.6"
                 priority="15306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.43"
                 priority="15304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('468') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '468' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('468') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Administrative Sex' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44"
                 priority="15303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('469') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '469' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('469') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Employer''s Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s Employer''s Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Employer''s Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1"
                 priority="15301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="15299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="15298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="15297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.2"
                 priority="15296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.3"
                 priority="15295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.4"
                 priority="15294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.5"
                 priority="15293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.6"
                 priority="15292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.7"
                 priority="15290"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.8"
                 priority="15288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.9"
                 priority="15287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.10"
                 priority="15286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.11"
                 priority="15285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12"
                 priority="15283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="15281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="15276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13"
                 priority="15271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="15269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="15268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14"
                 priority="15266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="15264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="15263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.45"
                 priority="15261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('470') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '470' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('470') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verification Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Verification Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Verification Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.46"
                 priority="15260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('471') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '471' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('471') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70072') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70072' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70072') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Insurance Plan ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Prior Insurance Plan ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Insurance Plan ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.47"
                 priority="15259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '1227' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70309') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70309' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70309') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coverage Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Coverage Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coverage Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.48"
                 priority="15258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '753' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70295' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Handicap' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49"
                 priority="15257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '1230' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured''s ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.1"
                 priority="15255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.2"
                 priority="15254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.3"
                 priority="15253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4"
                 priority="15251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.5"
                 priority="15245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6"
                 priority="15243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.7"
                 priority="15237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.8"
                 priority="15236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9"
                 priority="15235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10"
                 priority="15222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.50"
                 priority="15209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1854') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '1854' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1854') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70535') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70535' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70535') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Signature Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Signature Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Signature Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.51"
                 priority="15208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1855') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '1855' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1855') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Signature Code Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Signature Code Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Signature Code Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.52"
                 priority="15207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1899') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '1899' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1899') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured_s Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'Insured_s Birth Place' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured_s Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.53"
                 priority="15206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1852') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Item MOET '1852' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1852') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van Table MOET 'HL70099' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN1_segment_Lab2Lab): de waarde van LongName MOET 'VIP Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.4-2015-07-21T144808.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2"
                 priority="15205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.2 komt te vaak voor [max 1x]. (count(hl7v2:IN2.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.4 komt te vaak voor [max 1x]. (count(hl7v2:IN2.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.6 komt te vaak voor [max 1x]. (count(hl7v2:IN2.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.8 komt te vaak voor [max 1x]. (count(hl7v2:IN2.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.10 komt te vaak voor [max 1x]. (count(hl7v2:IN2.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.11 komt te vaak voor [max 1x]. (count(hl7v2:IN2.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.12 komt te vaak voor [max 1x]. (count(hl7v2:IN2.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.13 komt te vaak voor [max 1x]. (count(hl7v2:IN2.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.14 komt te vaak voor [max 1x]. (count(hl7v2:IN2.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.15 komt te vaak voor [max 1x]. (count(hl7v2:IN2.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.16 komt te vaak voor [max 1x]. (count(hl7v2:IN2.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.17 komt te vaak voor [max 1x]. (count(hl7v2:IN2.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.18 komt te vaak voor [max 1x]. (count(hl7v2:IN2.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.19 komt te vaak voor [max 1x]. (count(hl7v2:IN2.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.20 komt te vaak voor [max 1x]. (count(hl7v2:IN2.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.21 komt te vaak voor [max 1x]. (count(hl7v2:IN2.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.23 komt te vaak voor [max 1x]. (count(hl7v2:IN2.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.27 komt te vaak voor [max 1x]. (count(hl7v2:IN2.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.30 komt te vaak voor [max 1x]. (count(hl7v2:IN2.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.31 komt te vaak voor [max 1x]. (count(hl7v2:IN2.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.34 komt te vaak voor [max 1x]. (count(hl7v2:IN2.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.35 komt te vaak voor [max 1x]. (count(hl7v2:IN2.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.36 komt te vaak voor [max 1x]. (count(hl7v2:IN2.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.37 komt te vaak voor [max 1x]. (count(hl7v2:IN2.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.38 komt te vaak voor [max 1x]. (count(hl7v2:IN2.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.39 komt te vaak voor [max 1x]. (count(hl7v2:IN2.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.41 komt te vaak voor [max 1x]. (count(hl7v2:IN2.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.44 komt te vaak voor [max 1x]. (count(hl7v2:IN2.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.45) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.45 komt te vaak voor [max 1x]. (count(hl7v2:IN2.45) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.46) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.46 komt te vaak voor [max 1x]. (count(hl7v2:IN2.46) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.47 komt te vaak voor [max 1x]. (count(hl7v2:IN2.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.48 komt te vaak voor [max 1x]. (count(hl7v2:IN2.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.51) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.51 komt te vaak voor [max 1x]. (count(hl7v2:IN2.51) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.55) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.55 komt te vaak voor [max 1x]. (count(hl7v2:IN2.55) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.57) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.57 komt te vaak voor [max 1x]. (count(hl7v2:IN2.57) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.58) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.58 komt te vaak voor [max 1x]. (count(hl7v2:IN2.58) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.59) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.59 komt te vaak voor [max 1x]. (count(hl7v2:IN2.59) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.60) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.60 komt te vaak voor [max 1x]. (count(hl7v2:IN2.60) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.61) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.61 komt te vaak voor [max 1x]. (count(hl7v2:IN2.61) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.62) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.62 komt te vaak voor [max 1x]. (count(hl7v2:IN2.62) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.65) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.65 komt te vaak voor [max 1x]. (count(hl7v2:IN2.65) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.66) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.66 komt te vaak voor [max 1x]. (count(hl7v2:IN2.66) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.67) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.67 komt te vaak voor [max 1x]. (count(hl7v2:IN2.67) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.68) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.68 komt te vaak voor [max 1x]. (count(hl7v2:IN2.68) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN2.72) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): element hl7v2:IN2.72 komt te vaak voor [max 1x]. (count(hl7v2:IN2.72) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1"
                 priority="15204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('472') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '472' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('472') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Employee ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Employee ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Employee ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.1"
                 priority="15202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.2"
                 priority="15201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.3"
                 priority="15200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4"
                 priority="15198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/hl7v2:HD.1"
                 priority="15196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/hl7v2:HD.2"
                 priority="15195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/hl7v2:HD.3"
                 priority="15194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.5"
                 priority="15192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6"
                 priority="15190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/hl7v2:HD.1"
                 priority="15188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/hl7v2:HD.2"
                 priority="15187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/hl7v2:HD.3"
                 priority="15186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.7"
                 priority="15184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.8"
                 priority="15183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9"
                 priority="15182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="15180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="15179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="15178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="15176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="15175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="15174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="15172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="15171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="15170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10"
                 priority="15169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="15167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="15166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="15165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="15163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="15162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="15161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="15159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="15158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="15157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.2"
                 priority="15156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '473' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Social Security Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Social Security Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Social Security Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3"
                 priority="15155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '474' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Employer''s Name and ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Employer''s Name and ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Employer''s Name and ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.1"
                 priority="15153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2"
                 priority="15152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="15150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="15149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="15148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="15147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="15146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.3"
                 priority="15145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.4"
                 priority="15144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.5"
                 priority="15143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.6"
                 priority="15142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.7"
                 priority="15141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.8"
                 priority="15140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9"
                 priority="15139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="15137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="15136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="15135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.10"
                 priority="15133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.11"
                 priority="15131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.12"
                 priority="15130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.13"
                 priority="15128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14"
                 priority="15126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="15124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="15123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="15122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.15"
                 priority="15120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16"
                 priority="15118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="15116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="15115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="15114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="15112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="15111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="15110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17"
                 priority="15108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="15106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="15101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.18"
                 priority="15096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19"
                 priority="15094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="15092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="15091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20"
                 priority="15089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="15087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="15086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.21"
                 priority="15084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22"
                 priority="15083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="15081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="15080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="15079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="15077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="15076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="15075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="15073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="15072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="15071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23"
                 priority="15070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="15068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="15067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="15066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="15064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="15063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="15062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="15060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="15059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="15058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.4"
                 priority="15057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '475' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70139') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70139' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70139') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employer Information Data') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Employer Information Data' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employer Information Data') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.5"
                 priority="15056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('476') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '476' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('476') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70137') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70137' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70137') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mail Claim Party') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Mail Claim Party' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mail Claim Party') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.6"
                 priority="15055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('477') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '477' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('477') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medicare Health Ins Card Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Medicare Health Ins Card Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Medicare Health Ins Card Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7"
                 priority="15054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('478') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '478' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('478') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medicaid Case Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Medicaid Case Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Medicaid Case Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1"
                 priority="15052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="15050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="15049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="15048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="15047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="15046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.2"
                 priority="15045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.3"
                 priority="15044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.4"
                 priority="15043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.5"
                 priority="15042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.6"
                 priority="15041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.7"
                 priority="15040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.8"
                 priority="15038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9"
                 priority="15036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="15034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="15033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="15032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="15030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="15029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="15028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10"
                 priority="15026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="15024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="15022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="15021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="15019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="15017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="15016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.11"
                 priority="15014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12"
                 priority="15012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="15010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="15009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13"
                 priority="15007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="15005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="15004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.14"
                 priority="15002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.8"
                 priority="15001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medicaid Case Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Medicaid Case Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Medicaid Case Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9"
                 priority="15000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Sponsor Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Sponsor Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Sponsor Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1"
                 priority="14998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.2"
                 priority="14991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.3"
                 priority="14990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.4"
                 priority="14989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.5"
                 priority="14988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.6"
                 priority="14987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.7"
                 priority="14986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.8"
                 priority="14984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9"
                 priority="14982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10"
                 priority="14972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.11"
                 priority="14960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12"
                 priority="14958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13"
                 priority="14953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.14"
                 priority="14948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.10"
                 priority="14947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('481') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '481' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('481') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11"
                 priority="14946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('482') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '482' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('482') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70342') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70342' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70342') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dependent Of Military Recipient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Dependent Of Military Recipient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dependent Of Military Recipient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.1"
                 priority="14944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.2"
                 priority="14943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.3"
                 priority="14942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.4"
                 priority="14940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.5"
                 priority="14939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/hl7v2:CE.6"
                 priority="14938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.12"
                 priority="14936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('483') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '483' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('483') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Organization' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.13"
                 priority="14935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('484') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '484' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('484') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Station') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Station' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Station') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.14"
                 priority="14934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('485') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '485' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('485') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70140' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Service' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.15"
                 priority="14933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '486' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70141' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Rank/Grade' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.16"
                 priority="14932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('487') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '487' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('487') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70142' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.17"
                 priority="14931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('488') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '488' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('488') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Retire Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Retire Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Retire Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.18"
                 priority="14930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('489') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '489' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('489') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Non-Avail Cert On File') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Non-Avail Cert On File' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Non-Avail Cert On File') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.19"
                 priority="14928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('490') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '490' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('490') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Baby Coverage') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Baby Coverage' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Baby Coverage') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.20"
                 priority="14926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('491') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '491' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('491') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Combine Baby Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Combine Baby Bill' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Combine Baby Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.21"
                 priority="14924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('492') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '492' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('492') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Blood Deductible') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Blood Deductible' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Blood Deductible') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22"
                 priority="14923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('493') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '493' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('493') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Coverage Approval Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Special Coverage Approval Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Coverage Approval Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1"
                 priority="14921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.2"
                 priority="14914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.3"
                 priority="14913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.4"
                 priority="14912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.5"
                 priority="14911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.6"
                 priority="14910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.7"
                 priority="14909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.8"
                 priority="14907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9"
                 priority="14905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10"
                 priority="14895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.11"
                 priority="14883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12"
                 priority="14881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13"
                 priority="14876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.14"
                 priority="14871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.23"
                 priority="14870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('494') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '494' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('494') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Coverage Approval Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Special Coverage Approval Title' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Coverage Approval Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.24"
                 priority="14869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('495') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '495' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('495') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70143') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70143' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70143') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Non-Covered Insurance Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Non-Covered Insurance Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Non-Covered Insurance Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25"
                 priority="14868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('496') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '496' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('496') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Payor ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Payor ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Payor ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.1"
                 priority="14866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.2"
                 priority="14865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.3"
                 priority="14864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4"
                 priority="14862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.5"
                 priority="14856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6"
                 priority="14854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.7"
                 priority="14848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.8"
                 priority="14847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9"
                 priority="14846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10"
                 priority="14833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26"
                 priority="14820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('497') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '497' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('497') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Payor Subscriber ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Payor Subscriber ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Payor Subscriber ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.1"
                 priority="14818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.2"
                 priority="14817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.3"
                 priority="14816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4"
                 priority="14814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.5"
                 priority="14808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6"
                 priority="14806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.7"
                 priority="14800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.8"
                 priority="14799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9"
                 priority="14798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10"
                 priority="14785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.27"
                 priority="14772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('498') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '498' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('498') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70144') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70144' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70144') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Eligibility Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Eligibility Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Eligibility Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28"
                 priority="14771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.1 komt te vaak voor [max 1x]. (count(hl7v2:RMC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.2 komt te vaak voor [max 1x]. (count(hl7v2:RMC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.3 komt te vaak voor [max 1x]. (count(hl7v2:RMC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RMC.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): element hl7v2:RMC.4 komt te vaak voor [max 1x]. (count(hl7v2:RMC.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('499') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '499' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('499') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RMC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'RMC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RMC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room Coverage Type/Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Room Coverage Type/Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room Coverage Type/Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.1"
                 priority="14769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70145') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van Table MOET 'HL70145' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70145') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van LongName MOET 'Room Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.2"
                 priority="14768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70146') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van Table MOET 'HL70146' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70146') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Amount Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van LongName MOET 'Amount Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Amount Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.3"
                 priority="14767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coverage Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van LongName MOET 'Coverage Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coverage Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4"
                 priority="14766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.1 komt te vaak voor [max 1x]. (count(hl7v2:MOP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.2 komt te vaak voor [max 1x]. (count(hl7v2:MOP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.3 komt te vaak voor [max 1x]. (count(hl7v2:MOP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van Type MOET 'MOP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MOP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RMC_datatype): de waarde van LongName MOET 'Money or Percentage' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.55-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/hl7v2:MOP.1"
                 priority="14764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70148') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Table MOET 'HL70148' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70148') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Money or Percentage Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/hl7v2:MOP.2"
                 priority="14762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Money or Percentage Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/hl7v2:MOP.3"
                 priority="14761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Currency Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Currency Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Currency Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29"
                 priority="14759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.1 komt te vaak voor [max 1x]. (count(hl7v2:PTA.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.2 komt te vaak voor [max 1x]. (count(hl7v2:PTA.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.3 komt te vaak voor [max 1x]. (count(hl7v2:PTA.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PTA.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): element hl7v2:PTA.4 komt te vaak voor [max 1x]. (count(hl7v2:PTA.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('500') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '500' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('500') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PTA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'PTA' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PTA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Type/Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Policy Type/Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Type/Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.1"
                 priority="14757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70147') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van Table MOET 'HL70147' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70147') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van LongName MOET 'Policy Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.2"
                 priority="14756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70193') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van Table MOET 'HL70193' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70193') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Amount Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van LongName MOET 'Amount Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Amount Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.3"
                 priority="14755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van LongName MOET 'Money or Percentage Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4"
                 priority="14754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.1 komt te vaak voor [max 1x]. (count(hl7v2:MOP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.2 komt te vaak voor [max 1x]. (count(hl7v2:MOP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.3 komt te vaak voor [max 1x]. (count(hl7v2:MOP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van Type MOET 'MOP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MOP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PTA_datatype): de waarde van LongName MOET 'Money or Percentage' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.49-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/hl7v2:MOP.1"
                 priority="14752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70148') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Table MOET 'HL70148' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70148') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Money or Percentage Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/hl7v2:MOP.2"
                 priority="14750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Money or Percentage Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/hl7v2:MOP.3"
                 priority="14749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Currency Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Currency Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Currency Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30"
                 priority="14747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DDI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): element hl7v2:DDI.1 komt te vaak voor [max 1x]. (count(hl7v2:DDI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DDI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): element hl7v2:DDI.2 komt te vaak voor [max 1x]. (count(hl7v2:DDI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DDI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): element hl7v2:DDI.3 komt te vaak voor [max 1x]. (count(hl7v2:DDI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('501') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '501' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('501') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DDI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'DDI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DDI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Daily Deductible') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Daily Deductible' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Daily Deductible') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.1"
                 priority="14745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delay Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van LongName MOET 'Delay Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Delay Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2"
                 priority="14744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van LongName MOET 'Monetary Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2/hl7v2:MO.1"
                 priority="14742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2/hl7v2:MO.2"
                 priority="14741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.3"
                 priority="14739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DDI_datatype): de waarde van LongName MOET 'Number of Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Number of Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.13-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.31"
                 priority="14738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '755' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Living Dependency' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.32"
                 priority="14737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '145' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70009' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Ambulatory Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33"
                 priority="14736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.1"
                 priority="14734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.2"
                 priority="14733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.3"
                 priority="14732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.4"
                 priority="14730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.5"
                 priority="14729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/hl7v2:CE.6"
                 priority="14728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34"
                 priority="14726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.1"
                 priority="14724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.2"
                 priority="14723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.3"
                 priority="14722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.4"
                 priority="14720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.5"
                 priority="14719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/hl7v2:CE.6"
                 priority="14718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.35"
                 priority="14716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '742' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Living Arrangement' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36"
                 priority="14715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '743' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.1"
                 priority="14713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.2"
                 priority="14712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.3"
                 priority="14711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.4"
                 priority="14709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.5"
                 priority="14708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/hl7v2:CE.6"
                 priority="14707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.37"
                 priority="14705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '744' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.38"
                 priority="14703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '745' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Student Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39"
                 priority="14702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.1"
                 priority="14700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.2"
                 priority="14699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.3"
                 priority="14698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.4"
                 priority="14696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.5"
                 priority="14695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/hl7v2:CE.6"
                 priority="14694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40"
                 priority="14692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1"
                 priority="14690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.2"
                 priority="14683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.3"
                 priority="14682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.4"
                 priority="14681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.5"
                 priority="14680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.6"
                 priority="14679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.7"
                 priority="14678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.8"
                 priority="14676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9"
                 priority="14674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10"
                 priority="14664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.11"
                 priority="14652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12"
                 priority="14650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13"
                 priority="14645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.14"
                 priority="14640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41"
                 priority="14639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.1"
                 priority="14637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.2"
                 priority="14636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.3"
                 priority="14635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.4"
                 priority="14633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.5"
                 priority="14632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/hl7v2:CE.6"
                 priority="14631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42"
                 priority="14629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.1"
                 priority="14627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.2"
                 priority="14626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.3"
                 priority="14625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.4"
                 priority="14623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.5"
                 priority="14622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/hl7v2:CE.6"
                 priority="14621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43"
                 priority="14619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '119' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Marital Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.1"
                 priority="14617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.2"
                 priority="14616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.3"
                 priority="14615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.4"
                 priority="14613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.5"
                 priority="14612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/hl7v2:CE.6"
                 priority="14611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.44"
                 priority="14609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('787') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '787' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('787') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Employment Start Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Employment Start Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Employment Start Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.45"
                 priority="14608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('783') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '783' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('783') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employment Stop Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Employment Stop Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employment Stop Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.46"
                 priority="14607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('785') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '785' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('785') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Job Title' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47"
                 priority="14606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.1 komt te vaak voor [max 1x]. (count(hl7v2:JCC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.2 komt te vaak voor [max 1x]. (count(hl7v2:JCC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.3 komt te vaak voor [max 1x]. (count(hl7v2:JCC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('786') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '786' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('786') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('JCC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'JCC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('JCC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Code/Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Job Code/Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Code/Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.1"
                 priority="14604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70327') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Table MOET 'HL70327' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70327') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.2"
                 priority="14603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70328') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Table MOET 'HL70328' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70328') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3"
                 priority="14602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Description Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Description Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Description Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape"
                 priority="14601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape"
                 priority="14600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="14599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.48"
                 priority="14598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('752') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '752' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('752') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70311') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70311' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70311') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Job Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49"
                 priority="14597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('789') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '789' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('789') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employer Contact Person Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Employer Contact Person Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employer Contact Person Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1"
                 priority="14595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.2"
                 priority="14588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.3"
                 priority="14587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.4"
                 priority="14586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.5"
                 priority="14585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.6"
                 priority="14584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.7"
                 priority="14583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.8"
                 priority="14581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9"
                 priority="14579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10"
                 priority="14569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.11"
                 priority="14557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12"
                 priority="14555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13"
                 priority="14550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.14"
                 priority="14545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50"
                 priority="14544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('790') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '790' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('790') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employer Contact Person Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Employer Contact Person Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employer Contact Person Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.1"
                 priority="14542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.2"
                 priority="14541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.3"
                 priority="14539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.4"
                 priority="14537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.5"
                 priority="14536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.6"
                 priority="14535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.7"
                 priority="14534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.8"
                 priority="14533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.9"
                 priority="14532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.10"
                 priority="14531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.11"
                 priority="14530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/hl7v2:XTN.12"
                 priority="14529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.51"
                 priority="14528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('791') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '791' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('791') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70222' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employer Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Employer Contact Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employer Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52"
                 priority="14527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('792') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '792' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('792') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Contact Person''s Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Contact Person''s Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Contact Person''s Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1"
                 priority="14525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="14523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="14522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="14521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="14520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="14519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.2"
                 priority="14518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.3"
                 priority="14517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.4"
                 priority="14516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.5"
                 priority="14515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.6"
                 priority="14514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.7"
                 priority="14513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.8"
                 priority="14511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9"
                 priority="14509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="14507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="14506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="14505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="14503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="14502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="14501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10"
                 priority="14499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="14497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="14492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.11"
                 priority="14487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12"
                 priority="14485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="14483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="14482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13"
                 priority="14480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="14478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="14477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.14"
                 priority="14475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53"
                 priority="14474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('793') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '793' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('793') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Contact Person Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Contact Person Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Contact Person Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.1"
                 priority="14472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.2"
                 priority="14471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.3"
                 priority="14469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.4"
                 priority="14467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.5"
                 priority="14466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.6"
                 priority="14465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.7"
                 priority="14464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.8"
                 priority="14463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.9"
                 priority="14462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.10"
                 priority="14461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.11"
                 priority="14460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/hl7v2:XTN.12"
                 priority="14459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.54"
                 priority="14458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('794') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '794' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('794') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70222' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Contact Person Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Contact Person Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Contact Person Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.55"
                 priority="14457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('795') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '795' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('795') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relationship to the Patient Start Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Relationship to the Patient Start Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relationship to the Patient Start Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.56"
                 priority="14456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('796') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '796' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('796') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relationship to the Patient Stop Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Relationship to the Patient Stop Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relationship to the Patient Stop Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.57"
                 priority="14455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('797') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '797' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('797') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70232') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70232' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70232') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Co. Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insurance Co. Contact Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Co. Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58"
                 priority="14454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('798') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '798' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('798') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Co Contact Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insurance Co Contact Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Co Contact Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.1"
                 priority="14452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.2"
                 priority="14451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.3"
                 priority="14449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.4"
                 priority="14447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.5"
                 priority="14446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.6"
                 priority="14445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.7"
                 priority="14444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.8"
                 priority="14443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.9"
                 priority="14442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.10"
                 priority="14441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.11"
                 priority="14440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/hl7v2:XTN.12"
                 priority="14439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.59"
                 priority="14438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('799') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '799' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('799') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70312') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70312' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70312') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Scope') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Policy Scope' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Scope') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.60"
                 priority="14437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('800') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '800' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('800') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70313') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70313' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70313') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Policy Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Policy Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Policy Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61"
                 priority="14436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('801') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '801' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('801') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Member Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Patient Member Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Member Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.1"
                 priority="14434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.2"
                 priority="14433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.3"
                 priority="14432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4"
                 priority="14430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.5"
                 priority="14424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6"
                 priority="14422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.7"
                 priority="14416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.8"
                 priority="14415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9"
                 priority="14414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10"
                 priority="14401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62"
                 priority="14388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('802') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '802' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('802') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70063' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor''s Relationship To Insured') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Guarantor''s Relationship To Insured' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor''s Relationship To Insured') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.1"
                 priority="14386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.2"
                 priority="14385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.3"
                 priority="14384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.4"
                 priority="14382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.5"
                 priority="14381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/hl7v2:CE.6"
                 priority="14380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63"
                 priority="14378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('803') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '803' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('803') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Phone Number - Home' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.1"
                 priority="14376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.2"
                 priority="14375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.3"
                 priority="14373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.4"
                 priority="14371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.5"
                 priority="14370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.6"
                 priority="14369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.7"
                 priority="14368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.8"
                 priority="14367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.9"
                 priority="14366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.10"
                 priority="14365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.11"
                 priority="14364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/hl7v2:XTN.12"
                 priority="14363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64"
                 priority="14362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('804') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '804' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('804') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured''s Employer Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured''s Employer Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured''s Employer Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.1"
                 priority="14360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.2"
                 priority="14359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.3"
                 priority="14357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.4"
                 priority="14355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.5"
                 priority="14354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.6"
                 priority="14353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.7"
                 priority="14352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.8"
                 priority="14351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.9"
                 priority="14350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.10"
                 priority="14349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.11"
                 priority="14348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/hl7v2:XTN.12"
                 priority="14347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65"
                 priority="14346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('805') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '805' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('805') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70343') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70343' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70343') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Handicapped Program') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Military Handicapped Program' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Handicapped Program') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.1"
                 priority="14344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.2"
                 priority="14343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.3"
                 priority="14342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.4"
                 priority="14340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.5"
                 priority="14339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/hl7v2:CE.6"
                 priority="14338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.66"
                 priority="14336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('806') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '806' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('806') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suspend Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Suspend Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suspend Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.67"
                 priority="14334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('807') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '807' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('807') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Copay Limit Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Copay Limit Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Copay Limit Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.68"
                 priority="14332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('808') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '808' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('808') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Stoploss Limit Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Stoploss Limit Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Stoploss Limit Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69"
                 priority="14330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('809') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '809' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('809') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured Organization Name and ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured Organization Name and ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured Organization Name and ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.1"
                 priority="14328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.2"
                 priority="14327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.3"
                 priority="14326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.4"
                 priority="14325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.5"
                 priority="14324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6"
                 priority="14322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/hl7v2:HD.1"
                 priority="14320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/hl7v2:HD.2"
                 priority="14319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/hl7v2:HD.3"
                 priority="14318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.7"
                 priority="14316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8"
                 priority="14314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/hl7v2:HD.1"
                 priority="14312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/hl7v2:HD.2"
                 priority="14311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/hl7v2:HD.3"
                 priority="14310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.9"
                 priority="14308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.10"
                 priority="14306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70"
                 priority="14305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('810') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '810' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('810') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insured Employer Organization Name and ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Insured Employer Organization Name and ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insured Employer Organization Name and ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.1"
                 priority="14303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.2"
                 priority="14302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.3"
                 priority="14301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.4"
                 priority="14300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.5"
                 priority="14299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6"
                 priority="14297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/hl7v2:HD.1"
                 priority="14295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/hl7v2:HD.2"
                 priority="14294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/hl7v2:HD.3"
                 priority="14293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.7"
                 priority="14291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8"
                 priority="14289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/hl7v2:HD.1"
                 priority="14287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/hl7v2:HD.2"
                 priority="14286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/hl7v2:HD.3"
                 priority="14285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.9"
                 priority="14283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.10"
                 priority="14281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71"
                 priority="14280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'Race' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.1"
                 priority="14278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.2"
                 priority="14277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.3"
                 priority="14276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.4"
                 priority="14274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.5"
                 priority="14273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/hl7v2:CE.6"
                 priority="14272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72"
                 priority="14270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('811') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Item MOET '811' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('811') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70344') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van Table MOET 'HL70344' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70344') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('CMS Patient_s Relationship to Insured') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN2_segment): de waarde van LongName MOET 'CMS Patient_s Relationship to Insured' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('CMS Patient_s Relationship to Insured') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.1"
                 priority="14268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.2"
                 priority="14267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.3"
                 priority="14266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.4"
                 priority="14264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.5"
                 priority="14263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/hl7v2:CE.6"
                 priority="14262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3"
                 priority="14260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.1 is required [min 1x]. (count(hl7v2:IN3.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.1 komt te vaak voor [max 1x]. (count(hl7v2:IN3.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.2 komt te vaak voor [max 1x]. (count(hl7v2:IN3.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.4 komt te vaak voor [max 1x]. (count(hl7v2:IN3.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.5 komt te vaak voor [max 1x]. (count(hl7v2:IN3.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.6 komt te vaak voor [max 1x]. (count(hl7v2:IN3.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.7 komt te vaak voor [max 1x]. (count(hl7v2:IN3.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.9 komt te vaak voor [max 1x]. (count(hl7v2:IN3.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.10 komt te vaak voor [max 1x]. (count(hl7v2:IN3.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.11 komt te vaak voor [max 1x]. (count(hl7v2:IN3.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.12 komt te vaak voor [max 1x]. (count(hl7v2:IN3.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.13 komt te vaak voor [max 1x]. (count(hl7v2:IN3.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.15 komt te vaak voor [max 1x]. (count(hl7v2:IN3.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.17 komt te vaak voor [max 1x]. (count(hl7v2:IN3.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.18 komt te vaak voor [max 1x]. (count(hl7v2:IN3.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.21 komt te vaak voor [max 1x]. (count(hl7v2:IN3.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.22 komt te vaak voor [max 1x]. (count(hl7v2:IN3.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:IN3.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): element hl7v2:IN3.23 komt te vaak voor [max 1x]. (count(hl7v2:IN3.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.1"
                 priority="14259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('502') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '502' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('502') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - IN3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Set ID - IN3' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - IN3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2"
                 priority="14258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('503') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '503' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('503') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.1"
                 priority="14256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.2"
                 priority="14255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.3"
                 priority="14254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4"
                 priority="14252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="14250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="14249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="14248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.5"
                 priority="14246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6"
                 priority="14244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="14242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="14241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="14240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.7"
                 priority="14238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.8"
                 priority="14237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9"
                 priority="14236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="14234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="14233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="14232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="14230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="14229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="14228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="14226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="14225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="14224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10"
                 priority="14223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="14221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="14220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="14219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="14217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="14216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="14215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="14213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="14212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="14211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3"
                 priority="14210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('504') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '504' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('504') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certified By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.1"
                 priority="14208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2"
                 priority="14207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="14205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="14204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="14203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="14202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="14201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.3"
                 priority="14200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.4"
                 priority="14199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.5"
                 priority="14198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.6"
                 priority="14197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.7"
                 priority="14196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.8"
                 priority="14195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9"
                 priority="14194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="14192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="14191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="14190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.10"
                 priority="14188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.11"
                 priority="14186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.12"
                 priority="14185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.13"
                 priority="14183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14"
                 priority="14181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="14179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="14178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="14177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.15"
                 priority="14175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16"
                 priority="14173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="14171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="14170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="14169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="14167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="14166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="14165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17"
                 priority="14163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="14161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="14156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.18"
                 priority="14151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19"
                 priority="14149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="14147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="14146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20"
                 priority="14144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="14142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="14141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.21"
                 priority="14139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22"
                 priority="14138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="14136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="14135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="14134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="14132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="14131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="14130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="14128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="14127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="14126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23"
                 priority="14125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="14123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="14122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="14121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="14119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="14118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="14117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="14115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="14114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="14113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.4"
                 priority="14112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('505') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '505' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('505') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Required' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5"
                 priority="14110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.1 komt te vaak voor [max 1x]. (count(hl7v2:MOP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.2 komt te vaak voor [max 1x]. (count(hl7v2:MOP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): element hl7v2:MOP.3 komt te vaak voor [max 1x]. (count(hl7v2:MOP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('506') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '506' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('506') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'MOP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MOP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Penalty') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Penalty' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Penalty') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/hl7v2:MOP.1"
                 priority="14108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70148') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Table MOET 'HL70148' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70148') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Money or Percentage Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/hl7v2:MOP.2"
                 priority="14106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Money or Percentage Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Money or Percentage Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Money or Percentage Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/hl7v2:MOP.3"
                 priority="14105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Currency Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOP_datatype): de waarde van LongName MOET 'Currency Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Currency Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.35-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6"
                 priority="14103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('507') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '507' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('507') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6/hl7v2:TS.1"
                 priority="14101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6/hl7v2:TS.2"
                 priority="14100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7"
                 priority="14098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('508') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '508' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('508') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Modify Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Modify Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Modify Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7/hl7v2:TS.1"
                 priority="14096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7/hl7v2:TS.2"
                 priority="14095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8"
                 priority="14093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('509') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '509' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('509') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Operator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Operator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Operator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.1"
                 priority="14091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2"
                 priority="14090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="14088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="14087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="14086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="14085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="14084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.3"
                 priority="14083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.4"
                 priority="14082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.5"
                 priority="14081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.6"
                 priority="14080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.7"
                 priority="14079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.8"
                 priority="14078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9"
                 priority="14077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="14075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="14074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="14073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.10"
                 priority="14071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.11"
                 priority="14069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.12"
                 priority="14068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.13"
                 priority="14066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14"
                 priority="14064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="14062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="14061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="14060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.15"
                 priority="14058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16"
                 priority="14056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="14054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="14053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="14052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="14050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="14049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="14048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17"
                 priority="14046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="14044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="14042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="14041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="14039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="14037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="14036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.18"
                 priority="14034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19"
                 priority="14032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="14030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="14029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20"
                 priority="14027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="14025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="14024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.21"
                 priority="14022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22"
                 priority="14021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="14019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="14018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="14017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="14015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="14014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="14013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="14011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="14010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="14009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23"
                 priority="14008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="14006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="14005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="14004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="14002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="14001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="14000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="13998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="13997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="13996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.9"
                 priority="13995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('510') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '510' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('510') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Begin Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Begin Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Begin Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.10"
                 priority="13994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('511') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '511' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('511') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification End Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification End Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification End Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11"
                 priority="13993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): element hl7v2:DTN.1 komt te vaak voor [max 1x]. (count(hl7v2:DTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): element hl7v2:DTN.2 komt te vaak voor [max 1x]. (count(hl7v2:DTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('512') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '512' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('512') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'DTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11/hl7v2:DTN.1"
                 priority="13991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70149') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van Table MOET 'HL70149' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70149') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Day Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van LongName MOET 'Day Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Day Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11/hl7v2:DTN.2"
                 priority="13990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DTN_datatype): de waarde van LongName MOET 'Number of Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Number of Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.19-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12"
                 priority="13989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('513') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '513' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('513') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70233') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70233' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70233') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Non-Concur Code/Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Non-Concur Code/Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Non-Concur Code/Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.1"
                 priority="13987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.2"
                 priority="13986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.3"
                 priority="13985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.4"
                 priority="13983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.5"
                 priority="13982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/hl7v2:CE.6"
                 priority="13981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13"
                 priority="13979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('514') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '514' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('514') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Non-Concur Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Non-Concur Effective Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Non-Concur Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13/hl7v2:TS.1"
                 priority="13977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13/hl7v2:TS.2"
                 priority="13976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14"
                 priority="13974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('515') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '515' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('515') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Physician Reviewer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Physician Reviewer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Physician Reviewer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.1"
                 priority="13972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2"
                 priority="13971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="13969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="13968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="13967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="13966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="13965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.3"
                 priority="13964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.4"
                 priority="13963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.5"
                 priority="13962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.6"
                 priority="13961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.7"
                 priority="13960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.8"
                 priority="13959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9"
                 priority="13958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="13956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="13955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="13954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.10"
                 priority="13952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.11"
                 priority="13950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.12"
                 priority="13949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.13"
                 priority="13947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14"
                 priority="13945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="13943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="13942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="13941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.15"
                 priority="13939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16"
                 priority="13937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="13935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="13934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="13933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="13931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="13930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="13929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17"
                 priority="13927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="13925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="13920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.18"
                 priority="13915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19"
                 priority="13913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="13911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="13910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20"
                 priority="13908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="13906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="13905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.21"
                 priority="13903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22"
                 priority="13902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="13900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="13899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="13898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="13896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="13895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="13894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="13892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="13891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="13890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23"
                 priority="13889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="13887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="13886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="13885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="13883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="13882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="13881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="13879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="13878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="13877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.15"
                 priority="13876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('516') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '516' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('516') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Contact') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Contact' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Contact') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16"
                 priority="13875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('517') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '517' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('517') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Contact Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Contact Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Contact Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.1"
                 priority="13873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.2"
                 priority="13872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.3"
                 priority="13870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.4"
                 priority="13868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.5"
                 priority="13867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.6"
                 priority="13866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.7"
                 priority="13865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.8"
                 priority="13864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.9"
                 priority="13863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.10"
                 priority="13862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.11"
                 priority="13861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/hl7v2:XTN.12"
                 priority="13860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17"
                 priority="13859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('518') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '518' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('518') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70345') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70345' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70345') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Appeal Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Appeal Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Appeal Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.1"
                 priority="13857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.2"
                 priority="13856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.3"
                 priority="13855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.4"
                 priority="13853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.5"
                 priority="13852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/hl7v2:CE.6"
                 priority="13851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18"
                 priority="13849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('519') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '519' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('519') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70346') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70346' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70346') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Agency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Agency' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Agency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.1"
                 priority="13847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.2"
                 priority="13846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.3"
                 priority="13845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.4"
                 priority="13843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.5"
                 priority="13842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/hl7v2:CE.6"
                 priority="13841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19"
                 priority="13839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('520') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '520' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('520') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Agency Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Certification Agency Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Agency Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.1"
                 priority="13837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.2"
                 priority="13836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.3"
                 priority="13834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.4"
                 priority="13832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.5"
                 priority="13831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.6"
                 priority="13830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.7"
                 priority="13829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.8"
                 priority="13828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.9"
                 priority="13827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.10"
                 priority="13826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.11"
                 priority="13825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/hl7v2:XTN.12"
                 priority="13824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20"
                 priority="13823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ICD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): element hl7v2:ICD.1 komt te vaak voor [max 1x]. (count(hl7v2:ICD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ICD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): element hl7v2:ICD.2 komt te vaak voor [max 1x]. (count(hl7v2:ICD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ICD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): element hl7v2:ICD.3 komt te vaak voor [max 1x]. (count(hl7v2:ICD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('521') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '521' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('521') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ICD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'ICD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ICD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pre-Certification Requirement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Pre-Certification Requirement' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Pre-Certification Requirement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.1"
                 priority="13821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70150') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van Table MOET 'HL70150' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70150') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van LongName MOET 'Certification Patient Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.2"
                 priority="13820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Certification Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van LongName MOET 'Certification Required' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Certification Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3"
                 priority="13818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time Certification Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ICD_datatype): de waarde van LongName MOET 'Date/Time Certification Required' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time Certification Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.29-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3/hl7v2:TS.1"
                 priority="13816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3/hl7v2:TS.2"
                 priority="13815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.21"
                 priority="13813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('522') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '522' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('522') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Case Manager') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Case Manager' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Case Manager') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.22"
                 priority="13812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('523') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '523' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('523') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second Opinion Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Second Opinion Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second Opinion Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.23"
                 priority="13811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('524') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '524' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('524') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70151') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70151' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70151') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second Opinion Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Second Opinion Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second Opinion Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.24"
                 priority="13810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('525') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '525' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('525') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70152') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70152' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70152') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second Opinion Documentation Received') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Second Opinion Documentation Received' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second Opinion Documentation Received') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25"
                 priority="13809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('526') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Item MOET '526' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('526') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second Opinion Physician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(IN3_segment): de waarde van LongName MOET 'Second Opinion Physician' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second Opinion Physician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.58-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.1"
                 priority="13807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2"
                 priority="13806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="13804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="13803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="13802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="13801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="13800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.3"
                 priority="13799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.4"
                 priority="13798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.5"
                 priority="13797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.6"
                 priority="13796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.7"
                 priority="13795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.8"
                 priority="13794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9"
                 priority="13793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="13791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="13790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="13789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.10"
                 priority="13787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.11"
                 priority="13785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.12"
                 priority="13784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.13"
                 priority="13782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14"
                 priority="13780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="13778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="13777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="13776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.15"
                 priority="13774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16"
                 priority="13772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="13770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="13769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="13768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="13766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="13765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="13764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17"
                 priority="13762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="13760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="13755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.18"
                 priority="13750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19"
                 priority="13748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="13746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="13745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20"
                 priority="13743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="13741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="13740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.21"
                 priority="13738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22"
                 priority="13737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="13735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="13734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="13733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="13731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="13730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="13729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="13727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="13726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="13725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23"
                 priority="13724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="13722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="13721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="13720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="13718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="13717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="13716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="13714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="13713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="13712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1"
                 priority="13711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.1 is required [min 1x]. (count(hl7v2:GT1.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.1 komt te vaak voor [max 1x]. (count(hl7v2:GT1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.3 is required [min 1x]. (count(hl7v2:GT1.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.8 komt te vaak voor [max 1x]. (count(hl7v2:GT1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.9 komt te vaak voor [max 1x]. (count(hl7v2:GT1.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.10 komt te vaak voor [max 1x]. (count(hl7v2:GT1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.11 komt te vaak voor [max 1x]. (count(hl7v2:GT1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.12 komt te vaak voor [max 1x]. (count(hl7v2:GT1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.13 komt te vaak voor [max 1x]. (count(hl7v2:GT1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.14 komt te vaak voor [max 1x]. (count(hl7v2:GT1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.15 komt te vaak voor [max 1x]. (count(hl7v2:GT1.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.20 komt te vaak voor [max 1x]. (count(hl7v2:GT1.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.22 komt te vaak voor [max 1x]. (count(hl7v2:GT1.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.23 komt te vaak voor [max 1x]. (count(hl7v2:GT1.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.24 komt te vaak voor [max 1x]. (count(hl7v2:GT1.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.25 komt te vaak voor [max 1x]. (count(hl7v2:GT1.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.26 komt te vaak voor [max 1x]. (count(hl7v2:GT1.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.27 komt te vaak voor [max 1x]. (count(hl7v2:GT1.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.28 komt te vaak voor [max 1x]. (count(hl7v2:GT1.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.30 komt te vaak voor [max 1x]. (count(hl7v2:GT1.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.31 komt te vaak voor [max 1x]. (count(hl7v2:GT1.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.32 komt te vaak voor [max 1x]. (count(hl7v2:GT1.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.33 komt te vaak voor [max 1x]. (count(hl7v2:GT1.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.36 komt te vaak voor [max 1x]. (count(hl7v2:GT1.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.37 komt te vaak voor [max 1x]. (count(hl7v2:GT1.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.38 komt te vaak voor [max 1x]. (count(hl7v2:GT1.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.39 komt te vaak voor [max 1x]. (count(hl7v2:GT1.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.40 komt te vaak voor [max 1x]. (count(hl7v2:GT1.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.41 komt te vaak voor [max 1x]. (count(hl7v2:GT1.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.43) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.43 komt te vaak voor [max 1x]. (count(hl7v2:GT1.43) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.47 komt te vaak voor [max 1x]. (count(hl7v2:GT1.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.48 komt te vaak voor [max 1x]. (count(hl7v2:GT1.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.49) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.49 komt te vaak voor [max 1x]. (count(hl7v2:GT1.49) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.50) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.50 komt te vaak voor [max 1x]. (count(hl7v2:GT1.50) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.52) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.52 komt te vaak voor [max 1x]. (count(hl7v2:GT1.52) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.53) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.53 komt te vaak voor [max 1x]. (count(hl7v2:GT1.53) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.54) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.54 komt te vaak voor [max 1x]. (count(hl7v2:GT1.54) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.56) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.56 komt te vaak voor [max 1x]. (count(hl7v2:GT1.56) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:GT1.57) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): element hl7v2:GT1.57 komt te vaak voor [max 1x]. (count(hl7v2:GT1.57) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.1"
                 priority="13710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('405') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '405' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('405') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - GT1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Set ID - GT1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - GT1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2"
                 priority="13709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('406') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '406' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('406') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.1"
                 priority="13707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.2"
                 priority="13706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.3"
                 priority="13705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4"
                 priority="13703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="13701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="13700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="13699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.5"
                 priority="13697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6"
                 priority="13695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="13693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="13692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="13691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.7"
                 priority="13689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.8"
                 priority="13688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9"
                 priority="13687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="13685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="13684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="13683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="13681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="13680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="13679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="13677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="13676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="13675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10"
                 priority="13674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="13672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="13671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="13670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="13668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="13667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="13666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="13664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="13663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="13662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3"
                 priority="13661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('407') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '407' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('407') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1"
                 priority="13659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.2"
                 priority="13652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.3"
                 priority="13651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.4"
                 priority="13650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.5"
                 priority="13649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.6"
                 priority="13648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.7"
                 priority="13647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.8"
                 priority="13645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9"
                 priority="13643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10"
                 priority="13633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.11"
                 priority="13621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12"
                 priority="13619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13"
                 priority="13614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.14"
                 priority="13609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4"
                 priority="13608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('408') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '408' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('408') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Spouse Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Spouse Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Spouse Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1"
                 priority="13606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.2"
                 priority="13599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.3"
                 priority="13598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.4"
                 priority="13597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.5"
                 priority="13596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.6"
                 priority="13595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.7"
                 priority="13594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.8"
                 priority="13592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9"
                 priority="13590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10"
                 priority="13580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.11"
                 priority="13568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12"
                 priority="13566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13"
                 priority="13561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.14"
                 priority="13556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5"
                 priority="13555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('409') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '409' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('409') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1"
                 priority="13553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="13551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="13550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="13549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.2"
                 priority="13548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.3"
                 priority="13547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.4"
                 priority="13546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.5"
                 priority="13545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.6"
                 priority="13544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.7"
                 priority="13542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.8"
                 priority="13540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.9"
                 priority="13539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.10"
                 priority="13538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.11"
                 priority="13537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12"
                 priority="13535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="13533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="13528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13"
                 priority="13523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="13521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="13520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14"
                 priority="13518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="13516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="13515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6"
                 priority="13513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('410') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '410' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('410') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Ph Num - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Ph Num - Home' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Ph Num - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.1"
                 priority="13511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.2"
                 priority="13510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.3"
                 priority="13508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.4"
                 priority="13506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.5"
                 priority="13505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.6"
                 priority="13504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.7"
                 priority="13503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.8"
                 priority="13502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.9"
                 priority="13501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.10"
                 priority="13500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.11"
                 priority="13499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/hl7v2:XTN.12"
                 priority="13498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7"
                 priority="13497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('411') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '411' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('411') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Ph Num - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Ph Num - Business' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Ph Num - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.1"
                 priority="13495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.2"
                 priority="13494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.3"
                 priority="13492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.4"
                 priority="13490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.5"
                 priority="13489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.6"
                 priority="13488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.7"
                 priority="13487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.8"
                 priority="13486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.9"
                 priority="13485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.10"
                 priority="13484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.11"
                 priority="13483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/hl7v2:XTN.12"
                 priority="13482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8"
                 priority="13481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('412') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '412' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('412') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Date/Time Of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Date/Time Of Birth' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Date/Time Of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8/hl7v2:TS.1"
                 priority="13479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8/hl7v2:TS.2"
                 priority="13478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.9"
                 priority="13476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '413' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Administrative Sex' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.10"
                 priority="13475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('414') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '414' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('414') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70068') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70068' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70068') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11"
                 priority="13474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('415') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '415' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('415') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70063' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Relationship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.1"
                 priority="13472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.2"
                 priority="13471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.3"
                 priority="13470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.4"
                 priority="13468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.5"
                 priority="13467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/hl7v2:CE.6"
                 priority="13466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.12"
                 priority="13464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '416' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor SSN') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor SSN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor SSN') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.13"
                 priority="13463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('417') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '417' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('417') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Date - Begin') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Date - Begin' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Date - Begin') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.14"
                 priority="13462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('418') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '418' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('418') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Date - End') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Date - End' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Date - End') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.15"
                 priority="13461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('419') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '419' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('419') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16"
                 priority="13460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '420' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employer Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employer Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employer Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1"
                 priority="13458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.2"
                 priority="13451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.3"
                 priority="13450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.4"
                 priority="13449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.5"
                 priority="13448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.6"
                 priority="13447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.7"
                 priority="13446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.8"
                 priority="13444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9"
                 priority="13442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10"
                 priority="13432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.11"
                 priority="13420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12"
                 priority="13418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13"
                 priority="13413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.14"
                 priority="13408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17"
                 priority="13407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '421' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employer Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employer Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employer Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1"
                 priority="13405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="13403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="13402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="13401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.2"
                 priority="13400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.3"
                 priority="13399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.4"
                 priority="13398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.5"
                 priority="13397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.6"
                 priority="13396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.7"
                 priority="13394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.8"
                 priority="13392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.9"
                 priority="13391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.10"
                 priority="13390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.11"
                 priority="13389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12"
                 priority="13387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="13385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="13380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13"
                 priority="13375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="13373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="13372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14"
                 priority="13370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="13368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="13367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18"
                 priority="13365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '422' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employer Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employer Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employer Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.1"
                 priority="13363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.2"
                 priority="13362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.3"
                 priority="13360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.4"
                 priority="13358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.5"
                 priority="13357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.6"
                 priority="13356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.7"
                 priority="13355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.8"
                 priority="13354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.9"
                 priority="13353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.10"
                 priority="13352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.11"
                 priority="13351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/hl7v2:XTN.12"
                 priority="13350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19"
                 priority="13349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('423') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '423' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('423') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employee ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employee ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employee ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.1"
                 priority="13347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.2"
                 priority="13346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.3"
                 priority="13345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4"
                 priority="13343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="13341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="13340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="13339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.5"
                 priority="13337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6"
                 priority="13335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="13333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="13332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="13331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.7"
                 priority="13329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.8"
                 priority="13328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9"
                 priority="13327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="13325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="13324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="13323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="13321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="13320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="13319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="13317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="13316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="13315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10"
                 priority="13314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="13312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="13311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="13310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="13308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="13307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="13306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="13304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="13303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="13302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.20"
                 priority="13301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '424' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70066') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70066' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70066') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employment Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employment Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employment Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21"
                 priority="13300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '425' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.1"
                 priority="13298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.2"
                 priority="13297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.3"
                 priority="13296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.4"
                 priority="13295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.5"
                 priority="13294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6"
                 priority="13292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="13290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="13289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="13288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.7"
                 priority="13286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8"
                 priority="13284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="13282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="13281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="13280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.9"
                 priority="13278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.10"
                 priority="13276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.22"
                 priority="13275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('773') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '773' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('773') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Billing Hold Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Billing Hold Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Billing Hold Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23"
                 priority="13273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('774') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '774' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('774') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70341') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70341' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70341') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Credit Rating Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Credit Rating Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Credit Rating Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.1"
                 priority="13271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.2"
                 priority="13270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.3"
                 priority="13269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.4"
                 priority="13267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.5"
                 priority="13266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/hl7v2:CE.6"
                 priority="13265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24"
                 priority="13263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('775') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '775' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('775') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Death Date And Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Death Date And Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Death Date And Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24/hl7v2:TS.1"
                 priority="13261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24/hl7v2:TS.2"
                 priority="13260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.25"
                 priority="13258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('776') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '776' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('776') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Death Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Death Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Death Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26"
                 priority="13256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('777') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '777' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('777') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70218' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Charge Adjustment Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.1"
                 priority="13254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.2"
                 priority="13253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.3"
                 priority="13252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.4"
                 priority="13250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.5"
                 priority="13249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/hl7v2:CE.6"
                 priority="13248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27"
                 priority="13246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('778') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '778' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('778') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Household Annual Income') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Household Annual Income' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Household Annual Income') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1"
                 priority="13244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1/hl7v2:MO.1"
                 priority="13242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1/hl7v2:MO.2"
                 priority="13241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.2"
                 priority="13239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.3"
                 priority="13237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.4"
                 priority="13236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5"
                 priority="13235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.1"
                 priority="13233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.2"
                 priority="13232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.3"
                 priority="13231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.4"
                 priority="13229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.5"
                 priority="13228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/hl7v2:CE.6"
                 priority="13227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.6"
                 priority="13225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.28"
                 priority="13223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('779') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '779' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('779') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Household Size') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Household Size' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Household Size') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29"
                 priority="13222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('780') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '780' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('780') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employer ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employer ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employer ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.1"
                 priority="13220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.2"
                 priority="13219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.3"
                 priority="13218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4"
                 priority="13216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/hl7v2:HD.1"
                 priority="13214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/hl7v2:HD.2"
                 priority="13213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/hl7v2:HD.3"
                 priority="13212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.5"
                 priority="13210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6"
                 priority="13208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/hl7v2:HD.1"
                 priority="13206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/hl7v2:HD.2"
                 priority="13205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/hl7v2:HD.3"
                 priority="13204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.7"
                 priority="13202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.8"
                 priority="13201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9"
                 priority="13200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="13198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="13197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="13196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="13194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="13193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="13192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="13190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="13189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="13188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10"
                 priority="13187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="13185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="13184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="13183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="13181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="13180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="13179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="13177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="13176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="13175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30"
                 priority="13174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('781') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '781' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('781') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Marital Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Marital Status Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Marital Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.1"
                 priority="13172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.2"
                 priority="13171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.3"
                 priority="13170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.4"
                 priority="13168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.5"
                 priority="13167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/hl7v2:CE.6"
                 priority="13166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.31"
                 priority="13164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('782') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '782' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('782') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Hire Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Hire Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Hire Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.32"
                 priority="13163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('783') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '783' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('783') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employment Stop Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Employment Stop Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employment Stop Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.33"
                 priority="13162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '755' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Living Dependency' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.34"
                 priority="13161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '145' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70009' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Ambulatory Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35"
                 priority="13160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.1"
                 priority="13158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.2"
                 priority="13157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.3"
                 priority="13156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.4"
                 priority="13154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.5"
                 priority="13153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/hl7v2:CE.6"
                 priority="13152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36"
                 priority="13150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.1"
                 priority="13148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.2"
                 priority="13147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.3"
                 priority="13146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.4"
                 priority="13144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.5"
                 priority="13143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/hl7v2:CE.6"
                 priority="13142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.37"
                 priority="13140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '742' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Living Arrangement' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38"
                 priority="13139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '743' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.1"
                 priority="13137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.2"
                 priority="13136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.3"
                 priority="13135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.4"
                 priority="13133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.5"
                 priority="13132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/hl7v2:CE.6"
                 priority="13131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.39"
                 priority="13129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '744' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.40"
                 priority="13127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '745' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Student Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41"
                 priority="13126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.1"
                 priority="13124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.2"
                 priority="13123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.3"
                 priority="13122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.4"
                 priority="13120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.5"
                 priority="13119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/hl7v2:CE.6"
                 priority="13118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42"
                 priority="13116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1"
                 priority="13114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.2"
                 priority="13107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.3"
                 priority="13106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.4"
                 priority="13105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.5"
                 priority="13104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.6"
                 priority="13103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.7"
                 priority="13102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.8"
                 priority="13100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9"
                 priority="13098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10"
                 priority="13088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.11"
                 priority="13076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12"
                 priority="13074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="13072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="13071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13"
                 priority="13069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="13067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="13066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.14"
                 priority="13064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43"
                 priority="13063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.1"
                 priority="13061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.2"
                 priority="13060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.3"
                 priority="13059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.4"
                 priority="13057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.5"
                 priority="13056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/hl7v2:CE.6"
                 priority="13055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44"
                 priority="13053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.1"
                 priority="13051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.2"
                 priority="13050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.3"
                 priority="13049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.4"
                 priority="13047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.5"
                 priority="13046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/hl7v2:CE.6"
                 priority="13045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45"
                 priority="13043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('748') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '748' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('748') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Person''s Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Contact Person''s Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Person''s Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1"
                 priority="13041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="13039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="13038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="13037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="13036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="13035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.2"
                 priority="13034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.3"
                 priority="13033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.4"
                 priority="13032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.5"
                 priority="13031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.6"
                 priority="13030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.7"
                 priority="13029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.8"
                 priority="13027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9"
                 priority="13025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="13023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="13022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="13021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="13019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="13018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="13017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10"
                 priority="13015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="13013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="13011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="13010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="13008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="13006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="13005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.11"
                 priority="13003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12"
                 priority="13001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="12999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="12998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13"
                 priority="12996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="12994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="12993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.14"
                 priority="12991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46"
                 priority="12990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('749') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '749' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('749') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Person''s Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Contact Person''s Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Person''s Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.1"
                 priority="12988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.2"
                 priority="12987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.3"
                 priority="12985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.4"
                 priority="12983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.5"
                 priority="12982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.6"
                 priority="12981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.7"
                 priority="12980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.8"
                 priority="12979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.9"
                 priority="12978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.10"
                 priority="12977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.11"
                 priority="12976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/hl7v2:XTN.12"
                 priority="12975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47"
                 priority="12974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('747') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '747' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('747') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70222') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70222' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70222') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Contact Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.1"
                 priority="12972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.2"
                 priority="12971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.3"
                 priority="12970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.4"
                 priority="12968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.5"
                 priority="12967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/hl7v2:CE.6"
                 priority="12966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.48"
                 priority="12964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('784') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '784' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('784') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70063') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70063' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70063') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Contact Relationship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.49"
                 priority="12963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('785') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '785' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('785') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Title') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Job Title' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Title') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50"
                 priority="12962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.1 komt te vaak voor [max 1x]. (count(hl7v2:JCC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.2 komt te vaak voor [max 1x]. (count(hl7v2:JCC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:JCC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): element hl7v2:JCC.3 komt te vaak voor [max 1x]. (count(hl7v2:JCC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('786') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '786' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('786') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('JCC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'JCC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('JCC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Code/Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Job Code/Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Code/Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.1"
                 priority="12960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70327') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Table MOET 'HL70327' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70327') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.2"
                 priority="12959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70328') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Table MOET 'HL70328' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70328') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3"
                 priority="12958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Description Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(JCC_datatype): de waarde van LongName MOET 'Job Description Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Description Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape"
                 priority="12957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape"
                 priority="12956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="12955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51"
                 priority="12954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1299') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '1299' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1299') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Employer''s Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Employer''s Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Employer''s Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.1"
                 priority="12952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.2"
                 priority="12951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.3"
                 priority="12950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.4"
                 priority="12949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.5"
                 priority="12948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6"
                 priority="12946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/hl7v2:HD.1"
                 priority="12944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/hl7v2:HD.2"
                 priority="12943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/hl7v2:HD.3"
                 priority="12942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.7"
                 priority="12940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8"
                 priority="12938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/hl7v2:HD.1"
                 priority="12936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/hl7v2:HD.2"
                 priority="12935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/hl7v2:HD.3"
                 priority="12934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.9"
                 priority="12932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.10"
                 priority="12930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.52"
                 priority="12929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '753' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70295' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Handicap' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.53"
                 priority="12928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('752') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '752' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('752') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70311') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70311' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70311') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Job Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Job Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Job Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54"
                 priority="12927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '1231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'FC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Financial Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.1"
                 priority="12925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van LongName MOET 'Financial Class Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2"
                 priority="12924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2/hl7v2:TS.1"
                 priority="12922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2/hl7v2:TS.2"
                 priority="12921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55"
                 priority="12919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1291') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '1291' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1291') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Race' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.1"
                 priority="12917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.2"
                 priority="12916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.3"
                 priority="12915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.4"
                 priority="12913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.5"
                 priority="12912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/hl7v2:CE.6"
                 priority="12911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.56"
                 priority="12909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1851') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '1851' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1851') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Guarantor Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'Guarantor Birth Place' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Guarantor Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.57"
                 priority="12908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Item MOET '146' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van Table MOET 'HL70099' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(GT1_segment): de waarde van LongName MOET 'VIP Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.53-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1"
                 priority="12907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.1 is required [min 1x]. (count(hl7v2:AL1.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.1 komt te vaak voor [max 1x]. (count(hl7v2:AL1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.2 komt te vaak voor [max 1x]. (count(hl7v2:AL1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.3 is required [min 1x]. (count(hl7v2:AL1.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.3 komt te vaak voor [max 1x]. (count(hl7v2:AL1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): element hl7v2:AL1.4 komt te vaak voor [max 1x]. (count(hl7v2:AL1.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.1"
                 priority="12906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('203') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Item MOET '203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('203') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - AL1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van LongName MOET 'Set ID - AL1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - AL1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2"
                 priority="12905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('204') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Item MOET '204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('204') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70127') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Table MOET 'HL70127' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70127') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergen Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van LongName MOET 'Allergen Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergen Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.1"
                 priority="12903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.2"
                 priority="12902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.3"
                 priority="12901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.4"
                 priority="12899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.5"
                 priority="12898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.6"
                 priority="12897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3"
                 priority="12895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('205') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Item MOET '205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('205') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergen Code/Mnemonic/Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van LongName MOET 'Allergen Code/Mnemonic/Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergen Code/Mnemonic/Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.1"
                 priority="12893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.2"
                 priority="12892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.3"
                 priority="12891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.4"
                 priority="12889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.5"
                 priority="12888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.6"
                 priority="12887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4"
                 priority="12885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('206') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Item MOET '206' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('206') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70128') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van Table MOET 'HL70128' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70128') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergy Severity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment_Relevante_allergieen_antibiotica_overgevoeligheden): de waarde van LongName MOET 'Allergy Severity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergy Severity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.31-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.1"
                 priority="12883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.2"
                 priority="12882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.3"
                 priority="12881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.4"
                 priority="12879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.5"
                 priority="12878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.6"
                 priority="12877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3727-false-d135425e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER"
                 priority="12875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:ORC is required [min 1x]. (count(hl7v2:ORC) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:ORC komt te vaak voor [max 1x]. (count(hl7v2:ORC) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION_REQUEST) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION_REQUEST komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION_REQUEST) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:BLG komt te vaak voor [max 1x]. (count(hl7v2:BLG) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC"
                 priority="12874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.1 is required [min 1x]. (count(hl7v2:ORC.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.1 komt te vaak voor [max 1x]. (count(hl7v2:ORC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.2 is required [min 1x]. (count(hl7v2:ORC.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.2 komt te vaak voor [max 1x]. (count(hl7v2:ORC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.3 komt te vaak voor [max 1x]. (count(hl7v2:ORC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.4 komt te vaak voor [max 1x]. (count(hl7v2:ORC.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.5 komt te vaak voor [max 1x]. (count(hl7v2:ORC.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.6 komt te vaak voor [max 1x]. (count(hl7v2:ORC.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.8 komt te vaak voor [max 1x]. (count(hl7v2:ORC.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.9 komt te vaak voor [max 1x]. (count(hl7v2:ORC.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.13 komt te vaak voor [max 1x]. (count(hl7v2:ORC.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.15 komt te vaak voor [max 1x]. (count(hl7v2:ORC.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.16 komt te vaak voor [max 1x]. (count(hl7v2:ORC.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.17 komt te vaak voor [max 1x]. (count(hl7v2:ORC.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.18 komt te vaak voor [max 1x]. (count(hl7v2:ORC.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.20 komt te vaak voor [max 1x]. (count(hl7v2:ORC.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.25 komt te vaak voor [max 1x]. (count(hl7v2:ORC.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.26 komt te vaak voor [max 1x]. (count(hl7v2:ORC.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.27 komt te vaak voor [max 1x]. (count(hl7v2:ORC.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.28 komt te vaak voor [max 1x]. (count(hl7v2:ORC.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.29 komt te vaak voor [max 1x]. (count(hl7v2:ORC.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.30 komt te vaak voor [max 1x]. (count(hl7v2:ORC.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.1"
                 priority="12873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('215') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('215') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70119' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70119') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Control' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Control') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2"
                 priority="12871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="12869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="12868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="12867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="12866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3"
                 priority="12864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="12862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="12861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="12860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="12859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4"
                 priority="12857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('218') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '218' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('218') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Placer Group Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="12855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="12854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="12853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="12852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.5"
                 priority="12850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('219') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '219' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('219') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70038' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70038') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.6"
                 priority="12848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('220') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('220') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70121' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70121') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Response Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Response Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7"
                 priority="12846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="12844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="12842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="12841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="12831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="12829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="12828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="12827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="12826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="12824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="12823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="12821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="12819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="12818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="12816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="12815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="12814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="12813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="12812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="12811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="12810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="12808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="12806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="12804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="12803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="12802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="12801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="12800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="12799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="12798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="12797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="12795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="12794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="12792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="12790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="12789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="12788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="12786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="12785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="12784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="12782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8"
                 priority="12781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('222') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '222' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('222') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="12779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="12777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="12776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="12775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="12774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="12772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="12770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="12769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="12768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="12767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9"
                 priority="12765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('223') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('223') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time of Transaction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of Transaction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="12763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="12762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10"
                 priority="12760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('224') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '224' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('224') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Entered By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entered By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="12758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="12757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="12750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="12749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="12748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="12747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="12746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="12745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="12744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="12738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="12736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="12735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="12733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="12731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="12725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="12723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="12713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="12701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="12699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="12694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="12689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="12688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="12675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11"
                 priority="12662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('225') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '225' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('225') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Verified By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Verified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="12660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="12659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="12652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="12651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="12650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="12649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="12648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="12647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="12646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="12640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="12638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="12637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="12635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="12633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="12627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="12625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="12615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="12603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="12601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="12596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="12591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="12590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="12577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12"
                 priority="12564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="12562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="12561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="12554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="12553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="12552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="12551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="12550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="12549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="12548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="12542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="12540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="12539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="12537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="12535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="12529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="12527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="12517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="12505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="12503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="12498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="12493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="12492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="12479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13"
                 priority="12466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '227' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Enterer''s Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Enterer''s Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="12464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="12463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="12462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="12461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="12459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="12458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="12457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="12455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="12454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="12453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="12452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="12451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="12450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="12448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="12447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="12446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="12445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="12443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="12441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="12440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="12439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14"
                 priority="12437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('228') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '228' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('228') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Call Back Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Call Back Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="12435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="12434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="12432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="12430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="12429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="12428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="12427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="12426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="12425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="12424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="12423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="12422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15"
                 priority="12421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('229') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '229' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('229') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Effective Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="12419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="12418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16"
                 priority="12416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '230' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Control Code Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Control Code Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="12414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="12413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="12412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="12410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="12409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="12408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17"
                 priority="12406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Entering Organization' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entering Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="12404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="12403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="12402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="12400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="12399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="12398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18"
                 priority="12396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('232') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '232' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('232') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Entering Device' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entering Device') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="12394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="12393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="12392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="12390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="12389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="12388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19"
                 priority="12386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('233') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '233' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('233') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Action By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Action By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="12384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="12383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="12381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="12380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="12379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="12378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="12377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="12376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="12375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="12374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="12373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="12372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="12371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="12370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="12368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="12367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="12366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="12364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="12362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="12361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="12359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="12357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="12355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="12354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="12353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="12351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="12349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="12347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="12346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="12345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="12343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="12342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="12341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="12339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="12337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="12332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="12327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="12325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="12323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="12322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="12320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="12318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="12317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="12315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="12314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="12312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="12311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="12310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="12308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="12307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="12306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="12304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="12303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="12302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="12301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="12299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="12298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="12297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="12295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="12294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="12293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="12291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="12290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="12289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20"
                 priority="12288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1310' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70339' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Advanced Beneficiary Notice Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="12286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="12285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="12284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="12282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="12281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="12280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21"
                 priority="12278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1311') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1311' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1311') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Facility Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Facility Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="12276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="12275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="12274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="12273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="12272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="12270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="12268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="12267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="12266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="12264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="12262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="12260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="12259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="12258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="12256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="12254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22"
                 priority="12253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1312') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1312' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1312') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Facility Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Facility Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="12251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="12249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="12248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="12247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="12246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="12245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="12244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="12243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="12242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="12240"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="12238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="12237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="12236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="12235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="12233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="12231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="12226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="12221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="12219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="12218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="12216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="12214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="12213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23"
                 priority="12211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1313') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1313' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1313') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Facility Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="12209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="12208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="12206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="12204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="12203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="12202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="12201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="12200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="12199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="12198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="12197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="12196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24"
                 priority="12195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1314') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1314' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1314') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Provider Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Provider Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="12193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="12191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="12190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="12189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="12188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="12187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="12186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="12185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="12184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="12182"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="12180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="12179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="12178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="12177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="12175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="12173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="12171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="12170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="12168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="12166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="12165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="12163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="12161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="12160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="12158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="12156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="12155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25"
                 priority="12153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1473' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Status Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Status Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="12151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="12150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="12149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="12147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="12146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="12145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="12143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="12142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="12141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26"
                 priority="12140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1641') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1641' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1641') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70552' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70552') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="12138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="12137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="12136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="12134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="12133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="12132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="12130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="12129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="12128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27"
                 priority="12127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1642') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1642' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1642') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Filler''s Expected Availability Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="12125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="12124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28"
                 priority="12122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('615') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '615' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('615') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70177' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70177') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Confidentiality Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Confidentiality Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="12120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="12119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="12118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="12116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="12115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="12114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="12112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="12111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="12110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29"
                 priority="12109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1643') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1643' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1643') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70482' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70482') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="12107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="12106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="12105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="12103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="12102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="12101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="12099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="12098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="12097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30"
                 priority="12096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1644' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CNE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70483' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70483') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Enterer Authorization Mode' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Enterer Authorization Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="12094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="12093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="12092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="12090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="12089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="12088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="12086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="12085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="12084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3731-false-d152814e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR"
                 priority="12083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 is required [min 1x]. (count(hl7v2:TQ1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1"
                 priority="12082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="12081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1627') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1627' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1627') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - TQ1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - TQ1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="12080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1628') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1628' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1628') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="12078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="12077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="12067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x]. (count(hl7v2:RPT.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x]. (count(hl7v2:RPT.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x]. (count(hl7v2:RPT.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x]. (count(hl7v2:RPT.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x]. (count(hl7v2:RPT.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x]. (count(hl7v2:RPT.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x]. (count(hl7v2:RPT.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x]. (count(hl7v2:RPT.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x]. (count(hl7v2:RPT.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x]. (count(hl7v2:RPT.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x]. (count(hl7v2:RPT.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1629') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1629' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1629') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'RPT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RPT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="12065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Repeat Pattern Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="12063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="12062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="12061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="12059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="12058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="12057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="12055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="12054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="12053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="12052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70527' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70527') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Calendar Alignment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Calendar Alignment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="12050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Phase Range Begin Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phase Range Begin Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="12049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Phase Range End Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phase Range End Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="12048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Period Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Period Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="12047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Period Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Period Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="12046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Institution Specified Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Institution Specified Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="12044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70528' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70528') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Event' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="12042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Event Offset Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Event Offset Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="12041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Event Offset Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Event Offset Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="12040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'GTS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('GTS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'General Timing Specification' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('General Timing Specification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="12039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1630') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1630' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1630') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Explicit Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Explicit Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="12038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1631') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1631' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1631') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Relative Time and Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relative Time and Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="12036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="12035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="12025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1632') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1632' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1632') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Service Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Service Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="12023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="12022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="12020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="12019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="12018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="12016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="12015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="12014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="12012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1633') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1633' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1633') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Start date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="12010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="12009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="12007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1634') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1634' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1634') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'End date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="12005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="12004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="12002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1635') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1635' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1635') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70485' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70485') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="12000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="11999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="11998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="11996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="11995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="11994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="11992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="11991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="11990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="11989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1636') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1636' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1636') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Condition text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Condition text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="11988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="11987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="11985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1637') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1637' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1637') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Text instruction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text instruction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="11984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="11983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="11981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1638') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1638' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1638') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70427' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70427') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="11979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1639') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1639' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1639') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Occurrence duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Occurrence duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="11977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="11976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="11974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="11973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="11972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="11970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="11969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="11968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="11966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1640') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1640' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1640') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Total occurrence''s' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total occurrence''s') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2"
                 priority="11965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="11964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1648') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1648' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1648') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Set ID - TQ2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - TQ2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="11963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1649') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1649' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1649') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70503' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70503') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="11961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1650') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1650' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1650') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Related Placer Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Related Placer Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="11959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="11958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="11957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="11956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="11954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1651') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1651' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1651') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Related Filler Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Related Filler Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="11952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="11951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="11950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="11949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="11947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1652') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1652' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1652') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Related Placer Group Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Related Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="11945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="11944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="11943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="11942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="11940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1653') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1653' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1653') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70504' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70504') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="11938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1654') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1654' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1654') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70505' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70505') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Cyclic Entry/Exit Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="11936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1655') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1655' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1655') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Time Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="11934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="11933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="11931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="11930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="11929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="11927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="11926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="11925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="11923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1656') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1656' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1656') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="11922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1657') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1657' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1657') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70506' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70506') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Special Service Request Relationship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Service Request Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3738-false-d156410e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST"
                 priority="11920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR is required [min 1x]. (count(hl7v2:OBR) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR komt te vaak voor [max 1x]. (count(hl7v2:OBR) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TCD komt te vaak voor [max 1x]. (count(hl7v2:TCD) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:CTD komt te vaak voor [max 1x]. (count(hl7v2:CTD) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.OBSERVATION) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION is required [min 1x]. (count(hl7v2:OML_O21.OBSERVATION) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR"
                 priority="11919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.1 komt te vaak voor [max 1x]. (count(hl7v2:OBR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.2 komt te vaak voor [max 1x]. (count(hl7v2:OBR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.3 komt te vaak voor [max 1x]. (count(hl7v2:OBR.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 is required [min 1x]. (count(hl7v2:OBR.4) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 komt te vaak voor [max 1x]. (count(hl7v2:OBR.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.5 komt te vaak voor [max 1x]. (count(hl7v2:OBR.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.6 komt te vaak voor [max 1x]. (count(hl7v2:OBR.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.7 komt te vaak voor [max 1x]. (count(hl7v2:OBR.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.8 komt te vaak voor [max 1x]. (count(hl7v2:OBR.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.9 komt te vaak voor [max 1x]. (count(hl7v2:OBR.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.11 komt te vaak voor [max 1x]. (count(hl7v2:OBR.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.12 komt te vaak voor [max 1x]. (count(hl7v2:OBR.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.13 komt te vaak voor [max 1x]. (count(hl7v2:OBR.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.14 komt te vaak voor [max 1x]. (count(hl7v2:OBR.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.15 komt te vaak voor [max 1x]. (count(hl7v2:OBR.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.18 komt te vaak voor [max 1x]. (count(hl7v2:OBR.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.19 komt te vaak voor [max 1x]. (count(hl7v2:OBR.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.20 komt te vaak voor [max 1x]. (count(hl7v2:OBR.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.21 komt te vaak voor [max 1x]. (count(hl7v2:OBR.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.22 komt te vaak voor [max 1x]. (count(hl7v2:OBR.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.23 komt te vaak voor [max 1x]. (count(hl7v2:OBR.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.24 komt te vaak voor [max 1x]. (count(hl7v2:OBR.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.25 komt te vaak voor [max 1x]. (count(hl7v2:OBR.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.26 komt te vaak voor [max 1x]. (count(hl7v2:OBR.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.29 komt te vaak voor [max 1x]. (count(hl7v2:OBR.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.30 komt te vaak voor [max 1x]. (count(hl7v2:OBR.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.32 komt te vaak voor [max 1x]. (count(hl7v2:OBR.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.36 komt te vaak voor [max 1x]. (count(hl7v2:OBR.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.37 komt te vaak voor [max 1x]. (count(hl7v2:OBR.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.40 komt te vaak voor [max 1x]. (count(hl7v2:OBR.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.41 komt te vaak voor [max 1x]. (count(hl7v2:OBR.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.42 komt te vaak voor [max 1x]. (count(hl7v2:OBR.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.44 komt te vaak voor [max 1x]. (count(hl7v2:OBR.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.48 komt te vaak voor [max 1x]. (count(hl7v2:OBR.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.49 komt te vaak voor [max 1x]. (count(hl7v2:OBR.49) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.1"
                 priority="11918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('237') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '237' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('237') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - OBR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2"
                 priority="11917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="11915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="11914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="11913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="11912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3"
                 priority="11910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="11908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="11907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="11906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="11905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4"
                 priority="11903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="11901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="11900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="11899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="11897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="11896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="11895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.5"
                 priority="11893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('239') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '239' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('239') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Priority _ OBR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority _ OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6"
                 priority="11891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('240') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '240' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('240') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Requested Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Requested Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="11889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="11888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7"
                 priority="11886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('241') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '241' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('241') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="11884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="11883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8"
                 priority="11881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('242') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '242' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('242') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="11879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="11878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9"
                 priority="11876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('243') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '243' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('243') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collection Volume' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collection Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="11874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="11873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="11871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="11870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="11869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="11867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="11866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="11865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10"
                 priority="11863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('244') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '244' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('244') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collector Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collector Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="11861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="11860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="11858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="11857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="11856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="11855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="11854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="11853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="11852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="11851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="11850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="11849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="11848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="11847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="11845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="11844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="11843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="11841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="11839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="11838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="11836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="11834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="11832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="11831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="11830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="11828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="11826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="11824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="11823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="11822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="11820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="11819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="11818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="11816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="11814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="11809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="11804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="11802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="11800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="11799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="11797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="11795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="11794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="11792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="11791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="11789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="11788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="11787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="11785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="11784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="11783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="11781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="11780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="11779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="11778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="11776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="11775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="11774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="11772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="11771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="11770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="11768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="11767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="11766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.11"
                 priority="11765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('245') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '245' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('245') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70065' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70065') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Action Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12"
                 priority="11763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('246') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '246' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('246') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Danger Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Danger Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="11761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="11760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="11759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="11757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="11756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="11755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.13"
                 priority="11753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('247') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '247' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('247') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Relevant Clinical Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relevant Clinical Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14"
                 priority="11752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="11750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="11749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15"
                 priority="11747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="11745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="11743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="11742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="11741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="11739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="11738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="11737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="11735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="11734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="11733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="11732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="11730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="11729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="11728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="11726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="11725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="11724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="11722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="11721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="11720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="11719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="11718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="11717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="11715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="11713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="11712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="11711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="11709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="11708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="11707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="11705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="11704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="11703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="11702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="11700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="11699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="11698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="11696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="11695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="11694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="11692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="11691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="11690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="11689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="11687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="11686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="11685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="11683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="11682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="11681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="11679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="11678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="11677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="11676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="11674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="11673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="11672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="11670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="11669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="11668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="11666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="11665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="11664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16"
                 priority="11663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="11661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="11660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="11658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="11657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="11656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="11655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="11654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="11653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="11652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="11651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="11650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="11649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="11648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="11647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="11645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="11644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="11643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="11641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="11639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="11638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="11636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="11634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="11632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="11631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="11630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="11628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="11626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="11624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="11623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="11622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="11620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="11619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="11618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="11616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="11614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="11609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="11604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="11602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="11600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="11599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="11597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="11595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="11594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="11592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="11591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="11589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="11588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="11587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="11585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="11584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="11583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="11581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="11580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="11579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="11578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="11576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="11575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="11574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="11572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="11571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="11570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="11568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="11567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="11566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17"
                 priority="11565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('250') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '250' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('250') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Callback Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Callback Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="11563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="11562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="11560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="11558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="11557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="11556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="11555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="11554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="11553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="11552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="11551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="11550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.18"
                 priority="11549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('251') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '251' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('251') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Field 1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.19"
                 priority="11548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('252') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '252' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('252') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Field 2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.20"
                 priority="11547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('253') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '253' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('253') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Field 1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.21"
                 priority="11546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('254') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '254' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('254') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Field 2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22"
                 priority="11545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('255') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '255' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('255') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="11543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="11542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23"
                 priority="11540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x]. (count(hl7v2:MOC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x]. (count(hl7v2:MOC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('256') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '256' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('256') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'MOC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MOC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Charge to Practice' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge to Practice') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="11538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van LongName MOET 'Monetary Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="11536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="11535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="11533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van LongName MOET 'Charge Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="11531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="11530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="11529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="11527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="11526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="11525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.24"
                 priority="11523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('257') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '257' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('257') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70074' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70074') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Diagnostic Serv Sect ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.25"
                 priority="11521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('258') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '258' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('258') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70123' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70123') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26"
                 priority="11519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x]. (count(hl7v2:PRL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x]. (count(hl7v2:PRL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x]. (count(hl7v2:PRL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('259') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '259' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('259') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'PRL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PRL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent Result' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Result') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="11517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="11515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="11514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="11513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="11511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="11510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="11509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="11507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Sub-identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="11506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Value Descriptor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="11505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="11504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27"
                 priority="11502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="11500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="11498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="11497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="11495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="11494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="11493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="11491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="11490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="11489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="11487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="11485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="11484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="11483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="11482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="11480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="11479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="11477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="11475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="11474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="11472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="11471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="11470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="11469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="11468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="11467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="11466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="11464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="11462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="11460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="11459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="11458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="11457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="11456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="11455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="11454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="11453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="11451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="11450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="11448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="11446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="11445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="11444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="11442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="11441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="11440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="11438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28"
                 priority="11437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('260') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '260' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('260') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Copies To' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Result Copies To') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="11435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="11434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="11432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="11431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="11430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="11429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="11428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="11427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="11426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="11425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="11424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="11423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="11422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="11421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="11419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="11418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="11417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="11415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="11413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="11412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="11410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="11408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="11406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="11405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="11404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="11402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="11400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="11398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="11397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="11396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="11394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="11393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="11392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="11390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="11388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="11386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="11385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="11383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="11381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="11380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="11378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="11376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="11374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="11373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="11371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="11369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="11368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="11366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="11365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="11363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="11362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="11361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="11359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="11358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="11357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="11355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="11354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="11353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="11352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="11350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="11349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="11348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="11346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="11345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="11344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="11342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="11341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="11340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29"
                 priority="11339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('261') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '261' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('261') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="11337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="11335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="11334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="11333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="11332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="11330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="11328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="11327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="11326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="11325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.30"
                 priority="11323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('262') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '262' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('262') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70124' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70124') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transportation Mode' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transportation Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31"
                 priority="11321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('263') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '263' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('263') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Reason for Study' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Reason for Study') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="11319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="11318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="11317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="11315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="11314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="11313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32"
                 priority="11311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('264') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '264' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('264') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Principal Result Interpreter' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Principal Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="11309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="11295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="11290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="11285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="11284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="11283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="11282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="11276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="11275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="11274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="11273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33"
                 priority="11272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('265') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '265' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('265') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Assistant Result Interpreter' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assistant Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="11270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="11256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="11251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="11246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="11245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="11244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="11243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="11237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="11236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="11235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="11234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34"
                 priority="11233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('266') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '266' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('266') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Technician' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Technician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="11231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="11217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="11212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="11207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="11206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="11205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="11204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="11198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="11197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="11196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="11195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35"
                 priority="11194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('267') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '267' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('267') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transcriptionist' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transcriptionist') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="11192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="11190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="11189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="11188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="11187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="11186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="11185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="11184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="11183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="11182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="11181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="11180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="11178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="11176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="11175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="11173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="11171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="11170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="11168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="11167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="11166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="11165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="11163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="11162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="11161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="11159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="11158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="11157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="11156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36"
                 priority="11155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('268') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '268' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('268') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Scheduled Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Scheduled Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="11153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="11152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.37"
                 priority="11150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1028') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1028' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1028') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Number of Sample Containers *' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Number of Sample Containers *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38"
                 priority="11149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1029') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1029' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1029') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Logistics of Collected Sample' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="11147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="11146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="11145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="11143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="11142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="11141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39"
                 priority="11139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1030') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1030' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1030') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collector''s Comment *' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collector''s Comment *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="11137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="11136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="11135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="11133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="11132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="11131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40"
                 priority="11129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1031') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1031' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1031') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Arrangement Responsibility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="11127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="11126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="11125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="11123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="11122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="11121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.41"
                 priority="11119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1032') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1032' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1032') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70224' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70224') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Arranged' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transport Arranged') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.42"
                 priority="11117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1033') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1033' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1033') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70225' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70225') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Escort Required' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Escort Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43"
                 priority="11115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1034') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1034' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1034') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Planned Patient Transport Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="11113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="11112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="11111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="11109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="11108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="11107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44"
                 priority="11105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '393' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70088' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Procedure Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="11103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="11102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="11101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="11099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="11098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="11097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45"
                 priority="11095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70340' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Procedure Code Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="11093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="11092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="11091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="11089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="11088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="11087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46"
                 priority="11085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1474' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="11083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="11082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="11081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="11079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="11078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="11077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47"
                 priority="11075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1475' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="11073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="11072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="11071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="11069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="11068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="11067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48"
                 priority="11065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1646' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70476' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="11063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="11062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="11061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="11059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="11058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="11057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="11055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="11054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="11053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.49"
                 priority="11052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1647' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70507' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70507') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Handling' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Result Handling') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD"
                 priority="11051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 is required [min 1x]. (count(hl7v2:TCD.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x]. (count(hl7v2:TCD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x]. (count(hl7v2:TCD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x]. (count(hl7v2:TCD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x]. (count(hl7v2:TCD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x]. (count(hl7v2:TCD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x]. (count(hl7v2:TCD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x]. (count(hl7v2:TCD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x]. (count(hl7v2:TCD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1"
                 priority="11050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="11048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="11047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="11046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="11044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="11043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="11042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2"
                 priority="11040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1420' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Auto-Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Auto-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="11038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="11037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="11036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="11035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3"
                 priority="11034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1421' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Rerun Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Rerun Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="11032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="11031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="11030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="11029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4"
                 priority="11028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1422' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Pre-Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Pre-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="11026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="11025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="11024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="11023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5"
                 priority="11022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1413' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Endogenous Content of Pre-Dilution Diluent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="11020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="11019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="11018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="11017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.6"
                 priority="11016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1416' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Automatic Repeat Allowed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Automatic Repeat Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.7"
                 priority="11014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1424' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Reflex Allowed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Reflex Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8"
                 priority="11012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1425' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Table MOET 'HL70389' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70389') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Analyte Repeat Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Analyte Repeat Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="11010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="11009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="11008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="11006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="11005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="11004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE"
                 priority="11002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.1"
                 priority="11001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.2"
                 priority="11000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3"
                 priority="10998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="10997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="10996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="10995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4"
                 priority="10994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="10992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="10991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="10990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="10988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="10987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="10986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD"
                 priority="10984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): element hl7v2:CTD.1 is required [min 1x]. (count(hl7v2:CTD.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): element hl7v2:CTD.4 komt te vaak voor [max 1x]. (count(hl7v2:CTD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): element hl7v2:CTD.6 komt te vaak voor [max 1x]. (count(hl7v2:CTD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1"
                 priority="10983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('196') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '196' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('196') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70131') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Table MOET 'HL70131' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70131') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Contact Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.1"
                 priority="10981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.2"
                 priority="10980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.3"
                 priority="10979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.4"
                 priority="10977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.5"
                 priority="10976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/hl7v2:CE.6"
                 priority="10975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2"
                 priority="10973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '1165' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Contact Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1"
                 priority="10971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="10969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="10968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="10967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="10966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="10965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.2"
                 priority="10964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.3"
                 priority="10963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.4"
                 priority="10962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.5"
                 priority="10961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.6"
                 priority="10960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.7"
                 priority="10959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.8"
                 priority="10957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9"
                 priority="10955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="10953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="10952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="10951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="10949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="10948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="10947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10"
                 priority="10945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="10943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="10938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.11"
                 priority="10933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12"
                 priority="10931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="10929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="10928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13"
                 priority="10926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="10924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="10923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.14"
                 priority="10921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3"
                 priority="10920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '1166' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Contact Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1"
                 priority="10918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="10916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="10915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="10914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.2"
                 priority="10913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.3"
                 priority="10912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.4"
                 priority="10911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.5"
                 priority="10910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.6"
                 priority="10909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.7"
                 priority="10907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.8"
                 priority="10905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.9"
                 priority="10904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.10"
                 priority="10903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.11"
                 priority="10902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12"
                 priority="10900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="10898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="10893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13"
                 priority="10888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="10886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="10885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14"
                 priority="10883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.73-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="10881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="10880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4"
                 priority="10878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '1167' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Contact Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.1"
                 priority="10876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.2"
                 priority="10875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.3"
                 priority="10874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4"
                 priority="10873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/hl7v2:HD.1"
                 priority="10871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/hl7v2:HD.2"
                 priority="10870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/hl7v2:HD.3"
                 priority="10869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.5"
                 priority="10867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.6"
                 priority="10866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.7"
                 priority="10865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.8"
                 priority="10864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.9"
                 priority="10863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10"
                 priority="10862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.1"
                 priority="10860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.2"
                 priority="10859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.3"
                 priority="10858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/hl7v2:EI.4"
                 priority="10857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11"
                 priority="10855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/hl7v2:HD.1"
                 priority="10853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/hl7v2:HD.2"
                 priority="10852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/hl7v2:HD.3"
                 priority="10851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5"
                 priority="10849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '1168' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Communication Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Contact Communication Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Communication Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.1"
                 priority="10847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.2"
                 priority="10846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.3"
                 priority="10844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.4"
                 priority="10842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.5"
                 priority="10841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.6"
                 priority="10840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.7"
                 priority="10839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.8"
                 priority="10838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.9"
                 priority="10837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.10"
                 priority="10836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.11"
                 priority="10835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/hl7v2:XTN.12"
                 priority="10834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6"
                 priority="10833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('684') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '684' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('684') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70185') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Table MOET 'HL70185' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70185') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preferred Method of Contact') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Preferred Method of Contact' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Preferred Method of Contact') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.1"
                 priority="10831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.2"
                 priority="10830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.3"
                 priority="10829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.4"
                 priority="10827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.5"
                 priority="10826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/hl7v2:CE.6"
                 priority="10825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7"
                 priority="10823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.1 komt te vaak voor [max 1x]. (count(hl7v2:PLN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.2 komt te vaak voor [max 1x]. (count(hl7v2:PLN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.3 komt te vaak voor [max 1x]. (count(hl7v2:PLN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PLN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): element hl7v2:PLN.4 komt te vaak voor [max 1x]. (count(hl7v2:PLN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Item MOET '1171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van Type MOET 'PLN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contact Identifiers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTD_segment): de waarde van LongName MOET 'Contact Identifiers' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contact Identifiers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.30-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.1"
                 priority="10821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.2"
                 priority="10820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70338') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van Table MOET 'HL70338' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70338') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Type of ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van LongName MOET 'Type of ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Type of ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.3"
                 priority="10819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State/other Qualifying Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van LongName MOET 'State/other Qualifying Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State/other Qualifying Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/hl7v2:PLN.4"
                 priority="10818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PLN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.45-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1"
                 priority="10817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.1 is required [min 1x]. (count(hl7v2:DG1.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.1 komt te vaak voor [max 1x]. (count(hl7v2:DG1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.2 is required [min 1x]. (count(hl7v2:DG1.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.2 komt te vaak voor [max 1x]. (count(hl7v2:DG1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.3 komt te vaak voor [max 1x]. (count(hl7v2:DG1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.4 komt te vaak voor [max 1x]. (count(hl7v2:DG1.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.5 komt te vaak voor [max 1x]. (count(hl7v2:DG1.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.6 is required [min 1x]. (count(hl7v2:DG1.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.6 komt te vaak voor [max 1x]. (count(hl7v2:DG1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.7 komt te vaak voor [max 1x]. (count(hl7v2:DG1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.8 komt te vaak voor [max 1x]. (count(hl7v2:DG1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.9 komt te vaak voor [max 1x]. (count(hl7v2:DG1.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.10 komt te vaak voor [max 1x]. (count(hl7v2:DG1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.11 komt te vaak voor [max 1x]. (count(hl7v2:DG1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.12 komt te vaak voor [max 1x]. (count(hl7v2:DG1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.13 komt te vaak voor [max 1x]. (count(hl7v2:DG1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.14 komt te vaak voor [max 1x]. (count(hl7v2:DG1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.15 komt te vaak voor [max 1x]. (count(hl7v2:DG1.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.17 komt te vaak voor [max 1x]. (count(hl7v2:DG1.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.18 komt te vaak voor [max 1x]. (count(hl7v2:DG1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.19 komt te vaak voor [max 1x]. (count(hl7v2:DG1.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.20 komt te vaak voor [max 1x]. (count(hl7v2:DG1.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DG1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): element hl7v2:DG1.21 komt te vaak voor [max 1x]. (count(hl7v2:DG1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.1"
                 priority="10816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('375') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '375' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('375') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - DG1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Set ID - DG1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - DG1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.2"
                 priority="10815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('376') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '376' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('376') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70053') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70053' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70053') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Coding Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Coding Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Coding Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3"
                 priority="10813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('377') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '377' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('377') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70051') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70051' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70051') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Code - DG1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Code - DG1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Code - DG1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.1"
                 priority="10811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.2"
                 priority="10810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.3"
                 priority="10809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.4"
                 priority="10807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.5"
                 priority="10806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/hl7v2:CE.6"
                 priority="10805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.4"
                 priority="10803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('378') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '378' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('378') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5"
                 priority="10802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('379') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '379' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('379') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5/hl7v2:TS.1"
                 priority="10800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5/hl7v2:TS.2"
                 priority="10799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.6"
                 priority="10797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('380') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '380' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('380') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70052') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70052' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70052') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7"
                 priority="10796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('381') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '381' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('381') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70118') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70118' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70118') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Major Diagnostic Category') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Major Diagnostic Category' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Major Diagnostic Category') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.1"
                 priority="10794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.2"
                 priority="10793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.3"
                 priority="10792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.4"
                 priority="10790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.5"
                 priority="10789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/hl7v2:CE.6"
                 priority="10788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8"
                 priority="10786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('382') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '382' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('382') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70055') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70055' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70055') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Related Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnostic Related Group' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnostic Related Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.1"
                 priority="10784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.2"
                 priority="10783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.3"
                 priority="10782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.4"
                 priority="10780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.5"
                 priority="10779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/hl7v2:CE.6"
                 priority="10778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.9"
                 priority="10776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('383') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '383' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('383') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('DRG Approval Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'DRG Approval Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('DRG Approval Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.10"
                 priority="10774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('384') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '384' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('384') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70056') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70056' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70056') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('DRG Grouper Review Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'DRG Grouper Review Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('DRG Grouper Review Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11"
                 priority="10773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('385') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '385' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('385') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70083') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70083' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70083') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Outlier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Outlier Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Outlier Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.1"
                 priority="10771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.2"
                 priority="10770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.3"
                 priority="10769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.4"
                 priority="10767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.5"
                 priority="10766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/hl7v2:CE.6"
                 priority="10765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.12"
                 priority="10763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('386') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '386' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('386') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Outlier Days') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Outlier Days' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Outlier Days') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13"
                 priority="10762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('387') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '387' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('387') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Outlier Cost') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Outlier Cost' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Outlier Cost') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1"
                 priority="10760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1/hl7v2:MO.1"
                 priority="10758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1/hl7v2:MO.2"
                 priority="10757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.2"
                 priority="10755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.3"
                 priority="10753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.4"
                 priority="10752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5"
                 priority="10751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.1"
                 priority="10749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.2"
                 priority="10748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.3"
                 priority="10747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.4"
                 priority="10745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.5"
                 priority="10744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/hl7v2:CE.6"
                 priority="10743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.6"
                 priority="10741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.14"
                 priority="10739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('388') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '388' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('388') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Grouper Version And Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Grouper Version And Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Grouper Version And Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.15"
                 priority="10738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('389') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '389' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('389') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70359') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70359' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70359') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16"
                 priority="10736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('390') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '390' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('390') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosing Clinician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosing Clinician' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosing Clinician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.1"
                 priority="10734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2"
                 priority="10733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.3"
                 priority="10726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.4"
                 priority="10725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.5"
                 priority="10724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.6"
                 priority="10723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.7"
                 priority="10722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.8"
                 priority="10721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9"
                 priority="10720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.10"
                 priority="10714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.11"
                 priority="10712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.12"
                 priority="10711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.13"
                 priority="10709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14"
                 priority="10707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.15"
                 priority="10701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16"
                 priority="10699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17"
                 priority="10689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.18"
                 priority="10677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19"
                 priority="10675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20"
                 priority="10670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.21"
                 priority="10665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22"
                 priority="10664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23"
                 priority="10651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.17"
                 priority="10638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('766') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '766' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('766') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70228') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70228' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70228') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Classification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Classification' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Classification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.18"
                 priority="10637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('767') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '767' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('767') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Confidential Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Confidential Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Confidential Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19"
                 priority="10635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('768') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '768' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('768') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Attestation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Attestation Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Attestation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19/hl7v2:TS.1"
                 priority="10633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19/hl7v2:TS.2"
                 priority="10632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20"
                 priority="10630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1850') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '1850' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1850') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.1"
                 priority="10628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.2"
                 priority="10627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.3"
                 priority="10626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/hl7v2:EI.4"
                 priority="10625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.21"
                 priority="10623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1894') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Item MOET '1894' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1894') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70206') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van Table MOET 'HL70206' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70206') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DG1_segment): de waarde van LongName MOET 'Diagnosis Action Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3751-false-d185349e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE' or text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''CNE' of 'ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='CNE' or text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '55607006' codeSystem '2.16.840.1.113883.6.96' displayName='Problem (finding)' codeSystemName='SCT''. (@nullFlavor or (@code='55607006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Problem (finding)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10605"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][completeCodeSystem[@codeSystem=$theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(NM_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1][completeCodeSystem[@codeSystem=$theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.86-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1]/conceptList/exception[@code = $theNullFlavor][@codeSystem = '2.16.840.1.113883.5.1008'])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@nullFlavor) or $validNullFlavorsFound"/>
         <xsl:otherwise>
            <xsl:message>(NM_datatype): de nulwaarde '<xsl:text/>
               <xsl:value-of select="@nullFlavor"/>
               <xsl:text/>' voor @code MOET komen uit de set die is gedefinieerd voor dit attribuut of zijn gekoppeld aan waardelijst 2.16.840.1.113883.2.4.3.11.60.25.11.406 VraagstellingAanvraag (2015-07-09T10:43:07). (not(@nullFlavor) or $validNullFlavorsFound / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.86-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>
      <xsl:variable name="theNullFlavor" select="@nullFlavor"/>
      <xsl:variable name="validNullFlavorsFound"
                    select="exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.406-2015-07-09T104307.xml')//valueSet[1]/conceptList/exception[@code = $theNullFlavor][@codeSystem = '2.16.840.1.113883.5.1008'])"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''. (@nullFlavor or (@code='kg') or (@code='g') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vraagstelling): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.50-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3759-false-d189249e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '282291009' codeSystem '2.16.840.1.113883.6.96' displayName='Diagnosis interpretation (observable entity)' codeSystemName='SCT''. (@nullFlavor or (@code='282291009' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Diagnosis interpretation (observable entity)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Onderliggend_lijden): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.11-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3767-false-d193102e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''NM'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '29463-7' codeSystem '2.16.840.1.113883.6.1' displayName='Body weight' codeSystemName='LN''. (@nullFlavor or (@code='29463-7' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body weight' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='kg') or (@code='g')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'kg' of code 'g''. (@nullFlavor or (@code='kg') or (@code='g') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="10174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="10172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="10171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="10170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="10168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="10166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="10164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="10163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="10161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="10159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="10158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="10156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="10154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="10152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="10151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="10149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="10147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="10146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="10144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="10143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="10141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="10140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="10139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="10137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="10136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="10135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="10133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="10132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="10131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="10130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="10128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="10127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="10126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="10124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="10123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="10122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="10120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="10119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="10118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="10117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="10115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="10114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="10113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="10111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="10110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="10109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="10107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="10105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="10104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="10103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="10102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="10100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Gewicht): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.12-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="10098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="10097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3775-false-d196979e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="10095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="10094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="10093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="10092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''NM'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="10090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '8302-2' codeSystem '2.16.840.1.113883.6.1' displayName='Body height' codeSystemName='LN''. (@nullFlavor or (@code='8302-2' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Body height' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="10088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="10087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="10086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="10084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="10083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="10082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="10080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="10079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="10078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='cm')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'cm''. (@nullFlavor or (@code='cm') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="10076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="10075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="10074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="10072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="10071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="10070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="10068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="10067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="10066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="10065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="10063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="10061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="10059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="10058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="10056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="10055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="10053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="10052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="10050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="10048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="10047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="10046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="10044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="10043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="10042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="10040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="10038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="10037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="10035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="10034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="10033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="10032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="10031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="10030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="10029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="10028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="10027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="10026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="10025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="10024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="10022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="10021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="10020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="10018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="10016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="10015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="10013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="10011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="10009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="10008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="10007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="10005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="10003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="10001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="10000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lengte): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.13-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3783-false-d200852e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''TS'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11368-8' codeSystem '2.16.840.1.113883.6.1' displayName='Illness or injury onset date and time' codeSystemName='LN''. (@nullFlavor or (@code='11368-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Illness or injury onset date and time' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="9902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="9901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Eerste_ziektedag): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.14-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3791-false-d204779e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.2 is mandatory [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.3 is mandatory [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.5 is mandatory [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Duur_van_de_klacht): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.15-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3800-false-d208630e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='CNE'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''CNE'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='CNE' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '77386006' codeSystem '2.16.840.1.113883.6.96' displayName='Pregnant (finding)' codeSystemName='SCT''. (@nullFlavor or (@code='77386006' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Pregnant (finding)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_zwanger): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.16-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3808-false-d212491e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''NM'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11996-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Pregnancies' codeSystemName='LN''. (@nullFlavor or (@code='11996-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Pregnancies' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_graviditeit): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.17-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3816-false-d216352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''NM'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11977-6' codeSystem '2.16.840.1.113883.6.1' displayName='[#] Parity' codeSystemName='LN''. (@nullFlavor or (@code='11977-6' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='[#] Parity' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="9177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="9176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="9174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="9173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="9171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="9169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="9168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="9167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="9165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="9164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="9163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="9161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="9159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="9158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="9156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="9155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="9154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="9153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="9152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="9151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="9150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="9149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="9148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="9147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="9146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="9145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="9143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="9142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="9141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="9139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="9137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="9136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="9134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="9132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="9130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="9129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="9128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="9126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="9124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="9122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="9121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="9120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="9118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="9117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="9116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="9114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="9112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="9110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="9109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="9107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="9105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="9104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="9102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="9100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="9098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="9097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="9095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="9093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="9092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="9090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="9089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="9087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="9086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="9085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="9083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="9082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="9081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="9079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="9078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="9077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="9076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="9074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="9073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="9072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="9070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="9069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="9068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="9066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="9065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="9064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="9063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="9061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="9060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="9059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="9057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="9056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="9055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="9053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="9051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="9050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="9049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="9048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="9046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_pariteit): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.18-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="9044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="9043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3824-false-d220213e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="9041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="9040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="9039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="9038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''TS'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="9036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '11778-8' codeSystem '2.16.840.1.113883.6.1' displayName='Delivery date Estimated' codeSystemName='LN''. (@nullFlavor or (@code='11778-8' and @codeSystem='2.16.840.1.113883.6.1' and @displayName='Delivery date Estimated' and @codeSystemName='LN') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="9034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="9033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="9032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="9030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="9029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="9028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="9026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="9025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="9023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="9022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="9020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="9018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="9017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="9016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="9014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="9013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="9012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="9010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="9009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="9008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="9007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="9005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="9003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="9001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="9000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_a_terme_datum): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.19-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3832-false-d224140e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.6 is required [min 1x]. (count(hl7v2:OBX.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='NM'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''NM'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='NM' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='d')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code 'd''. (@nullFlavor or (@code='d') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Zwangerschap_duur_in_dagen): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.20-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3840-false-d228003e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Relevante_medicatie): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.21-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3849-false-d231854e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '418799008' codeSystem '2.16.840.1.113883.6.96' displayName='Finding reported by subject or history provider (finding)' codeSystemName='SCT''. (@nullFlavor or (@code='418799008' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Finding reported by subject or history provider (finding)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Symptoom): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.22-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3857-false-d235715e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''TS'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="8319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="8318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="8178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="8177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="8176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="8174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="8173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="8172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="8170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="8168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="8167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="8166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="8165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="8163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Vaccinatiestatus): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.23-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="8161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="8160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3865-false-d239630e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="8158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="8157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.5 komt te vaak voor [max 1x]. (count(hl7v2:OBX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="8156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="8155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='TS'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''TS'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='TS' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="8153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '71388002' codeSystem '2.16.840.1.113883.6.96' displayName='Verrichting (verrichting)' codeSystemName='SCT''. (@nullFlavor or (@code='71388002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Verrichting (verrichting)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="8151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="8150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="8149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="8147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="8146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="8145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="8143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="8142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.1"
                 priority="8140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/hl7v2:TS.2"
                 priority="8139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="8137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="8135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="8134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="8133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="8131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="8130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="8129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="8127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="8126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="8125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="8124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="8122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="8120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="8118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="8117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="8115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="8114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="8112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="8111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="8109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="8107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="8106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="8105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="8103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="8102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="8101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="8099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="8097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="8096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="8094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="8093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="8092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="8091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="8090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="8089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="8088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="8087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="8086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="8085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="8084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="8083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="8081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="8080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="8079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="8077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="8075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="8074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="8072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="8070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="8068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="8067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="8066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="8064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="8062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="8060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="8059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="8058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="8056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="8055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="8054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="8052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="8050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="8048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="8047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="8045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="8043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="8042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="8040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="8038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="8036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="8035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="8033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="8031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="8030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="8028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="8027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="8025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="8024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="8023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="8021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="8020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="8019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="8017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="8016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="8015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="8014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="8012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="8011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="8010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="8008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="8007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="8006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="8004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="8003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="8002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="8001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Recente_ingrepen): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.24-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3873-false-d243557e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '313150002' codeSystem '2.16.840.1.113883.6.96' displayName='Synthetic surgical material (substance)' codeSystemName='SCT''. (@nullFlavor or (@code='313150002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Synthetic surgical material (substance)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Prothetisch_materiaal): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.25-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3881-false-d247408e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_contact_dieren_planten): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.26-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3889-false-d251249e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:NTE komt te vaak voor [max 1x]. (count(hl7v2:NTE) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_verblijf_in_buitenland): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.27-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE"
                 priority="7454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.1"
                 priority="7453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.2"
                 priority="7452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3"
                 priority="7450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="7449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="7448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="7447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4"
                 priority="7446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment_externe_factor_ziekenhuisopname_buitenland): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.30-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="7444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="7443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="7442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="7440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="7439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="7438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3900-false-d255507e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.2 is required [min 1x]. (count(hl7v2:OBX.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.5 is required [min 1x]. (count(hl7v2:OBX.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SCT')"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de elementwaarde MOET een zijn van 'code '184104002' codeSystem '2.16.840.1.113883.6.96' displayName='Patient occupation (observable entity)' codeSystemName='SCT''. (@nullFlavor or (@code='184104002' and @codeSystem='2.16.840.1.113883.6.96' and @displayName='Patient occupation (observable entity)' and @codeSystemName='SCT') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Externe_factor_beroep): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.28-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3908-false-d259366e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="7174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="7173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="7171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="7169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="7167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="7166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="7165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="7163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="7162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="7161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="7159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="7157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="7155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="7154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="7152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="7150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="7149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="7147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="7145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="7143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="7142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="7140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="7138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="7137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="7135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="7134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="7132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="7131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="7130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="7128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="7127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="7126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="7124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="7123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="7122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="7121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="7119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="7118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="7117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="7115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="7114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="7113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="7111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="7110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="7109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="7108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="7106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="7105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="7104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="7102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="7101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="7100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="7098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="7096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="7095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="7094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="7093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="7091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Resultaat_sneltest): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.29-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="7089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="7088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3916-false-d263203e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION"
                 priority="7086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TCD komt te vaak voor [max 1x]. (count(hl7v2:TCD) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX"
                 priority="7085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.1"
                 priority="7084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.2"
                 priority="7083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3"
                 priority="7081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="7079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="7078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="7077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="7075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="7074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="7073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.4"
                 priority="7071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5"
                 priority="7070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6"
                 priority="7069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="7067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="7066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="7065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="7063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="7062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="7061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.7"
                 priority="7059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.8"
                 priority="7058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.9"
                 priority="7057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.10"
                 priority="7056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.11"
                 priority="7054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12"
                 priority="7052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="7050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="7049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.13"
                 priority="7047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14"
                 priority="7046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="7044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="7043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15"
                 priority="7041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="7039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="7038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="7037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="7035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="7034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="7033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16"
                 priority="7031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="7029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="7028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="7026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="7025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="7024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="7023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="7022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="7021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="7020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="7019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="7018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="7017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="7016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="7015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="7013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="7012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="7011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="7009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="7007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="7006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="7004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="7002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="7000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="6996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="6994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="6984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="6972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="6970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="6965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="6960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="6959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="6946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17"
                 priority="6933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="6931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="6930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="6929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="6927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="6926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="6925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18"
                 priority="6923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="6921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="6920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="6919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="6918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19"
                 priority="6916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.6-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="6914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="6913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD"
                 priority="6911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 is required [min 1x]. (count(hl7v2:TCD.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.1 komt te vaak voor [max 1x]. (count(hl7v2:TCD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.2 komt te vaak voor [max 1x]. (count(hl7v2:TCD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.3 komt te vaak voor [max 1x]. (count(hl7v2:TCD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.4 komt te vaak voor [max 1x]. (count(hl7v2:TCD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.5 komt te vaak voor [max 1x]. (count(hl7v2:TCD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.6 komt te vaak voor [max 1x]. (count(hl7v2:TCD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.7 komt te vaak voor [max 1x]. (count(hl7v2:TCD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TCD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): element hl7v2:TCD.8 komt te vaak voor [max 1x]. (count(hl7v2:TCD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1"
                 priority="6910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.1"
                 priority="6908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.2"
                 priority="6907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.3"
                 priority="6906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.4"
                 priority="6904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.5"
                 priority="6903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/hl7v2:CE.6"
                 priority="6902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2"
                 priority="6900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1420') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1420' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1420') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Auto-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Auto-Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Auto-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.1"
                 priority="6898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.2"
                 priority="6897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.3"
                 priority="6896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/hl7v2:SN.4"
                 priority="6895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3"
                 priority="6894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1421') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1421' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1421') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Rerun Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Rerun Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Rerun Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.1"
                 priority="6892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.2"
                 priority="6891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.3"
                 priority="6890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/hl7v2:SN.4"
                 priority="6889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4"
                 priority="6888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1422') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1422' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1422') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pre-Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Pre-Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Pre-Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.1"
                 priority="6886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.2"
                 priority="6885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.3"
                 priority="6884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/hl7v2:SN.4"
                 priority="6883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5"
                 priority="6882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1413') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1413' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1413') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Endogenous Content of Pre-Dilution Diluent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Endogenous Content of Pre-Dilution Diluent' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Endogenous Content of Pre-Dilution Diluent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.1"
                 priority="6880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.2"
                 priority="6879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.3"
                 priority="6878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/hl7v2:SN.4"
                 priority="6877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.6"
                 priority="6876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1416') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1416' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1416') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Automatic Repeat Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Automatic Repeat Allowed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Automatic Repeat Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.7"
                 priority="6874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1424') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1424' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1424') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reflex Allowed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Reflex Allowed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Reflex Allowed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8"
                 priority="6872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1425') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Item MOET '1425' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1425') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70389') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van Table MOET 'HL70389' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70389') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Analyte Repeat Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TCD_segment): de waarde van LongName MOET 'Analyte Repeat Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Analyte Repeat Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.141-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.1"
                 priority="6870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.2"
                 priority="6869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.3"
                 priority="6868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.4"
                 priority="6866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.5"
                 priority="6865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/hl7v2:CE.6"
                 priority="6864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE"
                 priority="6862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.1"
                 priority="6861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.2"
                 priority="6860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3"
                 priority="6858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="6857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="6856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4"
                 priority="6854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="6852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="6851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="6850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="6848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="6847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="6846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3928-false-d268576e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN"
                 priority="6844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SPM is required [min 1x]. (count(hl7v2:SPM) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SPM komt te vaak voor [max 1x]. (count(hl7v2:SPM) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM"
                 priority="6843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.1 komt te vaak voor [max 1x]. (count(hl7v2:SPM.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.2 is required [min 1x]. (count(hl7v2:SPM.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.2 komt te vaak voor [max 1x]. (count(hl7v2:SPM.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.4 is required [min 1x]. (count(hl7v2:SPM.4) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.4 komt te vaak voor [max 1x]. (count(hl7v2:SPM.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.7 komt te vaak voor [max 1x]. (count(hl7v2:SPM.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.8 komt te vaak voor [max 1x]. (count(hl7v2:SPM.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.10 komt te vaak voor [max 1x]. (count(hl7v2:SPM.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.12 komt te vaak voor [max 1x]. (count(hl7v2:SPM.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.13 komt te vaak voor [max 1x]. (count(hl7v2:SPM.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.17 komt te vaak voor [max 1x]. (count(hl7v2:SPM.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.18 komt te vaak voor [max 1x]. (count(hl7v2:SPM.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.19 komt te vaak voor [max 1x]. (count(hl7v2:SPM.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.20 komt te vaak voor [max 1x]. (count(hl7v2:SPM.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.22 komt te vaak voor [max 1x]. (count(hl7v2:SPM.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.23 komt te vaak voor [max 1x]. (count(hl7v2:SPM.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.25 komt te vaak voor [max 1x]. (count(hl7v2:SPM.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.26 komt te vaak voor [max 1x]. (count(hl7v2:SPM.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.27 komt te vaak voor [max 1x]. (count(hl7v2:SPM.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.28 komt te vaak voor [max 1x]. (count(hl7v2:SPM.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPM.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): element hl7v2:SPM.29 komt te vaak voor [max 1x]. (count(hl7v2:SPM.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.1"
                 priority="6842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1754') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1754' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1754') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID _ SPM') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Set ID _ SPM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID _ SPM') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2"
                 priority="6841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1755' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1"
                 priority="6839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="6837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="6836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="6835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="6834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2"
                 priority="6832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="6830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="6829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="6828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="6827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3"
                 priority="6825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1756' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Parent IDs') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Parent IDs' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Parent IDs') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1"
                 priority="6823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="6821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="6820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="6819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="6818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2"
                 priority="6816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="6814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="6813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="6812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="6811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4"
                 priority="6809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1900') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1900' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1900') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70487') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70487' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70487') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.1"
                 priority="6807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.2"
                 priority="6806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.3"
                 priority="6805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.4"
                 priority="6803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.5"
                 priority="6802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.6"
                 priority="6801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.7"
                 priority="6799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.8"
                 priority="6798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/hl7v2:CWE.9"
                 priority="6797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5"
                 priority="6796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1757' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70541') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70541' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70541') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Type Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Type Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Type Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.1"
                 priority="6794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.2"
                 priority="6793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.3"
                 priority="6792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.4"
                 priority="6790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.5"
                 priority="6789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.6"
                 priority="6788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.7"
                 priority="6786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.8"
                 priority="6785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/hl7v2:CWE.9"
                 priority="6784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6"
                 priority="6783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1758') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1758' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1758') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Additives' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.1"
                 priority="6781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.2"
                 priority="6780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.3"
                 priority="6779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.4"
                 priority="6777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.5"
                 priority="6776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.6"
                 priority="6775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.7"
                 priority="6773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.8"
                 priority="6772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/hl7v2:CWE.9"
                 priority="6771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7"
                 priority="6770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1759' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70488') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70488' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70488') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.1"
                 priority="6768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.2"
                 priority="6767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.3"
                 priority="6766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.4"
                 priority="6764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.5"
                 priority="6763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.6"
                 priority="6762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.7"
                 priority="6760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.8"
                 priority="6759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/hl7v2:CWE.9"
                 priority="6758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8"
                 priority="6757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1901') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1901' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1901') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Source Site' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.1"
                 priority="6755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.2"
                 priority="6754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.3"
                 priority="6753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.4"
                 priority="6751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.5"
                 priority="6750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.6"
                 priority="6749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.7"
                 priority="6747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.8"
                 priority="6746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/hl7v2:CWE.9"
                 priority="6745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9"
                 priority="6744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1760' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70542') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70542' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70542') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Source Site Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.1"
                 priority="6742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.2"
                 priority="6741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.3"
                 priority="6740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.4"
                 priority="6738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.5"
                 priority="6737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.6"
                 priority="6736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.7"
                 priority="6734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.8"
                 priority="6733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/hl7v2:CWE.9"
                 priority="6732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10"
                 priority="6731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1761' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70543') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70543' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70543') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Collection Site' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.1"
                 priority="6729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.2"
                 priority="6728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.3"
                 priority="6727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.4"
                 priority="6725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.5"
                 priority="6724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.6"
                 priority="6723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.7"
                 priority="6721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.8"
                 priority="6720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/hl7v2:CWE.9"
                 priority="6719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11"
                 priority="6718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1762' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.1"
                 priority="6716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.2"
                 priority="6715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.3"
                 priority="6714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.4"
                 priority="6712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.5"
                 priority="6711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.6"
                 priority="6710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.7"
                 priority="6708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.8"
                 priority="6707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/hl7v2:CWE.9"
                 priority="6706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12"
                 priority="6705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1902') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1902' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1902') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Collection Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.1"
                 priority="6703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2"
                 priority="6702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.13"
                 priority="6692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1763') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1763' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1763') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Grouped Specimen Count') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Grouped Specimen Count' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Grouped Specimen Count') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.14"
                 priority="6691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1764') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1764' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1764') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15"
                 priority="6690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1908') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1908' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1908') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70376' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70376') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Handling Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Handling Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.1"
                 priority="6688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.2"
                 priority="6687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.3"
                 priority="6686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.4"
                 priority="6684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.5"
                 priority="6683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.6"
                 priority="6682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.7"
                 priority="6680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.8"
                 priority="6679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/hl7v2:CWE.9"
                 priority="6678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16"
                 priority="6677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1903') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1903' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1903') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70489') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70489' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70489') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Risk Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Risk Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Risk Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.1"
                 priority="6675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.2"
                 priority="6674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.3"
                 priority="6673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.4"
                 priority="6671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.5"
                 priority="6670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.6"
                 priority="6669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.7"
                 priority="6667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.8"
                 priority="6666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/hl7v2:CWE.9"
                 priority="6665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17"
                 priority="6664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1765') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1765' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1765') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Collection Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1"
                 priority="6662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2"
                 priority="6657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18"
                 priority="6652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.1"
                 priority="6650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/hl7v2:TS.2"
                 priority="6649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19"
                 priority="6647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1904') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1904' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1904') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Expiration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Expiration Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Expiration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.1"
                 priority="6645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/hl7v2:TS.2"
                 priority="6644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.20"
                 priority="6642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1766') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1766' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1766') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Availability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Availability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Availability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21"
                 priority="6640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1767') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1767' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1767') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70490') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70490' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70490') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Reject Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Reject Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Reject Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.1"
                 priority="6638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.2"
                 priority="6637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.3"
                 priority="6636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.4"
                 priority="6634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.5"
                 priority="6633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.6"
                 priority="6632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.7"
                 priority="6630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.8"
                 priority="6629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/hl7v2:CWE.9"
                 priority="6628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22"
                 priority="6627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1768') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1768' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1768') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70491') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70491' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70491') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Quality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Quality' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Quality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.1"
                 priority="6625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.2"
                 priority="6624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.3"
                 priority="6623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.4"
                 priority="6621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.5"
                 priority="6620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.6"
                 priority="6619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.7"
                 priority="6617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.8"
                 priority="6616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/hl7v2:CWE.9"
                 priority="6615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23"
                 priority="6614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1769') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1769' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1769') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70492') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70492' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70492') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Appropriateness') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Appropriateness' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Appropriateness') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.1"
                 priority="6612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.2"
                 priority="6611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.3"
                 priority="6610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.4"
                 priority="6608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.5"
                 priority="6607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.6"
                 priority="6606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.7"
                 priority="6604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.8"
                 priority="6603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/hl7v2:CWE.9"
                 priority="6602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24"
                 priority="6601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1770') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1770' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1770') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70493') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70493' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70493') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Condition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.1"
                 priority="6599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.2"
                 priority="6598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.3"
                 priority="6597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.4"
                 priority="6595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.5"
                 priority="6594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.6"
                 priority="6593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.7"
                 priority="6591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.8"
                 priority="6590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/hl7v2:CWE.9"
                 priority="6589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25"
                 priority="6588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1771') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1771' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1771') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Current Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Current Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Current Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.1"
                 priority="6586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2"
                 priority="6585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="6583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="6582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="6581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="6579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="6578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="6577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.26"
                 priority="6575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1772') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1772' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1772') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Specimen Containers') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Number of Specimen Containers' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Number of Specimen Containers') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27"
                 priority="6574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1773') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1773' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1773') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Container Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.1"
                 priority="6572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.2"
                 priority="6571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.3"
                 priority="6570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.4"
                 priority="6568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.5"
                 priority="6567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.6"
                 priority="6566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.7"
                 priority="6564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.8"
                 priority="6563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/hl7v2:CWE.9"
                 priority="6562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28"
                 priority="6561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1774') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1774' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1774') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70544') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70544' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70544') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Container Condition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.1"
                 priority="6559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.2"
                 priority="6558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.3"
                 priority="6557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.4"
                 priority="6555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.5"
                 priority="6554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.6"
                 priority="6553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.7"
                 priority="6551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.8"
                 priority="6550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/hl7v2:CWE.9"
                 priority="6549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29"
                 priority="6548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1775') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Item MOET '1775' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1775') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70494') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van Table MOET 'HL70494' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70494') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Child Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPM_segment_Lab_algemeen): de waarde van LongName MOET 'Specimen Child Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Child Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.48-2017-05-13T205543.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.1"
                 priority="6546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.2"
                 priority="6545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.3"
                 priority="6544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.4"
                 priority="6542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.5"
                 priority="6541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.6"
                 priority="6540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.7"
                 priority="6538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.8"
                 priority="6537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/hl7v2:CWE.9"
                 priority="6536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX"
                 priority="6535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.1"
                 priority="6534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.2"
                 priority="6533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="text()='ST'"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementinhoud van hl7v2:OBX.2 MOET ''ST'' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="."/>
               <xsl:text/>" (text()='ST' / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3"
                 priority="6531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="6529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="6528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="6527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="6525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="6524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="6523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.4"
                 priority="6521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.5"
                 priority="6520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6"
                 priority="6519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="6517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="6516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="6515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="6513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="6512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="6511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.7"
                 priority="6509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.8"
                 priority="6508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.9"
                 priority="6507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.10"
                 priority="6506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.11"
                 priority="6504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12"
                 priority="6502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="6500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="6499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.13"
                 priority="6497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14"
                 priority="6496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="6494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="6493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15"
                 priority="6491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="6489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="6488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="6487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="6485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="6484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="6483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16"
                 priority="6481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="6479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="6478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="6476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="6475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="6474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="6473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="6472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="6471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="6470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="6469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="6468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="6467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="6466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="6465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="6463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="6462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="6461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="6459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="6457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="6456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="6454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="6452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="6450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="6449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="6448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="6446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="6444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="6442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="6441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="6440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="6438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="6437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="6436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="6434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="6432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="6430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="6429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="6427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="6425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="6424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="6422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="6420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="6418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="6417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="6415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="6413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="6412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="6410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="6409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="6407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="6406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="6405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="6403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="6402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="6401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="6399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="6398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="6397"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="6396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="6394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="6393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="6392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="6390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="6389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="6388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="6386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="6385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="6384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17"
                 priority="6383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="6381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="6380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="6379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="6377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="6376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="6375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18"
                 priority="6373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="6371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="6370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="6369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="6368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19"
                 priority="6366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Aspect_van_het_materiaal): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.37-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="6364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="6363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3936-false-d279472e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER"
                 priority="6361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SAC is required [min 1x]. (count(hl7v2:SAC) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:SAC komt te vaak voor [max 1x]. (count(hl7v2:SAC) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC"
                 priority="6360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.1 komt te vaak voor [max 1x]. (count(hl7v2:SAC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.2 komt te vaak voor [max 1x]. (count(hl7v2:SAC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.3 komt te vaak voor [max 1x]. (count(hl7v2:SAC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.4 komt te vaak voor [max 1x]. (count(hl7v2:SAC.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.5 komt te vaak voor [max 1x]. (count(hl7v2:SAC.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.6 komt te vaak voor [max 1x]. (count(hl7v2:SAC.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.7 komt te vaak voor [max 1x]. (count(hl7v2:SAC.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.8 komt te vaak voor [max 1x]. (count(hl7v2:SAC.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.9 komt te vaak voor [max 1x]. (count(hl7v2:SAC.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.10 komt te vaak voor [max 1x]. (count(hl7v2:SAC.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.11 komt te vaak voor [max 1x]. (count(hl7v2:SAC.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.12 komt te vaak voor [max 1x]. (count(hl7v2:SAC.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.13 komt te vaak voor [max 1x]. (count(hl7v2:SAC.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.14 komt te vaak voor [max 1x]. (count(hl7v2:SAC.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.16 komt te vaak voor [max 1x]. (count(hl7v2:SAC.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.17 komt te vaak voor [max 1x]. (count(hl7v2:SAC.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.18 komt te vaak voor [max 1x]. (count(hl7v2:SAC.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.19 komt te vaak voor [max 1x]. (count(hl7v2:SAC.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.20 komt te vaak voor [max 1x]. (count(hl7v2:SAC.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.21 komt te vaak voor [max 1x]. (count(hl7v2:SAC.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.22 komt te vaak voor [max 1x]. (count(hl7v2:SAC.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.23 komt te vaak voor [max 1x]. (count(hl7v2:SAC.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.24 komt te vaak voor [max 1x]. (count(hl7v2:SAC.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.25 komt te vaak voor [max 1x]. (count(hl7v2:SAC.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.26 komt te vaak voor [max 1x]. (count(hl7v2:SAC.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.28 komt te vaak voor [max 1x]. (count(hl7v2:SAC.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.29 komt te vaak voor [max 1x]. (count(hl7v2:SAC.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.30 komt te vaak voor [max 1x]. (count(hl7v2:SAC.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.31 komt te vaak voor [max 1x]. (count(hl7v2:SAC.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.32 komt te vaak voor [max 1x]. (count(hl7v2:SAC.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.33 komt te vaak voor [max 1x]. (count(hl7v2:SAC.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.34 komt te vaak voor [max 1x]. (count(hl7v2:SAC.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.35 komt te vaak voor [max 1x]. (count(hl7v2:SAC.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.36 komt te vaak voor [max 1x]. (count(hl7v2:SAC.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.37 komt te vaak voor [max 1x]. (count(hl7v2:SAC.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.38 komt te vaak voor [max 1x]. (count(hl7v2:SAC.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.39 komt te vaak voor [max 1x]. (count(hl7v2:SAC.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAC.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): element hl7v2:SAC.42 komt te vaak voor [max 1x]. (count(hl7v2:SAC.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1"
                 priority="6359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1329') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1329' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1329') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('External Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'External Accession Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('External Accession Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.1"
                 priority="6357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.2"
                 priority="6356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.3"
                 priority="6355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/hl7v2:EI.4"
                 priority="6354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2"
                 priority="6352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1330') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1330' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1330') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accession Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Accession Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Accession Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.1"
                 priority="6350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.2"
                 priority="6349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.3"
                 priority="6348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/hl7v2:EI.4"
                 priority="6347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3"
                 priority="6345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1331') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1331' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1331') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Container Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.1"
                 priority="6343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.2"
                 priority="6342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.3"
                 priority="6341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/hl7v2:EI.4"
                 priority="6340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4"
                 priority="6338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1332') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1332' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1332') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary (parent) Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Primary (parent) Container Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Primary (parent) Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.1"
                 priority="6336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.2"
                 priority="6335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.3"
                 priority="6334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/hl7v2:EI.4"
                 priority="6333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5"
                 priority="6331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1333') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1333' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1333') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Container Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Equipment Container Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Container Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.1"
                 priority="6329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.2"
                 priority="6328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.3"
                 priority="6327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/hl7v2:EI.4"
                 priority="6326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6"
                 priority="6324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1"
                 priority="6322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="6320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="6319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="6318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="6316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="6315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="6314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="6312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="6311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="6310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2"
                 priority="6309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="6307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="6306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="6305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="6303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="6302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="6301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="6299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="6298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="6297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3"
                 priority="6296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape"
                 priority="6295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="6294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="6293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4"
                 priority="6292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="6290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="6289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="6288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="6286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="6285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="6284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="6282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="6281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="6280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5"
                 priority="6279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="6277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="6276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="6275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="6273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="6272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="6271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="6269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="6268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="6267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6"
                 priority="6266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="6264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="6263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="6262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="6260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="6259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="6258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="6256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="6255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="6254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7"
                 priority="6253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="6251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="6250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="6249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="6247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="6246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="6245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="6243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="6242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="6241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7"
                 priority="6240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1334') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1334' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1334') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Registration Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Registration Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Registration Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.1"
                 priority="6238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/hl7v2:TS.2"
                 priority="6237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8"
                 priority="6235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1335') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1335') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70370') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70370' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70370') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Container Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.1"
                 priority="6233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.2"
                 priority="6232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.3"
                 priority="6231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.4"
                 priority="6229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.5"
                 priority="6228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/hl7v2:CE.6"
                 priority="6227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9"
                 priority="6225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1336') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1336' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1336') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70378') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70378' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70378') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Carrier Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Carrier Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Carrier Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.1"
                 priority="6223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.2"
                 priority="6222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.3"
                 priority="6221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.4"
                 priority="6219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.5"
                 priority="6218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/hl7v2:CE.6"
                 priority="6217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10"
                 priority="6215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1337') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1337' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1337') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Carrier Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Carrier Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Carrier Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.1"
                 priority="6213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.2"
                 priority="6212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.3"
                 priority="6211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/hl7v2:EI.4"
                 priority="6210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11"
                 priority="6208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer (*[matches(local-name(),'^NA\.\d+$')] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric (*[. castable as xs:decimal] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 is required [min 1x]. (count(hl7v2:NA.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x]. (count(hl7v2:NA.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x]. (count(hl7v2:NA.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x]. (count(hl7v2:NA.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x]. (count(hl7v2:NA.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1338') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1338' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1338') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NA' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position in Carrier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Position in Carrier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Position in Carrier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.1"
                 priority="6206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.2"
                 priority="6205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.3"
                 priority="6204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value3' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/hl7v2:NA.4"
                 priority="6203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value4' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value4') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12"
                 priority="6202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1339') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1339' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1339') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70379') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70379' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70379') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tray Type - SAC') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Tray Type - SAC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Tray Type - SAC') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.1"
                 priority="6200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.2"
                 priority="6199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.3"
                 priority="6198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.4"
                 priority="6196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.5"
                 priority="6195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/hl7v2:CE.6"
                 priority="6194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13"
                 priority="6192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1340') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1340' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1340') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tray Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Tray Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Tray Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.1"
                 priority="6190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.2"
                 priority="6189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.3"
                 priority="6188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/hl7v2:EI.4"
                 priority="6187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14"
                 priority="6185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[matches(local-name(),'^NA\.\d+$')]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element names in the datatype NA SHALL conform to pattern 'NA.n' where n is an integer (*[matches(local-name(),'^NA\.\d+$')] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="*[. castable as xs:decimal]"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): Element values in the datatype NA SHALL be a valid NM - Numeric (*[. castable as xs:decimal] / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 is required [min 1x]. (count(hl7v2:NA.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.1 komt te vaak voor [max 1x]. (count(hl7v2:NA.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.2 komt te vaak voor [max 1x]. (count(hl7v2:NA.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.3 komt te vaak voor [max 1x]. (count(hl7v2:NA.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NA.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): element hl7v2:NA.4 komt te vaak voor [max 1x]. (count(hl7v2:NA.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1341') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1341' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1341') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NA') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NA' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NA') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Position in Tray') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Position in Tray' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Position in Tray') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.1"
                 priority="6183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.2"
                 priority="6182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.3"
                 priority="6181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value3') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value3' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value3') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/hl7v2:NA.4"
                 priority="6180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value4') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NA_datatype): de waarde van LongName MOET 'Value4' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value4') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.37-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15"
                 priority="6179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1342') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1342' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1342') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.1"
                 priority="6177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.2"
                 priority="6176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.3"
                 priority="6175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.4"
                 priority="6173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.5"
                 priority="6172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/hl7v2:CE.6"
                 priority="6171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.16"
                 priority="6169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1343') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1343' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1343') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Height') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Container Height' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Height') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.17"
                 priority="6168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1344') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1344' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1344') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Diameter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Container Diameter' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Diameter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.18"
                 priority="6167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1345') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1345' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1345') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Barrier Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Barrier Delta' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Barrier Delta') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.19"
                 priority="6166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1346') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1346' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1346') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bottom Delta') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Bottom Delta' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bottom Delta') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20"
                 priority="6165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1347') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1347' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1347') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Height/Diameter/Delta Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Container Height/Diameter/Delta Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Height/Diameter/Delta Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.1"
                 priority="6163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.2"
                 priority="6162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.3"
                 priority="6161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.4"
                 priority="6159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.5"
                 priority="6158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/hl7v2:CE.6"
                 priority="6157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.21"
                 priority="6155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '644' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Container Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Container Volume' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Container Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.22"
                 priority="6154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1349') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1349' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1349') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Available Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Available Specimen Volume' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Available Specimen Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.23"
                 priority="6153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1350') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1350' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1350') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Initial Specimen Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Initial Specimen Volume' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Initial Specimen Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24"
                 priority="6152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1351') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1351' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1351') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Volume Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Volume Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Volume Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.1"
                 priority="6150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.2"
                 priority="6149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.3"
                 priority="6148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.4"
                 priority="6146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.5"
                 priority="6145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/hl7v2:CE.6"
                 priority="6144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25"
                 priority="6142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1352') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1352' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1352') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70380') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70380' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70380') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Separator Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.1"
                 priority="6140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.2"
                 priority="6139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.3"
                 priority="6138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.4"
                 priority="6136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.5"
                 priority="6135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/hl7v2:CE.6"
                 priority="6134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26"
                 priority="6132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1353') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1353' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1353') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70381') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70381' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70381') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cap Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Cap Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Cap Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.1"
                 priority="6130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.2"
                 priority="6129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.3"
                 priority="6128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.4"
                 priority="6126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.5"
                 priority="6125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/hl7v2:CE.6"
                 priority="6124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27"
                 priority="6122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '647' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additive') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Additive' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Additive') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.1"
                 priority="6120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.2"
                 priority="6119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.3"
                 priority="6118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.4"
                 priority="6116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.5"
                 priority="6115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.6"
                 priority="6114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.7"
                 priority="6112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.8"
                 priority="6111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/hl7v2:CWE.9"
                 priority="6110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28"
                 priority="6109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1355') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1355' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1355') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Component') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Specimen Component' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Component') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.1"
                 priority="6107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.2"
                 priority="6106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.3"
                 priority="6105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.4"
                 priority="6103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.5"
                 priority="6102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/hl7v2:CE.6"
                 priority="6101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29"
                 priority="6099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1356') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1356' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1356') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dilution Factor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Dilution Factor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dilution Factor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.1"
                 priority="6097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.2"
                 priority="6096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.3"
                 priority="6095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/hl7v2:SN.4"
                 priority="6094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30"
                 priority="6093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1357') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1357' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1357') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70373') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70373' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70373') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Treatment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Treatment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Treatment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.1"
                 priority="6091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.2"
                 priority="6090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.3"
                 priority="6089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.4"
                 priority="6087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.5"
                 priority="6086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/hl7v2:CE.6"
                 priority="6085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31"
                 priority="6083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.1 komt te vaak voor [max 1x]. (count(hl7v2:SN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.2 komt te vaak voor [max 1x]. (count(hl7v2:SN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.3 komt te vaak voor [max 1x]. (count(hl7v2:SN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): element hl7v2:SN.4 komt te vaak voor [max 1x]. (count(hl7v2:SN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1358') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1358' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1358') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'SN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Temperature') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Temperature' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Temperature') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.1"
                 priority="6081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comparator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Comparator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comparator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.2"
                 priority="6080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.3"
                 priority="6079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separator/Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Separator/Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separator/Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/hl7v2:SN.4"
                 priority="6078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Num2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SN_datatype): de waarde van LongName MOET 'Num2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Num2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.59-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.32"
                 priority="6077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1359') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1359' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1359') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hemolysis Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Hemolysis Index' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Hemolysis Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33"
                 priority="6076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1360') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1360') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hemolysis Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Hemolysis Index Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Hemolysis Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.1"
                 priority="6074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.2"
                 priority="6073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.3"
                 priority="6072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.4"
                 priority="6070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.5"
                 priority="6069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/hl7v2:CE.6"
                 priority="6068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.34"
                 priority="6066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1361') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1361' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1361') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lipemia Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Lipemia Index' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Lipemia Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35"
                 priority="6065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1362') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1362' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1362') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Lipemia Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Lipemia Index Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Lipemia Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.1"
                 priority="6063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.2"
                 priority="6062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.3"
                 priority="6061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.4"
                 priority="6059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.5"
                 priority="6058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/hl7v2:CE.6"
                 priority="6057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.36"
                 priority="6055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1363') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1363') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Icterus Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Icterus Index' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Icterus Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37"
                 priority="6054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1364') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1364') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Icterus Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Icterus Index Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Icterus Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.1"
                 priority="6052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.2"
                 priority="6051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.3"
                 priority="6050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.4"
                 priority="6048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.5"
                 priority="6047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/hl7v2:CE.6"
                 priority="6046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.38"
                 priority="6044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1365') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1365' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1365') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fibrin Index') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Fibrin Index' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Fibrin Index') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39"
                 priority="6043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1366') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1366' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1366') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fibrin Index Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Fibrin Index Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Fibrin Index Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.1"
                 priority="6041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.2"
                 priority="6040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.3"
                 priority="6039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.4"
                 priority="6037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.5"
                 priority="6036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/hl7v2:CE.6"
                 priority="6035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40"
                 priority="6033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1367') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1367' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1367') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70374') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70374' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70374') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('System Induced Contaminants') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'System Induced Contaminants' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('System Induced Contaminants') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.1"
                 priority="6031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.2"
                 priority="6030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.3"
                 priority="6029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.4"
                 priority="6027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.5"
                 priority="6026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/hl7v2:CE.6"
                 priority="6025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41"
                 priority="6023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1368' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70382') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70382' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70382') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Drug Interference') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Drug Interference' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Drug Interference') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.1"
                 priority="6021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.2"
                 priority="6020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.3"
                 priority="6019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.4"
                 priority="6017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.5"
                 priority="6016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/hl7v2:CE.6"
                 priority="6015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42"
                 priority="6013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1369') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1369' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1369') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70375') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70375' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70375') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Artificial Blood') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Artificial Blood' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Artificial Blood') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.1"
                 priority="6011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.2"
                 priority="6010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.3"
                 priority="6009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.4"
                 priority="6007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.5"
                 priority="6006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/hl7v2:CE.6"
                 priority="6005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43"
                 priority="6003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1370') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1370' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1370') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70376') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70376' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70376') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Handling Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Special Handling Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Handling Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.1"
                 priority="6001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.2"
                 priority="6000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.3"
                 priority="5999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.4"
                 priority="5997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.5"
                 priority="5996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.6"
                 priority="5995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.7"
                 priority="5993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.8"
                 priority="5992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/hl7v2:CWE.9"
                 priority="5991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44"
                 priority="5990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1371') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Item MOET '1371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1371') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70377') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van Table MOET 'HL70377' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70377') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Environmental Factors') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAC_segment): de waarde van LongName MOET 'Other Environmental Factors' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Environmental Factors') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.133-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.1"
                 priority="5988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.2"
                 priority="5987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.3"
                 priority="5986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.4"
                 priority="5984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.5"
                 priority="5983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/hl7v2:CE.6"
                 priority="5982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX"
                 priority="5980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.8 komt te vaak voor [max 1x]. (count(hl7v2:OBX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.1"
                 priority="5979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.2"
                 priority="5978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3"
                 priority="5976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="5974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="5973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="5972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="5970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="5969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="5968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.4"
                 priority="5966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.5"
                 priority="5965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6"
                 priority="5964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="5962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="5961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="5960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="5958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="5957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="5956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.7"
                 priority="5954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.8"
                 priority="5953"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.9"
                 priority="5951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.10"
                 priority="5950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.11"
                 priority="5948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12"
                 priority="5946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="5944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="5943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.13"
                 priority="5941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14"
                 priority="5940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="5938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="5937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15"
                 priority="5935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="5933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="5932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="5931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="5929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="5928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="5927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16"
                 priority="5925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="5923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="5922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="5915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="5914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="5913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="5912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="5911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="5910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="5909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="5903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="5901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="5900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="5898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="5896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="5890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="5888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="5878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="5866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="5864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="5859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="5854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="5853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="5840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17"
                 priority="5827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="5825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="5824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="5823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="5821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="5820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="5819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18"
                 priority="5817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="5815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="5814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="5813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="5812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19"
                 priority="5810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="5808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="5807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3944-false-d292020e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT"
                 priority="5805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT_PRIOR) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT_PRIOR komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT_PRIOR) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.PATIENT_VISIT_PRIOR) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.PATIENT_VISIT_PRIOR komt te vaak voor [max 1x]. (count(hl7v2:OML_O21.PATIENT_VISIT_PRIOR) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.ORDER_PRIOR) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.ORDER_PRIOR is required [min 1x]. (count(hl7v2:OML_O21.ORDER_PRIOR) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3954-false-d292040e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR"
                 priority="5804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID is required [min 1x]. (count(hl7v2:PID) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PID komt te vaak voor [max 1x]. (count(hl7v2:PID) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PD1 komt te vaak voor [max 1x]. (count(hl7v2:PD1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID"
                 priority="5803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.1 komt te vaak voor [max 1x]. (count(hl7v2:PID.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.2 komt te vaak voor [max 1x]. (count(hl7v2:PID.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.3 is required [min 1x]. (count(hl7v2:PID.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.5) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.5 is required [min 1x]. (count(hl7v2:PID.5) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.7 komt te vaak voor [max 1x]. (count(hl7v2:PID.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.8 komt te vaak voor [max 1x]. (count(hl7v2:PID.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.12 komt te vaak voor [max 1x]. (count(hl7v2:PID.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.15 komt te vaak voor [max 1x]. (count(hl7v2:PID.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.16 komt te vaak voor [max 1x]. (count(hl7v2:PID.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.17 komt te vaak voor [max 1x]. (count(hl7v2:PID.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.18 komt te vaak voor [max 1x]. (count(hl7v2:PID.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.19 komt te vaak voor [max 1x]. (count(hl7v2:PID.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.20 komt te vaak voor [max 1x]. (count(hl7v2:PID.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.23 komt te vaak voor [max 1x]. (count(hl7v2:PID.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.24 komt te vaak voor [max 1x]. (count(hl7v2:PID.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.25 komt te vaak voor [max 1x]. (count(hl7v2:PID.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.27 komt te vaak voor [max 1x]. (count(hl7v2:PID.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.28 komt te vaak voor [max 1x]. (count(hl7v2:PID.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.29 komt te vaak voor [max 1x]. (count(hl7v2:PID.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.30 komt te vaak voor [max 1x]. (count(hl7v2:PID.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.31 komt te vaak voor [max 1x]. (count(hl7v2:PID.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.33 komt te vaak voor [max 1x]. (count(hl7v2:PID.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.34 komt te vaak voor [max 1x]. (count(hl7v2:PID.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.35 komt te vaak voor [max 1x]. (count(hl7v2:PID.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.36 komt te vaak voor [max 1x]. (count(hl7v2:PID.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.37 komt te vaak voor [max 1x]. (count(hl7v2:PID.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PID.38) &lt;= 2"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): element hl7v2:PID.38 komt te vaak voor [max 2x]. (count(hl7v2:PID.38) &lt;= 2 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.1"
                 priority="5802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('104') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '104' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('104') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Set ID - PID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2"
                 priority="5801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('105') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('105') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.1"
                 priority="5799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.2"
                 priority="5798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.3"
                 priority="5797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4"
                 priority="5795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.5"
                 priority="5789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6"
                 priority="5787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.7"
                 priority="5781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.8"
                 priority="5780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9"
                 priority="5779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10"
                 priority="5766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3"
                 priority="5753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('106') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '106' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('106') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Identifier List') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Identifier List' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Identifier List') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.1"
                 priority="5751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.2"
                 priority="5750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.3"
                 priority="5749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4"
                 priority="5747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.5"
                 priority="5741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6"
                 priority="5739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.7"
                 priority="5733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.8"
                 priority="5732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9"
                 priority="5731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10"
                 priority="5718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4"
                 priority="5705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('107') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '107' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('107') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Alternate Patient ID - PID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Patient ID - PID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.1"
                 priority="5703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.2"
                 priority="5702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.3"
                 priority="5701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4"
                 priority="5699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.5"
                 priority="5693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6"
                 priority="5691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.7"
                 priority="5685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.8"
                 priority="5684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9"
                 priority="5683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10"
                 priority="5670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5"
                 priority="5657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('108') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '108' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('108') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1"
                 priority="5655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="5653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="5652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="5651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="5650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="5649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.2"
                 priority="5648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.3"
                 priority="5647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.4"
                 priority="5646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.5"
                 priority="5645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.6"
                 priority="5644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.7"
                 priority="5643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.8"
                 priority="5641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9"
                 priority="5639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10"
                 priority="5629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.11"
                 priority="5617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12"
                 priority="5615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13"
                 priority="5610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.14"
                 priority="5605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6"
                 priority="5604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('109') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '109' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('109') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Maiden Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Mother''s Maiden Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Maiden Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1"
                 priority="5602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="5600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="5599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="5598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="5597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="5596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.2"
                 priority="5595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.3"
                 priority="5594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.4"
                 priority="5593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.5"
                 priority="5592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.6"
                 priority="5591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.7"
                 priority="5590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.8"
                 priority="5588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9"
                 priority="5586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10"
                 priority="5576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.11"
                 priority="5564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12"
                 priority="5562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13"
                 priority="5557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.14"
                 priority="5552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7"
                 priority="5551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('110') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '110' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('110') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Birth') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time of Birth' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of Birth') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.1"
                 priority="5549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7/hl7v2:TS.2"
                 priority="5548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.8"
                 priority="5546"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.1 Administrative Sex (2013-02-10T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.1-2013-02-10T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('111') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '111' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('111') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70001') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70001' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70001') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Administrative Sex') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Administrative Sex' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Administrative Sex') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9"
                 priority="5544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.1 komt te vaak voor [max 1x]. (count(hl7v2:XPN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.2 komt te vaak voor [max 1x]. (count(hl7v2:XPN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.3 komt te vaak voor [max 1x]. (count(hl7v2:XPN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.4 komt te vaak voor [max 1x]. (count(hl7v2:XPN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.5 komt te vaak voor [max 1x]. (count(hl7v2:XPN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.6 komt te vaak voor [max 1x]. (count(hl7v2:XPN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.7 komt te vaak voor [max 1x]. (count(hl7v2:XPN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.8 komt te vaak voor [max 1x]. (count(hl7v2:XPN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.9 komt te vaak voor [max 1x]. (count(hl7v2:XPN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.10 komt te vaak voor [max 1x]. (count(hl7v2:XPN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.11 komt te vaak voor [max 1x]. (count(hl7v2:XPN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.12 komt te vaak voor [max 1x]. (count(hl7v2:XPN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.13 komt te vaak voor [max 1x]. (count(hl7v2:XPN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XPN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): element hl7v2:XPN.14 komt te vaak voor [max 1x]. (count(hl7v2:XPN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('112') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '112' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('112') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XPN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XPN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XPN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Alias') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Alias' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Alias') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1"
                 priority="5542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.1"
                 priority="5540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.2"
                 priority="5539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.3"
                 priority="5538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.4"
                 priority="5537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/hl7v2:FN.5"
                 priority="5536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.2"
                 priority="5535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.3"
                 priority="5534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.4"
                 priority="5533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.5"
                 priority="5532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.6"
                 priority="5531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.7"
                 priority="5530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.8"
                 priority="5528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9"
                 priority="5526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.1"
                 priority="5524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.2"
                 priority="5523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.3"
                 priority="5522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.4"
                 priority="5520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.5"
                 priority="5519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/hl7v2:CE.6"
                 priority="5518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10"
                 priority="5516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1"
                 priority="5514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2"
                 priority="5509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.11"
                 priority="5504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12"
                 priority="5502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.1"
                 priority="5500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/hl7v2:TS.2"
                 priority="5499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13"
                 priority="5497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.1"
                 priority="5495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/hl7v2:TS.2"
                 priority="5494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.14"
                 priority="5492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XPN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.76-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10"
                 priority="5491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('113') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('113') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70005') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70005' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70005') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Race') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Race' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Race') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.1"
                 priority="5489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.2"
                 priority="5488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.3"
                 priority="5487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.4"
                 priority="5485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.5"
                 priority="5484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/hl7v2:CE.6"
                 priority="5483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11"
                 priority="5481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('114') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '114' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('114') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1"
                 priority="5479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="5477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="5476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="5475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.2"
                 priority="5474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.3"
                 priority="5473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.4"
                 priority="5472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.5"
                 priority="5471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.6"
                 priority="5470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.7"
                 priority="5468"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.8"
                 priority="5466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.9"
                 priority="5465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.10"
                 priority="5464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.11"
                 priority="5463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12"
                 priority="5461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="5459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="5454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13"
                 priority="5449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="5447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="5446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14"
                 priority="5444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="5442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="5441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.12"
                 priority="5439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('115') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '115' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('115') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'County Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13"
                 priority="5438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('116') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '116' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('116') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Home') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Phone Number - Home' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phone Number - Home') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.1"
                 priority="5436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.2"
                 priority="5435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.3"
                 priority="5433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.4"
                 priority="5431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.5"
                 priority="5430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.6"
                 priority="5429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.7"
                 priority="5428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.8"
                 priority="5427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.9"
                 priority="5426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.10"
                 priority="5425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.11"
                 priority="5424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/hl7v2:XTN.12"
                 priority="5423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14"
                 priority="5422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('117') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '117' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('117') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phone Number - Business') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Phone Number - Business' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phone Number - Business') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.1"
                 priority="5420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.2"
                 priority="5419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.3"
                 priority="5417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.4"
                 priority="5415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.5"
                 priority="5414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.6"
                 priority="5413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.7"
                 priority="5412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.8"
                 priority="5411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.9"
                 priority="5410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.10"
                 priority="5409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.11"
                 priority="5408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/hl7v2:XTN.12"
                 priority="5407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15"
                 priority="5406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('118') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '118' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('118') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70296') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70296' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70296') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Primary Language') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Primary Language' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Primary Language') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.1"
                 priority="5404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.2"
                 priority="5403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.3"
                 priority="5402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.4"
                 priority="5400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.5"
                 priority="5399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/hl7v2:CE.6"
                 priority="5398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16"
                 priority="5396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('119') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '119' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('119') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70002') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70002' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70002') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Marital Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Marital Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Marital Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.1"
                 priority="5394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.2"
                 priority="5393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.3"
                 priority="5392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.4"
                 priority="5390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.5"
                 priority="5389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/hl7v2:CE.6"
                 priority="5388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17"
                 priority="5386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('120') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '120' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('120') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70006') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70006' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70006') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Religion') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Religion' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Religion') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.1"
                 priority="5384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.2"
                 priority="5383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.3"
                 priority="5382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.4"
                 priority="5380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.5"
                 priority="5379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/hl7v2:CE.6"
                 priority="5378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18"
                 priority="5376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('121') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '121' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('121') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Account Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Account Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Account Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.1"
                 priority="5374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.2"
                 priority="5373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.3"
                 priority="5372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4"
                 priority="5370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.5"
                 priority="5364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6"
                 priority="5362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.7"
                 priority="5356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.8"
                 priority="5355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9"
                 priority="5354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10"
                 priority="5341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.19"
                 priority="5328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('122') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '122' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('122') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('SSN Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'SSN Number - Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('SSN Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20"
                 priority="5327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.1 komt te vaak voor [max 1x]. (count(hl7v2:DLN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.2 komt te vaak voor [max 1x]. (count(hl7v2:DLN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): element hl7v2:DLN.3 komt te vaak voor [max 1x]. (count(hl7v2:DLN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('123') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '123' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('123') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'DLN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DLN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Driver''s License Number - Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Driver''s License Number - Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.1"
                 priority="5325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('License Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van LongName MOET 'License Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('License Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.2"
                 priority="5324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70333') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Table MOET 'HL70333' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70333') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Issuing State, Province, Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van LongName MOET 'Issuing State, Province, Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Issuing State, Province, Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/hl7v2:DLN.3"
                 priority="5323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.16-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21"
                 priority="5322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('124') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '124' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('124') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mother''s Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Mother''s Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mother''s Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.1"
                 priority="5320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.2"
                 priority="5319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.3"
                 priority="5318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4"
                 priority="5316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.5"
                 priority="5310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6"
                 priority="5308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.7"
                 priority="5302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.8"
                 priority="5301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9"
                 priority="5300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="5288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10"
                 priority="5287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="5285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="5284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="5283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="5281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="5280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="5279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="5277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="5276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="5275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22"
                 priority="5274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('125') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('125') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70189') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70189') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ethnic Group') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Ethnic Group' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ethnic Group') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.1"
                 priority="5272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.2"
                 priority="5271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.3"
                 priority="5270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.4"
                 priority="5268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.5"
                 priority="5267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/hl7v2:CE.6"
                 priority="5266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.23"
                 priority="5264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('126') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '126' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('126') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Place') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Birth Place' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Birth Place') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.24"
                 priority="5263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('127') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '127' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('127') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Multiple Birth Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Multiple Birth Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Multiple Birth Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.25"
                 priority="5261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('128') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '128' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('128') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Birth Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Birth Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Birth Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26"
                 priority="5260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('129') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('129') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.1"
                 priority="5258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.2"
                 priority="5257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.3"
                 priority="5256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.4"
                 priority="5254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.5"
                 priority="5253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/hl7v2:CE.6"
                 priority="5252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27"
                 priority="5250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('130') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '130' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('130') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70172') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70172' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70172') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Veterans Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Veterans Military Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Veterans Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.1"
                 priority="5248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.2"
                 priority="5247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.3"
                 priority="5246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.4"
                 priority="5244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.5"
                 priority="5243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/hl7v2:CE.6"
                 priority="5242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28"
                 priority="5240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('739') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '739' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('739') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70212') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70212' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70212') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nationality') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Nationality' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nationality') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.1"
                 priority="5238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.2"
                 priority="5237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.3"
                 priority="5236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.4"
                 priority="5234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.5"
                 priority="5233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/hl7v2:CE.6"
                 priority="5232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29"
                 priority="5230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('740') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '740' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('740') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Death Date and Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Death Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.1"
                 priority="5228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29/hl7v2:TS.2"
                 priority="5227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.30"
                 priority="5225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('741') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '741' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('741') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Death Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Patient Death Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Death Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.31"
                 priority="5223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1535') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1535' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1535') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Unknown Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Identity Unknown Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identity Unknown Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.32"
                 priority="5221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1536') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1536' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1536') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70445') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70445' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70445') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identity Reliability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Identity Reliability Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identity Reliability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33"
                 priority="5220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1537') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1537' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1537') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Last Update Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Last Update Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.1"
                 priority="5218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33/hl7v2:TS.2"
                 priority="5217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34"
                 priority="5215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1538') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1538' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1538') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Last Update Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Last Update Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Last Update Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.1"
                 priority="5213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.2"
                 priority="5212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/hl7v2:HD.3"
                 priority="5211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35"
                 priority="5209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1539') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1539' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1539') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70446') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70446' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70446') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Species Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Species Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Species Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.1"
                 priority="5207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.2"
                 priority="5206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.3"
                 priority="5205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.4"
                 priority="5203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.5"
                 priority="5202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/hl7v2:CE.6"
                 priority="5201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36"
                 priority="5199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1540') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1540' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1540') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70447') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70447' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70447') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Breed Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Breed Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Breed Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.1"
                 priority="5197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.2"
                 priority="5196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.3"
                 priority="5195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.4"
                 priority="5193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.5"
                 priority="5192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/hl7v2:CE.6"
                 priority="5191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.37"
                 priority="5189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1541') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1541' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1541') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Strain') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Strain' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Strain') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38"
                 priority="5188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1542') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1542' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1542') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70429') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70429' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70429') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Production Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Production Class Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Production Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.1"
                 priority="5186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.2"
                 priority="5185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.3"
                 priority="5184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.4"
                 priority="5182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.5"
                 priority="5181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/hl7v2:CE.6"
                 priority="5180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39"
                 priority="5178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1840') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Item MOET '1840' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1840') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70171') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van Table MOET 'HL70171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70171') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Tribal Citizenship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PID_segment_Lab_algemeen): de waarde van LongName MOET 'Tribal Citizenship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Tribal Citizenship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.3-2015-07-21T114402.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.1"
                 priority="5176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.2"
                 priority="5175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.3"
                 priority="5174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.4"
                 priority="5172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.5"
                 priority="5171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.6"
                 priority="5170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.7"
                 priority="5168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.8"
                 priority="5167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/hl7v2:CWE.9"
                 priority="5166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1"
                 priority="5165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.2 komt te vaak voor [max 1x]. (count(hl7v2:PD1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.5 komt te vaak voor [max 1x]. (count(hl7v2:PD1.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.6 komt te vaak voor [max 1x]. (count(hl7v2:PD1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.7 komt te vaak voor [max 1x]. (count(hl7v2:PD1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.8 komt te vaak voor [max 1x]. (count(hl7v2:PD1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.9 komt te vaak voor [max 1x]. (count(hl7v2:PD1.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.11 komt te vaak voor [max 1x]. (count(hl7v2:PD1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.12 komt te vaak voor [max 1x]. (count(hl7v2:PD1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.13 komt te vaak voor [max 1x]. (count(hl7v2:PD1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.16 komt te vaak voor [max 1x]. (count(hl7v2:PD1.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.17 komt te vaak voor [max 1x]. (count(hl7v2:PD1.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.18 komt te vaak voor [max 1x]. (count(hl7v2:PD1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.19 komt te vaak voor [max 1x]. (count(hl7v2:PD1.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.20 komt te vaak voor [max 1x]. (count(hl7v2:PD1.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PD1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): element hl7v2:PD1.21 komt te vaak voor [max 1x]. (count(hl7v2:PD1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.1"
                 priority="5164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('755') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '755' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('755') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70223') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70223') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Dependency') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Living Dependency' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Dependency') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.2"
                 priority="5163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('742') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '742' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('742') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70220') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70220') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Arrangement') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Living Arrangement' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Arrangement') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3"
                 priority="5162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('756') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '756' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('756') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Primary Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Patient Primary Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Primary Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.1"
                 priority="5160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.2"
                 priority="5159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.3"
                 priority="5158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.4"
                 priority="5157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.5"
                 priority="5156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6"
                 priority="5154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.1"
                 priority="5152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.2"
                 priority="5151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/hl7v2:HD.3"
                 priority="5150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.7"
                 priority="5148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8"
                 priority="5146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.1"
                 priority="5144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.2"
                 priority="5143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/hl7v2:HD.3"
                 priority="5142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.9"
                 priority="5140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.10"
                 priority="5138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4"
                 priority="5137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('757') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '757' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('757') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Patient Primary Care Provider Name &amp; ID No.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Primary Care Provider Name &amp; ID No.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.1"
                 priority="5135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2"
                 priority="5134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="5132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="5131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="5130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="5129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="5128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.3"
                 priority="5127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.4"
                 priority="5126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.5"
                 priority="5125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.6"
                 priority="5124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.7"
                 priority="5123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.8"
                 priority="5122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9"
                 priority="5121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="5119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="5118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="5117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.10"
                 priority="5115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.11"
                 priority="5113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.12"
                 priority="5112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.13"
                 priority="5110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14"
                 priority="5108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="5106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="5105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="5104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.15"
                 priority="5102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16"
                 priority="5100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="5098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="5097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="5096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="5094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="5093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="5092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17"
                 priority="5090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="5088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="5086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="5085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="5083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="5081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="5080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.18"
                 priority="5078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19"
                 priority="5076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="5074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="5073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20"
                 priority="5071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="5069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="5068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.21"
                 priority="5066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22"
                 priority="5065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="5063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="5062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="5061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="5059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="5058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="5057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="5055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="5054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="5053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23"
                 priority="5052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="5050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="5049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="5048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="5046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="5045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="5044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="5042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="5041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="5040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.5"
                 priority="5039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('745') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '745' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('745') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70231') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70231') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Student Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Student Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Student Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.6"
                 priority="5038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('753') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '753' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('753') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70295') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70295' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70295') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Handicap') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Handicap' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Handicap') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.7"
                 priority="5037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '759' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70315' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Living Will Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.8"
                 priority="5036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '760' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Organ Donor Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.9"
                 priority="5035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('761') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '761' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('761') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Separate Bill') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Separate Bill' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Separate Bill') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10"
                 priority="5033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('762') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '762' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('762') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duplicate Patient') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Duplicate Patient' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Duplicate Patient') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.1"
                 priority="5031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.2"
                 priority="5030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.3"
                 priority="5029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4"
                 priority="5027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.1"
                 priority="5025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.2"
                 priority="5024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/hl7v2:HD.3"
                 priority="5023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.5"
                 priority="5021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6"
                 priority="5019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.1"
                 priority="5017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.2"
                 priority="5016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/hl7v2:HD.3"
                 priority="5015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.7"
                 priority="5013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.8"
                 priority="5012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9"
                 priority="5011"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="5009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="5008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="5007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="5005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="5004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="5003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="5001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="5000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10"
                 priority="4998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11"
                 priority="4985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('743') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '743' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('743') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.1"
                 priority="4983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.2"
                 priority="4982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.3"
                 priority="4981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.4"
                 priority="4979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.5"
                 priority="4978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/hl7v2:CE.6"
                 priority="4977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.12"
                 priority="4975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('744') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '744' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('744') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.13"
                 priority="4973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1566') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1566' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1566') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Protection Indicator Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Protection Indicator Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Protection Indicator Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14"
                 priority="4972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1567') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1567' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1567') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Place of Worship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Place of Worship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Place of Worship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.1"
                 priority="4970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.2"
                 priority="4969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.3"
                 priority="4968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.4"
                 priority="4967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.5"
                 priority="4966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6"
                 priority="4964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.1"
                 priority="4962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.2"
                 priority="4961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/hl7v2:HD.3"
                 priority="4960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.7"
                 priority="4958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8"
                 priority="4956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.1"
                 priority="4954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.2"
                 priority="4953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/hl7v2:HD.3"
                 priority="4952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.9"
                 priority="4950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.10"
                 priority="4948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15"
                 priority="4947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1568') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1568' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1568') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70435' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Advance Directive Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.1"
                 priority="4945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.2"
                 priority="4944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.3"
                 priority="4943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.4"
                 priority="4941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.5"
                 priority="4940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/hl7v2:CE.6"
                 priority="4939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.16"
                 priority="4937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70441') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70441' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70441') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Immunization Registry Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Immunization Registry Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Immunization Registry Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.17"
                 priority="4936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Immunization Registry Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Immunization Registry Status Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Immunization Registry Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.18"
                 priority="4935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Publicity Code Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Publicity Code Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Publicity Code Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.19"
                 priority="4934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70140') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70140' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70140') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Branch') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Military Branch' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Branch') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.20"
                 priority="4933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('486') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '486' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('486') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70141') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70141' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70141') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Rank/Grade') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Military Rank/Grade' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Rank/Grade') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.21"
                 priority="4932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Item MOET '1573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70142') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van Table MOET 'HL70142' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70142') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PD1_segment): de waarde van LongName MOET 'Military Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.96-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3961-false-d311434e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR"
                 priority="4931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 is required [min 1x]. (count(hl7v2:PV1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV1 komt te vaak voor [max 1x]. (count(hl7v2:PV1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:PV2 komt te vaak voor [max 1x]. (count(hl7v2:PV2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1"
                 priority="4930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.1 komt te vaak voor [max 1x]. (count(hl7v2:PV1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.2 is required [min 1x]. (count(hl7v2:PV1.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.2 komt te vaak voor [max 1x]. (count(hl7v2:PV1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.3 komt te vaak voor [max 1x]. (count(hl7v2:PV1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.4 komt te vaak voor [max 1x]. (count(hl7v2:PV1.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.5 komt te vaak voor [max 1x]. (count(hl7v2:PV1.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.6 komt te vaak voor [max 1x]. (count(hl7v2:PV1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.10 komt te vaak voor [max 1x]. (count(hl7v2:PV1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.11 komt te vaak voor [max 1x]. (count(hl7v2:PV1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.12 komt te vaak voor [max 1x]. (count(hl7v2:PV1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.13 komt te vaak voor [max 1x]. (count(hl7v2:PV1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.14 komt te vaak voor [max 1x]. (count(hl7v2:PV1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.16 komt te vaak voor [max 1x]. (count(hl7v2:PV1.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.18 komt te vaak voor [max 1x]. (count(hl7v2:PV1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.19 komt te vaak voor [max 1x]. (count(hl7v2:PV1.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.21 komt te vaak voor [max 1x]. (count(hl7v2:PV1.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.22 komt te vaak voor [max 1x]. (count(hl7v2:PV1.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.23 komt te vaak voor [max 1x]. (count(hl7v2:PV1.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.28 komt te vaak voor [max 1x]. (count(hl7v2:PV1.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.29 komt te vaak voor [max 1x]. (count(hl7v2:PV1.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.30 komt te vaak voor [max 1x]. (count(hl7v2:PV1.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.31 komt te vaak voor [max 1x]. (count(hl7v2:PV1.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.32 komt te vaak voor [max 1x]. (count(hl7v2:PV1.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.33 komt te vaak voor [max 1x]. (count(hl7v2:PV1.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.34 komt te vaak voor [max 1x]. (count(hl7v2:PV1.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.35 komt te vaak voor [max 1x]. (count(hl7v2:PV1.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.36 komt te vaak voor [max 1x]. (count(hl7v2:PV1.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.37 komt te vaak voor [max 1x]. (count(hl7v2:PV1.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.38 komt te vaak voor [max 1x]. (count(hl7v2:PV1.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.39) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.39 komt te vaak voor [max 1x]. (count(hl7v2:PV1.39) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.40 komt te vaak voor [max 1x]. (count(hl7v2:PV1.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.41 komt te vaak voor [max 1x]. (count(hl7v2:PV1.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.42 komt te vaak voor [max 1x]. (count(hl7v2:PV1.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.43) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.43 komt te vaak voor [max 1x]. (count(hl7v2:PV1.43) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.44 komt te vaak voor [max 1x]. (count(hl7v2:PV1.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.46) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.46 komt te vaak voor [max 1x]. (count(hl7v2:PV1.46) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.47 komt te vaak voor [max 1x]. (count(hl7v2:PV1.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.48 komt te vaak voor [max 1x]. (count(hl7v2:PV1.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.49) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.49 komt te vaak voor [max 1x]. (count(hl7v2:PV1.49) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.50) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.50 komt te vaak voor [max 1x]. (count(hl7v2:PV1.50) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV1.51) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): element hl7v2:PV1.51 komt te vaak voor [max 1x]. (count(hl7v2:PV1.51) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.1"
                 priority="4929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('131') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '131' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('131') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - PV1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Set ID - PV1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - PV1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.2"
                 priority="4928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('132') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '132' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('132') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70004') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70004' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70004') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Patient Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3"
                 priority="4927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '133' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Assigned Patient Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.1"
                 priority="4925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.2"
                 priority="4924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.3"
                 priority="4923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4"
                 priority="4922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.5"
                 priority="4916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.6"
                 priority="4915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.7"
                 priority="4914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.8"
                 priority="4913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.9"
                 priority="4912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10"
                 priority="4911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11"
                 priority="4904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.4"
                 priority="4898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('134') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '134' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('134') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70007') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70007' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70007') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admission Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Admission Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admission Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5"
                 priority="4897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('135') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '135' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('135') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preadmit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Preadmit Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Preadmit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.1"
                 priority="4895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.2"
                 priority="4894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.3"
                 priority="4893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4"
                 priority="4891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.5"
                 priority="4885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6"
                 priority="4883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.7"
                 priority="4877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.8"
                 priority="4876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9"
                 priority="4875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10"
                 priority="4862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6"
                 priority="4849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('136') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('136') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Prior Patient Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.1"
                 priority="4847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.2"
                 priority="4846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.3"
                 priority="4845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4"
                 priority="4844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.5"
                 priority="4838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.6"
                 priority="4837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.7"
                 priority="4836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.8"
                 priority="4835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.9"
                 priority="4834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10"
                 priority="4833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4828"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11"
                 priority="4826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7"
                 priority="4820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('137') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '137' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('137') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Attending Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Attending Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Attending Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.1"
                 priority="4818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2"
                 priority="4817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.3"
                 priority="4810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.4"
                 priority="4809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.5"
                 priority="4808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.6"
                 priority="4807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.7"
                 priority="4806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.8"
                 priority="4805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9"
                 priority="4804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.10"
                 priority="4798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.11"
                 priority="4796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.12"
                 priority="4795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.13"
                 priority="4793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14"
                 priority="4791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.15"
                 priority="4785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16"
                 priority="4783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17"
                 priority="4773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.18"
                 priority="4761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19"
                 priority="4759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20"
                 priority="4754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.21"
                 priority="4749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22"
                 priority="4748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23"
                 priority="4735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8"
                 priority="4722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('138') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '138' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('138') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Referring Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Referring Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Referring Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.1"
                 priority="4720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2"
                 priority="4719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.3"
                 priority="4712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.4"
                 priority="4711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.5"
                 priority="4710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.6"
                 priority="4709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.7"
                 priority="4708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.8"
                 priority="4707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9"
                 priority="4706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.10"
                 priority="4700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.11"
                 priority="4698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.12"
                 priority="4697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.13"
                 priority="4695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14"
                 priority="4693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.15"
                 priority="4687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16"
                 priority="4685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17"
                 priority="4675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.18"
                 priority="4663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19"
                 priority="4661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20"
                 priority="4656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.21"
                 priority="4651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22"
                 priority="4650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4647"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23"
                 priority="4637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9"
                 priority="4624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('139') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '139' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('139') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Consulting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Consulting Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Consulting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.1"
                 priority="4622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2"
                 priority="4621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.3"
                 priority="4614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.4"
                 priority="4613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.5"
                 priority="4612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.6"
                 priority="4611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.7"
                 priority="4610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.8"
                 priority="4609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9"
                 priority="4608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.10"
                 priority="4602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.11"
                 priority="4600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.12"
                 priority="4599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.13"
                 priority="4597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14"
                 priority="4595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.15"
                 priority="4589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16"
                 priority="4587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17"
                 priority="4577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.18"
                 priority="4565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19"
                 priority="4563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20"
                 priority="4558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.21"
                 priority="4553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22"
                 priority="4552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23"
                 priority="4539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.10"
                 priority="4526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('140') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '140' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('140') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70069') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70069' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70069') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Hospital Service') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Hospital Service' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Hospital Service') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11"
                 priority="4525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('141') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '141' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('141') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Temporary Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.1"
                 priority="4523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.2"
                 priority="4522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.3"
                 priority="4521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4"
                 priority="4520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.5"
                 priority="4514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.6"
                 priority="4513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.7"
                 priority="4512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.8"
                 priority="4511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.9"
                 priority="4510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10"
                 priority="4509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11"
                 priority="4502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4499"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.12"
                 priority="4496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('142') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '142' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('142') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70087') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70087' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70087') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Preadmit Test Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Preadmit Test Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Preadmit Test Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.13"
                 priority="4495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('143') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '143' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('143') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70092') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70092' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70092') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Re-admission Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Re-admission Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Re-admission Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.14"
                 priority="4494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('144') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '144' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('144') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70023') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70023' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70023') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Admit Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admit Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.15"
                 priority="4493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('145') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '145' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('145') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70009') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70009' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70009') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ambulatory Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Ambulatory Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ambulatory Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.16"
                 priority="4492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('146') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '146' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('146') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70099') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70099' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70099') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('VIP Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'VIP Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('VIP Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17"
                 priority="4491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('147') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '147' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('147') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admitting Doctor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Admitting Doctor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admitting Doctor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.1"
                 priority="4489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2"
                 priority="4488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.3"
                 priority="4481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.4"
                 priority="4480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.5"
                 priority="4479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.6"
                 priority="4478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.7"
                 priority="4477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.8"
                 priority="4476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9"
                 priority="4475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.10"
                 priority="4469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.11"
                 priority="4467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.12"
                 priority="4466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.13"
                 priority="4464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14"
                 priority="4462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.15"
                 priority="4456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16"
                 priority="4454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17"
                 priority="4444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.18"
                 priority="4432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19"
                 priority="4430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20"
                 priority="4425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.21"
                 priority="4420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22"
                 priority="4419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23"
                 priority="4406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4395"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.18"
                 priority="4393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '148' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70018' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Patient Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19"
                 priority="4392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('149') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '149' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('149') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Visit Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.1"
                 priority="4390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.2"
                 priority="4389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.3"
                 priority="4388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4"
                 priority="4386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.5"
                 priority="4380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6"
                 priority="4378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.7"
                 priority="4372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.8"
                 priority="4371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9"
                 priority="4370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10"
                 priority="4357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20"
                 priority="4344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.1 komt te vaak voor [max 1x]. (count(hl7v2:FC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): element hl7v2:FC.2 komt te vaak voor [max 1x]. (count(hl7v2:FC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('150') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '150' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('150') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'FC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Financial Class' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Financial Class') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.1"
                 priority="4342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70064') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Table MOET 'HL70064' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70064') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Financial Class Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van LongName MOET 'Financial Class Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Financial Class Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2"
                 priority="4341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FC_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.25-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.1"
                 priority="4339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/hl7v2:TS.2"
                 priority="4338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.21"
                 priority="4336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('151') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '151' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('151') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70032') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70032' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70032') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Price Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Charge Price Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge Price Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.22"
                 priority="4335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('152') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '152' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('152') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70045') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70045' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70045') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Courtesy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Courtesy Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Courtesy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.23"
                 priority="4334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('153') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '153' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('153') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70046') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70046' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70046') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Credit Rating') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Credit Rating' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Credit Rating') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.24"
                 priority="4333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('154') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '154' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('154') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70044') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70044' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70044') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Contract Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.25"
                 priority="4332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('155') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '155' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('155') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Contract Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.26"
                 priority="4331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('156') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '156' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('156') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Contract Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.27"
                 priority="4330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('157') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '157' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('157') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Contract Period') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Contract Period' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Contract Period') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.28"
                 priority="4329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('158') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '158' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('158') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70073') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70073' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70073') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interest Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Interest Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Interest Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.29"
                 priority="4328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('159') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '159' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('159') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70110') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70110' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70110') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer to Bad Debt Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Transfer to Bad Debt Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transfer to Bad Debt Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.30"
                 priority="4327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('160') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '160' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('160') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer to Bad Debt Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Transfer to Bad Debt Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transfer to Bad Debt Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.31"
                 priority="4326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('161') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '161' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('161') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70021') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70021' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70021') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Agency Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Bad Debt Agency Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bad Debt Agency Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.32"
                 priority="4325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('162') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '162' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('162') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Transfer Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Bad Debt Transfer Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bad Debt Transfer Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.33"
                 priority="4324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('163') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '163' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('163') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bad Debt Recovery Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Bad Debt Recovery Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bad Debt Recovery Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.34"
                 priority="4323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('164') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '164' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('164') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70111') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70111' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70111') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delete Account Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Delete Account Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Delete Account Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.35"
                 priority="4322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('165') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '165' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('165') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Delete Account Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Delete Account Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Delete Account Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.36"
                 priority="4321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('166') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '166' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('166') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70112' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Discharge Disposition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37"
                 priority="4320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.1 komt te vaak voor [max 1x]. (count(hl7v2:DLD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DLD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): element hl7v2:DLD.2 komt te vaak voor [max 1x]. (count(hl7v2:DLD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('167') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '167' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('167') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DLD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'DLD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DLD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharged to Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Discharged to Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharged to Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.1"
                 priority="4318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70113') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van Table MOET 'HL70113' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70113') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van LongName MOET 'Discharge Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharge Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2"
                 priority="4317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DLD_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.1"
                 priority="4315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/hl7v2:TS.2"
                 priority="4314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38"
                 priority="4312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('168') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '168' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('168') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70114') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70114' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70114') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diet Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Diet Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diet Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.1"
                 priority="4310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.2"
                 priority="4309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.3"
                 priority="4308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.4"
                 priority="4306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.5"
                 priority="4305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/hl7v2:CE.6"
                 priority="4304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.39"
                 priority="4302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('169') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '169' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('169') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70115') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70115' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70115') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Servicing Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Servicing Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Servicing Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.40"
                 priority="4301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('170') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '170' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('170') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70116') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70116' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70116') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Bed Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.41"
                 priority="4300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('171') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '171' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('171') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70117') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70117' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70117') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Account Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Account Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Account Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42"
                 priority="4299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('172') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '172' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('172') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Pending Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.1"
                 priority="4297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.2"
                 priority="4296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.3"
                 priority="4295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4"
                 priority="4294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.5"
                 priority="4288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.6"
                 priority="4287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.7"
                 priority="4286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.8"
                 priority="4285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.9"
                 priority="4284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10"
                 priority="4283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11"
                 priority="4276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43"
                 priority="4270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('173') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '173' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('173') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Temporary Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Prior Temporary Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Temporary Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.1"
                 priority="4268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.2"
                 priority="4267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.3"
                 priority="4266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4"
                 priority="4265"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.5"
                 priority="4259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.6"
                 priority="4258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.7"
                 priority="4257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.8"
                 priority="4256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.9"
                 priority="4255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10"
                 priority="4254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11"
                 priority="4247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44"
                 priority="4241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('174') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '174' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('174') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Admit Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.1"
                 priority="4239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44/hl7v2:TS.2"
                 priority="4238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45"
                 priority="4236"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('175') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '175' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('175') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Discharge Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.1"
                 priority="4234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45/hl7v2:TS.2"
                 priority="4233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.46"
                 priority="4231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('176') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '176' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('176') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Current Patient Balance') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Current Patient Balance' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Current Patient Balance') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.47"
                 priority="4230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('177') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '177' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('177') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Charges') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Total Charges' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Charges') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.48"
                 priority="4229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('178') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '178' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('178') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Adjustments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Total Adjustments' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Adjustments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.49"
                 priority="4228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('179') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '179' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('179') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Payments') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Total Payments' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Payments') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50"
                 priority="4227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('180') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '180' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('180') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Visit ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Alternate Visit ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Visit ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.1"
                 priority="4225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.2"
                 priority="4224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.3"
                 priority="4223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4"
                 priority="4221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.1"
                 priority="4219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.2"
                 priority="4218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/hl7v2:HD.3"
                 priority="4217"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.5"
                 priority="4215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6"
                 priority="4213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.1"
                 priority="4211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.2"
                 priority="4210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/hl7v2:HD.3"
                 priority="4209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.7"
                 priority="4207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.8"
                 priority="4206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9"
                 priority="4205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="4203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="4202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="4201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="4199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="4198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="4197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="4195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="4194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="4193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10"
                 priority="4192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="4190"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="4189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="4188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="4186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="4185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="4184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="4182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="4181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="4180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.51"
                 priority="4179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '1226' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70326') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70326' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70326') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Visit Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52"
                 priority="4178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1274') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Item MOET '1274' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1274') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70010') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van Table MOET 'HL70010' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70010') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Healthcare Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV1_segment): de waarde van LongName MOET 'Other Healthcare Provider' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Healthcare Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.109-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.1"
                 priority="4176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2"
                 priority="4175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="4173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="4172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="4171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="4170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="4169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.3"
                 priority="4168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.4"
                 priority="4167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.5"
                 priority="4166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.6"
                 priority="4165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.7"
                 priority="4164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.8"
                 priority="4163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9"
                 priority="4162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="4160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="4159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="4158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.10"
                 priority="4156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.11"
                 priority="4154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.12"
                 priority="4153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.13"
                 priority="4151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14"
                 priority="4149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="4147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="4146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="4145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.15"
                 priority="4143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16"
                 priority="4141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="4139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="4138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="4137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="4135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="4134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="4133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17"
                 priority="4131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="4129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="4127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="4126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="4124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="4122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="4121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.18"
                 priority="4119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19"
                 priority="4117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="4115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="4114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20"
                 priority="4112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="4110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="4109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.21"
                 priority="4107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22"
                 priority="4106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="4104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="4103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="4102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="4100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="4099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="4098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="4096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="4095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="4094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23"
                 priority="4093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="4091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="4090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="4089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="4087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="4086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="4085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="4083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="4082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="4081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2"
                 priority="4080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.1 komt te vaak voor [max 1x]. (count(hl7v2:PV2.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.2 komt te vaak voor [max 1x]. (count(hl7v2:PV2.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.3 komt te vaak voor [max 1x]. (count(hl7v2:PV2.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.4 komt te vaak voor [max 1x]. (count(hl7v2:PV2.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.6 komt te vaak voor [max 1x]. (count(hl7v2:PV2.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.8 komt te vaak voor [max 1x]. (count(hl7v2:PV2.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.9 komt te vaak voor [max 1x]. (count(hl7v2:PV2.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.10 komt te vaak voor [max 1x]. (count(hl7v2:PV2.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.11 komt te vaak voor [max 1x]. (count(hl7v2:PV2.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.12 komt te vaak voor [max 1x]. (count(hl7v2:PV2.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.14 komt te vaak voor [max 1x]. (count(hl7v2:PV2.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.15 komt te vaak voor [max 1x]. (count(hl7v2:PV2.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.16 komt te vaak voor [max 1x]. (count(hl7v2:PV2.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.17 komt te vaak voor [max 1x]. (count(hl7v2:PV2.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.18 komt te vaak voor [max 1x]. (count(hl7v2:PV2.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.19 komt te vaak voor [max 1x]. (count(hl7v2:PV2.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.20 komt te vaak voor [max 1x]. (count(hl7v2:PV2.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.21 komt te vaak voor [max 1x]. (count(hl7v2:PV2.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.22 komt te vaak voor [max 1x]. (count(hl7v2:PV2.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.24 komt te vaak voor [max 1x]. (count(hl7v2:PV2.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.25 komt te vaak voor [max 1x]. (count(hl7v2:PV2.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.26 komt te vaak voor [max 1x]. (count(hl7v2:PV2.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.27 komt te vaak voor [max 1x]. (count(hl7v2:PV2.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.28 komt te vaak voor [max 1x]. (count(hl7v2:PV2.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.29 komt te vaak voor [max 1x]. (count(hl7v2:PV2.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.30 komt te vaak voor [max 1x]. (count(hl7v2:PV2.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.31) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.31 komt te vaak voor [max 1x]. (count(hl7v2:PV2.31) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.32 komt te vaak voor [max 1x]. (count(hl7v2:PV2.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.33) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.33 komt te vaak voor [max 1x]. (count(hl7v2:PV2.33) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.34) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.34 komt te vaak voor [max 1x]. (count(hl7v2:PV2.34) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.35) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.35 komt te vaak voor [max 1x]. (count(hl7v2:PV2.35) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.36 komt te vaak voor [max 1x]. (count(hl7v2:PV2.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.37 komt te vaak voor [max 1x]. (count(hl7v2:PV2.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.38) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.38 komt te vaak voor [max 1x]. (count(hl7v2:PV2.38) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.40 komt te vaak voor [max 1x]. (count(hl7v2:PV2.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.42 komt te vaak voor [max 1x]. (count(hl7v2:PV2.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.43) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.43 komt te vaak voor [max 1x]. (count(hl7v2:PV2.43) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.44 komt te vaak voor [max 1x]. (count(hl7v2:PV2.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.46) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.46 komt te vaak voor [max 1x]. (count(hl7v2:PV2.46) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.47) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.47 komt te vaak voor [max 1x]. (count(hl7v2:PV2.47) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PV2.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): element hl7v2:PV2.48 komt te vaak voor [max 1x]. (count(hl7v2:PV2.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1"
                 priority="4079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('181') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '181' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('181') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prior Pending Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Prior Pending Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prior Pending Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.1"
                 priority="4077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.2"
                 priority="4076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.3"
                 priority="4075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4"
                 priority="4074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.1"
                 priority="4072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.2"
                 priority="4071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/hl7v2:HD.3"
                 priority="4070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.5"
                 priority="4068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.6"
                 priority="4067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.7"
                 priority="4066"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.8"
                 priority="4065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.9"
                 priority="4064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10"
                 priority="4063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.1"
                 priority="4061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.2"
                 priority="4060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.3"
                 priority="4059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/hl7v2:EI.4"
                 priority="4058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11"
                 priority="4056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.1"
                 priority="4054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.2"
                 priority="4053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/hl7v2:HD.3"
                 priority="4052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2"
                 priority="4050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('182') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '182' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('182') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70129') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70129' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70129') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Accommodation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Accommodation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Accommodation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.1"
                 priority="4048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.2"
                 priority="4047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.3"
                 priority="4046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.4"
                 priority="4044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.5"
                 priority="4043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/hl7v2:CE.6"
                 priority="4042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3"
                 priority="4040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('183') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '183' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('183') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admit Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Admit Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admit Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.1"
                 priority="4038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.2"
                 priority="4037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.3"
                 priority="4036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.4"
                 priority="4034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.5"
                 priority="4033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/hl7v2:CE.6"
                 priority="4032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4"
                 priority="4030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('184') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '184' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('184') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transfer Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Transfer Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transfer Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.1"
                 priority="4028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.2"
                 priority="4027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.3"
                 priority="4026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.4"
                 priority="4024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.5"
                 priority="4023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/hl7v2:CE.6"
                 priority="4022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.5"
                 priority="4020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('185') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '185' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('185') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Valuables') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Valuables' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Valuables') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.6"
                 priority="4019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('186') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '186' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('186') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Valuables Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Valuables Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Valuables Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.7"
                 priority="4018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('187') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '187' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('187') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70130') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70130' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70130') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit User Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit User Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit User Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8"
                 priority="4017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('188') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '188' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('188') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Admit Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Admit Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Admit Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.1"
                 priority="4015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8/hl7v2:TS.2"
                 priority="4014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9"
                 priority="4012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('189') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '189' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('189') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Discharge Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Discharge Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Discharge Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.1"
                 priority="4010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9/hl7v2:TS.2"
                 priority="4009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.10"
                 priority="4007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('711') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '711' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('711') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Estimated Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Estimated Length of Inpatient Stay' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Estimated Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.11"
                 priority="4006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('712') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '712' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('712') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Actual Length of Inpatient Stay') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Actual Length of Inpatient Stay' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Actual Length of Inpatient Stay') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.12"
                 priority="4005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('713') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '713' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('713') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13"
                 priority="4004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('714') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '714' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('714') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Referral Source Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Referral Source Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Referral Source Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.1"
                 priority="4002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2"
                 priority="4001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3998"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.3"
                 priority="3994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.4"
                 priority="3993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.5"
                 priority="3992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.6"
                 priority="3991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.7"
                 priority="3990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.8"
                 priority="3989"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9"
                 priority="3988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3985"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.10"
                 priority="3982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.11"
                 priority="3980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.12"
                 priority="3979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.13"
                 priority="3977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14"
                 priority="3975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3971"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.15"
                 priority="3969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16"
                 priority="3967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17"
                 priority="3957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.18"
                 priority="3945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19"
                 priority="3943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20"
                 priority="3938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.21"
                 priority="3933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22"
                 priority="3932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23"
                 priority="3919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3916"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.14"
                 priority="3906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('715') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '715' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('715') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Previous Service Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Previous Service Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Previous Service Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.15"
                 priority="3905"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('716') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '716' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('716') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Employment Illness Related Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Employment Illness Related Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Employment Illness Related Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.16"
                 priority="3903"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('717') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '717' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('717') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70213') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70213' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70213') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Purge Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Purge Status Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Purge Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.17"
                 priority="3902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('718') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '718' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('718') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Purge Status Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Purge Status Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Purge Status Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.18"
                 priority="3901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('719') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '719' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('719') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70214') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70214' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70214') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Program Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Special Program Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Program Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.19"
                 priority="3900"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('720') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '720' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('720') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Retention Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Retention Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Retention Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.20"
                 priority="3898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('721') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '721' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('721') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Number of Insurance Plans') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Number of Insurance Plans' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Number of Insurance Plans') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.21"
                 priority="3897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('722') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '722' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('722') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70215') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70215') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Publicity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Publicity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Publicity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.22"
                 priority="3896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('723') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '723' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('723') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Protection Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Protection Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Protection Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23"
                 priority="3894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('724') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '724' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('724') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Clinic Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Clinic Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Clinic Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.1"
                 priority="3892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.2"
                 priority="3891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.3"
                 priority="3890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.4"
                 priority="3889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.5"
                 priority="3888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6"
                 priority="3886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.1"
                 priority="3884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.2"
                 priority="3883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/hl7v2:HD.3"
                 priority="3882"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.7"
                 priority="3880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8"
                 priority="3878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.1"
                 priority="3876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.2"
                 priority="3875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/hl7v2:HD.3"
                 priority="3874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.9"
                 priority="3872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.10"
                 priority="3870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.24"
                 priority="3869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('725') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '725' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('725') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70216') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70216' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70216') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Status Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Status Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Status Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.25"
                 priority="3868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('726') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '726' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('726') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70217') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70217') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Visit Priority Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Visit Priority Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Visit Priority Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.26"
                 priority="3867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('727') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '727' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('727') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Previous Treatment Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Previous Treatment Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Previous Treatment Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.27"
                 priority="3866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('728') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '728' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('728') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70112') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70112' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70112') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Discharge Disposition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Discharge Disposition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Discharge Disposition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.28"
                 priority="3865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('729') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '729' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('729') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Signature on File Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Signature on File Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Signature on File Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.29"
                 priority="3864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('730') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '730' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('730') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('First Similar Illness Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'First Similar Illness Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('First Similar Illness Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30"
                 priority="3863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('731') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '731' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('731') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70218') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70218' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70218') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Charge Adjustment Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Charge Adjustment Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Charge Adjustment Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.1"
                 priority="3861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.2"
                 priority="3860"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.3"
                 priority="3859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.4"
                 priority="3857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.5"
                 priority="3856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/hl7v2:CE.6"
                 priority="3855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.31"
                 priority="3853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('732') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '732' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('732') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70219') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70219' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70219') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Recurring Service Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Recurring Service Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Recurring Service Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.32"
                 priority="3852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('733') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '733' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('733') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Billing Media Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Billing Media Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Billing Media Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33"
                 priority="3850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('734') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '734' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('734') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Surgery Date and Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Surgery Date and Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Surgery Date and Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.1"
                 priority="3848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33/hl7v2:TS.2"
                 priority="3847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.34"
                 priority="3845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('735') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '735' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('735') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Partnership Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Military Partnership Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Partnership Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.35"
                 priority="3843"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('736') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '736' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('736') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Military Non-Availability Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Military Non-Availability Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Military Non-Availability Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.36"
                 priority="3841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('737') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '737' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('737') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Newborn Baby Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Newborn Baby Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Newborn Baby Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.37"
                 priority="3839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('738') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '738' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('738') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Baby Detained Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Baby Detained Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Baby Detained Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38"
                 priority="3837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1543') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1543' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1543') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70430') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70430' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70430') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Mode of Arrival Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Mode of Arrival Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Mode of Arrival Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.1"
                 priority="3835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.2"
                 priority="3834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.3"
                 priority="3833"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.4"
                 priority="3831"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.5"
                 priority="3830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/hl7v2:CE.6"
                 priority="3829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39"
                 priority="3827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1544') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1544' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1544') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70431') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70431' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70431') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Recreational Drug Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Recreational Drug Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Recreational Drug Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.1"
                 priority="3825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.2"
                 priority="3824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.3"
                 priority="3823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.4"
                 priority="3821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.5"
                 priority="3820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/hl7v2:CE.6"
                 priority="3819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40"
                 priority="3817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1545') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1545' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1545') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70432') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70432' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70432') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Admission Level of Care Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Admission Level of Care Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Admission Level of Care Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.1"
                 priority="3815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.2"
                 priority="3814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.3"
                 priority="3813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.4"
                 priority="3811"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.5"
                 priority="3810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/hl7v2:CE.6"
                 priority="3809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41"
                 priority="3807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1546') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1546' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1546') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70433') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70433' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70433') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Precaution Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Precaution Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Precaution Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.1"
                 priority="3805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.2"
                 priority="3804"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.3"
                 priority="3803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.4"
                 priority="3801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.5"
                 priority="3800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/hl7v2:CE.6"
                 priority="3799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42"
                 priority="3797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1547') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1547' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1547') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70434') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70434' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70434') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Condition Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.1"
                 priority="3795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.2"
                 priority="3794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.3"
                 priority="3793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.4"
                 priority="3791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.5"
                 priority="3790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/hl7v2:CE.6"
                 priority="3789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.43"
                 priority="3787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('759') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '759' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('759') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70315') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70315' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70315') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Living Will Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Living Will Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Living Will Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.44"
                 priority="3786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('760') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '760' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('760') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70316') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70316') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organ Donor Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Organ Donor Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organ Donor Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45"
                 priority="3785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1548') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1548' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1548') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70435') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70435' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70435') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advance Directive Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Advance Directive Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advance Directive Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.1"
                 priority="3783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.2"
                 priority="3782"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.3"
                 priority="3781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.4"
                 priority="3779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.5"
                 priority="3778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/hl7v2:CE.6"
                 priority="3777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.46"
                 priority="3775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1549') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1549' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1549') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Status Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Patient Status Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Status Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47"
                 priority="3774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1550') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1550' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1550') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected LOA Return Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected LOA Return Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected LOA Return Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.1"
                 priority="3772"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47/hl7v2:TS.2"
                 priority="3771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48"
                 priority="3769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1841') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1841' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1841') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expected Pre-admission Testing Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Expected Pre-admission Testing Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expected Pre-admission Testing Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.1"
                 priority="3767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48/hl7v2:TS.2"
                 priority="3766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.49"
                 priority="3764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1842') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Item MOET '1842' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1842') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70534') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van Table MOET 'HL70534' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70534') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Notify Clergy Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PV2_segment): de waarde van LongName MOET 'Notify Clergy Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Notify Clergy Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.110-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1"
                 priority="3763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.1 is required [min 1x]. (count(hl7v2:AL1.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.1 komt te vaak voor [max 1x]. (count(hl7v2:AL1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.2 komt te vaak voor [max 1x]. (count(hl7v2:AL1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.3 is required [min 1x]. (count(hl7v2:AL1.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.3 komt te vaak voor [max 1x]. (count(hl7v2:AL1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.4 komt te vaak voor [max 1x]. (count(hl7v2:AL1.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:AL1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): element hl7v2:AL1.6 komt te vaak voor [max 1x]. (count(hl7v2:AL1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.1"
                 priority="3762"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('203') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Item MOET '203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('203') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - AL1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van LongName MOET 'Set ID - AL1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - AL1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2"
                 priority="3761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('204') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Item MOET '204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('204') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70127') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Table MOET 'HL70127' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70127') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergen Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van LongName MOET 'Allergen Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergen Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.1"
                 priority="3759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.2"
                 priority="3758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.3"
                 priority="3757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.4"
                 priority="3755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.5"
                 priority="3754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/hl7v2:CE.6"
                 priority="3753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3"
                 priority="3751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('205') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Item MOET '205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('205') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergen Code/Mnemonic/Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van LongName MOET 'Allergen Code/Mnemonic/Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergen Code/Mnemonic/Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.1"
                 priority="3749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.2"
                 priority="3748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.3"
                 priority="3747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.4"
                 priority="3745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.5"
                 priority="3744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/hl7v2:CE.6"
                 priority="3743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4"
                 priority="3741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('206') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Item MOET '206' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('206') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70128') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Table MOET 'HL70128' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70128') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergy Severity Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van LongName MOET 'Allergy Severity Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergy Severity Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.1"
                 priority="3739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.2"
                 priority="3738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.3"
                 priority="3737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.4"
                 priority="3735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.5"
                 priority="3734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/hl7v2:CE.6"
                 priority="3733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.5"
                 priority="3731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('207') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Item MOET '207' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('207') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Allergy Reaction Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van LongName MOET 'Allergy Reaction Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Allergy Reaction Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.6"
                 priority="3730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('208') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Item MOET '208' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('208') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identification Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(AL1_segment): de waarde van LongName MOET 'Identification Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identification Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3971-false-d338705e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR"
                 priority="3729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:ORC komt te vaak voor [max 1x]. (count(hl7v2:ORC) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR is required [min 1x]. (count(hl7v2:OBR) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBR komt te vaak voor [max 1x]. (count(hl7v2:OBR) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OML_O21.OBSERVATION_PRIOR) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OML_O21.OBSERVATION_PRIOR is required [min 1x]. (count(hl7v2:OML_O21.OBSERVATION_PRIOR) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC"
                 priority="3728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.1 is required [min 1x]. (count(hl7v2:ORC.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.1 komt te vaak voor [max 1x]. (count(hl7v2:ORC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.2 is required [min 1x]. (count(hl7v2:ORC.2) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.2 komt te vaak voor [max 1x]. (count(hl7v2:ORC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.3 komt te vaak voor [max 1x]. (count(hl7v2:ORC.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.4 komt te vaak voor [max 1x]. (count(hl7v2:ORC.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.5 komt te vaak voor [max 1x]. (count(hl7v2:ORC.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.6 komt te vaak voor [max 1x]. (count(hl7v2:ORC.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.8 komt te vaak voor [max 1x]. (count(hl7v2:ORC.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.9 komt te vaak voor [max 1x]. (count(hl7v2:ORC.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.13 komt te vaak voor [max 1x]. (count(hl7v2:ORC.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.15 komt te vaak voor [max 1x]. (count(hl7v2:ORC.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.16 komt te vaak voor [max 1x]. (count(hl7v2:ORC.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.17 komt te vaak voor [max 1x]. (count(hl7v2:ORC.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.18 komt te vaak voor [max 1x]. (count(hl7v2:ORC.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.20 komt te vaak voor [max 1x]. (count(hl7v2:ORC.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.25 komt te vaak voor [max 1x]. (count(hl7v2:ORC.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.26 komt te vaak voor [max 1x]. (count(hl7v2:ORC.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.27 komt te vaak voor [max 1x]. (count(hl7v2:ORC.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.28 komt te vaak voor [max 1x]. (count(hl7v2:ORC.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.29 komt te vaak voor [max 1x]. (count(hl7v2:ORC.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:ORC.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): element hl7v2:ORC.30 komt te vaak voor [max 1x]. (count(hl7v2:ORC.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.1"
                 priority="3727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('215') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '215' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('215') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70119') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70119' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70119') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Control' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Control') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2"
                 priority="3725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.1"
                 priority="3723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.2"
                 priority="3722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.3"
                 priority="3721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/hl7v2:EI.4"
                 priority="3720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3"
                 priority="3718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.1"
                 priority="3716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.2"
                 priority="3715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.3"
                 priority="3714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/hl7v2:EI.4"
                 priority="3713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4"
                 priority="3711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('218') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '218' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('218') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Placer Group Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.1"
                 priority="3709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.2"
                 priority="3708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.3"
                 priority="3707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/hl7v2:EI.4"
                 priority="3706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.5"
                 priority="3704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('219') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '219' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('219') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70038') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70038' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70038') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.6"
                 priority="3702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('220') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '220' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('220') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70121') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70121' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70121') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Response Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Response Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Response Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7"
                 priority="3700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1"
                 priority="3698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="3696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="3695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="3693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="3692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="3691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="3689"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="3688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="3687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2"
                 priority="3685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="3683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="3682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.3"
                 priority="3681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4"
                 priority="3680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="3678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="3677"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5"
                 priority="3675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="3673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="3672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.6"
                 priority="3670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.7"
                 priority="3669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8"
                 priority="3668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape"
                 priority="3667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="3666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="3665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.9"
                 priority="3664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10"
                 priority="3662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="3660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="3658"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="3657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="3656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="3655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="3654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="3653"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="3652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="3651"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="3649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="3648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11"
                 priority="3646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="3644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="3643"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="3642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="3640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="3639"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="3638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.12"
                 priority="3636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8"
                 priority="3635"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('222') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '222' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('222') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1"
                 priority="3633"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="3631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="3630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="3629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="3628"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2"
                 priority="3626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="3624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="3623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="3622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="3621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9"
                 priority="3619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('223') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '223' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('223') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of Transaction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Date/Time of Transaction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of Transaction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.1"
                 priority="3617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9/hl7v2:TS.2"
                 priority="3616"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10"
                 priority="3614"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('224') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '224' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('224') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entered By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Entered By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entered By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.1"
                 priority="3612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2"
                 priority="3611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3608"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.3"
                 priority="3604"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.4"
                 priority="3603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.5"
                 priority="3602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.6"
                 priority="3601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.7"
                 priority="3600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.8"
                 priority="3599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9"
                 priority="3598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.10"
                 priority="3592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.11"
                 priority="3590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.12"
                 priority="3589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.13"
                 priority="3587"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14"
                 priority="3585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.15"
                 priority="3579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16"
                 priority="3577"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17"
                 priority="3567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.18"
                 priority="3555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19"
                 priority="3553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20"
                 priority="3548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3546"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.21"
                 priority="3543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22"
                 priority="3542"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3538"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3534"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3530"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23"
                 priority="3529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11"
                 priority="3516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('225') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '225' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('225') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Verified By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Verified By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Verified By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.1"
                 priority="3514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2"
                 priority="3513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.3"
                 priority="3506"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.4"
                 priority="3505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.5"
                 priority="3504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.6"
                 priority="3503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.7"
                 priority="3502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.8"
                 priority="3501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9"
                 priority="3500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.10"
                 priority="3494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.11"
                 priority="3492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.12"
                 priority="3491"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.13"
                 priority="3489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14"
                 priority="3487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3483"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.15"
                 priority="3481"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16"
                 priority="3479"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17"
                 priority="3469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3467"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.18"
                 priority="3457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19"
                 priority="3455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20"
                 priority="3450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.21"
                 priority="3445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22"
                 priority="3444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23"
                 priority="3431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3427"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12"
                 priority="3418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.1"
                 priority="3416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2"
                 priority="3415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.3"
                 priority="3408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.4"
                 priority="3407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.5"
                 priority="3406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.6"
                 priority="3405"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.7"
                 priority="3404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.8"
                 priority="3403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9"
                 priority="3402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.10"
                 priority="3396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.11"
                 priority="3394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.12"
                 priority="3393"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.13"
                 priority="3391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14"
                 priority="3389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3385"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.15"
                 priority="3383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16"
                 priority="3381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3378"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17"
                 priority="3371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3369"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3361"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.18"
                 priority="3359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19"
                 priority="3357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3354"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20"
                 priority="3352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.21"
                 priority="3347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22"
                 priority="3346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23"
                 priority="3333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3330"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13"
                 priority="3320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('227') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '227' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('227') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer''s Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Enterer''s Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Enterer''s Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.1"
                 priority="3318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.2"
                 priority="3317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.3"
                 priority="3316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4"
                 priority="3315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.1"
                 priority="3313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.2"
                 priority="3312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/hl7v2:HD.3"
                 priority="3311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.5"
                 priority="3309"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.6"
                 priority="3308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.7"
                 priority="3307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.8"
                 priority="3306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.9"
                 priority="3305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10"
                 priority="3304"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.1"
                 priority="3302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.2"
                 priority="3301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.3"
                 priority="3300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/hl7v2:EI.4"
                 priority="3299"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11"
                 priority="3297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.1"
                 priority="3295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.2"
                 priority="3294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/hl7v2:HD.3"
                 priority="3293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14"
                 priority="3291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('228') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '228' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('228') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Call Back Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Call Back Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Call Back Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.1"
                 priority="3289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.2"
                 priority="3288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.3"
                 priority="3286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.4"
                 priority="3284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.5"
                 priority="3283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.6"
                 priority="3282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.7"
                 priority="3281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.8"
                 priority="3280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.9"
                 priority="3279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.10"
                 priority="3278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.11"
                 priority="3277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/hl7v2:XTN.12"
                 priority="3276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15"
                 priority="3275"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('229') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '229' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('229') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Effective Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Effective Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Effective Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.1"
                 priority="3273"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15/hl7v2:TS.2"
                 priority="3272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16"
                 priority="3270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('230') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '230' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('230') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Control Code Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Control Code Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Control Code Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.1"
                 priority="3268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.2"
                 priority="3267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.3"
                 priority="3266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.4"
                 priority="3264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.5"
                 priority="3263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/hl7v2:CE.6"
                 priority="3262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17"
                 priority="3260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('231') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '231' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('231') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Organization') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Entering Organization' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entering Organization') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.1"
                 priority="3258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.2"
                 priority="3257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.3"
                 priority="3256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.4"
                 priority="3254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.5"
                 priority="3253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/hl7v2:CE.6"
                 priority="3252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18"
                 priority="3250"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('232') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '232' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('232') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entering Device') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Entering Device' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entering Device') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.1"
                 priority="3248"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.2"
                 priority="3247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.3"
                 priority="3246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.4"
                 priority="3244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.5"
                 priority="3243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/hl7v2:CE.6"
                 priority="3242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19"
                 priority="3240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('233') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '233' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('233') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Action By') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Action By' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Action By') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.1"
                 priority="3238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2"
                 priority="3237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="3235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="3234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="3233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="3232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="3231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.3"
                 priority="3230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.4"
                 priority="3229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.5"
                 priority="3228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.6"
                 priority="3227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.7"
                 priority="3226"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.8"
                 priority="3225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9"
                 priority="3224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="3222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="3221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="3220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.10"
                 priority="3218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.11"
                 priority="3216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.12"
                 priority="3215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.13"
                 priority="3213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14"
                 priority="3211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="3209"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="3208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="3207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.15"
                 priority="3205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16"
                 priority="3203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="3201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="3200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="3199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="3197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="3196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="3195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17"
                 priority="3193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="3191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="3186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.18"
                 priority="3181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19"
                 priority="3179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="3177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="3176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20"
                 priority="3174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="3172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="3171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.21"
                 priority="3169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22"
                 priority="3168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="3166"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="3165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="3164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="3162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="3161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="3160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="3158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="3157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="3156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23"
                 priority="3155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="3153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="3152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="3151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="3149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="3148"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="3147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="3145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="3144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="3143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20"
                 priority="3142"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1310' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70339' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Advanced Beneficiary Notice Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.1"
                 priority="3140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.2"
                 priority="3139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.3"
                 priority="3138"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.4"
                 priority="3136"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.5"
                 priority="3135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/hl7v2:CE.6"
                 priority="3134"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21"
                 priority="3132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.1 komt te vaak voor [max 1x]. (count(hl7v2:XON.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.2 komt te vaak voor [max 1x]. (count(hl7v2:XON.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.3 komt te vaak voor [max 1x]. (count(hl7v2:XON.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.4 komt te vaak voor [max 1x]. (count(hl7v2:XON.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.5 komt te vaak voor [max 1x]. (count(hl7v2:XON.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.6 komt te vaak voor [max 1x]. (count(hl7v2:XON.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.7 komt te vaak voor [max 1x]. (count(hl7v2:XON.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.8 komt te vaak voor [max 1x]. (count(hl7v2:XON.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.9 komt te vaak voor [max 1x]. (count(hl7v2:XON.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XON.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): element hl7v2:XON.10 komt te vaak voor [max 1x]. (count(hl7v2:XON.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1311') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1311' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1311') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XON') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XON' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XON') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Facility Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Facility Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.1"
                 priority="3130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.2"
                 priority="3129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70204') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70204' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70204') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.3"
                 priority="3128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.4"
                 priority="3127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.5"
                 priority="3126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6"
                 priority="3124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.1"
                 priority="3122"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.2"
                 priority="3121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/hl7v2:HD.3"
                 priority="3120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.7"
                 priority="3118"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8"
                 priority="3116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.1"
                 priority="3114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.2"
                 priority="3113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/hl7v2:HD.3"
                 priority="3112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.9"
                 priority="3110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.10"
                 priority="3108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Organization Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XON_datatype): de waarde van LongName MOET 'Organization Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Organization Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.75-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22"
                 priority="3107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1312') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1312' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1312') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Facility Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Facility Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1"
                 priority="3105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="3103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="3102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="3101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.2"
                 priority="3100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.3"
                 priority="3099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.4"
                 priority="3098"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.5"
                 priority="3097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.6"
                 priority="3096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.7"
                 priority="3094"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.8"
                 priority="3092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.9"
                 priority="3091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.10"
                 priority="3090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.11"
                 priority="3089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12"
                 priority="3087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="3085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="3080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13"
                 priority="3075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="3073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="3072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14"
                 priority="3070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="3068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="3067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23"
                 priority="3065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1313') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1313' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1313') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Facility Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Facility Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.1"
                 priority="3063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.2"
                 priority="3062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.3"
                 priority="3060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.4"
                 priority="3058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.5"
                 priority="3057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.6"
                 priority="3056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.7"
                 priority="3055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.8"
                 priority="3054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.9"
                 priority="3053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.10"
                 priority="3052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.11"
                 priority="3051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/hl7v2:XTN.12"
                 priority="3050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24"
                 priority="3049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.1 komt te vaak voor [max 1x]. (count(hl7v2:XAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.2 komt te vaak voor [max 1x]. (count(hl7v2:XAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.3 komt te vaak voor [max 1x]. (count(hl7v2:XAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.4 komt te vaak voor [max 1x]. (count(hl7v2:XAD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.5 komt te vaak voor [max 1x]. (count(hl7v2:XAD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.6 komt te vaak voor [max 1x]. (count(hl7v2:XAD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.7 komt te vaak voor [max 1x]. (count(hl7v2:XAD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.8 komt te vaak voor [max 1x]. (count(hl7v2:XAD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.9 komt te vaak voor [max 1x]. (count(hl7v2:XAD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.10 komt te vaak voor [max 1x]. (count(hl7v2:XAD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.11 komt te vaak voor [max 1x]. (count(hl7v2:XAD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.12 komt te vaak voor [max 1x]. (count(hl7v2:XAD.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.13 komt te vaak voor [max 1x]. (count(hl7v2:XAD.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XAD.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): element hl7v2:XAD.14 komt te vaak voor [max 1x]. (count(hl7v2:XAD.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1314') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1314' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1314') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'XAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Ordering Provider Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Provider Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1"
                 priority="3047"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.1 komt te vaak voor [max 1x]. (count(hl7v2:SAD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.2 komt te vaak voor [max 1x]. (count(hl7v2:SAD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SAD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): element hl7v2:SAD.3 komt te vaak voor [max 1x]. (count(hl7v2:SAD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SAD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'SAD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SAD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Street Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.1"
                 priority="3045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street or Mailing Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street or Mailing Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street or Mailing Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.2"
                 priority="3044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Street Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Street Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Street Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/hl7v2:SAD.3"
                 priority="3043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Dwelling Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SAD_datatype): de waarde van LongName MOET 'Dwelling Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Dwelling Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.57-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.2"
                 priority="3042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.3"
                 priority="3041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('City') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'City' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('City') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.4"
                 priority="3040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('State or Province') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'State or Province' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('State or Province') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.5"
                 priority="3039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Zip or Postal Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Zip or Postal Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Zip or Postal Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.6"
                 priority="3038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70399') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70399' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70399') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Country' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.7"
                 priority="3036"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.2.4.3.11.60.25.11.409 Adrestype HL7v2 NL (DYNAMISCH)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.2.4.3.11.60.25.11.409-DYNAMIC.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70190') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70190' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70190') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.8"
                 priority="3034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Other Geographic Designation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Other Geographic Designation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Other Geographic Designation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.9"
                 priority="3033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70289') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70289' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70289') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('County/Parish Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'County/Parish Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('County/Parish Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.10"
                 priority="3032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70288') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70288' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70288') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Census Tract') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Census Tract' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Census Tract') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.11"
                 priority="3031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12"
                 priority="3029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Address Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Address Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Address Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1"
                 priority="3027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.1"
                 priority="3025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/hl7v2:TS.2"
                 priority="3024"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2"
                 priority="3022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.1"
                 priority="3020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/hl7v2:TS.2"
                 priority="3019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13"
                 priority="3017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.1"
                 priority="3015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/hl7v2:TS.2"
                 priority="3014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14"
                 priority="3012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XAD_datatype_NL): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.36-2016-07-19T160132.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.1"
                 priority="3010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/hl7v2:TS.2"
                 priority="3009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25"
                 priority="3007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1473') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1473' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1473') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Status Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Status Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Status Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.1"
                 priority="3005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.2"
                 priority="3004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.3"
                 priority="3003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.4"
                 priority="3001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.5"
                 priority="3000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.6"
                 priority="2999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.7"
                 priority="2997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.8"
                 priority="2996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/hl7v2:CWE.9"
                 priority="2995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26"
                 priority="2994"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1641') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1641' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1641') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70552') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70552' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70552') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Advanced Beneficiary Notice Override Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advanced Beneficiary Notice Override Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.1"
                 priority="2992"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.2"
                 priority="2991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.3"
                 priority="2990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.4"
                 priority="2988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.5"
                 priority="2987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.6"
                 priority="2986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.7"
                 priority="2984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.8"
                 priority="2983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/hl7v2:CWE.9"
                 priority="2982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27"
                 priority="2981"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1642') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1642' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1642') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Filler''s Expected Availability Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler''s Expected Availability Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.1"
                 priority="2979"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27/hl7v2:TS.2"
                 priority="2978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28"
                 priority="2976"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('615') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '615' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('615') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70177') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70177' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70177') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Confidentiality Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Confidentiality Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Confidentiality Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.1"
                 priority="2974"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.2"
                 priority="2973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.3"
                 priority="2972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.4"
                 priority="2970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.5"
                 priority="2969"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.6"
                 priority="2968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.7"
                 priority="2966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.8"
                 priority="2965"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/hl7v2:CWE.9"
                 priority="2964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29"
                 priority="2963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1643') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1643' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1643') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70482') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70482' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70482') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Order Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.1"
                 priority="2961"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.2"
                 priority="2960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.3"
                 priority="2959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.4"
                 priority="2957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.5"
                 priority="2956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.6"
                 priority="2955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.7"
                 priority="2953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.8"
                 priority="2952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/hl7v2:CWE.9"
                 priority="2951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30"
                 priority="2950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1644') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Item MOET '1644' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1644') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Type MOET 'CNE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70483') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van Table MOET 'HL70483' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70483') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Enterer Authorization Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(ORC_segment_Lab_algemeen): de waarde van LongName MOET 'Enterer Authorization Mode' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Enterer Authorization Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.7-2015-07-21T172057.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.1"
                 priority="2948"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.2"
                 priority="2947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.3"
                 priority="2946"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.4"
                 priority="2944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.5"
                 priority="2943"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.6"
                 priority="2942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.7"
                 priority="2940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.8"
                 priority="2939"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/hl7v2:CNE.9"
                 priority="2938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR"
                 priority="2937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.1 komt te vaak voor [max 1x]. (count(hl7v2:OBR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.2 komt te vaak voor [max 1x]. (count(hl7v2:OBR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.3 komt te vaak voor [max 1x]. (count(hl7v2:OBR.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 is required [min 1x]. (count(hl7v2:OBR.4) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.4 komt te vaak voor [max 1x]. (count(hl7v2:OBR.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.5 komt te vaak voor [max 1x]. (count(hl7v2:OBR.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.6 komt te vaak voor [max 1x]. (count(hl7v2:OBR.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.7 komt te vaak voor [max 1x]. (count(hl7v2:OBR.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.8 komt te vaak voor [max 1x]. (count(hl7v2:OBR.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.9 komt te vaak voor [max 1x]. (count(hl7v2:OBR.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.11 komt te vaak voor [max 1x]. (count(hl7v2:OBR.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.12 komt te vaak voor [max 1x]. (count(hl7v2:OBR.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.13 komt te vaak voor [max 1x]. (count(hl7v2:OBR.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.14 komt te vaak voor [max 1x]. (count(hl7v2:OBR.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.15 komt te vaak voor [max 1x]. (count(hl7v2:OBR.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.18 komt te vaak voor [max 1x]. (count(hl7v2:OBR.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.19 komt te vaak voor [max 1x]. (count(hl7v2:OBR.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.20 komt te vaak voor [max 1x]. (count(hl7v2:OBR.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.21 komt te vaak voor [max 1x]. (count(hl7v2:OBR.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.22 komt te vaak voor [max 1x]. (count(hl7v2:OBR.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.23 komt te vaak voor [max 1x]. (count(hl7v2:OBR.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.24) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.24 komt te vaak voor [max 1x]. (count(hl7v2:OBR.24) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.25 komt te vaak voor [max 1x]. (count(hl7v2:OBR.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.26) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.26 komt te vaak voor [max 1x]. (count(hl7v2:OBR.26) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.29 komt te vaak voor [max 1x]. (count(hl7v2:OBR.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.30 komt te vaak voor [max 1x]. (count(hl7v2:OBR.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.32) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.32 komt te vaak voor [max 1x]. (count(hl7v2:OBR.32) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.36) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.36 komt te vaak voor [max 1x]. (count(hl7v2:OBR.36) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.37) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.37 komt te vaak voor [max 1x]. (count(hl7v2:OBR.37) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.40) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.40 komt te vaak voor [max 1x]. (count(hl7v2:OBR.40) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.41) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.41 komt te vaak voor [max 1x]. (count(hl7v2:OBR.41) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.42) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.42 komt te vaak voor [max 1x]. (count(hl7v2:OBR.42) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.44) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.44 komt te vaak voor [max 1x]. (count(hl7v2:OBR.44) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.48) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.48 komt te vaak voor [max 1x]. (count(hl7v2:OBR.48) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBR.49) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): element hl7v2:OBR.49 komt te vaak voor [max 1x]. (count(hl7v2:OBR.49) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.1"
                 priority="2936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('237') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '237' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('237') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - OBR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2"
                 priority="2935"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('216') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '216' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('216') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.1"
                 priority="2933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.2"
                 priority="2932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.3"
                 priority="2931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/hl7v2:EI.4"
                 priority="2930"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3"
                 priority="2928"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.1"
                 priority="2926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.2"
                 priority="2925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.3"
                 priority="2924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/hl7v2:EI.4"
                 priority="2923"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4"
                 priority="2921"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('238') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '238' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('238') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal Service Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Universal Service Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal Service Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.1"
                 priority="2919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.2"
                 priority="2918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.3"
                 priority="2917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.4"
                 priority="2915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.5"
                 priority="2914"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/hl7v2:CE.6"
                 priority="2913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.5"
                 priority="2911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('239') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '239' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('239') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority _ OBR') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Priority _ OBR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority _ OBR') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6"
                 priority="2909"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('240') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '240' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('240') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Requested Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Requested Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Requested Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.1"
                 priority="2907"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6/hl7v2:TS.2"
                 priority="2906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7"
                 priority="2904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('241') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '241' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('241') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.1"
                 priority="2902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7/hl7v2:TS.2"
                 priority="2901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8"
                 priority="2899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('242') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '242' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('242') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Observation End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.1"
                 priority="2897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8/hl7v2:TS.2"
                 priority="2896"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9"
                 priority="2894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('243') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '243' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('243') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Volume') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collection Volume' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collection Volume') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.1"
                 priority="2892"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2"
                 priority="2891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2889"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2884"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10"
                 priority="2881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('244') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '244' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('244') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collector Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collector Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.1"
                 priority="2879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2"
                 priority="2878"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2874"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.3"
                 priority="2871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.4"
                 priority="2870"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.5"
                 priority="2869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.6"
                 priority="2868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.7"
                 priority="2867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.8"
                 priority="2866"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9"
                 priority="2865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2862"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.10"
                 priority="2859"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.11"
                 priority="2857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.12"
                 priority="2856"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.13"
                 priority="2854"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14"
                 priority="2852"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2849"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.15"
                 priority="2846"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16"
                 priority="2844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2841"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2837"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17"
                 priority="2834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.18"
                 priority="2822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19"
                 priority="2820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20"
                 priority="2815"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.21"
                 priority="2810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22"
                 priority="2809"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2806"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2802"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2798"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23"
                 priority="2796"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2794"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2790"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2786"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2784"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.11"
                 priority="2783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('245') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '245' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('245') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70065') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70065' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70065') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Action Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Action Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Action Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12"
                 priority="2781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('246') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '246' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('246') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Danger Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Danger Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Danger Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.1"
                 priority="2779"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.2"
                 priority="2778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.3"
                 priority="2777"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.4"
                 priority="2775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.5"
                 priority="2774"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/hl7v2:CE.6"
                 priority="2773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.13"
                 priority="2771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('247') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '247' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('247') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relevant Clinical Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Relevant Clinical Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relevant Clinical Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14"
                 priority="2770"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('248') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '248' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('248') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Received Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Received Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Received Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.1"
                 priority="2768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14/hl7v2:TS.2"
                 priority="2767"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15"
                 priority="2765"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.1 komt te vaak voor [max 1x]. (count(hl7v2:SPS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.2 komt te vaak voor [max 1x]. (count(hl7v2:SPS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.3 komt te vaak voor [max 1x]. (count(hl7v2:SPS.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.4 komt te vaak voor [max 1x]. (count(hl7v2:SPS.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.5 komt te vaak voor [max 1x]. (count(hl7v2:SPS.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.6 komt te vaak voor [max 1x]. (count(hl7v2:SPS.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:SPS.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): element hl7v2:SPS.7 komt te vaak voor [max 1x]. (count(hl7v2:SPS.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('249') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '249' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('249') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SPS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SPS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SPS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Specimen Source' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1"
                 priority="2763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Source Name or Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Source Name or Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Source Name or Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.1"
                 priority="2761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.2"
                 priority="2760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.3"
                 priority="2759"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.4"
                 priority="2757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.5"
                 priority="2756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.6"
                 priority="2755"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.7"
                 priority="2753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.8"
                 priority="2752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/hl7v2:CWE.9"
                 priority="2751"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2"
                 priority="2750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70371') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70371') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Additives') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Additives' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Additives') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.1"
                 priority="2748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.2"
                 priority="2747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.3"
                 priority="2746"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.4"
                 priority="2744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.5"
                 priority="2743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.6"
                 priority="2742"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.7"
                 priority="2740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.8"
                 priority="2739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/hl7v2:CWE.9"
                 priority="2738"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3"
                 priority="2737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Collection Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Collection Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Collection Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape"
                 priority="2736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape"
                 priority="2735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4"
                 priority="2733"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70163') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70163' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70163') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Body Site') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Body Site' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Body Site') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.1"
                 priority="2731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.2"
                 priority="2730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.3"
                 priority="2729"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.4"
                 priority="2727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.5"
                 priority="2726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.6"
                 priority="2725"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.7"
                 priority="2723"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.8"
                 priority="2722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/hl7v2:CWE.9"
                 priority="2721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5"
                 priority="2720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70495') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70495' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70495') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Site Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Site Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Site Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.1"
                 priority="2718"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.2"
                 priority="2717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.3"
                 priority="2716"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.4"
                 priority="2714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.5"
                 priority="2713"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.6"
                 priority="2712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.7"
                 priority="2710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.8"
                 priority="2709"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/hl7v2:CWE.9"
                 priority="2708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6"
                 priority="2707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collection Method Modifier Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Collection Method Modifier Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collection Method Modifier Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.1"
                 priority="2705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.2"
                 priority="2704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.3"
                 priority="2703"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.4"
                 priority="2701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.5"
                 priority="2700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.6"
                 priority="2699"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.7"
                 priority="2697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.8"
                 priority="2696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/hl7v2:CWE.9"
                 priority="2695"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7"
                 priority="2694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70369') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van Table MOET 'HL70369' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70369') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Specimen Role') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(SPS_datatype): de waarde van LongName MOET 'Specimen Role' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Specimen Role') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.61-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.1"
                 priority="2692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.2"
                 priority="2691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.3"
                 priority="2690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.4"
                 priority="2688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.5"
                 priority="2687"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.6"
                 priority="2686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.7"
                 priority="2684"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.8"
                 priority="2683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/hl7v2:CWE.9"
                 priority="2682"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16"
                 priority="2681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('226') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '226' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('226') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordering Provider') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Ordering Provider' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordering Provider') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.1"
                 priority="2679"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2"
                 priority="2678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2674"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.3"
                 priority="2671"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.4"
                 priority="2670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.5"
                 priority="2669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.6"
                 priority="2668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.7"
                 priority="2667"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.8"
                 priority="2666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9"
                 priority="2665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2663"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.10"
                 priority="2659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.11"
                 priority="2657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.12"
                 priority="2656"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.13"
                 priority="2654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14"
                 priority="2652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.15"
                 priority="2646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16"
                 priority="2644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2637"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17"
                 priority="2634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2630"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2624"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.18"
                 priority="2622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19"
                 priority="2620"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20"
                 priority="2615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2612"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.21"
                 priority="2610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22"
                 priority="2609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2602"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2598"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23"
                 priority="2596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2594"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2592"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2590"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2585"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17"
                 priority="2583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.1 komt te vaak voor [max 1x]. (count(hl7v2:XTN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.2 komt te vaak voor [max 1x]. (count(hl7v2:XTN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.3 komt te vaak voor [max 1x]. (count(hl7v2:XTN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.4 komt te vaak voor [max 1x]. (count(hl7v2:XTN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.5 komt te vaak voor [max 1x]. (count(hl7v2:XTN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.6 komt te vaak voor [max 1x]. (count(hl7v2:XTN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.7 komt te vaak voor [max 1x]. (count(hl7v2:XTN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.8 komt te vaak voor [max 1x]. (count(hl7v2:XTN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.9 komt te vaak voor [max 1x]. (count(hl7v2:XTN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.10 komt te vaak voor [max 1x]. (count(hl7v2:XTN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.11 komt te vaak voor [max 1x]. (count(hl7v2:XTN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XTN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): element hl7v2:XTN.12 komt te vaak voor [max 1x]. (count(hl7v2:XTN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('250') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '250' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('250') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XTN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XTN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XTN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Callback Phone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Order Callback Phone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Callback Phone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.1"
                 priority="2581"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telephone Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telephone Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telephone Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.2"
                 priority="2580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70201') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70201' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70201') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Use Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Use Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Use Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.3"
                 priority="2578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70202') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Table MOET 'HL70202' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70202') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Telecommunication Equipment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Telecommunication Equipment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.4"
                 priority="2576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Email Address') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Email Address' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Email Address') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.5"
                 priority="2575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Country Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Country Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Country Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.6"
                 priority="2574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Area/City Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Area/City Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Area/City Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.7"
                 priority="2573"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Local Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Local Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Local Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.8"
                 priority="2572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.9"
                 priority="2571"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Any Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Any Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Any Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.10"
                 priority="2570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Extension Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Extension Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Extension Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.11"
                 priority="2569"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Speed Dial Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Speed Dial Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Speed Dial Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/hl7v2:XTN.12"
                 priority="2568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unformatted Telephone number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XTN_datatype): de waarde van LongName MOET 'Unformatted Telephone number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unformatted Telephone number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.77-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.18"
                 priority="2567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('251') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '251' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('251') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Field 1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.19"
                 priority="2566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('252') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '252' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('252') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Field 2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.20"
                 priority="2565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('253') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '253' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('253') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Field 1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Field 1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.21"
                 priority="2564"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('254') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '254' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('254') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Field 2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Field 2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Field 2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22"
                 priority="2563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('255') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '255' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('255') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Results Rpt/Status Chng - Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Results Rpt/Status Chng - Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.1"
                 priority="2561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22/hl7v2:TS.2"
                 priority="2560"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23"
                 priority="2558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.1 komt te vaak voor [max 1x]. (count(hl7v2:MOC.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MOC.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): element hl7v2:MOC.2 komt te vaak voor [max 1x]. (count(hl7v2:MOC.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('256') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '256' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('256') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MOC') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'MOC' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MOC') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge to Practice') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Charge to Practice' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge to Practice') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1"
                 priority="2556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Monetary Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van LongName MOET 'Monetary Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Monetary Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.1"
                 priority="2554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/hl7v2:MO.2"
                 priority="2553"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2"
                 priority="2551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MOC_datatype): de waarde van LongName MOET 'Charge Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.34-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.1"
                 priority="2549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.2"
                 priority="2548"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.3"
                 priority="2547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.4"
                 priority="2545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.5"
                 priority="2544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/hl7v2:CE.6"
                 priority="2543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.24"
                 priority="2541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('257') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '257' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('257') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70074') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70074' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70074') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Diagnostic Serv Sect ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnostic Serv Sect ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.25"
                 priority="2539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('258') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '258' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('258') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70123') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70123' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70123') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26"
                 priority="2537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.1 komt te vaak voor [max 1x]. (count(hl7v2:PRL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.2 komt te vaak voor [max 1x]. (count(hl7v2:PRL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PRL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): element hl7v2:PRL.3 komt te vaak voor [max 1x]. (count(hl7v2:PRL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('259') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '259' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('259') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PRL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'PRL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PRL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Result') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent Result' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Result') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1"
                 priority="2535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.1"
                 priority="2533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.2"
                 priority="2532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.3"
                 priority="2531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.4"
                 priority="2529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.5"
                 priority="2528"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/hl7v2:CE.6"
                 priority="2527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.2"
                 priority="2525"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Sub-identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Observation Sub-identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3"
                 priority="2524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PRL_datatype): de waarde van LongName MOET 'Parent Observation Value Descriptor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent Observation Value Descriptor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.47-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape"
                 priority="2523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape"
                 priority="2522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27"
                 priority="2520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.3 komt te vaak voor [max 1x]. (count(hl7v2:TQ.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.4 komt te vaak voor [max 1x]. (count(hl7v2:TQ.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.5 komt te vaak voor [max 1x]. (count(hl7v2:TQ.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): element hl7v2:TQ.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('221') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '221' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('221') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity/Timing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity/Timing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity/Timing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1"
                 priority="2518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.1"
                 priority="2516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2"
                 priority="2515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2512"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2508"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2"
                 priority="2505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.1 komt te vaak voor [max 1x]. (count(hl7v2:RI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): element hl7v2:RI.2 komt te vaak voor [max 1x]. (count(hl7v2:RI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'RI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.1"
                 priority="2503"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/hl7v2:RI.2"
                 priority="2502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RI_datatype): de waarde van LongName MOET 'Explicit Time Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Explicit Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.54-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.3"
                 priority="2501"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4"
                 priority="2500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.1"
                 priority="2498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/hl7v2:TS.2"
                 priority="2497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5"
                 priority="2495"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.1"
                 priority="2493"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/hl7v2:TS.2"
                 priority="2492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.6"
                 priority="2490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.7"
                 priority="2489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Condition' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Condition') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8"
                 priority="2488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape"
                 priority="2487"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape"
                 priority="2486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.9"
                 priority="2484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70472') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Table MOET 'HL70472' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70472') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10"
                 priority="2482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.1 komt te vaak voor [max 1x]. (count(hl7v2:OSD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.2 komt te vaak voor [max 1x]. (count(hl7v2:OSD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.3 komt te vaak voor [max 1x]. (count(hl7v2:OSD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.4 komt te vaak voor [max 1x]. (count(hl7v2:OSD.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.5 komt te vaak voor [max 1x]. (count(hl7v2:OSD.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.6 komt te vaak voor [max 1x]. (count(hl7v2:OSD.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.7 komt te vaak voor [max 1x]. (count(hl7v2:OSD.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.8 komt te vaak voor [max 1x]. (count(hl7v2:OSD.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.9 komt te vaak voor [max 1x]. (count(hl7v2:OSD.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.10 komt te vaak voor [max 1x]. (count(hl7v2:OSD.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OSD.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): element hl7v2:OSD.11 komt te vaak voor [max 1x]. (count(hl7v2:OSD.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('OSD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'OSD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('OSD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Order Sequencing') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Order Sequencing' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Order Sequencing') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.1"
                 priority="2480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70524') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70524' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70524') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.2"
                 priority="2478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.3"
                 priority="2477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.4"
                 priority="2476"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.5"
                 priority="2475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.6"
                 priority="2474"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Sequence Condition Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.7"
                 priority="2473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.8"
                 priority="2472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.9"
                 priority="2471"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Placer Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.10"
                 priority="2469"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/hl7v2:OSD.11"
                 priority="2468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OSD_datatype): de waarde van LongName MOET 'Filler Order Number: Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number: Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.41-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11"
                 priority="2466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Occurrence Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Occurrence Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.1"
                 priority="2464"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.2"
                 priority="2463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.3"
                 priority="2462"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.4"
                 priority="2460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.5"
                 priority="2459"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/hl7v2:CE.6"
                 priority="2458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.12"
                 priority="2456"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total Occurrences') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ_datatype): de waarde van LongName MOET 'Total Occurrences' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total Occurrences') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.63-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28"
                 priority="2455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('260') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '260' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('260') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Copies To') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Copies To' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Result Copies To') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.1"
                 priority="2453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2"
                 priority="2452"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="2450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="2449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="2448"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="2447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="2446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.3"
                 priority="2445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.4"
                 priority="2444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.5"
                 priority="2443"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.6"
                 priority="2442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.7"
                 priority="2441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.8"
                 priority="2440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9"
                 priority="2439"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="2437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="2436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="2435"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.10"
                 priority="2433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.11"
                 priority="2431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.12"
                 priority="2430"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.13"
                 priority="2428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14"
                 priority="2426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="2424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="2423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="2422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.15"
                 priority="2420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16"
                 priority="2418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="2416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="2415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="2414"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="2412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="2411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="2410"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17"
                 priority="2408"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="2406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="2404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="2403"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="2401"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="2399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="2398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.18"
                 priority="2396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19"
                 priority="2394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="2392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="2391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20"
                 priority="2389"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="2387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="2386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.21"
                 priority="2384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22"
                 priority="2383"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="2381"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="2380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="2379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="2377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="2376"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="2375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="2373"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="2372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="2371"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23"
                 priority="2370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="2368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="2367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="2366"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="2364"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="2363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="2362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="2360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="2359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="2358"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29"
                 priority="2357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.1 komt te vaak voor [max 1x]. (count(hl7v2:EIP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EIP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): element hl7v2:EIP.2 komt te vaak voor [max 1x]. (count(hl7v2:EIP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('261') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '261' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('261') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EIP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'EIP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EIP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Parent') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Parent' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Parent') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1"
                 priority="2355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Placer Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.1"
                 priority="2353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.2"
                 priority="2352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.3"
                 priority="2351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/hl7v2:EI.4"
                 priority="2350"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2"
                 priority="2348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Assigned Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EIP_datatype): de waarde van LongName MOET 'Filler Assigned Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Assigned Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.22-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.1"
                 priority="2346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.2"
                 priority="2345"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.3"
                 priority="2344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/hl7v2:EI.4"
                 priority="2343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.30"
                 priority="2341"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('262') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '262' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('262') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70124') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70124' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70124') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transportation Mode') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transportation Mode' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transportation Mode') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31"
                 priority="2339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('263') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '263' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('263') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Reason for Study') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Reason for Study' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Reason for Study') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.1"
                 priority="2337"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.2"
                 priority="2336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.3"
                 priority="2335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.4"
                 priority="2333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.5"
                 priority="2332"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/hl7v2:CE.6"
                 priority="2331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32"
                 priority="2329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('264') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '264' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('264') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Principal Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Principal Result Interpreter' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Principal Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1"
                 priority="2327"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2325"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2321"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2317"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2"
                 priority="2313"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2311"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3"
                 priority="2308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.4"
                 priority="2303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.5"
                 priority="2302"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.6"
                 priority="2301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7"
                 priority="2300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.8"
                 priority="2294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.9"
                 priority="2293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.10"
                 priority="2292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.11"
                 priority="2291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33"
                 priority="2290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('265') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '265' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('265') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assistant Result Interpreter') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Assistant Result Interpreter' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assistant Result Interpreter') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1"
                 priority="2288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2286"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2282"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2280"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2277"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2"
                 priority="2274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3"
                 priority="2269"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2267"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.4"
                 priority="2264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.5"
                 priority="2263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.6"
                 priority="2262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7"
                 priority="2261"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2257"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.8"
                 priority="2255"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.9"
                 priority="2254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.10"
                 priority="2253"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.11"
                 priority="2252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34"
                 priority="2251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('266') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '266' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('266') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Technician') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Technician' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Technician') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1"
                 priority="2249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2245"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2243"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2241"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2238"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2"
                 priority="2235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2233"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3"
                 priority="2230"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.4"
                 priority="2225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.5"
                 priority="2224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.6"
                 priority="2223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7"
                 priority="2222"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.8"
                 priority="2216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.9"
                 priority="2215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.10"
                 priority="2214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.11"
                 priority="2213"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35"
                 priority="2212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.1 komt te vaak voor [max 1x]. (count(hl7v2:NDL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.2 komt te vaak voor [max 1x]. (count(hl7v2:NDL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.3 komt te vaak voor [max 1x]. (count(hl7v2:NDL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.4 komt te vaak voor [max 1x]. (count(hl7v2:NDL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.5 komt te vaak voor [max 1x]. (count(hl7v2:NDL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.6 komt te vaak voor [max 1x]. (count(hl7v2:NDL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.7 komt te vaak voor [max 1x]. (count(hl7v2:NDL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.8 komt te vaak voor [max 1x]. (count(hl7v2:NDL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.9 komt te vaak voor [max 1x]. (count(hl7v2:NDL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.10 komt te vaak voor [max 1x]. (count(hl7v2:NDL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NDL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): element hl7v2:NDL.11 komt te vaak voor [max 1x]. (count(hl7v2:NDL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('267') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '267' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('267') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NDL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NDL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NDL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transcriptionist') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transcriptionist' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transcriptionist') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1"
                 priority="2210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.1 komt te vaak voor [max 1x]. (count(hl7v2:CNN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.2 komt te vaak voor [max 1x]. (count(hl7v2:CNN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.3 komt te vaak voor [max 1x]. (count(hl7v2:CNN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.4 komt te vaak voor [max 1x]. (count(hl7v2:CNN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.5 komt te vaak voor [max 1x]. (count(hl7v2:CNN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.6 komt te vaak voor [max 1x]. (count(hl7v2:CNN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.7 komt te vaak voor [max 1x]. (count(hl7v2:CNN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.8 komt te vaak voor [max 1x]. (count(hl7v2:CNN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.9 komt te vaak voor [max 1x]. (count(hl7v2:CNN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.10 komt te vaak voor [max 1x]. (count(hl7v2:CNN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): element hl7v2:CNN.11 komt te vaak voor [max 1x]. (count(hl7v2:CNN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'CNN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.1"
                 priority="2208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.2"
                 priority="2207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.3"
                 priority="2206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.4"
                 priority="2205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.5"
                 priority="2204"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.6"
                 priority="2203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.7"
                 priority="2202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Degree (e.g., MD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.8"
                 priority="2201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.9"
                 priority="2200"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.10"
                 priority="2199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/hl7v2:CNN.11"
                 priority="2198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNN_datatype): de waarde van LongName MOET 'Assigning Authority - Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority - Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.7-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2"
                 priority="2196"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Start Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.1"
                 priority="2194"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/hl7v2:TS.2"
                 priority="2193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3"
                 priority="2191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'End Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.1"
                 priority="2189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/hl7v2:TS.2"
                 priority="2188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.4"
                 priority="2186"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.5"
                 priority="2185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.6"
                 priority="2184"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7"
                 priority="2183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.1"
                 priority="2181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.2"
                 priority="2180"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/hl7v2:HD.3"
                 priority="2179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.8"
                 priority="2177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.9"
                 priority="2176"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Patient Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.10"
                 priority="2175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.11"
                 priority="2174"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NDL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.38-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36"
                 priority="2173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('268') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '268' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('268') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Scheduled Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Scheduled Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Scheduled Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.1"
                 priority="2171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36/hl7v2:TS.2"
                 priority="2170"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.37"
                 priority="2168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1028') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1028' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1028') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Number of Sample Containers *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Number of Sample Containers *' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Number of Sample Containers *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38"
                 priority="2167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1029') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1029' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1029') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Logistics of Collected Sample' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transport Logistics of Collected Sample') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.1"
                 priority="2165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.2"
                 priority="2164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.3"
                 priority="2163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.4"
                 priority="2161"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.5"
                 priority="2160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/hl7v2:CE.6"
                 priority="2159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39"
                 priority="2157"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1030') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1030' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1030') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Collector''s Comment *') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Collector''s Comment *' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Collector''s Comment *') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.1"
                 priority="2155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.2"
                 priority="2154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.3"
                 priority="2153"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.4"
                 priority="2151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.5"
                 priority="2150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/hl7v2:CE.6"
                 priority="2149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40"
                 priority="2147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1031') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1031' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1031') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Arrangement Responsibility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transport Arrangement Responsibility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.1"
                 priority="2145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.2"
                 priority="2144"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.3"
                 priority="2143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.4"
                 priority="2141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.5"
                 priority="2140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/hl7v2:CE.6"
                 priority="2139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.41"
                 priority="2137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1032') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1032' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1032') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70224') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70224' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70224') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transport Arranged') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Transport Arranged' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transport Arranged') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.42"
                 priority="2135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1033') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1033' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1033') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70225') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70225' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70225') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Escort Required') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Escort Required' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Escort Required') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43"
                 priority="2133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1034') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1034' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1034') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Planned Patient Transport Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Planned Patient Transport Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.1"
                 priority="2131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.2"
                 priority="2130"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.3"
                 priority="2129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.4"
                 priority="2127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.5"
                 priority="2126"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/hl7v2:CE.6"
                 priority="2125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44"
                 priority="2123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '393' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70088' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Procedure Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.1"
                 priority="2121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.2"
                 priority="2120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.3"
                 priority="2119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.4"
                 priority="2117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.5"
                 priority="2116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/hl7v2:CE.6"
                 priority="2115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45"
                 priority="2113"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70340' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Procedure Code Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.1"
                 priority="2111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.2"
                 priority="2110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.3"
                 priority="2109"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.4"
                 priority="2107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.5"
                 priority="2106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/hl7v2:CE.6"
                 priority="2105"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46"
                 priority="2103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1474') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1474' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1474') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Placer Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Placer Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.1"
                 priority="2101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.2"
                 priority="2100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.3"
                 priority="2099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.4"
                 priority="2097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.5"
                 priority="2096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/hl7v2:CE.6"
                 priority="2095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47"
                 priority="2093"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1475') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1475' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1475') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70411') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70411' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70411') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Filler Supplemental Service Information' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Supplemental Service Information') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.1"
                 priority="2091"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.2"
                 priority="2090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.3"
                 priority="2089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.4"
                 priority="2087"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.5"
                 priority="2086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/hl7v2:CE.6"
                 priority="2085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48"
                 priority="2083"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1646' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70476' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.1"
                 priority="2081"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.2"
                 priority="2080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.3"
                 priority="2079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.4"
                 priority="2077"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.5"
                 priority="2076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.6"
                 priority="2075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.7"
                 priority="2073"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.8"
                 priority="2072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/hl7v2:CWE.9"
                 priority="2071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.49"
                 priority="2070"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1647') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1647' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1647') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70507') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70507' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70507') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Result Handling') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBR_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Result Handling' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Result Handling') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.5-2015-07-21T171850.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE"
                 priority="2069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.1"
                 priority="2068"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.2"
                 priority="2067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3"
                 priority="2065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="2064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="2063"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="2062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4"
                 priority="2061"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="2059"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="2058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="2057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="2055"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="2054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="2053"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3979-false-d375838e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR"
                 priority="2051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 is required [min 1x]. (count(hl7v2:TQ1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:TQ1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1"
                 priority="2050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.11 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.12 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.13 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): element hl7v2:TQ1.14 komt te vaak voor [max 1x]. (count(hl7v2:TQ1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.1"
                 priority="2049"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1627') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1627' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1627') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Set ID - TQ1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - TQ1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2"
                 priority="2048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1628') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1628' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1628') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.1"
                 priority="2046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2"
                 priority="2045"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="2041"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="2039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="2038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="2037"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3"
                 priority="2035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.1 komt te vaak voor [max 1x]. (count(hl7v2:RPT.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.2 komt te vaak voor [max 1x]. (count(hl7v2:RPT.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.3 komt te vaak voor [max 1x]. (count(hl7v2:RPT.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.4 komt te vaak voor [max 1x]. (count(hl7v2:RPT.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.5 komt te vaak voor [max 1x]. (count(hl7v2:RPT.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.6 komt te vaak voor [max 1x]. (count(hl7v2:RPT.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.7 komt te vaak voor [max 1x]. (count(hl7v2:RPT.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.8 komt te vaak voor [max 1x]. (count(hl7v2:RPT.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.9 komt te vaak voor [max 1x]. (count(hl7v2:RPT.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.10 komt te vaak voor [max 1x]. (count(hl7v2:RPT.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:RPT.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): element hl7v2:RPT.11 komt te vaak voor [max 1x]. (count(hl7v2:RPT.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1629') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1629' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1629') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('RPT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'RPT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('RPT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Repeat Pattern' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1"
                 priority="2033"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70335') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70335' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70335') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Repeat Pattern Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Repeat Pattern Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Repeat Pattern Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.1"
                 priority="2031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.2"
                 priority="2030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.3"
                 priority="2029"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.4"
                 priority="2027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.5"
                 priority="2026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.6"
                 priority="2025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.7"
                 priority="2023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.8"
                 priority="2022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/hl7v2:CWE.9"
                 priority="2021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.2"
                 priority="2020"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70527') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70527' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70527') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Calendar Alignment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Calendar Alignment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Calendar Alignment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.3"
                 priority="2018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range Begin Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Phase Range Begin Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phase Range Begin Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.4"
                 priority="2017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Phase Range End Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Phase Range End Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Phase Range End Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.5"
                 priority="2016"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Period Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Period Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.6"
                 priority="2015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Period Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Period Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Period Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.7"
                 priority="2014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70136') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70136' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70136') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Institution Specified Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Institution Specified Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Institution Specified Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.8"
                 priority="2012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70528') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Table MOET 'HL70528' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70528') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Event' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.9"
                 priority="2010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Event Offset Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Event Offset Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.10"
                 priority="2009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Event Offset Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'Event Offset Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Event Offset Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.11"
                 priority="2008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('GTS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van Type MOET 'GTS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('GTS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('General Timing Specification') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(RPT_datatype): de waarde van LongName MOET 'General Timing Specification' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('General Timing Specification') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.56-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.4"
                 priority="2007"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1630') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1630' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1630') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Explicit Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Explicit Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Explicit Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5"
                 priority="2006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1631') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1631' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1631') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Relative Time and Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Relative Time and Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Relative Time and Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.1"
                 priority="2004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2"
                 priority="2003"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="2001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="2000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1999"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1997"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1996"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1995"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6"
                 priority="1993"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1632') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1632' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1632') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Service Duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Service Duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Service Duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.1"
                 priority="1991"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2"
                 priority="1990"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1988"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1987"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1986"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1984"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1983"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1982"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7"
                 priority="1980"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1633') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1633' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1633') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Start date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Start date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Start date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.1"
                 priority="1978"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/hl7v2:TS.2"
                 priority="1977"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8"
                 priority="1975"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1634') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1634' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1634') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('End date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'End date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('End date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.1"
                 priority="1973"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/hl7v2:TS.2"
                 priority="1972"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9"
                 priority="1970"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1635') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1635' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1635') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70485') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70485' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70485') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Priority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Priority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Priority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.1"
                 priority="1968"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.2"
                 priority="1967"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.3"
                 priority="1966"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.4"
                 priority="1964"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.5"
                 priority="1963"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.6"
                 priority="1962"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.7"
                 priority="1960"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.8"
                 priority="1959"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/hl7v2:CWE.9"
                 priority="1958"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10"
                 priority="1957"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1636') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1636' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1636') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Condition text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Condition text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Condition text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape"
                 priority="1956"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape"
                 priority="1955"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1954"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11"
                 priority="1953"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1637') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1637' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1637') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'TX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text instruction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Text instruction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text instruction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape"
                 priority="1952"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(TX_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.65-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape"
                 priority="1951"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1950"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.12"
                 priority="1949"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1638') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1638' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1638') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70427') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Table MOET 'HL70427' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70427') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Conjunction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Conjunction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Conjunction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13"
                 priority="1947"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1639') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1639' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1639') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Occurrence duration') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Occurrence duration' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Occurrence duration') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.1"
                 priority="1945"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2"
                 priority="1944"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1942"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1941"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1940"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1938"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1937"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1936"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.14"
                 priority="1934"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1640') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Item MOET '1640' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1640') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Total occurrence''s') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ1_segment_Lab2Lab_aanvraag): de waarde van LongName MOET 'Total occurrence''s' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Total occurrence''s') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.10-2015-12-28T143014.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2"
                 priority="1933"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.1 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.2 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.6 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.7 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.8 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.9 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TQ2.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): element hl7v2:TQ2.10 komt te vaak voor [max 1x]. (count(hl7v2:TQ2.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.1"
                 priority="1932"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1648') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1648' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1648') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - TQ2') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Set ID - TQ2' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - TQ2') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.2"
                 priority="1931"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1649') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1649' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1649') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70503') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70503' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70503') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence/Results Flag') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Sequence/Results Flag' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence/Results Flag') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3"
                 priority="1929"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1650') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1650' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1650') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Related Placer Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Related Placer Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.1"
                 priority="1927"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.2"
                 priority="1926"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.3"
                 priority="1925"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/hl7v2:EI.4"
                 priority="1924"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4"
                 priority="1922"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1651') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1651' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1651') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Filler Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Related Filler Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Related Filler Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.1"
                 priority="1920"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.2"
                 priority="1919"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.3"
                 priority="1918"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/hl7v2:EI.4"
                 priority="1917"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5"
                 priority="1915"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1652') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1652' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1652') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Related Placer Group Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Related Placer Group Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Related Placer Group Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.1"
                 priority="1913"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.2"
                 priority="1912"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.3"
                 priority="1911"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/hl7v2:EI.4"
                 priority="1910"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.6"
                 priority="1908"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1653') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1653' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1653') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70504') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70504' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70504') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.7"
                 priority="1906"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1654') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1654' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1654') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70505') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70505' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70505') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Cyclic Entry/Exit Indicator' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Cyclic Entry/Exit Indicator') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8"
                 priority="1904"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.1 komt te vaak voor [max 1x]. (count(hl7v2:CQ.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CQ.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): element hl7v2:CQ.2 komt te vaak voor [max 1x]. (count(hl7v2:CQ.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1655') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1655' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1655') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CQ') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'CQ' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CQ') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Sequence Condition Time Interval' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sequence Condition Time Interval') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.1"
                 priority="1902"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2"
                 priority="1901"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CQ_datatype): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.9-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.1"
                 priority="1899"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.2"
                 priority="1898"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.3"
                 priority="1897"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.4"
                 priority="1895"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.5"
                 priority="1894"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/hl7v2:CE.6"
                 priority="1893"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.9"
                 priority="1891"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1656') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1656' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1656') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Cyclic Group Maximum Number of Repeats' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Cyclic Group Maximum Number of Repeats') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.10"
                 priority="1890"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1657') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Item MOET '1657' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1657') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70506') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van Table MOET 'HL70506' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70506') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Special Service Request Relationship') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TQ2_segment): de waarde van LongName MOET 'Special Service Request Relationship' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Special Service Request Relationship') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.143-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE d20e3986-false-d379434e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR"
                 priority="1888"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX is required [min 1x]. (count(hl7v2:OBX) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab): element hl7v2:OBX komt te vaak voor [max 1x]. (count(hl7v2:OBX) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX"
                 priority="1887"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.1 komt te vaak voor [max 1x]. (count(hl7v2:OBX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.2 komt te vaak voor [max 1x]. (count(hl7v2:OBX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 is required [min 1x]. (count(hl7v2:OBX.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.3 komt te vaak voor [max 1x]. (count(hl7v2:OBX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.4 komt te vaak voor [max 1x]. (count(hl7v2:OBX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.6 komt te vaak voor [max 1x]. (count(hl7v2:OBX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.7 komt te vaak voor [max 1x]. (count(hl7v2:OBX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.8 komt te vaak voor [max 1x]. (count(hl7v2:OBX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.9 komt te vaak voor [max 1x]. (count(hl7v2:OBX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 is required [min 1x]. (count(hl7v2:OBX.11) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.11 komt te vaak voor [max 1x]. (count(hl7v2:OBX.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.12 komt te vaak voor [max 1x]. (count(hl7v2:OBX.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.13 komt te vaak voor [max 1x]. (count(hl7v2:OBX.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.14 komt te vaak voor [max 1x]. (count(hl7v2:OBX.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.15 komt te vaak voor [max 1x]. (count(hl7v2:OBX.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:OBX.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): element hl7v2:OBX.19 komt te vaak voor [max 1x]. (count(hl7v2:OBX.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.1"
                 priority="1886"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('569') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '569' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('569') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - OBX') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Set ID - OBX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - OBX') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.2"
                 priority="1885"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('570') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '570' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('570') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70125') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70125' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70125') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Value Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Value Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Value Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3"
                 priority="1883"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('571') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '571' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('571') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.1"
                 priority="1881"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.2"
                 priority="1880"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.3"
                 priority="1879"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.4"
                 priority="1877"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.5"
                 priority="1876"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/hl7v2:CE.6"
                 priority="1875"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.4"
                 priority="1873"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('572') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '572' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('572') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Sub-ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Sub-ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Sub-ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.5"
                 priority="1872"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('573') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '573' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('573') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('varies') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'varies' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('varies') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6"
                 priority="1871"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('574') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '574' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('574') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.1"
                 priority="1869"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.2"
                 priority="1868"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.3"
                 priority="1867"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.4"
                 priority="1865"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.5"
                 priority="1864"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/hl7v2:CE.6"
                 priority="1863"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.7"
                 priority="1861"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('575') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '575' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('575') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('References Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'References Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('References Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.8"
                 priority="1860"
                 mode="M14">
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]])"/>
         <xsl:otherwise>
            <xsl:message>(IS_datatype): de elementwaarde MOET een zijn van '2.16.840.1.113883.3.1937.777.10.11.78 Abnormal flags (2015-09-04T00:00:00)'. (@nullFlavor or exists(doc('include/voc-2.16.840.1.113883.3.1937.777.10.11.78-2015-09-04T000000.xml')//valueSet[1][conceptList/concept[@code = $theCode][@codeSystem = $theCodeSystem]]) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.84-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:variable name="theCode" select="@code"/>
      <xsl:variable name="theCodeSystem" select="@codeSystem"/>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('576') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '576' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('576') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70078') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70078' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70078') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Abnormal Flags') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Abnormal Flags' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Abnormal Flags') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.9"
                 priority="1858"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('577') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '577' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('577') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Probability') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Probability' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Probability') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.10"
                 priority="1857"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('578') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '578' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('578') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70080') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70080' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70080') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Nature of Abnormal Test') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Nature of Abnormal Test' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Nature of Abnormal Test') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.11"
                 priority="1855"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('579') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '579' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('579') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70085') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Table MOET 'HL70085' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70085') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Result Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Result Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Result Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12"
                 priority="1853"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('580') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '580' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('580') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date of Reference Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Effective Date of Reference Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date of Reference Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.1"
                 priority="1851"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12/hl7v2:TS.2"
                 priority="1850"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.13"
                 priority="1848"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('581') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '581' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('581') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('User Defined Access Checks') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'User Defined Access Checks' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('User Defined Access Checks') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14"
                 priority="1847"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('582') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '582' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('582') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Observation') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Date/Time of the Observation' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Observation') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.1"
                 priority="1845"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14/hl7v2:TS.2"
                 priority="1844"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15"
                 priority="1842"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('583') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '583' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('583') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Producer''s ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Producer''s ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Producer''s ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.1"
                 priority="1840"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.2"
                 priority="1839"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.3"
                 priority="1838"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.4"
                 priority="1836"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.5"
                 priority="1835"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/hl7v2:CE.6"
                 priority="1834"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16"
                 priority="1832"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('584') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '584' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('584') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Responsible Observer') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Responsible Observer' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Responsible Observer') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.1"
                 priority="1830"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2"
                 priority="1829"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1827"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1826"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1825"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1824"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1823"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.3"
                 priority="1822"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.4"
                 priority="1821"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.5"
                 priority="1820"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.6"
                 priority="1819"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.7"
                 priority="1818"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.8"
                 priority="1817"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9"
                 priority="1816"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1814"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1813"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1812"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.10"
                 priority="1810"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.11"
                 priority="1808"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.12"
                 priority="1807"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.13"
                 priority="1805"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14"
                 priority="1803"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1801"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1800"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1799"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.15"
                 priority="1797"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16"
                 priority="1795"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1793"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1792"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1791"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1789"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1788"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1787"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17"
                 priority="1785"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1783"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1781"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1780"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1778"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1776"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1775"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.18"
                 priority="1773"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19"
                 priority="1771"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1769"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1768"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20"
                 priority="1766"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1764"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1763"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.21"
                 priority="1761"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22"
                 priority="1760"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1758"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1757"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1756"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1754"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1753"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1752"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1750"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1749"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1748"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23"
                 priority="1747"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1745"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1744"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1743"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1741"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1740"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1739"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1737"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1736"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1735"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17"
                 priority="1734"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('936') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '936' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('936') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Observation Method') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Observation Method' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Observation Method') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.1"
                 priority="1732"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.2"
                 priority="1731"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.3"
                 priority="1730"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.4"
                 priority="1728"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.5"
                 priority="1727"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/hl7v2:CE.6"
                 priority="1726"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18"
                 priority="1724"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1479') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '1479' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1479') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Equipment Instance Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Equipment Instance Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Equipment Instance Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.1"
                 priority="1722"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.2"
                 priority="1721"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.3"
                 priority="1720"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/hl7v2:EI.4"
                 priority="1719"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19"
                 priority="1717"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1480') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Item MOET '1480' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1480') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/Time of the Analysis') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(OBX_segment_Lab2Lab_resultaat): de waarde van LongName MOET 'Date/Time of the Analysis' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/Time of the Analysis') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.45-2015-07-21T172000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.1"
                 priority="1715"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19/hl7v2:TS.2"
                 priority="1714"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE"
                 priority="1712"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.1 komt te vaak voor [max 1x]. (count(hl7v2:NTE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.2 komt te vaak voor [max 1x]. (count(hl7v2:NTE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.3) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.3 is required [min 1x]. (count(hl7v2:NTE.3) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:NTE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): element hl7v2:NTE.4 komt te vaak voor [max 1x]. (count(hl7v2:NTE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.1"
                 priority="1711"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('96') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '96' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('96') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - NTE') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Set ID - NTE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - NTE') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.2"
                 priority="1710"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('97') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '97' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('97') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70105') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70105' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70105') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source of Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Source of Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source of Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3"
                 priority="1708"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('98') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '98' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('98') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'FT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape"
                 priority="1707"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(FT_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.27-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape"
                 priority="1706"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/hl7v2:escape"
                 priority="1705"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="@V"/>
         <xsl:otherwise>
            <xsl:message>(escapeType_datatype): attribute @V MOET aanwezig zijn. (@V / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.0-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4"
                 priority="1704"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1318') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Item MOET '1318' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1318') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70364') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van Table MOET 'HL70364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70364') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comment Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(NTE_segment): de waarde van LongName MOET 'Comment Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comment Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.39-2016-05-31T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.1"
                 priority="1702"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.2"
                 priority="1701"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.3"
                 priority="1700"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.4"
                 priority="1698"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.5"
                 priority="1697"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/hl7v2:CE.6"
                 priority="1696"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1"
                 priority="1694"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.1 komt te vaak voor [max 1x]. (count(hl7v2:FT1.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.2 komt te vaak voor [max 1x]. (count(hl7v2:FT1.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.3 komt te vaak voor [max 1x]. (count(hl7v2:FT1.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.4) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.4 is required [min 1x]. (count(hl7v2:FT1.4) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.4 komt te vaak voor [max 1x]. (count(hl7v2:FT1.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.5 komt te vaak voor [max 1x]. (count(hl7v2:FT1.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.6) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.6 is required [min 1x]. (count(hl7v2:FT1.6) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.6 komt te vaak voor [max 1x]. (count(hl7v2:FT1.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.7) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.7 is required [min 1x]. (count(hl7v2:FT1.7) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.7 komt te vaak voor [max 1x]. (count(hl7v2:FT1.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.8 komt te vaak voor [max 1x]. (count(hl7v2:FT1.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.9 komt te vaak voor [max 1x]. (count(hl7v2:FT1.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.10 komt te vaak voor [max 1x]. (count(hl7v2:FT1.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.11 komt te vaak voor [max 1x]. (count(hl7v2:FT1.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.12 komt te vaak voor [max 1x]. (count(hl7v2:FT1.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.13 komt te vaak voor [max 1x]. (count(hl7v2:FT1.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.14 komt te vaak voor [max 1x]. (count(hl7v2:FT1.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.15 komt te vaak voor [max 1x]. (count(hl7v2:FT1.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.16 komt te vaak voor [max 1x]. (count(hl7v2:FT1.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.17 komt te vaak voor [max 1x]. (count(hl7v2:FT1.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.18 komt te vaak voor [max 1x]. (count(hl7v2:FT1.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.22 komt te vaak voor [max 1x]. (count(hl7v2:FT1.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.23 komt te vaak voor [max 1x]. (count(hl7v2:FT1.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.25) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.25 komt te vaak voor [max 1x]. (count(hl7v2:FT1.25) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.27) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.27 komt te vaak voor [max 1x]. (count(hl7v2:FT1.27) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.28) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.28 komt te vaak voor [max 1x]. (count(hl7v2:FT1.28) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.29) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.29 komt te vaak voor [max 1x]. (count(hl7v2:FT1.29) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FT1.30) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): element hl7v2:FT1.30 komt te vaak voor [max 1x]. (count(hl7v2:FT1.30) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.1"
                 priority="1693"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('355') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '355' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('355') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Set ID - FT1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Set ID - FT1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Set ID - FT1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.2"
                 priority="1692"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('356') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '356' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('356') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.3"
                 priority="1691"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('357') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '357' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('357') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Batch ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Batch ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Batch ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4"
                 priority="1690"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('358') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '358' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('358') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1"
                 priority="1688"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1686"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1685"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2"
                 priority="1683"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1681"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1680"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5"
                 priority="1678"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('359') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '359' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('359') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Posting Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Posting Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Posting Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5/hl7v2:TS.1"
                 priority="1676"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5/hl7v2:TS.2"
                 priority="1675"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.6"
                 priority="1673"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('360') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('360') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70017') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70017' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70017') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7"
                 priority="1672"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('361') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '361' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('361') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70132') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70132' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70132') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.1"
                 priority="1670"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.2"
                 priority="1669"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.3"
                 priority="1668"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.4"
                 priority="1666"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.5"
                 priority="1665"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/hl7v2:CE.6"
                 priority="1664"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.8"
                 priority="1662"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('362') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '362' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('362') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.9"
                 priority="1661"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('363') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('363') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Description - Alt') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Description - Alt' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Description - Alt') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.10"
                 priority="1660"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('364') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '364' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('364') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11"
                 priority="1659"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('365') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '365' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('365') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Amount - Extended') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Amount - Extended' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Amount - Extended') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1"
                 priority="1657"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1655"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1654"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.2"
                 priority="1652"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.3"
                 priority="1650"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.4"
                 priority="1649"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5"
                 priority="1648"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1646"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1645"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1644"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1642"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1641"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1640"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.6"
                 priority="1638"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12"
                 priority="1636"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('366') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '366' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('366') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Amount - Unit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Amount - Unit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Amount - Unit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1"
                 priority="1634"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1632"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1631"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.2"
                 priority="1629"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.3"
                 priority="1627"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.4"
                 priority="1626"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5"
                 priority="1625"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1623"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1622"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1621"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1619"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1618"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1617"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.6"
                 priority="1615"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13"
                 priority="1613"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('367') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '367' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('367') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70049') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70049' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70049') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Department Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Department Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Department Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.1"
                 priority="1611"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.2"
                 priority="1610"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.3"
                 priority="1609"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.4"
                 priority="1607"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.5"
                 priority="1606"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/hl7v2:CE.6"
                 priority="1605"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14"
                 priority="1603"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('368') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '368' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('368') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70072') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70072' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70072') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Plan ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Insurance Plan ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Plan ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.1"
                 priority="1601"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.2"
                 priority="1600"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.3"
                 priority="1599"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.4"
                 priority="1597"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.5"
                 priority="1596"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/hl7v2:CE.6"
                 priority="1595"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15"
                 priority="1593"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('369') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '369' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('369') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Insurance Amount') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Insurance Amount' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Insurance Amount') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1"
                 priority="1591"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1589"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1588"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.2"
                 priority="1586"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.3"
                 priority="1584"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.4"
                 priority="1583"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5"
                 priority="1582"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1580"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1579"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1578"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1576"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1575"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1574"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.6"
                 priority="1572"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16"
                 priority="1570"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.1 komt te vaak voor [max 1x]. (count(hl7v2:PL.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.2 komt te vaak voor [max 1x]. (count(hl7v2:PL.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.3 komt te vaak voor [max 1x]. (count(hl7v2:PL.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.4 komt te vaak voor [max 1x]. (count(hl7v2:PL.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.5 komt te vaak voor [max 1x]. (count(hl7v2:PL.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.6 komt te vaak voor [max 1x]. (count(hl7v2:PL.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.7 komt te vaak voor [max 1x]. (count(hl7v2:PL.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.8 komt te vaak voor [max 1x]. (count(hl7v2:PL.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.9 komt te vaak voor [max 1x]. (count(hl7v2:PL.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.10 komt te vaak voor [max 1x]. (count(hl7v2:PL.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:PL.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): element hl7v2:PL.11 komt te vaak voor [max 1x]. (count(hl7v2:PL.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('133') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '133' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('133') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('PL') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'PL' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('PL') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigned Patient Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Assigned Patient Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigned Patient Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.1"
                 priority="1568"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70302') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70302' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70302') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Point of Care') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Point of Care' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Point of Care') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.2"
                 priority="1567"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70303') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70303' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70303') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Room') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Room' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Room') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.3"
                 priority="1566"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70304') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70304' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70304') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Bed') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Bed' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Bed') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4"
                 priority="1565"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/hl7v2:HD.1"
                 priority="1563"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/hl7v2:HD.2"
                 priority="1562"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/hl7v2:HD.3"
                 priority="1561"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.5"
                 priority="1559"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70306') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70306' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70306') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Status') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Status' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Status') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.6"
                 priority="1558"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70305') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70305' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70305') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Person Location Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Person Location Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Person Location Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.7"
                 priority="1557"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70307') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70307' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70307') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Building') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Building' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Building') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.8"
                 priority="1556"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70308') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Table MOET 'HL70308' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70308') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Floor') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Floor' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Floor') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.9"
                 priority="1555"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Location Description') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Location Description' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Location Description') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10"
                 priority="1554"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Comprehensive Location Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Comprehensive Location Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.1"
                 priority="1552"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.2"
                 priority="1551"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.3"
                 priority="1550"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/hl7v2:EI.4"
                 priority="1549"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11"
                 priority="1547"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority for Location') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(PL_datatype): de waarde van LongName MOET 'Assigning Authority for Location' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority for Location') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.44-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/hl7v2:HD.1"
                 priority="1545"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/hl7v2:HD.2"
                 priority="1544"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/hl7v2:HD.3"
                 priority="1543"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.17"
                 priority="1541"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('370') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '370' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('370') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70024') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70024' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70024') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Fee Schedule') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Fee Schedule' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Fee Schedule') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.18"
                 priority="1540"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('148') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '148' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('148') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70018') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70018' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70018') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Patient Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Patient Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Patient Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19"
                 priority="1539"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('371') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '371' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('371') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70051') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70051' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70051') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Diagnosis Code - FT1') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Diagnosis Code - FT1' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Diagnosis Code - FT1') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.1"
                 priority="1537"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.2"
                 priority="1536"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.3"
                 priority="1535"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.4"
                 priority="1533"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.5"
                 priority="1532"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/hl7v2:CE.6"
                 priority="1531"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20"
                 priority="1529"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('372') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '372' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('372') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70084') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70084' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70084') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Performed By Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Performed By Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Performed By Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.1"
                 priority="1527"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2"
                 priority="1526"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1524"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1523"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1522"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1521"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1520"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.3"
                 priority="1519"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.4"
                 priority="1518"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.5"
                 priority="1517"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.6"
                 priority="1516"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.7"
                 priority="1515"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.8"
                 priority="1514"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9"
                 priority="1513"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1511"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1510"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1509"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.10"
                 priority="1507"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.11"
                 priority="1505"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.12"
                 priority="1504"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.13"
                 priority="1502"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14"
                 priority="1500"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1498"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1497"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1496"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.15"
                 priority="1494"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16"
                 priority="1492"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1490"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1489"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1488"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1486"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1485"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1484"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17"
                 priority="1482"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1480"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1478"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1477"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1475"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1473"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1472"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.18"
                 priority="1470"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19"
                 priority="1468"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1466"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1465"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20"
                 priority="1463"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1461"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1460"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.21"
                 priority="1458"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22"
                 priority="1457"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1455"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1454"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1453"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1451"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1450"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1449"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1447"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1446"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1445"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23"
                 priority="1444"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1442"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1441"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1440"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1438"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1437"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1436"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1434"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1433"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1432"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21"
                 priority="1431"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('373') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '373' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('373') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Ordered By Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Ordered By Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Ordered By Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.1"
                 priority="1429"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2"
                 priority="1428"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1426"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1425"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1424"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1423"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1422"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.3"
                 priority="1421"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.4"
                 priority="1420"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.5"
                 priority="1419"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.6"
                 priority="1418"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.7"
                 priority="1417"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.8"
                 priority="1416"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9"
                 priority="1415"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1413"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1412"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1411"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.10"
                 priority="1409"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.11"
                 priority="1407"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.12"
                 priority="1406"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.13"
                 priority="1404"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14"
                 priority="1402"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1400"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1399"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1398"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.15"
                 priority="1396"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16"
                 priority="1394"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1392"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1391"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1390"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1388"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1387"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1386"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17"
                 priority="1384"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1382"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1380"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1379"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1377"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1375"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1374"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.18"
                 priority="1372"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19"
                 priority="1370"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1368"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1367"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20"
                 priority="1365"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1363"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1362"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.21"
                 priority="1360"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22"
                 priority="1359"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1357"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1356"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1355"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1353"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1352"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1351"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1349"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1348"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1347"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23"
                 priority="1346"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1344"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1343"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1342"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1340"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1339"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1338"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1336"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1335"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1334"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22"
                 priority="1333"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.1 komt te vaak voor [max 1x]. (count(hl7v2:CP.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.2 komt te vaak voor [max 1x]. (count(hl7v2:CP.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.3 komt te vaak voor [max 1x]. (count(hl7v2:CP.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.4 komt te vaak voor [max 1x]. (count(hl7v2:CP.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.5 komt te vaak voor [max 1x]. (count(hl7v2:CP.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CP.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): element hl7v2:CP.6 komt te vaak voor [max 1x]. (count(hl7v2:CP.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('374') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '374' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('374') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CP') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CP' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CP') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Unit Cost') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Unit Cost' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Unit Cost') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1"
                 priority="1331"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.1 komt te vaak voor [max 1x]. (count(hl7v2:MO.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:MO.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): element hl7v2:MO.2 komt te vaak voor [max 1x]. (count(hl7v2:MO.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('MO') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'MO' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('MO') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1/hl7v2:MO.1"
                 priority="1329"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Quantity') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Quantity' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Quantity') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1/hl7v2:MO.2"
                 priority="1328"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Denomination') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(MO_datatype): de waarde van LongName MOET 'Denomination' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Denomination') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.33-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.2"
                 priority="1326"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70205') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70205' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70205') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Price Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Price Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Price Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.3"
                 priority="1324"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.4"
                 priority="1323"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('NM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'NM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('NM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('To Value') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'To Value' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('To Value') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5"
                 priority="1322"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Units') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Units' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Units') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.1"
                 priority="1320"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.2"
                 priority="1319"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.3"
                 priority="1318"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.4"
                 priority="1316"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.5"
                 priority="1315"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/hl7v2:CE.6"
                 priority="1314"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.6"
                 priority="1312"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70298') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van Table MOET 'HL70298' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70298') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CP_datatype): de waarde van LongName MOET 'Range Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.8-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23"
                 priority="1310"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('217') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '217' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('217') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Filler Order Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Filler Order Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Filler Order Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.1"
                 priority="1308"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.2"
                 priority="1307"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.3"
                 priority="1306"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/hl7v2:EI.4"
                 priority="1305"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24"
                 priority="1303"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.1 komt te vaak voor [max 1x]. (count(hl7v2:XCN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.2 komt te vaak voor [max 1x]. (count(hl7v2:XCN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.3 komt te vaak voor [max 1x]. (count(hl7v2:XCN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.4 komt te vaak voor [max 1x]. (count(hl7v2:XCN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.5 komt te vaak voor [max 1x]. (count(hl7v2:XCN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.6 komt te vaak voor [max 1x]. (count(hl7v2:XCN.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.7 komt te vaak voor [max 1x]. (count(hl7v2:XCN.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.8 komt te vaak voor [max 1x]. (count(hl7v2:XCN.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.9 komt te vaak voor [max 1x]. (count(hl7v2:XCN.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.10 komt te vaak voor [max 1x]. (count(hl7v2:XCN.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.11) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.11 komt te vaak voor [max 1x]. (count(hl7v2:XCN.11) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.12) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.12 komt te vaak voor [max 1x]. (count(hl7v2:XCN.12) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.13) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.13 komt te vaak voor [max 1x]. (count(hl7v2:XCN.13) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.14) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.14 komt te vaak voor [max 1x]. (count(hl7v2:XCN.14) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.15) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.15 komt te vaak voor [max 1x]. (count(hl7v2:XCN.15) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.16) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.16 komt te vaak voor [max 1x]. (count(hl7v2:XCN.16) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.17) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.17 komt te vaak voor [max 1x]. (count(hl7v2:XCN.17) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.18) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.18 komt te vaak voor [max 1x]. (count(hl7v2:XCN.18) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.19) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.19 komt te vaak voor [max 1x]. (count(hl7v2:XCN.19) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.20) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.20 komt te vaak voor [max 1x]. (count(hl7v2:XCN.20) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.21) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.21 komt te vaak voor [max 1x]. (count(hl7v2:XCN.21) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.22) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.22 komt te vaak voor [max 1x]. (count(hl7v2:XCN.22) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:XCN.23) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): element hl7v2:XCN.23 komt te vaak voor [max 1x]. (count(hl7v2:XCN.23) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('765') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '765' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('765') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('XCN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'XCN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('XCN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entered By Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Entered By Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entered By Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.1"
                 priority="1301"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2"
                 priority="1300"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.1 komt te vaak voor [max 1x]. (count(hl7v2:FN.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.2 komt te vaak voor [max 1x]. (count(hl7v2:FN.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.3 komt te vaak voor [max 1x]. (count(hl7v2:FN.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.4 komt te vaak voor [max 1x]. (count(hl7v2:FN.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:FN.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): element hl7v2:FN.5 komt te vaak voor [max 1x]. (count(hl7v2:FN.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('FN') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'FN' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('FN') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Family Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Family Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Family Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.1"
                 priority="1298"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.2"
                 priority="1297"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname Prefix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname Prefix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname Prefix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.3"
                 priority="1296"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Own Surname') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Own Surname' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Own Surname') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.4"
                 priority="1295"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname Prefix From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname Prefix From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/hl7v2:FN.5"
                 priority="1294"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FN_datatype): de waarde van LongName MOET 'Surname From Partner/Spouse' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Surname From Partner/Spouse') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.26-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.3"
                 priority="1293"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Given Name') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Given Name' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Given Name') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.4"
                 priority="1292"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Second and Further Given Names or Initials Thereof' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Second and Further Given Names or Initials Thereof') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.5"
                 priority="1291"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Suffix (e.g., JR or III)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Suffix (e.g., JR or III)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.6"
                 priority="1290"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Prefix (e.g., DR)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Prefix (e.g., DR)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.7"
                 priority="1289"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70360') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70360' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70360') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree (e.g., MD)') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Degree (e.g., MD)' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree (e.g., MD)') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.8"
                 priority="1288"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70297') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70297' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70297') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Source Table') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Source Table' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Source Table') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9"
                 priority="1287"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/hl7v2:HD.1"
                 priority="1285"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/hl7v2:HD.2"
                 priority="1284"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/hl7v2:HD.3"
                 priority="1283"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.10"
                 priority="1281"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70200') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70200' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70200') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.11"
                 priority="1279"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.12"
                 priority="1278"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.13"
                 priority="1276"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14"
                 priority="1274"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/hl7v2:HD.1"
                 priority="1272"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/hl7v2:HD.2"
                 priority="1271"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/hl7v2:HD.3"
                 priority="1270"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.15"
                 priority="1268"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70465') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70465' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70465') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Representation Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Representation Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Representation Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16"
                 priority="1266"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70448') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70448' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70448') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Context') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Context' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Context') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.1"
                 priority="1264"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.2"
                 priority="1263"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.3"
                 priority="1262"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.4"
                 priority="1260"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.5"
                 priority="1259"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/hl7v2:CE.6"
                 priority="1258"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17"
                 priority="1256"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.1 komt te vaak voor [max 1x]. (count(hl7v2:DR.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:DR.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): element hl7v2:DR.2 komt te vaak voor [max 1x]. (count(hl7v2:DR.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DR') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'DR' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DR') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Validity Range') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Validity Range' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Validity Range') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1"
                 priority="1254"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range Start Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range Start Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range Start Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.1"
                 priority="1252"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1/hl7v2:TS.2"
                 priority="1251"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2"
                 priority="1249"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Range End Date/Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(DR_datatype): de waarde van LongName MOET 'Range End Date/Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Range End Date/Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.18-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.1"
                 priority="1247"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2/hl7v2:TS.2"
                 priority="1246"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.18"
                 priority="1244"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70444') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Table MOET 'HL70444' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70444') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name Assembly Order') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Name Assembly Order' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name Assembly Order') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19"
                 priority="1242"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19/hl7v2:TS.1"
                 priority="1240"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19/hl7v2:TS.2"
                 priority="1239"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20"
                 priority="1237"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20/hl7v2:TS.1"
                 priority="1235"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20/hl7v2:TS.2"
                 priority="1234"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.21"
                 priority="1232"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Professional Suffix') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Professional Suffix' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Professional Suffix') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22"
                 priority="1231"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.1"
                 priority="1229"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.2"
                 priority="1228"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.3"
                 priority="1227"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.4"
                 priority="1225"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.5"
                 priority="1224"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.6"
                 priority="1223"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.7"
                 priority="1221"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.8"
                 priority="1220"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/hl7v2:CWE.9"
                 priority="1219"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23"
                 priority="1218"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(XCN_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.74-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.1"
                 priority="1216"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.2"
                 priority="1215"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.3"
                 priority="1214"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.4"
                 priority="1212"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.5"
                 priority="1211"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.6"
                 priority="1210"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.7"
                 priority="1208"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.8"
                 priority="1207"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/hl7v2:CWE.9"
                 priority="1206"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25"
                 priority="1205"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('393') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '393' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('393') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70088') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70088' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70088') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Procedure Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Procedure Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.1"
                 priority="1203"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.2"
                 priority="1202"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.3"
                 priority="1201"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.4"
                 priority="1199"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.5"
                 priority="1198"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/hl7v2:CE.6"
                 priority="1197"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26"
                 priority="1195"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1316') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '1316' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1316') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70340') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70340' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70340') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Procedure Code Modifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Procedure Code Modifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Procedure Code Modifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.1"
                 priority="1193"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.2"
                 priority="1192"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.3"
                 priority="1191"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.4"
                 priority="1189"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.5"
                 priority="1188"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/hl7v2:CE.6"
                 priority="1187"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27"
                 priority="1185"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1310') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '1310' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1310') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70339') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70339' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70339') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Advanced Beneficiary Notice Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Advanced Beneficiary Notice Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.1"
                 priority="1183"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.2"
                 priority="1182"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.3"
                 priority="1181"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.4"
                 priority="1179"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.5"
                 priority="1178"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/hl7v2:CE.6"
                 priority="1177"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28"
                 priority="1175"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1646') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '1646' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1646') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70476') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70476' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70476') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Medically Necessary Duplicate Procedure Reason.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Medically Necessary Duplicate Procedure Reason.') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.1"
                 priority="1173"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.2"
                 priority="1172"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.3"
                 priority="1171"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.4"
                 priority="1169"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.5"
                 priority="1168"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.6"
                 priority="1167"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.7"
                 priority="1165"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.8"
                 priority="1164"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/hl7v2:CWE.9"
                 priority="1163"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29"
                 priority="1162"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.1 komt te vaak voor [max 1x]. (count(hl7v2:CNE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.2 komt te vaak voor [max 1x]. (count(hl7v2:CNE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.3 komt te vaak voor [max 1x]. (count(hl7v2:CNE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.4 komt te vaak voor [max 1x]. (count(hl7v2:CNE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.5 komt te vaak voor [max 1x]. (count(hl7v2:CNE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.6 komt te vaak voor [max 1x]. (count(hl7v2:CNE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.7 komt te vaak voor [max 1x]. (count(hl7v2:CNE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.8 komt te vaak voor [max 1x]. (count(hl7v2:CNE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CNE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): element hl7v2:CNE.9 komt te vaak voor [max 1x]. (count(hl7v2:CNE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1845') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '1845' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1845') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CNE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CNE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CNE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70549') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Table MOET 'HL70549' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70549') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('NDC Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'NDC Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('NDC Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.1"
                 priority="1160"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.2"
                 priority="1159"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.3"
                 priority="1158"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.4"
                 priority="1156"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.5"
                 priority="1155"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.6"
                 priority="1154"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.7"
                 priority="1152"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.8"
                 priority="1151"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/hl7v2:CNE.9"
                 priority="1150"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CNE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.6-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30"
                 priority="1149"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1846') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '1846' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1846') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Payment Reference ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Payment Reference ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Payment Reference ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.1"
                 priority="1147"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.2"
                 priority="1146"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.3"
                 priority="1145"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4"
                 priority="1143"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/hl7v2:HD.1"
                 priority="1141"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/hl7v2:HD.2"
                 priority="1140"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/hl7v2:HD.3"
                 priority="1139"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.5"
                 priority="1137"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6"
                 priority="1135"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/hl7v2:HD.1"
                 priority="1133"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/hl7v2:HD.2"
                 priority="1132"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/hl7v2:HD.3"
                 priority="1131"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.7"
                 priority="1129"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.8"
                 priority="1128"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9"
                 priority="1127"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="1125"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="1124"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="1123"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="1121"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="1120"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="1119"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="1117"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="1116"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="1115"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10"
                 priority="1114"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="1112"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="1111"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="1110"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="1108"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="1107"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="1106"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="1104"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="1103"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="1102"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.31"
                 priority="1101"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1847') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Item MOET '1847' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1847') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('SI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van Type MOET 'SI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('SI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Transaction Reference Key') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(FT1_segment): de waarde van LongName MOET 'Transaction Reference Key' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Transaction Reference Key') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.48-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI"
                 priority="1100"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1) &gt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.1 is required [min 1x]. (count(hl7v2:CTI.1) &gt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.1 komt te vaak voor [max 1x]. (count(hl7v2:CTI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.2 komt te vaak voor [max 1x]. (count(hl7v2:CTI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CTI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): element hl7v2:CTI.3 komt te vaak voor [max 1x]. (count(hl7v2:CTI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1"
                 priority="1099"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.1 komt te vaak voor [max 1x]. (count(hl7v2:EI.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.2 komt te vaak voor [max 1x]. (count(hl7v2:EI.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.3 komt te vaak voor [max 1x]. (count(hl7v2:EI.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:EI.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): element hl7v2:EI.4 komt te vaak voor [max 1x]. (count(hl7v2:EI.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1011') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van Item MOET '1011' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1011') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('EI') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van Type MOET 'EI' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('EI') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Sponsor Study ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van LongName MOET 'Sponsor Study ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Sponsor Study ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.1"
                 priority="1097"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Entity Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Entity Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Entity Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.2"
                 priority="1096"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.3"
                 priority="1095"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/hl7v2:EI.4"
                 priority="1094"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(EI_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.21-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2"
                 priority="1092"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1022') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van Item MOET '1022' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1022') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Study Phase Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van LongName MOET 'Study Phase Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Study Phase Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.1"
                 priority="1090"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.2"
                 priority="1089"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.3"
                 priority="1088"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.4"
                 priority="1086"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.5"
                 priority="1085"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/hl7v2:CE.6"
                 priority="1084"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3"
                 priority="1082"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.1 komt te vaak voor [max 1x]. (count(hl7v2:CE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.2 komt te vaak voor [max 1x]. (count(hl7v2:CE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.3 komt te vaak voor [max 1x]. (count(hl7v2:CE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.4 komt te vaak voor [max 1x]. (count(hl7v2:CE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.5 komt te vaak voor [max 1x]. (count(hl7v2:CE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): element hl7v2:CE.6 komt te vaak voor [max 1x]. (count(hl7v2:CE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1055') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van Item MOET '1055' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1055') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van Type MOET 'CE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Study Scheduled Time Point') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CTI_segment): de waarde van LongName MOET 'Study Scheduled Time Point' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Study Scheduled Time Point') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.31-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.1"
                 priority="1080"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.2"
                 priority="1079"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.3"
                 priority="1078"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.4"
                 priority="1076"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.5"
                 priority="1075"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/hl7v2:CE.6"
                 priority="1074"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.5-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG"
                 priority="1072"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.1 komt te vaak voor [max 1x]. (count(hl7v2:BLG.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.2 komt te vaak voor [max 1x]. (count(hl7v2:BLG.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.3 komt te vaak voor [max 1x]. (count(hl7v2:BLG.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:BLG.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): element hl7v2:BLG.4 komt te vaak voor [max 1x]. (count(hl7v2:BLG.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1"
                 priority="1071"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CCD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): element hl7v2:CCD.1 komt te vaak voor [max 1x]. (count(hl7v2:CCD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CCD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): element hl7v2:CCD.2 komt te vaak voor [max 1x]. (count(hl7v2:CCD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('234') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Item MOET '234' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('234') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CCD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Type MOET 'CCD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CCD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70100') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Table MOET 'HL70100' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70100') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('When to Charge') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van LongName MOET 'When to Charge' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('When to Charge') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.1"
                 priority="1069"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70100') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van Table MOET 'HL70100' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70100') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Invocation Event') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van LongName MOET 'Invocation Event' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Invocation Event') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2"
                 priority="1067"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.1 komt te vaak voor [max 1x]. (count(hl7v2:TS.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:TS.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): element hl7v2:TS.2 komt te vaak voor [max 1x]. (count(hl7v2:TS.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('TS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van Type MOET 'TS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('TS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Date/time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CCD_datatype): de waarde van LongName MOET 'Date/time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Date/time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.3-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2/hl7v2:TS.1"
                 priority="1065"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DTM') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'DTM' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DTM') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Time') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Time' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Time') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2/hl7v2:TS.2"
                 priority="1064"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70529') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van Table MOET 'HL70529' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70529') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Degree of Precision') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(TS_datatype): de waarde van LongName MOET 'Degree of Precision' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Degree of Precision') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.64-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.2"
                 priority="1062"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('235') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Item MOET '235' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('235') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70122') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Table MOET 'HL70122' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70122') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van LongName MOET 'Charge Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3"
                 priority="1060"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.1 komt te vaak voor [max 1x]. (count(hl7v2:CX.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.2 komt te vaak voor [max 1x]. (count(hl7v2:CX.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.3 komt te vaak voor [max 1x]. (count(hl7v2:CX.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.4 komt te vaak voor [max 1x]. (count(hl7v2:CX.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.5 komt te vaak voor [max 1x]. (count(hl7v2:CX.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.6 komt te vaak voor [max 1x]. (count(hl7v2:CX.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.7 komt te vaak voor [max 1x]. (count(hl7v2:CX.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.8 komt te vaak voor [max 1x]. (count(hl7v2:CX.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.9 komt te vaak voor [max 1x]. (count(hl7v2:CX.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CX.10) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): element hl7v2:CX.10 komt te vaak voor [max 1x]. (count(hl7v2:CX.10) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('236') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Item MOET '236' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('236') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CX') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Type MOET 'CX' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CX') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Account ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van LongName MOET 'Account ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Account ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.1"
                 priority="1058"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('ID Number') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'ID Number' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('ID Number') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.2"
                 priority="1057"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.3"
                 priority="1056"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70061') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70061' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70061') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Check Digit Scheme') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Check Digit Scheme' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Check Digit Scheme') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4"
                 priority="1054"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70363') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70363' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70363') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Authority') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Authority' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Authority') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/hl7v2:HD.1"
                 priority="1052"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/hl7v2:HD.2"
                 priority="1051"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/hl7v2:HD.3"
                 priority="1050"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.5"
                 priority="1048"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70203') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Table MOET 'HL70203' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70203') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier Type Code') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Identifier Type Code' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier Type Code') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6"
                 priority="1046"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.1 komt te vaak voor [max 1x]. (count(hl7v2:HD.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.2 komt te vaak voor [max 1x]. (count(hl7v2:HD.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:HD.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): element hl7v2:HD.3 komt te vaak voor [max 1x]. (count(hl7v2:HD.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('HD') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'HD' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('HD') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Facility') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Facility' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Facility') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/hl7v2:HD.1"
                 priority="1044"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('IS') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'IS' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('IS') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70300') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70300' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70300') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Namespace ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Namespace ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Namespace ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/hl7v2:HD.2"
                 priority="1043"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/hl7v2:HD.3"
                 priority="1042"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70301') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van Table MOET 'HL70301' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70301') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Universal ID Type') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(HD_datatype): de waarde van LongName MOET 'Universal ID Type' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Universal ID Type') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.28-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.7"
                 priority="1040"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Effective Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Effective Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Effective Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.8"
                 priority="1039"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('DT') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'DT' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('DT') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Expiration Date') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Expiration Date' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Expiration Date') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9"
                 priority="1038"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Jurisdiction') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Jurisdiction' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Jurisdiction') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.1"
                 priority="1036"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.2"
                 priority="1035"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.3"
                 priority="1034"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.4"
                 priority="1032"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.5"
                 priority="1031"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.6"
                 priority="1030"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.7"
                 priority="1028"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.8"
                 priority="1027"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/hl7v2:CWE.9"
                 priority="1026"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10"
                 priority="1025"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Assigning Agency or Department') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CX_datatype): de waarde van LongName MOET 'Assigning Agency or Department' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Assigning Agency or Department') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.12-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.1"
                 priority="1023"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.2"
                 priority="1022"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.3"
                 priority="1021"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.4"
                 priority="1019"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.5"
                 priority="1018"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.6"
                 priority="1017"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.7"
                 priority="1015"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.8"
                 priority="1014"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/hl7v2:CWE.9"
                 priority="1013"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4"
                 priority="1012"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.1) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.1 komt te vaak voor [max 1x]. (count(hl7v2:CWE.1) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.2) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.2 komt te vaak voor [max 1x]. (count(hl7v2:CWE.2) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.3) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.3 komt te vaak voor [max 1x]. (count(hl7v2:CWE.3) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.4) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.4 komt te vaak voor [max 1x]. (count(hl7v2:CWE.4) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.5) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.5 komt te vaak voor [max 1x]. (count(hl7v2:CWE.5) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.6) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.6 komt te vaak voor [max 1x]. (count(hl7v2:CWE.6) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.7) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.7 komt te vaak voor [max 1x]. (count(hl7v2:CWE.7) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.8) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.8 komt te vaak voor [max 1x]. (count(hl7v2:CWE.8) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="count(hl7v2:CWE.9) &lt;= 1"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): element hl7v2:CWE.9 komt te vaak voor [max 1x]. (count(hl7v2:CWE.9) &lt;= 1 / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Item) = ('1645') or not(@Item)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Item MOET '1645' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Item"/>
               <xsl:text/>" (string(@Item) = ('1645') or not(@Item) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('CWE') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Type MOET 'CWE' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('CWE') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70475') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van Table MOET 'HL70475' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70475') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Charge Type Reason') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(BLG_segment): de waarde van LongName MOET 'Charge Type Reason' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Charge Type Reason') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.13.15-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.1"
                 priority="1010"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.2"
                 priority="1009"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.3"
                 priority="1008"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.4"
                 priority="1006"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Identifier') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Identifier' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Identifier') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.5"
                 priority="1005"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.6"
                 priority="1004"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@MaxLength) = ('Varies - dependent on length of longest code in code set.')"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): de waarde van MaxLength MOET 'Varies - dependent on length of longest code in code set.' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@MaxLength"/>
               <xsl:text/>" (string(@MaxLength) = ('Varies - dependent on length of longest code in code set.') / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="not(@MaxLength)"/>
         <xsl:otherwise>
            <xsl:message>(ID_datatype): attribute @MaxLength MAG NIET voorkomen. (not(@MaxLength) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.83-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ID') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ID') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Table) = ('HL70396') or not(@Table)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Table MOET 'HL70396' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Table"/>
               <xsl:text/>" (string(@Table) = ('HL70396') or not(@Table) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Name of Alternate Coding System') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Name of Alternate Coding System' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Name of Alternate Coding System') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.7"
                 priority="1002"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.8"
                 priority="1001"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Alternate Coding System Version ID' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Alternate Coding System Version ID') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

	  <!--RULE -->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/hl7v2:CWE.9"
                 priority="1000"
                 mode="M14">

		<!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@Type) = ('ST') or not(@Type)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van Type MOET 'ST' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@Type"/>
               <xsl:text/>" (string(@Type) = ('ST') or not(@Type) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>

		    <!--ASSERT error-->
      <xsl:choose>
         <xsl:when test="string(@LongName) = ('Original Text') or not(@LongName)"/>
         <xsl:otherwise>
            <xsl:message>(CWE_datatype): de waarde van LongName MOET 'Original Text' zijn. Gevonden: "<xsl:text/>
               <xsl:value-of select="@LongName"/>
               <xsl:text/>" (string(@LongName) = ('Original Text') or not(@LongName) / error / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.3.1937.777.10.15.11-2013-02-10T000000.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M14"/>
   <xsl:template match="@*|node()" priority="-2" mode="M14">
      <xsl:apply-templates select="*" mode="M14"/>
   </xsl:template>

   <!--PATTERN template-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502-closedLab2Lab Aanvraagbericht (OML^O21)-->


	  <!--RULE d20e3426-true-d398976e0-->
   <xsl:template match="/hl7v2:OML_O21/*[not(@xsi:nil = 'true')][not(self::hl7v2:MSH | self::hl7v2:SFT | self::hl7v2:NTE | self::hl7v2:OML_O21.PATIENT | self::hl7v2:OML_O21.ORDER)]"
                 priority="3234"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3426-true-d398976e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH | hl7v2:SFT | hl7v2:NTE | hl7v2:OML_O21.PATIENT | hl7v2:OML_O21.ORDER (rule-reference: d20e3426-true-d398976e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3689-true-d399006e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/*[not(@xsi:nil = 'true')][not(self::hl7v2:MSH.1 | self::hl7v2:MSH.2 | self::hl7v2:MSH.3 | self::hl7v2:MSH.4 | self::hl7v2:MSH.5 | self::hl7v2:MSH.6 | self::hl7v2:MSH.7 | self::hl7v2:MSH.8 | self::hl7v2:MSH.9 | self::hl7v2:MSH.10 | self::hl7v2:MSH.11 | self::hl7v2:MSH.12 | self::hl7v2:MSH.13 | self::hl7v2:MSH.14 | self::hl7v2:MSH.15 | self::hl7v2:MSH.16 | self::hl7v2:MSH.17 | self::hl7v2:MSH.18 | self::hl7v2:MSH.19 | self::hl7v2:MSH.20 | self::hl7v2:MSH.21)]"
                 priority="3233"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3689-true-d399006e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSH.1 | hl7v2:MSH.2 | hl7v2:MSH.3 | hl7v2:MSH.4 | hl7v2:MSH.5 | hl7v2:MSH.6 | hl7v2:MSH.7 | hl7v2:MSH.8 | hl7v2:MSH.9 | hl7v2:MSH.10 | hl7v2:MSH.11 | hl7v2:MSH.12 | hl7v2:MSH.13 | hl7v2:MSH.14 | hl7v2:MSH.15 | hl7v2:MSH.16 | hl7v2:MSH.17 | hl7v2:MSH.18 | hl7v2:MSH.19 | hl7v2:MSH.20 | hl7v2:MSH.21 (rule-reference: d20e3689-true-d399006e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e35-true-d399030e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3232"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e35-true-d399030e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d398981e35-true-d399030e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e67-true-d399060e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3231"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e67-true-d399060e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d398981e67-true-d399060e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e105-true-d399090e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3230"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e105-true-d399090e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d398981e105-true-d399090e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e137-true-d399120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3229"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e137-true-d399120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d398981e137-true-d399120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e175-true-d399149e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3228"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e175-true-d399149e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d398981e175-true-d399149e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e221-true-d399179e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:MSG.1 | self::hl7v2:MSG.2 | self::hl7v2:MSG.3)]"
                 priority="3227"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e221-true-d399179e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MSG.1 | hl7v2:MSG.2 | hl7v2:MSG.3 (rule-reference: d398981e221-true-d399179e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e280-true-d399214e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:PT.1 | self::hl7v2:PT.2)]"
                 priority="3226"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e280-true-d399214e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PT.1 | hl7v2:PT.2 (rule-reference: d398981e280-true-d399214e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e307-true-d399238e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:VID.1 | self::hl7v2:VID.2 | self::hl7v2:VID.3)]"
                 priority="3225"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e307-true-d399238e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:VID.1 | hl7v2:VID.2 | hl7v2:VID.3 (rule-reference: d398981e307-true-d399238e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399230e36-true-d399259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3224"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399230e36-true-d399259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399230e36-true-d399259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399230e55-true-d399310e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.12/hl7v2:VID.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3223"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399230e55-true-d399310e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399230e55-true-d399310e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e521-true-d399397e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3222"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e521-true-d399397e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d398981e521-true-d399397e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d398981e556-true-d399452e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:MSH/hl7v2:MSH.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="3221"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d398981e556-true-d399452e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d398981e556-true-d399452e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3691-true-d399491e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/*[not(@xsi:nil = 'true')][not(self::hl7v2:SFT.1 | self::hl7v2:SFT.2 | self::hl7v2:SFT.3 | self::hl7v2:SFT.4 | self::hl7v2:SFT.5 | self::hl7v2:SFT.6)]"
                 priority="3220"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3691-true-d399491e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SFT.1 | hl7v2:SFT.2 | hl7v2:SFT.3 | hl7v2:SFT.4 | hl7v2:SFT.5 | hl7v2:SFT.6 (rule-reference: d20e3691-true-d399491e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399481e1-true-d399510e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="3219"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399481e1-true-d399510e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d399481e1-true-d399510e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399495e80-true-d399552e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3218"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399495e80-true-d399552e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d399495e80-true-d399552e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399495e119-true-d399588e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.1/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3217"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399495e119-true-d399588e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d399495e119-true-d399588e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399481e45-true-d399646e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3216"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399481e45-true-d399646e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d399481e45-true-d399646e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399640e15-true-d399656e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3215"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399640e15-true-d399656e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d399640e15-true-d399656e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399650e5-true-d399666e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.5/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3214"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399650e5-true-d399666e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d399650e5-true-d399666e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399481e56-true-d399681e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:SFT/hl7v2:SFT.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3213"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399481e56-true-d399681e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d399481e56-true-d399681e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3693-true-d399706e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="3212"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3693-true-d399706e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3693-true-d399706e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399698e110-true-d399728e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3211"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399698e110-true-d399728e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d399698e110-true-d399728e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399722e36-true-d399738e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3210"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399722e36-true-d399738e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d399722e36-true-d399738e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399732e5-true-d399748e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3209"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399732e5-true-d399748e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d399732e5-true-d399748e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399698e142-true-d399767e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3208"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399698e142-true-d399767e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399698e142-true-d399767e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3695-true-d399817e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/*[not(@xsi:nil = 'true')][not(self::hl7v2:PID | self::hl7v2:PD1 | self::hl7v2:NTE | self::hl7v2:NK1 | self::hl7v2:OML_O21.PATIENT_VISIT | self::hl7v2:OML_O21.INSURANCE | self::hl7v2:GT1 | self::hl7v2:AL1)]"
                 priority="3207"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3695-true-d399817e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID | hl7v2:PD1 | hl7v2:NTE | hl7v2:NK1 | hl7v2:OML_O21.PATIENT_VISIT | hl7v2:OML_O21.INSURANCE | hl7v2:GT1 | hl7v2:AL1 (rule-reference: d20e3695-true-d399817e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3697-true-d399865e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/*[not(@xsi:nil = 'true')][not(self::hl7v2:PID.1 | self::hl7v2:PID.2 | self::hl7v2:PID.3 | self::hl7v2:PID.4 | self::hl7v2:PID.5 | self::hl7v2:PID.6 | self::hl7v2:PID.7 | self::hl7v2:PID.8 | self::hl7v2:PID.9 | self::hl7v2:PID.10 | self::hl7v2:PID.11 | self::hl7v2:PID.12 | self::hl7v2:PID.13 | self::hl7v2:PID.14 | self::hl7v2:PID.15 | self::hl7v2:PID.16 | self::hl7v2:PID.17 | self::hl7v2:PID.18 | self::hl7v2:PID.19 | self::hl7v2:PID.20 | self::hl7v2:PID.21 | self::hl7v2:PID.22 | self::hl7v2:PID.23 | self::hl7v2:PID.24 | self::hl7v2:PID.25 | self::hl7v2:PID.26 | self::hl7v2:PID.27 | self::hl7v2:PID.28 | self::hl7v2:PID.29 | self::hl7v2:PID.30 | self::hl7v2:PID.31 | self::hl7v2:PID.32 | self::hl7v2:PID.33 | self::hl7v2:PID.34 | self::hl7v2:PID.35 | self::hl7v2:PID.36 | self::hl7v2:PID.37 | self::hl7v2:PID.38 | self::hl7v2:PID.39)]"
                 priority="3206"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3697-true-d399865e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID.1 | hl7v2:PID.2 | hl7v2:PID.3 | hl7v2:PID.4 | hl7v2:PID.5 | hl7v2:PID.6 | hl7v2:PID.7 | hl7v2:PID.8 | hl7v2:PID.9 | hl7v2:PID.10 | hl7v2:PID.11 | hl7v2:PID.12 | hl7v2:PID.13 | hl7v2:PID.14 | hl7v2:PID.15 | hl7v2:PID.16 | hl7v2:PID.17 | hl7v2:PID.18 | hl7v2:PID.19 | hl7v2:PID.20 | hl7v2:PID.21 | hl7v2:PID.22 | hl7v2:PID.23 | hl7v2:PID.24 | hl7v2:PID.25 | hl7v2:PID.26 | hl7v2:PID.27 | hl7v2:PID.28 | hl7v2:PID.29 | hl7v2:PID.30 | hl7v2:PID.31 | hl7v2:PID.32 | hl7v2:PID.33 | hl7v2:PID.34 | hl7v2:PID.35 | hl7v2:PID.36 | hl7v2:PID.37 | hl7v2:PID.38 | hl7v2:PID.39 (rule-reference: d20e3697-true-d399865e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e15-true-d399890e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3205"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e15-true-d399890e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d399822e15-true-d399890e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399875e221-true-d399920e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3204"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399875e221-true-d399920e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d399875e221-true-d399920e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399875e263-true-d399956e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3203"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399875e263-true-d399956e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d399875e263-true-d399956e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399875e305-true-d400004e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3202"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399875e305-true-d400004e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d399875e305-true-d400004e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399875e334-true-d400076e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3201"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399875e334-true-d400076e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d399875e334-true-d400076e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e26-true-d400149e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3200"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e26-true-d400149e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d399822e26-true-d400149e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400134e248-true-d400179e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3199"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400134e248-true-d400179e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d400134e248-true-d400179e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400134e290-true-d400215e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3198"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400134e290-true-d400215e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d400134e290-true-d400215e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400134e332-true-d400263e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3197"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400134e332-true-d400263e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d400134e332-true-d400263e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400134e361-true-d400335e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3196"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400134e361-true-d400335e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d400134e361-true-d400335e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e64-true-d400408e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3195"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e64-true-d400408e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d399822e64-true-d400408e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400393e221-true-d400438e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3194"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400393e221-true-d400438e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d400393e221-true-d400438e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400393e263-true-d400474e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3193"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400393e263-true-d400474e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d400393e263-true-d400474e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400393e305-true-d400522e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3192"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400393e305-true-d400522e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d400393e305-true-d400522e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400393e334-true-d400594e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3191"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400393e334-true-d400594e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d400393e334-true-d400594e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e75-true-d400671e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="3190"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e75-true-d400671e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d399822e75-true-d400671e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400652e26-true-d400685e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3189"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400652e26-true-d400685e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d400652e26-true-d400685e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400652e154-true-d400772e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3188"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400652e154-true-d400772e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d400652e154-true-d400772e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400652e167-true-d400819e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3187"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400652e167-true-d400819e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d400652e167-true-d400819e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400812e17-true-d400830e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3186"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400812e17-true-d400830e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d400812e17-true-d400830e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400812e28-true-d400853e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3185"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400812e28-true-d400853e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d400812e28-true-d400853e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400652e197-true-d400882e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3184"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400652e197-true-d400882e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d400652e197-true-d400882e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400652e208-true-d400905e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3183"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400652e208-true-d400905e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d400652e208-true-d400905e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e98-true-d400946e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="3182"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e98-true-d400946e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d399822e98-true-d400946e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400927e15-true-d400960e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3181"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400927e15-true-d400960e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d400927e15-true-d400960e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400927e142-true-d401047e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3180"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400927e142-true-d401047e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d400927e142-true-d401047e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400927e155-true-d401094e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3179"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400927e155-true-d401094e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d400927e155-true-d401094e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401087e17-true-d401105e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3178"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401087e17-true-d401105e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401087e17-true-d401105e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401087e28-true-d401128e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3177"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401087e28-true-d401128e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401087e28-true-d401128e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400927e186-true-d401157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3176"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400927e186-true-d401157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d400927e186-true-d401157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d400927e197-true-d401180e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3175"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d400927e197-true-d401180e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d400927e197-true-d401180e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e109-true-d401209e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3174"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e109-true-d401209e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d399822e109-true-d401209e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e163-true-d401250e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="3173"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e163-true-d401250e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d399822e163-true-d401250e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401231e15-true-d401264e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3172"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401231e15-true-d401264e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d401231e15-true-d401264e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401231e142-true-d401351e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3171"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401231e142-true-d401351e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d401231e142-true-d401351e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401231e155-true-d401398e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3170"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401231e155-true-d401398e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d401231e155-true-d401398e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401391e17-true-d401409e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3169"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401391e17-true-d401409e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401391e17-true-d401409e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401391e28-true-d401432e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3168"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401391e28-true-d401432e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401391e28-true-d401432e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401231e186-true-d401461e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3167"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401231e186-true-d401461e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401231e186-true-d401461e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401231e197-true-d401484e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3166"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401231e197-true-d401484e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401231e197-true-d401484e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e174-true-d401517e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3165"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e174-true-d401517e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e174-true-d401517e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e187-true-d401576e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="3164"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e187-true-d401576e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d399822e187-true-d401576e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401557e32-true-d401588e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="3163"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401557e32-true-d401588e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d401557e32-true-d401588e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401557e231-true-d401677e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3162"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401557e231-true-d401677e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d401557e231-true-d401677e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401670e23-true-d401688e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3161"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401670e23-true-d401688e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401670e23-true-d401688e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401670e34-true-d401711e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3160"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401670e34-true-d401711e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401670e34-true-d401711e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401557e252-true-d401734e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3159"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401557e252-true-d401734e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401557e252-true-d401734e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d401557e266-true-d401757e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3158"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d401557e266-true-d401757e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d401557e266-true-d401757e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e230-true-d401796e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="3157"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e230-true-d401796e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d399822e230-true-d401796e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e244-true-d401889e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="3156"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e244-true-d401889e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d399822e244-true-d401889e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e258-true-d401976e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3155"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e258-true-d401976e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e258-true-d401976e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e271-true-d402027e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3154"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e271-true-d402027e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e271-true-d402027e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e288-true-d402078e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3153"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e288-true-d402078e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e288-true-d402078e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e301-true-d402133e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3152"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e301-true-d402133e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d399822e301-true-d402133e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402118e221-true-d402163e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3151"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402118e221-true-d402163e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d402118e221-true-d402163e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402118e263-true-d402199e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3150"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402118e263-true-d402199e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d402118e263-true-d402199e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402118e305-true-d402247e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3149"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402118e305-true-d402247e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d402118e305-true-d402247e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402118e334-true-d402319e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3148"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402118e334-true-d402319e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d402118e334-true-d402319e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e323-true-d402391e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:DLN.1 | self::hl7v2:DLN.2 | self::hl7v2:DLN.3)]"
                 priority="3147"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e323-true-d402391e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLN.1 | hl7v2:DLN.2 | hl7v2:DLN.3 (rule-reference: d399822e323-true-d402391e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e334-true-d402428e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3146"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e334-true-d402428e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d399822e334-true-d402428e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402413e221-true-d402458e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3145"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402413e221-true-d402458e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d402413e221-true-d402458e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402413e263-true-d402494e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3144"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402413e263-true-d402494e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d402413e263-true-d402494e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402413e305-true-d402542e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3143"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402413e305-true-d402542e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d402413e305-true-d402542e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d402413e334-true-d402614e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3142"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d402413e334-true-d402614e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d402413e334-true-d402614e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e345-true-d402683e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3141"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e345-true-d402683e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e345-true-d402683e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e404-true-d402752e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3140"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e404-true-d402752e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e404-true-d402752e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e417-true-d402803e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3139"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e417-true-d402803e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e417-true-d402803e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e430-true-d402854e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3138"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e430-true-d402854e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e430-true-d402854e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e443-true-d402901e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3137"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e443-true-d402901e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d399822e443-true-d402901e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e493-true-d402942e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3136"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e493-true-d402942e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d399822e493-true-d402942e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e505-true-d402966e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.34/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3135"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e505-true-d402966e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d399822e505-true-d402966e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e516-true-d402999e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3134"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e516-true-d402999e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e516-true-d402999e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e529-true-d403050e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.36/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3133"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e529-true-d403050e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e529-true-d403050e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e553-true-d403107e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3132"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e553-true-d403107e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d399822e553-true-d403107e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d399822e566-true-d403161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PID/hl7v2:PID.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3131"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d399822e566-true-d403161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d399822e566-true-d403161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3699-true-d403245e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/*[not(@xsi:nil = 'true')][not(self::hl7v2:PD1.1 | self::hl7v2:PD1.2 | self::hl7v2:PD1.3 | self::hl7v2:PD1.4 | self::hl7v2:PD1.5 | self::hl7v2:PD1.6 | self::hl7v2:PD1.7 | self::hl7v2:PD1.8 | self::hl7v2:PD1.9 | self::hl7v2:PD1.10 | self::hl7v2:PD1.11 | self::hl7v2:PD1.12 | self::hl7v2:PD1.13 | self::hl7v2:PD1.14 | self::hl7v2:PD1.15 | self::hl7v2:PD1.16 | self::hl7v2:PD1.17 | self::hl7v2:PD1.18 | self::hl7v2:PD1.19 | self::hl7v2:PD1.20 | self::hl7v2:PD1.21)]"
                 priority="3130"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3699-true-d403245e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PD1.1 | hl7v2:PD1.2 | hl7v2:PD1.3 | hl7v2:PD1.4 | hl7v2:PD1.5 | hl7v2:PD1.6 | hl7v2:PD1.7 | hl7v2:PD1.8 | hl7v2:PD1.9 | hl7v2:PD1.10 | hl7v2:PD1.11 | hl7v2:PD1.12 | hl7v2:PD1.13 | hl7v2:PD1.14 | hl7v2:PD1.15 | hl7v2:PD1.16 | hl7v2:PD1.17 | hl7v2:PD1.18 | hl7v2:PD1.19 | hl7v2:PD1.20 | hl7v2:PD1.21 (rule-reference: d20e3699-true-d403245e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403220e27-true-d403276e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="3129"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403220e27-true-d403276e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d403220e27-true-d403276e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403261e80-true-d403318e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3128"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403261e80-true-d403318e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d403261e80-true-d403318e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403261e119-true-d403354e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3127"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403261e119-true-d403354e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d403261e119-true-d403354e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403220e38-true-d403416e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="3126"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403220e38-true-d403416e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d403220e38-true-d403416e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e32-true-d403436e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3125"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e32-true-d403436e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d403388e32-true-d403436e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e123-true-d403514e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3124"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e123-true-d403514e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d403388e123-true-d403514e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e215-true-d403568e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3123"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e215-true-d403568e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d403388e215-true-d403568e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e275-true-d403607e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3122"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e275-true-d403607e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d403388e275-true-d403607e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e288-true-d403654e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3121"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e288-true-d403654e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d403388e288-true-d403654e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403647e17-true-d403665e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3120"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403647e17-true-d403665e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d403647e17-true-d403665e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403647e28-true-d403688e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3119"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403647e28-true-d403688e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d403647e28-true-d403688e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e318-true-d403717e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3118"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e318-true-d403717e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d403388e318-true-d403717e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e329-true-d403740e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3117"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e329-true-d403740e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d403388e329-true-d403740e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e351-true-d403776e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3116"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e351-true-d403776e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d403388e351-true-d403776e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403388e369-true-d403848e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3115"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403388e369-true-d403848e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d403388e369-true-d403848e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403220e114-true-d403951e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3114"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403220e114-true-d403951e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d403220e114-true-d403951e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403936e221-true-d403981e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3113"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403936e221-true-d403981e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d403936e221-true-d403981e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403936e263-true-d404017e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3112"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403936e263-true-d404017e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d403936e263-true-d404017e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403936e305-true-d404065e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3111"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403936e305-true-d404065e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d403936e305-true-d404065e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403936e334-true-d404137e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3110"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403936e334-true-d404137e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d403936e334-true-d404137e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403220e125-true-d404206e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3109"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403220e125-true-d404206e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d403220e125-true-d404206e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403220e163-true-d404273e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="3108"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403220e163-true-d404273e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d403220e163-true-d404273e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404258e80-true-d404315e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3107"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404258e80-true-d404315e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d404258e80-true-d404315e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404258e119-true-d404351e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3106"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404258e119-true-d404351e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d404258e119-true-d404351e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d403220e174-true-d404396e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:PD1/hl7v2:PD1.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3105"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d403220e174-true-d404396e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d403220e174-true-d404396e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3701-true-d404481e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="3104"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3701-true-d404481e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3701-true-d404481e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404473e110-true-d404503e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3103"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404473e110-true-d404503e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d404473e110-true-d404503e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404497e36-true-d404513e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3102"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404497e36-true-d404513e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d404497e36-true-d404513e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404507e5-true-d404523e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3101"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404507e5-true-d404523e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d404507e5-true-d404523e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404473e142-true-d404542e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3100"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404473e142-true-d404542e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404473e142-true-d404542e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3703-true-d404626e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/*[not(@xsi:nil = 'true')][not(self::hl7v2:NK1.1 | self::hl7v2:NK1.2 | self::hl7v2:NK1.3 | self::hl7v2:NK1.4 | self::hl7v2:NK1.5 | self::hl7v2:NK1.6 | self::hl7v2:NK1.7 | self::hl7v2:NK1.8 | self::hl7v2:NK1.9 | self::hl7v2:NK1.10 | self::hl7v2:NK1.11 | self::hl7v2:NK1.12 | self::hl7v2:NK1.13 | self::hl7v2:NK1.14 | self::hl7v2:NK1.15 | self::hl7v2:NK1.16 | self::hl7v2:NK1.17 | self::hl7v2:NK1.18 | self::hl7v2:NK1.19 | self::hl7v2:NK1.20 | self::hl7v2:NK1.21 | self::hl7v2:NK1.22 | self::hl7v2:NK1.23 | self::hl7v2:NK1.24 | self::hl7v2:NK1.25 | self::hl7v2:NK1.26 | self::hl7v2:NK1.27 | self::hl7v2:NK1.28 | self::hl7v2:NK1.29 | self::hl7v2:NK1.30 | self::hl7v2:NK1.31 | self::hl7v2:NK1.32 | self::hl7v2:NK1.33 | self::hl7v2:NK1.34 | self::hl7v2:NK1.35 | self::hl7v2:NK1.36 | self::hl7v2:NK1.37 | self::hl7v2:NK1.38 | self::hl7v2:NK1.39)]"
                 priority="3099"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3703-true-d404626e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NK1.1 | hl7v2:NK1.2 | hl7v2:NK1.3 | hl7v2:NK1.4 | hl7v2:NK1.5 | hl7v2:NK1.6 | hl7v2:NK1.7 | hl7v2:NK1.8 | hl7v2:NK1.9 | hl7v2:NK1.10 | hl7v2:NK1.11 | hl7v2:NK1.12 | hl7v2:NK1.13 | hl7v2:NK1.14 | hl7v2:NK1.15 | hl7v2:NK1.16 | hl7v2:NK1.17 | hl7v2:NK1.18 | hl7v2:NK1.19 | hl7v2:NK1.20 | hl7v2:NK1.21 | hl7v2:NK1.22 | hl7v2:NK1.23 | hl7v2:NK1.24 | hl7v2:NK1.25 | hl7v2:NK1.26 | hl7v2:NK1.27 | hl7v2:NK1.28 | hl7v2:NK1.29 | hl7v2:NK1.30 | hl7v2:NK1.31 | hl7v2:NK1.32 | hl7v2:NK1.33 | hl7v2:NK1.34 | hl7v2:NK1.35 | hl7v2:NK1.36 | hl7v2:NK1.37 | hl7v2:NK1.38 | hl7v2:NK1.39 (rule-reference: d20e3703-true-d404626e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e12-true-d404655e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="3098"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e12-true-d404655e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d404583e12-true-d404655e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404636e15-true-d404669e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3097"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404636e15-true-d404669e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d404636e15-true-d404669e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404636e142-true-d404756e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3096"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404636e142-true-d404756e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404636e142-true-d404756e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404636e155-true-d404803e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3095"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404636e155-true-d404803e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d404636e155-true-d404803e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404796e17-true-d404814e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3094"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404796e17-true-d404814e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404796e17-true-d404814e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404796e28-true-d404837e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3093"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404796e28-true-d404837e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404796e28-true-d404837e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404636e186-true-d404866e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3092"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404636e186-true-d404866e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404636e186-true-d404866e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404636e197-true-d404889e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.2/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3091"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404636e197-true-d404889e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404636e197-true-d404889e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e23-true-d404922e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3090"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e23-true-d404922e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e23-true-d404922e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e36-true-d404981e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="3089"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e36-true-d404981e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d404583e36-true-d404981e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404962e15-true-d404993e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="3088"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404962e15-true-d404993e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d404962e15-true-d404993e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404962e189-true-d405082e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3087"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404962e189-true-d405082e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d404962e189-true-d405082e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405075e17-true-d405093e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3086"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405075e17-true-d405093e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d405075e17-true-d405093e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405075e28-true-d405116e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3085"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405075e28-true-d405116e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d405075e28-true-d405116e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404962e206-true-d405139e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3084"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404962e206-true-d405139e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404962e206-true-d405139e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404962e217-true-d405162e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.4/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3083"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404962e217-true-d405162e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404962e217-true-d405162e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e47-true-d405195e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="3082"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e47-true-d405195e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d404583e47-true-d405195e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e58-true-d405288e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="3081"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e58-true-d405288e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d404583e58-true-d405288e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e69-true-d405375e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3080"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e69-true-d405375e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e69-true-d405375e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e115-true-d405441e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:JCC.1 | self::hl7v2:JCC.2 | self::hl7v2:JCC.3)]"
                 priority="3079"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e115-true-d405441e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:JCC.1 | hl7v2:JCC.2 | hl7v2:JCC.3 (rule-reference: d404583e115-true-d405441e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405433e41-true-d405463e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3078"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405433e41-true-d405463e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d405433e41-true-d405463e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405457e11-true-d405473e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3077"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405457e11-true-d405473e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d405457e11-true-d405473e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405467e5-true-d405483e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.11/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="3076"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405467e5-true-d405483e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d405467e5-true-d405483e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e127-true-d405506e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3075"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e127-true-d405506e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d404583e127-true-d405506e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405491e221-true-d405536e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3074"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405491e221-true-d405536e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d405491e221-true-d405536e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405491e263-true-d405572e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3073"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405491e263-true-d405572e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d405491e263-true-d405572e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405491e305-true-d405620e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3072"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405491e305-true-d405620e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d405491e305-true-d405620e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405491e334-true-d405692e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.12/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3071"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405491e334-true-d405692e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d405491e334-true-d405692e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e138-true-d405765e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="3070"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e138-true-d405765e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d404583e138-true-d405765e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405750e80-true-d405807e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3069"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405750e80-true-d405807e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d405750e80-true-d405807e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d405750e119-true-d405843e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.13/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3068"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d405750e119-true-d405843e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d405750e119-true-d405843e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e149-true-d405888e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3067"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e149-true-d405888e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e149-true-d405888e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e175-true-d405941e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3066"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e175-true-d405941e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d404583e175-true-d405941e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e212-true-d405980e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3065"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e212-true-d405980e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e212-true-d405980e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e225-true-d406031e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3064"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e225-true-d406031e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e225-true-d406031e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e251-true-d406088e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3063"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e251-true-d406088e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e251-true-d406088e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e291-true-d406151e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3062"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e291-true-d406151e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e291-true-d406151e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e304-true-d406210e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="3061"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e304-true-d406210e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d404583e304-true-d406210e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406191e15-true-d406224e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3060"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406191e15-true-d406224e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d406191e15-true-d406224e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406191e142-true-d406311e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3059"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406191e142-true-d406311e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d406191e142-true-d406311e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406191e155-true-d406358e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3058"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406191e155-true-d406358e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d406191e155-true-d406358e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406351e17-true-d406369e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3057"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406351e17-true-d406369e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406351e17-true-d406369e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406351e28-true-d406392e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3056"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406351e28-true-d406392e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406351e28-true-d406392e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406191e186-true-d406421e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3055"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406191e186-true-d406421e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406191e186-true-d406421e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406191e197-true-d406444e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.26/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3054"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406191e197-true-d406444e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406191e197-true-d406444e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e315-true-d406477e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3053"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e315-true-d406477e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e315-true-d406477e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e328-true-d406528e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3052"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e328-true-d406528e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e328-true-d406528e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e341-true-d406579e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3051"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e341-true-d406579e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e341-true-d406579e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e354-true-d406638e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="3050"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e354-true-d406638e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d404583e354-true-d406638e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406619e15-true-d406652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3049"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406619e15-true-d406652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d406619e15-true-d406652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406619e142-true-d406739e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3048"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406619e142-true-d406739e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d406619e142-true-d406739e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406619e155-true-d406786e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3047"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406619e155-true-d406786e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d406619e155-true-d406786e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406779e17-true-d406797e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3046"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406779e17-true-d406797e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406779e17-true-d406797e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406779e28-true-d406820e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3045"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406779e28-true-d406820e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406779e28-true-d406820e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406619e186-true-d406849e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3044"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406619e186-true-d406849e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406619e186-true-d406849e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406619e197-true-d406872e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.30/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3043"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406619e197-true-d406872e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406619e197-true-d406872e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e365-true-d406911e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.31/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="3042"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e365-true-d406911e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d404583e365-true-d406911e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e376-true-d407006e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="3041"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e376-true-d407006e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d404583e376-true-d407006e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406987e15-true-d407018e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="3040"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406987e15-true-d407018e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d406987e15-true-d407018e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406987e189-true-d407107e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3039"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406987e189-true-d407107e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d406987e189-true-d407107e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407100e17-true-d407118e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3038"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407100e17-true-d407118e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d407100e17-true-d407118e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407100e28-true-d407141e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3037"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407100e28-true-d407141e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d407100e28-true-d407141e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406987e206-true-d407164e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3036"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406987e206-true-d407164e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406987e206-true-d407164e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d406987e217-true-d407187e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.32/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3035"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d406987e217-true-d407187e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d406987e217-true-d407187e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e387-true-d407218e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3034"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e387-true-d407218e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d404583e387-true-d407218e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407203e221-true-d407248e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3033"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407203e221-true-d407248e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d407203e221-true-d407248e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407203e263-true-d407284e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3032"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407203e263-true-d407284e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d407203e263-true-d407284e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407203e305-true-d407332e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3031"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407203e305-true-d407332e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d407203e305-true-d407332e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407203e334-true-d407404e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.33/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3030"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407203e334-true-d407404e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d407203e334-true-d407404e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d404583e412-true-d407479e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:NK1/hl7v2:NK1.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3029"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d404583e412-true-d407479e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d404583e412-true-d407479e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3705-true-d407547e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/*[not(@xsi:nil = 'true')][not(self::hl7v2:PV1 | self::hl7v2:PV2)]"
                 priority="3028"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3705-true-d407547e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV1 | hl7v2:PV2 (rule-reference: d20e3705-true-d407547e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3707-true-d407608e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/*[not(@xsi:nil = 'true')][not(self::hl7v2:PV1.1 | self::hl7v2:PV1.2 | self::hl7v2:PV1.3 | self::hl7v2:PV1.4 | self::hl7v2:PV1.5 | self::hl7v2:PV1.6 | self::hl7v2:PV1.7 | self::hl7v2:PV1.8 | self::hl7v2:PV1.9 | self::hl7v2:PV1.10 | self::hl7v2:PV1.11 | self::hl7v2:PV1.12 | self::hl7v2:PV1.13 | self::hl7v2:PV1.14 | self::hl7v2:PV1.15 | self::hl7v2:PV1.16 | self::hl7v2:PV1.17 | self::hl7v2:PV1.18 | self::hl7v2:PV1.19 | self::hl7v2:PV1.20 | self::hl7v2:PV1.21 | self::hl7v2:PV1.22 | self::hl7v2:PV1.23 | self::hl7v2:PV1.24 | self::hl7v2:PV1.25 | self::hl7v2:PV1.26 | self::hl7v2:PV1.27 | self::hl7v2:PV1.28 | self::hl7v2:PV1.29 | self::hl7v2:PV1.30 | self::hl7v2:PV1.31 | self::hl7v2:PV1.32 | self::hl7v2:PV1.33 | self::hl7v2:PV1.34 | self::hl7v2:PV1.35 | self::hl7v2:PV1.36 | self::hl7v2:PV1.37 | self::hl7v2:PV1.38 | self::hl7v2:PV1.39 | self::hl7v2:PV1.40 | self::hl7v2:PV1.41 | self::hl7v2:PV1.42 | self::hl7v2:PV1.43 | self::hl7v2:PV1.44 | self::hl7v2:PV1.45 | self::hl7v2:PV1.46 | self::hl7v2:PV1.47 | self::hl7v2:PV1.48 | self::hl7v2:PV1.49 | self::hl7v2:PV1.50 | self::hl7v2:PV1.51 | self::hl7v2:PV1.52)]"
                 priority="3027"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3707-true-d407608e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV1.1 | hl7v2:PV1.2 | hl7v2:PV1.3 | hl7v2:PV1.4 | hl7v2:PV1.5 | hl7v2:PV1.6 | hl7v2:PV1.7 | hl7v2:PV1.8 | hl7v2:PV1.9 | hl7v2:PV1.10 | hl7v2:PV1.11 | hl7v2:PV1.12 | hl7v2:PV1.13 | hl7v2:PV1.14 | hl7v2:PV1.15 | hl7v2:PV1.16 | hl7v2:PV1.17 | hl7v2:PV1.18 | hl7v2:PV1.19 | hl7v2:PV1.20 | hl7v2:PV1.21 | hl7v2:PV1.22 | hl7v2:PV1.23 | hl7v2:PV1.24 | hl7v2:PV1.25 | hl7v2:PV1.26 | hl7v2:PV1.27 | hl7v2:PV1.28 | hl7v2:PV1.29 | hl7v2:PV1.30 | hl7v2:PV1.31 | hl7v2:PV1.32 | hl7v2:PV1.33 | hl7v2:PV1.34 | hl7v2:PV1.35 | hl7v2:PV1.36 | hl7v2:PV1.37 | hl7v2:PV1.38 | hl7v2:PV1.39 | hl7v2:PV1.40 | hl7v2:PV1.41 | hl7v2:PV1.42 | hl7v2:PV1.43 | hl7v2:PV1.44 | hl7v2:PV1.45 | hl7v2:PV1.46 | hl7v2:PV1.47 | hl7v2:PV1.48 | hl7v2:PV1.49 | hl7v2:PV1.50 | hl7v2:PV1.51 | hl7v2:PV1.52 (rule-reference: d20e3707-true-d407608e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e32-true-d407640e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="3026"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e32-true-d407640e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d407552e32-true-d407640e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407624e81-true-d407670e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3025"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407624e81-true-d407670e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d407624e81-true-d407670e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407624e180-true-d407731e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="3024"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407624e180-true-d407731e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d407624e180-true-d407731e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407624e192-true-d407767e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3023"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407624e192-true-d407767e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d407624e192-true-d407767e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e83-true-d407810e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="3022"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e83-true-d407810e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d407552e83-true-d407810e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407795e221-true-d407840e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3021"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407795e221-true-d407840e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d407795e221-true-d407840e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407795e263-true-d407876e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3020"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407795e263-true-d407876e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d407795e263-true-d407876e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407795e305-true-d407924e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3019"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407795e305-true-d407924e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d407795e305-true-d407924e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407795e334-true-d407996e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3018"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407795e334-true-d407996e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d407795e334-true-d407996e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e94-true-d408070e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="3017"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e94-true-d408070e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d407552e94-true-d408070e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408054e48-true-d408100e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3016"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408054e48-true-d408100e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d408054e48-true-d408100e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408054e125-true-d408161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="3015"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408054e125-true-d408161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d408054e125-true-d408161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408054e134-true-d408197e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3014"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408054e134-true-d408197e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d408054e134-true-d408197e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e105-true-d408247e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="3013"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e105-true-d408247e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d407552e105-true-d408247e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e35-true-d408267e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3012"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e35-true-d408267e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d408219e35-true-d408267e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e127-true-d408345e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3011"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e127-true-d408345e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d408219e127-true-d408345e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e218-true-d408399e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="3010"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e218-true-d408399e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d408219e218-true-d408399e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e278-true-d408438e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="3009"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e278-true-d408438e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d408219e278-true-d408438e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e291-true-d408485e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="3008"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e291-true-d408485e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d408219e291-true-d408485e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408478e17-true-d408496e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3007"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408478e17-true-d408496e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408478e17-true-d408496e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408478e28-true-d408519e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3006"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408478e28-true-d408519e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408478e28-true-d408519e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e322-true-d408548e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3005"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e322-true-d408548e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408219e322-true-d408548e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e333-true-d408571e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="3004"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e333-true-d408571e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408219e333-true-d408571e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e355-true-d408607e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3003"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e355-true-d408607e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d408219e355-true-d408607e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408219e372-true-d408679e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="3002"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408219e372-true-d408679e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d408219e372-true-d408679e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e118-true-d408765e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="3001"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e118-true-d408765e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d407552e118-true-d408765e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e35-true-d408785e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="3000"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e35-true-d408785e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d408737e35-true-d408785e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e127-true-d408863e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2999"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e127-true-d408863e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d408737e127-true-d408863e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e218-true-d408917e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2998"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e218-true-d408917e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d408737e218-true-d408917e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e278-true-d408956e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2997"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e278-true-d408956e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d408737e278-true-d408956e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e291-true-d409003e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2996"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e291-true-d409003e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d408737e291-true-d409003e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408996e17-true-d409014e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2995"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408996e17-true-d409014e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408996e17-true-d409014e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408996e28-true-d409037e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2994"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408996e28-true-d409037e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408996e28-true-d409037e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e322-true-d409066e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2993"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e322-true-d409066e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408737e322-true-d409066e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e333-true-d409089e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2992"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e333-true-d409089e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d408737e333-true-d409089e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e355-true-d409125e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2991"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e355-true-d409125e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d408737e355-true-d409125e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d408737e372-true-d409197e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2990"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d408737e372-true-d409197e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d408737e372-true-d409197e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e131-true-d409283e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2989"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e131-true-d409283e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d407552e131-true-d409283e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e35-true-d409303e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2988"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e35-true-d409303e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d409255e35-true-d409303e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e127-true-d409381e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2987"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e127-true-d409381e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d409255e127-true-d409381e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e218-true-d409435e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2986"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e218-true-d409435e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d409255e218-true-d409435e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e278-true-d409474e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2985"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e278-true-d409474e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d409255e278-true-d409474e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e291-true-d409521e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2984"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e291-true-d409521e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d409255e291-true-d409521e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409514e17-true-d409532e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2983"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409514e17-true-d409532e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d409514e17-true-d409532e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409514e28-true-d409555e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2982"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409514e28-true-d409555e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d409514e28-true-d409555e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e322-true-d409584e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2981"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e322-true-d409584e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d409255e322-true-d409584e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e333-true-d409607e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2980"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e333-true-d409607e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d409255e333-true-d409607e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e355-true-d409643e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2979"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e355-true-d409643e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d409255e355-true-d409643e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409255e372-true-d409715e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2978"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409255e372-true-d409715e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d409255e372-true-d409715e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e166-true-d409795e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="2977"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e166-true-d409795e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d407552e166-true-d409795e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409779e48-true-d409825e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2976"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409779e48-true-d409825e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d409779e48-true-d409825e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409779e125-true-d409886e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2975"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409779e125-true-d409886e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d409779e125-true-d409886e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409779e134-true-d409922e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2974"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409779e134-true-d409922e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d409779e134-true-d409922e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e243-true-d410002e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2973"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e243-true-d410002e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d407552e243-true-d410002e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e35-true-d410022e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2972"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e35-true-d410022e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d409974e35-true-d410022e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e127-true-d410100e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2971"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e127-true-d410100e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d409974e127-true-d410100e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e218-true-d410154e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2970"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e218-true-d410154e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d409974e218-true-d410154e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e278-true-d410193e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2969"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e278-true-d410193e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d409974e278-true-d410193e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e291-true-d410240e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2968"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e291-true-d410240e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d409974e291-true-d410240e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410233e17-true-d410251e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2967"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410233e17-true-d410251e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d410233e17-true-d410251e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410233e28-true-d410274e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2966"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410233e28-true-d410274e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d410233e28-true-d410274e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e322-true-d410303e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2965"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e322-true-d410303e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d409974e322-true-d410303e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e333-true-d410326e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2964"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e333-true-d410326e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d409974e333-true-d410326e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e355-true-d410362e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2963"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e355-true-d410362e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d409974e355-true-d410362e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d409974e372-true-d410434e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2962"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d409974e372-true-d410434e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d409974e372-true-d410434e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e269-true-d410513e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2961"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e269-true-d410513e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d407552e269-true-d410513e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410498e221-true-d410543e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2960"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410498e221-true-d410543e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d410498e221-true-d410543e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410498e263-true-d410579e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2959"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410498e263-true-d410579e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d410498e263-true-d410579e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410498e305-true-d410627e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2958"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410498e305-true-d410627e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d410498e305-true-d410627e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410498e334-true-d410699e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2957"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410498e334-true-d410699e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d410498e334-true-d410699e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e280-true-d410764e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:FC.1 | self::hl7v2:FC.2)]"
                 priority="2956"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e280-true-d410764e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FC.1 | hl7v2:FC.2 (rule-reference: d407552e280-true-d410764e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410757e31-true-d410781e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2955"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410757e31-true-d410781e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d410757e31-true-d410781e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e489-true-d410900e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/*[not(@xsi:nil = 'true')][not(self::hl7v2:DLD.1 | self::hl7v2:DLD.2)]"
                 priority="2954"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e489-true-d410900e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLD.1 | hl7v2:DLD.2 (rule-reference: d407552e489-true-d410900e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d410893e31-true-d410917e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2953"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d410893e31-true-d410917e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d410893e31-true-d410917e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e502-true-d410944e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2952"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e502-true-d410944e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d407552e502-true-d410944e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e563-true-d411018e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="2951"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e563-true-d411018e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d407552e563-true-d411018e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411002e48-true-d411048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2950"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411002e48-true-d411048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411002e48-true-d411048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411002e125-true-d411109e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2949"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411002e125-true-d411109e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d411002e125-true-d411109e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411002e134-true-d411145e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2948"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411002e134-true-d411145e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411002e134-true-d411145e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e574-true-d411183e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="2947"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e574-true-d411183e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d407552e574-true-d411183e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411167e48-true-d411213e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2946"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411167e48-true-d411213e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411167e48-true-d411213e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411167e125-true-d411274e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2945"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411167e125-true-d411274e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d411167e125-true-d411274e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411167e134-true-d411310e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2944"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411167e134-true-d411310e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411167e134-true-d411310e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e585-true-d411339e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2943"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e585-true-d411339e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d407552e585-true-d411339e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e607-true-d411362e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2942"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e607-true-d411362e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d407552e607-true-d411362e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e662-true-d411417e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2941"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e662-true-d411417e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d407552e662-true-d411417e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411402e224-true-d411447e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2940"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411402e224-true-d411447e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411402e224-true-d411447e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411402e266-true-d411483e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2939"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411402e266-true-d411483e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411402e266-true-d411483e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411402e309-true-d411531e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2938"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411402e309-true-d411531e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d411402e309-true-d411531e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411402e338-true-d411603e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2937"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411402e338-true-d411603e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d411402e338-true-d411603e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d407552e688-true-d411695e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2936"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d407552e688-true-d411695e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d407552e688-true-d411695e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e35-true-d411715e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2935"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e35-true-d411715e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d411667e35-true-d411715e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e127-true-d411793e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2934"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e127-true-d411793e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411667e127-true-d411793e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e218-true-d411847e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2933"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e218-true-d411847e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d411667e218-true-d411847e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e278-true-d411886e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2932"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e278-true-d411886e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d411667e278-true-d411886e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e291-true-d411933e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2931"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e291-true-d411933e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d411667e291-true-d411933e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411926e17-true-d411944e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2930"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411926e17-true-d411944e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d411926e17-true-d411944e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411926e28-true-d411967e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2929"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411926e28-true-d411967e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d411926e28-true-d411967e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e322-true-d411996e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2928"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e322-true-d411996e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d411667e322-true-d411996e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e333-true-d412019e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2927"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e333-true-d412019e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d411667e333-true-d412019e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e355-true-d412055e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2926"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e355-true-d412055e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d411667e355-true-d412055e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d411667e372-true-d412127e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2925"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d411667e372-true-d412127e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d411667e372-true-d412127e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3709-true-d412239e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/*[not(@xsi:nil = 'true')][not(self::hl7v2:PV2.1 | self::hl7v2:PV2.2 | self::hl7v2:PV2.3 | self::hl7v2:PV2.4 | self::hl7v2:PV2.5 | self::hl7v2:PV2.6 | self::hl7v2:PV2.7 | self::hl7v2:PV2.8 | self::hl7v2:PV2.9 | self::hl7v2:PV2.10 | self::hl7v2:PV2.11 | self::hl7v2:PV2.12 | self::hl7v2:PV2.13 | self::hl7v2:PV2.14 | self::hl7v2:PV2.15 | self::hl7v2:PV2.16 | self::hl7v2:PV2.17 | self::hl7v2:PV2.18 | self::hl7v2:PV2.19 | self::hl7v2:PV2.20 | self::hl7v2:PV2.21 | self::hl7v2:PV2.22 | self::hl7v2:PV2.23 | self::hl7v2:PV2.24 | self::hl7v2:PV2.25 | self::hl7v2:PV2.26 | self::hl7v2:PV2.27 | self::hl7v2:PV2.28 | self::hl7v2:PV2.29 | self::hl7v2:PV2.30 | self::hl7v2:PV2.31 | self::hl7v2:PV2.32 | self::hl7v2:PV2.33 | self::hl7v2:PV2.34 | self::hl7v2:PV2.35 | self::hl7v2:PV2.36 | self::hl7v2:PV2.37 | self::hl7v2:PV2.38 | self::hl7v2:PV2.39 | self::hl7v2:PV2.40 | self::hl7v2:PV2.41 | self::hl7v2:PV2.42 | self::hl7v2:PV2.43 | self::hl7v2:PV2.44 | self::hl7v2:PV2.45 | self::hl7v2:PV2.46 | self::hl7v2:PV2.47 | self::hl7v2:PV2.48 | self::hl7v2:PV2.49)]"
                 priority="2924"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3709-true-d412239e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV2.1 | hl7v2:PV2.2 | hl7v2:PV2.3 | hl7v2:PV2.4 | hl7v2:PV2.5 | hl7v2:PV2.6 | hl7v2:PV2.7 | hl7v2:PV2.8 | hl7v2:PV2.9 | hl7v2:PV2.10 | hl7v2:PV2.11 | hl7v2:PV2.12 | hl7v2:PV2.13 | hl7v2:PV2.14 | hl7v2:PV2.15 | hl7v2:PV2.16 | hl7v2:PV2.17 | hl7v2:PV2.18 | hl7v2:PV2.19 | hl7v2:PV2.20 | hl7v2:PV2.21 | hl7v2:PV2.22 | hl7v2:PV2.23 | hl7v2:PV2.24 | hl7v2:PV2.25 | hl7v2:PV2.26 | hl7v2:PV2.27 | hl7v2:PV2.28 | hl7v2:PV2.29 | hl7v2:PV2.30 | hl7v2:PV2.31 | hl7v2:PV2.32 | hl7v2:PV2.33 | hl7v2:PV2.34 | hl7v2:PV2.35 | hl7v2:PV2.36 | hl7v2:PV2.37 | hl7v2:PV2.38 | hl7v2:PV2.39 | hl7v2:PV2.40 | hl7v2:PV2.41 | hl7v2:PV2.42 | hl7v2:PV2.43 | hl7v2:PV2.44 | hl7v2:PV2.45 | hl7v2:PV2.46 | hl7v2:PV2.47 | hl7v2:PV2.48 | hl7v2:PV2.49 (rule-reference: d20e3709-true-d412239e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e1-true-d412259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="2923"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e1-true-d412259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d412186e1-true-d412259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412243e48-true-d412289e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2922"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412243e48-true-d412289e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d412243e48-true-d412289e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412243e125-true-d412350e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2921"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412243e125-true-d412350e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d412243e125-true-d412350e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412243e134-true-d412386e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2920"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412243e134-true-d412386e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d412243e134-true-d412386e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e12-true-d412419e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2919"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e12-true-d412419e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e12-true-d412419e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e25-true-d412470e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2918"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e25-true-d412470e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e25-true-d412470e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e36-true-d412521e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2917"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e36-true-d412521e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e36-true-d412521e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e82-true-d412586e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2916"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e82-true-d412586e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412186e82-true-d412586e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e93-true-d412609e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2915"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e93-true-d412609e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412186e93-true-d412609e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e138-true-d412671e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2914"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e138-true-d412671e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d412186e138-true-d412671e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e32-true-d412691e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2913"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e32-true-d412691e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d412643e32-true-d412691e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e123-true-d412769e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2912"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e123-true-d412769e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d412643e123-true-d412769e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e215-true-d412823e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2911"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e215-true-d412823e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d412643e215-true-d412823e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e275-true-d412862e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2910"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e275-true-d412862e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412643e275-true-d412862e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e288-true-d412909e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2909"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e288-true-d412909e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d412643e288-true-d412909e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412902e17-true-d412920e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2908"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412902e17-true-d412920e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412902e17-true-d412920e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412902e28-true-d412943e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2907"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412902e28-true-d412943e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412902e28-true-d412943e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e318-true-d412972e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2906"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e318-true-d412972e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412643e318-true-d412972e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e329-true-d412995e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2905"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e329-true-d412995e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412643e329-true-d412995e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e351-true-d413031e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2904"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e351-true-d413031e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d412643e351-true-d413031e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412643e369-true-d413103e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2903"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412643e369-true-d413103e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d412643e369-true-d413103e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e261-true-d413230e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2902"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e261-true-d413230e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d412186e261-true-d413230e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413215e80-true-d413272e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2901"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413215e80-true-d413272e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d413215e80-true-d413272e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413215e119-true-d413308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2900"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413215e119-true-d413308e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d413215e119-true-d413308e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e344-true-d413389e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2899"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e344-true-d413389e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e344-true-d413389e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e383-true-d413448e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2898"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e383-true-d413448e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412186e383-true-d413448e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e447-true-d413499e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2897"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e447-true-d413499e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e447-true-d413499e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e460-true-d413550e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2896"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e460-true-d413550e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e460-true-d413550e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e473-true-d413601e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2895"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e473-true-d413601e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e473-true-d413601e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e486-true-d413652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.41/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2894"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e486-true-d413652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e486-true-d413652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e499-true-d413703e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2893"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e499-true-d413703e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e499-true-d413703e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e539-true-d413766e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2892"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e539-true-d413766e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d412186e539-true-d413766e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e563-true-d413819e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.47/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2891"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e563-true-d413819e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412186e563-true-d413819e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d412186e574-true-d413842e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.PATIENT_VISIT/hl7v2:PV2/hl7v2:PV2.48/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2890"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d412186e574-true-d413842e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d412186e574-true-d413842e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3713-true-d413869e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/*[not(@xsi:nil = 'true')][not(self::hl7v2:IN1 | self::hl7v2:IN2 | self::hl7v2:IN3)]"
                 priority="2889"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3713-true-d413869e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:IN1 | hl7v2:IN2 | hl7v2:IN3 (rule-reference: d20e3713-true-d413869e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3715-true-d413931e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/*[not(@xsi:nil = 'true')][not(self::hl7v2:IN1.1 | self::hl7v2:IN1.2 | self::hl7v2:IN1.3 | self::hl7v2:IN1.4 | self::hl7v2:IN1.5 | self::hl7v2:IN1.6 | self::hl7v2:IN1.7 | self::hl7v2:IN1.8 | self::hl7v2:IN1.9 | self::hl7v2:IN1.10 | self::hl7v2:IN1.11 | self::hl7v2:IN1.12 | self::hl7v2:IN1.13 | self::hl7v2:IN1.14 | self::hl7v2:IN1.15 | self::hl7v2:IN1.16 | self::hl7v2:IN1.17 | self::hl7v2:IN1.18 | self::hl7v2:IN1.19 | self::hl7v2:IN1.20 | self::hl7v2:IN1.21 | self::hl7v2:IN1.22 | self::hl7v2:IN1.23 | self::hl7v2:IN1.24 | self::hl7v2:IN1.25 | self::hl7v2:IN1.26 | self::hl7v2:IN1.27 | self::hl7v2:IN1.28 | self::hl7v2:IN1.29 | self::hl7v2:IN1.30 | self::hl7v2:IN1.31 | self::hl7v2:IN1.32 | self::hl7v2:IN1.33 | self::hl7v2:IN1.34 | self::hl7v2:IN1.35 | self::hl7v2:IN1.36 | self::hl7v2:IN1.37 | self::hl7v2:IN1.38 | self::hl7v2:IN1.39 | self::hl7v2:IN1.40 | self::hl7v2:IN1.41 | self::hl7v2:IN1.42 | self::hl7v2:IN1.43 | self::hl7v2:IN1.44 | self::hl7v2:IN1.45 | self::hl7v2:IN1.46 | self::hl7v2:IN1.47 | self::hl7v2:IN1.48 | self::hl7v2:IN1.49 | self::hl7v2:IN1.50 | self::hl7v2:IN1.51 | self::hl7v2:IN1.52 | self::hl7v2:IN1.53)]"
                 priority="2888"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3715-true-d413931e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:IN1.1 | hl7v2:IN1.2 | hl7v2:IN1.3 | hl7v2:IN1.4 | hl7v2:IN1.5 | hl7v2:IN1.6 | hl7v2:IN1.7 | hl7v2:IN1.8 | hl7v2:IN1.9 | hl7v2:IN1.10 | hl7v2:IN1.11 | hl7v2:IN1.12 | hl7v2:IN1.13 | hl7v2:IN1.14 | hl7v2:IN1.15 | hl7v2:IN1.16 | hl7v2:IN1.17 | hl7v2:IN1.18 | hl7v2:IN1.19 | hl7v2:IN1.20 | hl7v2:IN1.21 | hl7v2:IN1.22 | hl7v2:IN1.23 | hl7v2:IN1.24 | hl7v2:IN1.25 | hl7v2:IN1.26 | hl7v2:IN1.27 | hl7v2:IN1.28 | hl7v2:IN1.29 | hl7v2:IN1.30 | hl7v2:IN1.31 | hl7v2:IN1.32 | hl7v2:IN1.33 | hl7v2:IN1.34 | hl7v2:IN1.35 | hl7v2:IN1.36 | hl7v2:IN1.37 | hl7v2:IN1.38 | hl7v2:IN1.39 | hl7v2:IN1.40 | hl7v2:IN1.41 | hl7v2:IN1.42 | hl7v2:IN1.43 | hl7v2:IN1.44 | hl7v2:IN1.45 | hl7v2:IN1.46 | hl7v2:IN1.47 | hl7v2:IN1.48 | hl7v2:IN1.49 | hl7v2:IN1.50 | hl7v2:IN1.51 | hl7v2:IN1.52 | hl7v2:IN1.53 (rule-reference: d20e3715-true-d413931e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e15-true-d413952e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2887"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e15-true-d413952e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d413874e15-true-d413952e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e38-true-d414007e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2886"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e38-true-d414007e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d413874e38-true-d414007e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413992e227-true-d414037e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2885"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413992e227-true-d414037e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d413992e227-true-d414037e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413992e269-true-d414073e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2884"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413992e269-true-d414073e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d413992e269-true-d414073e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413992e311-true-d414121e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2883"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413992e311-true-d414121e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d413992e311-true-d414121e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413992e341-true-d414193e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.3/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2882"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413992e341-true-d414193e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d413992e341-true-d414193e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e55-true-d414266e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2881"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e55-true-d414266e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d413874e55-true-d414266e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414251e83-true-d414308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2880"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414251e83-true-d414308e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d414251e83-true-d414308e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414251e122-true-d414344e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.4/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2879"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414251e122-true-d414344e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d414251e122-true-d414344e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e69-true-d414397e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2878"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e69-true-d414397e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d413874e69-true-d414397e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414378e18-true-d414409e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2877"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414378e18-true-d414409e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d414378e18-true-d414409e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414378e217-true-d414498e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2876"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414378e217-true-d414498e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d414378e217-true-d414498e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414491e23-true-d414509e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2875"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414491e23-true-d414509e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414491e23-true-d414509e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414491e34-true-d414532e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2874"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414491e34-true-d414532e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414491e34-true-d414532e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414378e237-true-d414555e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2873"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414378e237-true-d414555e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414378e237-true-d414555e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414378e251-true-d414578e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.5/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2872"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414378e251-true-d414578e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414378e251-true-d414578e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e83-true-d414613e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2871"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e83-true-d414613e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d413874e83-true-d414613e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414594e18-true-d414627e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2870"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414594e18-true-d414627e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d414594e18-true-d414627e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414594e145-true-d414714e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2869"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414594e145-true-d414714e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d414594e145-true-d414714e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414594e159-true-d414761e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2868"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414594e159-true-d414761e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d414594e159-true-d414761e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414754e17-true-d414772e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2867"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414754e17-true-d414772e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414754e17-true-d414772e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414754e28-true-d414795e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2866"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414754e28-true-d414795e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414754e28-true-d414795e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414594e189-true-d414824e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2865"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414594e189-true-d414824e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414594e189-true-d414824e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414594e200-true-d414847e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.6/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2864"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414594e200-true-d414847e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d414594e200-true-d414847e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e97-true-d414886e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2863"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e97-true-d414886e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d413874e97-true-d414886e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e125-true-d414983e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2862"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e125-true-d414983e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d413874e125-true-d414983e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414968e83-true-d415025e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2861"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414968e83-true-d415025e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d414968e83-true-d415025e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d414968e122-true-d415061e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.9/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2860"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d414968e122-true-d415061e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d414968e122-true-d415061e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e139-true-d415110e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2859"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e139-true-d415110e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d413874e139-true-d415110e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415095e221-true-d415140e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2858"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415095e221-true-d415140e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d415095e221-true-d415140e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415095e263-true-d415176e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2857"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415095e263-true-d415176e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d415095e263-true-d415176e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415095e305-true-d415224e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2856"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415095e305-true-d415224e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d415095e305-true-d415224e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415095e334-true-d415296e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.10/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2855"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415095e334-true-d415296e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d415095e334-true-d415296e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e150-true-d415369e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2854"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e150-true-d415369e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d413874e150-true-d415369e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415354e80-true-d415411e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2853"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415354e80-true-d415411e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d415354e80-true-d415411e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415354e119-true-d415447e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.11/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2852"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415354e119-true-d415447e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d415354e119-true-d415447e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e190-true-d415501e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:AUI.1 | self::hl7v2:AUI.2 | self::hl7v2:AUI.3)]"
                 priority="2851"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e190-true-d415501e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:AUI.1 | hl7v2:AUI.2 | hl7v2:AUI.3 (rule-reference: d413874e190-true-d415501e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e218-true-d415548e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2850"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e218-true-d415548e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d413874e218-true-d415548e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415529e18-true-d415562e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2849"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415529e18-true-d415562e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d415529e18-true-d415562e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415529e145-true-d415649e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2848"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415529e145-true-d415649e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d415529e145-true-d415649e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415529e159-true-d415696e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2847"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415529e159-true-d415696e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d415529e159-true-d415696e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415689e17-true-d415707e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2846"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415689e17-true-d415707e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415689e17-true-d415707e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415689e28-true-d415730e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2845"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415689e28-true-d415730e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415689e28-true-d415730e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415529e189-true-d415759e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2844"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415529e189-true-d415759e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415529e189-true-d415759e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415529e200-true-d415782e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.16/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2843"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415529e200-true-d415782e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415529e200-true-d415782e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e232-true-d415815e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2842"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e232-true-d415815e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d413874e232-true-d415815e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e249-true-d415862e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2841"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e249-true-d415862e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d413874e249-true-d415862e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e263-true-d415897e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2840"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e263-true-d415897e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d413874e263-true-d415897e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415878e18-true-d415909e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2839"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415878e18-true-d415909e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d415878e18-true-d415909e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415878e217-true-d415998e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2838"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415878e217-true-d415998e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d415878e217-true-d415998e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415991e23-true-d416009e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2837"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415991e23-true-d416009e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415991e23-true-d416009e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415991e34-true-d416032e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2836"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415991e34-true-d416032e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415991e34-true-d416032e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415878e237-true-d416055e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2835"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415878e237-true-d416055e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415878e237-true-d416055e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d415878e251-true-d416078e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.19/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2834"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d415878e251-true-d416078e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d415878e251-true-d416078e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e387-true-d416155e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2833"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e387-true-d416155e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d413874e387-true-d416155e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e398-true-d416199e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2832"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e398-true-d416199e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d413874e398-true-d416199e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e32-true-d416219e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2831"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e32-true-d416219e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d416171e32-true-d416219e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e123-true-d416297e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2830"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e123-true-d416297e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d416171e123-true-d416297e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e215-true-d416351e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2829"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e215-true-d416351e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d416171e215-true-d416351e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e275-true-d416390e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2828"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e275-true-d416390e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d416171e275-true-d416390e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e288-true-d416437e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2827"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e288-true-d416437e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d416171e288-true-d416437e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416430e17-true-d416448e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2826"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416430e17-true-d416448e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d416430e17-true-d416448e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416430e28-true-d416471e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2825"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416430e28-true-d416471e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d416430e28-true-d416471e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e318-true-d416500e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2824"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e318-true-d416500e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d416171e318-true-d416500e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e329-true-d416523e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2823"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e329-true-d416523e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d416171e329-true-d416523e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e351-true-d416559e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2822"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e351-true-d416559e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d416171e351-true-d416559e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416171e369-true-d416631e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.30/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2821"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416171e369-true-d416631e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d416171e369-true-d416631e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e485-true-d416736e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="2820"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e485-true-d416736e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d413874e485-true-d416736e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416725e15-true-d416747e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2819"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416725e15-true-d416747e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d416725e15-true-d416747e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416725e82-true-d416792e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.37/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2818"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416725e82-true-d416792e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d416725e82-true-d416792e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e496-true-d416849e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="2817"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e496-true-d416849e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d413874e496-true-d416849e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416838e15-true-d416860e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2816"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416838e15-true-d416860e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d416838e15-true-d416860e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416838e82-true-d416905e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.38/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2815"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416838e82-true-d416905e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d416838e82-true-d416905e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e518-true-d416968e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="2814"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e518-true-d416968e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d413874e518-true-d416968e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416957e15-true-d416979e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2813"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416957e15-true-d416979e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d416957e15-true-d416979e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d416957e82-true-d417024e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.40/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2812"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d416957e82-true-d417024e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d416957e82-true-d417024e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e529-true-d417081e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="2811"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e529-true-d417081e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d413874e529-true-d417081e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417070e15-true-d417092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2810"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417070e15-true-d417092e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d417070e15-true-d417092e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417070e82-true-d417137e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.41/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2809"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417070e82-true-d417137e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417070e82-true-d417137e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e540-true-d417194e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2808"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e540-true-d417194e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d413874e540-true-d417194e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e566-true-d417259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2807"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e566-true-d417259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d413874e566-true-d417259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417240e15-true-d417271e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2806"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417240e15-true-d417271e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d417240e15-true-d417271e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417240e214-true-d417360e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2805"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417240e214-true-d417360e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d417240e214-true-d417360e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417353e23-true-d417371e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2804"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417353e23-true-d417371e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d417353e23-true-d417371e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417353e34-true-d417394e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2803"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417353e34-true-d417394e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d417353e34-true-d417394e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417240e234-true-d417417e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2802"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417240e234-true-d417417e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d417240e234-true-d417417e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417240e248-true-d417440e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.44/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2801"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417240e248-true-d417440e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d417240e248-true-d417440e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d413874e628-true-d417495e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2800"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d413874e628-true-d417495e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d413874e628-true-d417495e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417480e224-true-d417525e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2799"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417480e224-true-d417525e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d417480e224-true-d417525e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417480e266-true-d417561e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2798"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417480e266-true-d417561e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d417480e266-true-d417561e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417480e308-true-d417609e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2797"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417480e308-true-d417609e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d417480e308-true-d417609e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417480e338-true-d417681e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN1/hl7v2:IN1.49/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2796"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417480e338-true-d417681e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d417480e338-true-d417681e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3717-true-d417840e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/*[not(@xsi:nil = 'true')][not(self::hl7v2:IN2.1 | self::hl7v2:IN2.2 | self::hl7v2:IN2.3 | self::hl7v2:IN2.4 | self::hl7v2:IN2.5 | self::hl7v2:IN2.6 | self::hl7v2:IN2.7 | self::hl7v2:IN2.8 | self::hl7v2:IN2.9 | self::hl7v2:IN2.10 | self::hl7v2:IN2.11 | self::hl7v2:IN2.12 | self::hl7v2:IN2.13 | self::hl7v2:IN2.14 | self::hl7v2:IN2.15 | self::hl7v2:IN2.16 | self::hl7v2:IN2.17 | self::hl7v2:IN2.18 | self::hl7v2:IN2.19 | self::hl7v2:IN2.20 | self::hl7v2:IN2.21 | self::hl7v2:IN2.22 | self::hl7v2:IN2.23 | self::hl7v2:IN2.24 | self::hl7v2:IN2.25 | self::hl7v2:IN2.26 | self::hl7v2:IN2.27 | self::hl7v2:IN2.28 | self::hl7v2:IN2.29 | self::hl7v2:IN2.30 | self::hl7v2:IN2.31 | self::hl7v2:IN2.32 | self::hl7v2:IN2.33 | self::hl7v2:IN2.34 | self::hl7v2:IN2.35 | self::hl7v2:IN2.36 | self::hl7v2:IN2.37 | self::hl7v2:IN2.38 | self::hl7v2:IN2.39 | self::hl7v2:IN2.40 | self::hl7v2:IN2.41 | self::hl7v2:IN2.42 | self::hl7v2:IN2.43 | self::hl7v2:IN2.44 | self::hl7v2:IN2.45 | self::hl7v2:IN2.46 | self::hl7v2:IN2.47 | self::hl7v2:IN2.48 | self::hl7v2:IN2.49 | self::hl7v2:IN2.50 | self::hl7v2:IN2.51 | self::hl7v2:IN2.52 | self::hl7v2:IN2.53 | self::hl7v2:IN2.54 | self::hl7v2:IN2.55 | self::hl7v2:IN2.56 | self::hl7v2:IN2.57 | self::hl7v2:IN2.58 | self::hl7v2:IN2.59 | self::hl7v2:IN2.60 | self::hl7v2:IN2.61 | self::hl7v2:IN2.62 | self::hl7v2:IN2.63 | self::hl7v2:IN2.64 | self::hl7v2:IN2.65 | self::hl7v2:IN2.66 | self::hl7v2:IN2.67 | self::hl7v2:IN2.68 | self::hl7v2:IN2.69 | self::hl7v2:IN2.70 | self::hl7v2:IN2.71 | self::hl7v2:IN2.72)]"
                 priority="2795"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3717-true-d417840e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:IN2.1 | hl7v2:IN2.2 | hl7v2:IN2.3 | hl7v2:IN2.4 | hl7v2:IN2.5 | hl7v2:IN2.6 | hl7v2:IN2.7 | hl7v2:IN2.8 | hl7v2:IN2.9 | hl7v2:IN2.10 | hl7v2:IN2.11 | hl7v2:IN2.12 | hl7v2:IN2.13 | hl7v2:IN2.14 | hl7v2:IN2.15 | hl7v2:IN2.16 | hl7v2:IN2.17 | hl7v2:IN2.18 | hl7v2:IN2.19 | hl7v2:IN2.20 | hl7v2:IN2.21 | hl7v2:IN2.22 | hl7v2:IN2.23 | hl7v2:IN2.24 | hl7v2:IN2.25 | hl7v2:IN2.26 | hl7v2:IN2.27 | hl7v2:IN2.28 | hl7v2:IN2.29 | hl7v2:IN2.30 | hl7v2:IN2.31 | hl7v2:IN2.32 | hl7v2:IN2.33 | hl7v2:IN2.34 | hl7v2:IN2.35 | hl7v2:IN2.36 | hl7v2:IN2.37 | hl7v2:IN2.38 | hl7v2:IN2.39 | hl7v2:IN2.40 | hl7v2:IN2.41 | hl7v2:IN2.42 | hl7v2:IN2.43 | hl7v2:IN2.44 | hl7v2:IN2.45 | hl7v2:IN2.46 | hl7v2:IN2.47 | hl7v2:IN2.48 | hl7v2:IN2.49 | hl7v2:IN2.50 | hl7v2:IN2.51 | hl7v2:IN2.52 | hl7v2:IN2.53 | hl7v2:IN2.54 | hl7v2:IN2.55 | hl7v2:IN2.56 | hl7v2:IN2.57 | hl7v2:IN2.58 | hl7v2:IN2.59 | hl7v2:IN2.60 | hl7v2:IN2.61 | hl7v2:IN2.62 | hl7v2:IN2.63 | hl7v2:IN2.64 | hl7v2:IN2.65 | hl7v2:IN2.66 | hl7v2:IN2.67 | hl7v2:IN2.68 | hl7v2:IN2.69 | hl7v2:IN2.70 | hl7v2:IN2.71 | hl7v2:IN2.72 (rule-reference: d20e3717-true-d417840e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e1-true-d417859e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2794"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e1-true-d417859e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d417764e1-true-d417859e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417844e221-true-d417889e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2793"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417844e221-true-d417889e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d417844e221-true-d417889e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417844e263-true-d417925e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2792"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417844e263-true-d417925e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d417844e263-true-d417925e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417844e305-true-d417973e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2791"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417844e305-true-d417973e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d417844e305-true-d417973e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417844e334-true-d418045e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.1/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2790"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417844e334-true-d418045e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d417844e334-true-d418045e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e23-true-d418137e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2789"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e23-true-d418137e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d417764e23-true-d418137e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e32-true-d418157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2788"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e32-true-d418157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d418109e32-true-d418157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e123-true-d418235e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2787"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e123-true-d418235e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d418109e123-true-d418235e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e215-true-d418289e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2786"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e215-true-d418289e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d418109e215-true-d418289e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e275-true-d418328e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2785"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e275-true-d418328e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d418109e275-true-d418328e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e288-true-d418375e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2784"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e288-true-d418375e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d418109e288-true-d418375e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418368e17-true-d418386e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2783"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418368e17-true-d418386e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418368e17-true-d418386e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418368e28-true-d418409e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2782"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418368e28-true-d418409e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418368e28-true-d418409e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e318-true-d418438e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2781"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e318-true-d418438e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418109e318-true-d418438e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e329-true-d418461e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2780"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e329-true-d418461e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418109e329-true-d418461e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e351-true-d418497e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2779"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e351-true-d418497e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d418109e351-true-d418497e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418109e369-true-d418569e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.3/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2778"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418109e369-true-d418569e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d418109e369-true-d418569e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e71-true-d418664e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2777"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e71-true-d418664e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d417764e71-true-d418664e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418645e15-true-d418678e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2776"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418645e15-true-d418678e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d418645e15-true-d418678e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418645e142-true-d418765e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2775"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418645e142-true-d418765e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d418645e142-true-d418765e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418645e155-true-d418812e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2774"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418645e155-true-d418812e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d418645e155-true-d418812e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418805e17-true-d418823e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2773"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418805e17-true-d418823e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418805e17-true-d418823e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418805e28-true-d418846e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2772"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418805e28-true-d418846e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418805e28-true-d418846e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418645e186-true-d418875e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2771"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418645e186-true-d418875e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418645e186-true-d418875e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418645e197-true-d418898e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.7/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2770"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418645e197-true-d418898e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418645e197-true-d418898e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e93-true-d418945e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2769"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e93-true-d418945e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d417764e93-true-d418945e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418926e15-true-d418959e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2768"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418926e15-true-d418959e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d418926e15-true-d418959e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418926e142-true-d419046e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2767"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418926e142-true-d419046e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d418926e142-true-d419046e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418926e155-true-d419093e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2766"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418926e155-true-d419093e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d418926e155-true-d419093e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419086e17-true-d419104e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2765"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419086e17-true-d419104e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d419086e17-true-d419104e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419086e28-true-d419127e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2764"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419086e28-true-d419127e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d419086e28-true-d419127e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418926e186-true-d419156e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2763"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418926e186-true-d419156e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418926e186-true-d419156e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d418926e197-true-d419179e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.9/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2762"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d418926e197-true-d419179e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d418926e197-true-d419179e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e115-true-d419218e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2761"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e115-true-d419218e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e115-true-d419218e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e251-true-d419337e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2760"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e251-true-d419337e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d417764e251-true-d419337e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419318e15-true-d419351e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2759"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419318e15-true-d419351e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d419318e15-true-d419351e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419318e142-true-d419438e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2758"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419318e142-true-d419438e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d419318e142-true-d419438e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419318e155-true-d419485e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2757"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419318e155-true-d419485e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d419318e155-true-d419485e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419478e17-true-d419496e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2756"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419478e17-true-d419496e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d419478e17-true-d419496e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419478e28-true-d419519e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2755"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419478e28-true-d419519e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d419478e28-true-d419519e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419318e186-true-d419548e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2754"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419318e186-true-d419548e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d419318e186-true-d419548e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419318e197-true-d419571e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.22/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2753"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419318e197-true-d419571e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d419318e197-true-d419571e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e287-true-d419620e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2752"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e287-true-d419620e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d417764e287-true-d419620e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419605e221-true-d419650e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2751"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419605e221-true-d419650e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d419605e221-true-d419650e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419605e263-true-d419686e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2750"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419605e263-true-d419686e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d419605e263-true-d419686e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419605e305-true-d419734e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2749"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419605e305-true-d419734e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d419605e305-true-d419734e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419605e334-true-d419806e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.25/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2748"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419605e334-true-d419806e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d419605e334-true-d419806e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e298-true-d419879e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2747"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e298-true-d419879e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d417764e298-true-d419879e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419864e221-true-d419909e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2746"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419864e221-true-d419909e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d419864e221-true-d419909e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419864e263-true-d419945e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2745"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419864e263-true-d419945e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d419864e263-true-d419945e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419864e305-true-d419993e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2744"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419864e305-true-d419993e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d419864e305-true-d419993e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d419864e334-true-d420065e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.26/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2743"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d419864e334-true-d420065e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d419864e334-true-d420065e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e322-true-d420138e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:RMC.1 | self::hl7v2:RMC.2 | self::hl7v2:RMC.3 | self::hl7v2:RMC.4)]"
                 priority="2742"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e322-true-d420138e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RMC.1 | hl7v2:RMC.2 | hl7v2:RMC.3 | hl7v2:RMC.4 (rule-reference: d417764e322-true-d420138e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420129e70-true-d420168e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.28/hl7v2:RMC.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:MOP.1 | self::hl7v2:MOP.2 | self::hl7v2:MOP.3)]"
                 priority="2741"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420129e70-true-d420168e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOP.1 | hl7v2:MOP.2 | hl7v2:MOP.3 (rule-reference: d420129e70-true-d420168e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e333-true-d420199e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:PTA.1 | self::hl7v2:PTA.2 | self::hl7v2:PTA.3 | self::hl7v2:PTA.4)]"
                 priority="2740"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e333-true-d420199e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PTA.1 | hl7v2:PTA.2 | hl7v2:PTA.3 | hl7v2:PTA.4 (rule-reference: d417764e333-true-d420199e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420190e70-true-d420229e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.29/hl7v2:PTA.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:MOP.1 | self::hl7v2:MOP.2 | self::hl7v2:MOP.3)]"
                 priority="2739"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420190e70-true-d420229e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOP.1 | hl7v2:MOP.2 | hl7v2:MOP.3 (rule-reference: d420190e70-true-d420229e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e344-true-d420259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:DDI.1 | self::hl7v2:DDI.2 | self::hl7v2:DDI.3)]"
                 priority="2738"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e344-true-d420259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DDI.1 | hl7v2:DDI.2 | hl7v2:DDI.3 (rule-reference: d417764e344-true-d420259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420251e26-true-d420276e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.30/hl7v2:DDI.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2737"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420251e26-true-d420276e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d420251e26-true-d420276e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e381-true-d420321e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2736"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e381-true-d420321e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e381-true-d420321e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e395-true-d420372e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.34/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2735"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e395-true-d420372e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e395-true-d420372e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e421-true-d420429e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.36/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2734"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e421-true-d420429e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e421-true-d420429e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e460-true-d420492e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2733"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e460-true-d420492e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e460-true-d420492e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e473-true-d420551e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2732"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e473-true-d420551e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d417764e473-true-d420551e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420532e15-true-d420565e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2731"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420532e15-true-d420565e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d420532e15-true-d420565e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420532e142-true-d420652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2730"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420532e142-true-d420652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d420532e142-true-d420652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420532e155-true-d420699e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2729"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420532e155-true-d420699e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d420532e155-true-d420699e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420692e17-true-d420710e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2728"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420692e17-true-d420710e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d420692e17-true-d420710e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420692e28-true-d420733e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2727"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420692e28-true-d420733e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d420692e28-true-d420733e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420532e186-true-d420762e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2726"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420532e186-true-d420762e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d420532e186-true-d420762e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420532e197-true-d420785e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.40/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2725"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420532e197-true-d420785e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d420532e197-true-d420785e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e484-true-d420818e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.41/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2724"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e484-true-d420818e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e484-true-d420818e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e497-true-d420869e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2723"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e497-true-d420869e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e497-true-d420869e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e510-true-d420920e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2722"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e510-true-d420920e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e510-true-d420920e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e557-true-d420986e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/*[not(@xsi:nil = 'true')][not(self::hl7v2:JCC.1 | self::hl7v2:JCC.2 | self::hl7v2:JCC.3)]"
                 priority="2721"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e557-true-d420986e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:JCC.1 | hl7v2:JCC.2 | hl7v2:JCC.3 (rule-reference: d417764e557-true-d420986e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d420978e41-true-d421008e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2720"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d420978e41-true-d421008e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d420978e41-true-d421008e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421002e11-true-d421018e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2719"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421002e11-true-d421018e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d421002e11-true-d421018e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421012e5-true-d421028e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.47/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2718"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421012e5-true-d421028e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d421012e5-true-d421028e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e581-true-d421061e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2717"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e581-true-d421061e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d417764e581-true-d421061e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421042e15-true-d421075e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2716"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421042e15-true-d421075e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d421042e15-true-d421075e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421042e142-true-d421162e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2715"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421042e142-true-d421162e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d421042e142-true-d421162e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421042e155-true-d421209e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2714"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421042e155-true-d421209e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d421042e155-true-d421209e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421202e17-true-d421220e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2713"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421202e17-true-d421220e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421202e17-true-d421220e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421202e28-true-d421243e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2712"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421202e28-true-d421243e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421202e28-true-d421243e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421042e186-true-d421272e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2711"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421042e186-true-d421272e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421042e186-true-d421272e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421042e197-true-d421295e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.49/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2710"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421042e197-true-d421295e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421042e197-true-d421295e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e592-true-d421334e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.50/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2709"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e592-true-d421334e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d417764e592-true-d421334e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e616-true-d421435e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2708"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e616-true-d421435e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d417764e616-true-d421435e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421416e15-true-d421449e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2707"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421416e15-true-d421449e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d421416e15-true-d421449e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421416e142-true-d421536e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2706"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421416e142-true-d421536e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d421416e142-true-d421536e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421416e155-true-d421583e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2705"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421416e155-true-d421583e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d421416e155-true-d421583e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421576e17-true-d421594e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2704"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421576e17-true-d421594e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421576e17-true-d421594e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421576e28-true-d421617e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2703"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421576e28-true-d421617e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421576e28-true-d421617e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421416e186-true-d421646e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2702"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421416e186-true-d421646e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421416e186-true-d421646e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421416e197-true-d421669e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.52/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2701"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421416e197-true-d421669e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d421416e197-true-d421669e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e627-true-d421708e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.53/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2700"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e627-true-d421708e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d417764e627-true-d421708e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e687-true-d421825e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.58/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2699"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e687-true-d421825e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d417764e687-true-d421825e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e724-true-d421928e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2698"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e724-true-d421928e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d417764e724-true-d421928e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421913e221-true-d421958e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2697"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421913e221-true-d421958e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d421913e221-true-d421958e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421913e263-true-d421994e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2696"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421913e263-true-d421994e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d421913e263-true-d421994e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421913e305-true-d422042e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2695"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421913e305-true-d422042e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d421913e305-true-d422042e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d421913e334-true-d422114e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.61/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2694"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d421913e334-true-d422114e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d421913e334-true-d422114e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e735-true-d422183e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.62/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2693"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e735-true-d422183e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e735-true-d422183e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e748-true-d422240e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.63/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2692"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e748-true-d422240e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d417764e748-true-d422240e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e759-true-d422333e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.64/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2691"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e759-true-d422333e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d417764e759-true-d422333e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e770-true-d422420e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.65/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2690"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e770-true-d422420e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e770-true-d422420e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e823-true-d422493e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2689"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e823-true-d422493e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d417764e823-true-d422493e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422478e80-true-d422535e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2688"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422478e80-true-d422535e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d422478e80-true-d422535e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422478e119-true-d422571e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.69/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2687"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422478e119-true-d422571e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d422478e119-true-d422571e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e834-true-d422620e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2686"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e834-true-d422620e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d417764e834-true-d422620e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422605e80-true-d422662e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2685"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422605e80-true-d422662e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d422605e80-true-d422662e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422605e119-true-d422698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.70/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2684"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422605e119-true-d422698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d422605e119-true-d422698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e845-true-d422743e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.71/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2683"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e845-true-d422743e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e845-true-d422743e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d417764e858-true-d422794e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN2/hl7v2:IN2.72/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2682"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d417764e858-true-d422794e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d417764e858-true-d422794e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3719-true-d422864e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/*[not(@xsi:nil = 'true')][not(self::hl7v2:IN3.1 | self::hl7v2:IN3.2 | self::hl7v2:IN3.3 | self::hl7v2:IN3.4 | self::hl7v2:IN3.5 | self::hl7v2:IN3.6 | self::hl7v2:IN3.7 | self::hl7v2:IN3.8 | self::hl7v2:IN3.9 | self::hl7v2:IN3.10 | self::hl7v2:IN3.11 | self::hl7v2:IN3.12 | self::hl7v2:IN3.13 | self::hl7v2:IN3.14 | self::hl7v2:IN3.15 | self::hl7v2:IN3.16 | self::hl7v2:IN3.17 | self::hl7v2:IN3.18 | self::hl7v2:IN3.19 | self::hl7v2:IN3.20 | self::hl7v2:IN3.21 | self::hl7v2:IN3.22 | self::hl7v2:IN3.23 | self::hl7v2:IN3.24 | self::hl7v2:IN3.25)]"
                 priority="2681"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3719-true-d422864e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:IN3.1 | hl7v2:IN3.2 | hl7v2:IN3.3 | hl7v2:IN3.4 | hl7v2:IN3.5 | hl7v2:IN3.6 | hl7v2:IN3.7 | hl7v2:IN3.8 | hl7v2:IN3.9 | hl7v2:IN3.10 | hl7v2:IN3.11 | hl7v2:IN3.12 | hl7v2:IN3.13 | hl7v2:IN3.14 | hl7v2:IN3.15 | hl7v2:IN3.16 | hl7v2:IN3.17 | hl7v2:IN3.18 | hl7v2:IN3.19 | hl7v2:IN3.20 | hl7v2:IN3.21 | hl7v2:IN3.22 | hl7v2:IN3.23 | hl7v2:IN3.24 | hl7v2:IN3.25 (rule-reference: d20e3719-true-d422864e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e12-true-d422889e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2680"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e12-true-d422889e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d422835e12-true-d422889e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422874e221-true-d422919e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2679"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422874e221-true-d422919e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d422874e221-true-d422919e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422874e263-true-d422955e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2678"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422874e263-true-d422955e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d422874e263-true-d422955e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422874e305-true-d423003e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2677"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422874e305-true-d423003e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d422874e305-true-d423003e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422874e334-true-d423075e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.2/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2676"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422874e334-true-d423075e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d422874e334-true-d423075e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e23-true-d423161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2675"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e23-true-d423161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d422835e23-true-d423161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e32-true-d423181e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2674"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e32-true-d423181e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d423133e32-true-d423181e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e123-true-d423259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2673"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e123-true-d423259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d423133e123-true-d423259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e215-true-d423313e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2672"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e215-true-d423313e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d423133e215-true-d423313e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e275-true-d423352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2671"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e275-true-d423352e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d423133e275-true-d423352e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e288-true-d423399e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2670"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e288-true-d423399e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d423133e288-true-d423399e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423392e17-true-d423410e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2669"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423392e17-true-d423410e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423392e17-true-d423410e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423392e28-true-d423433e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2668"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423392e28-true-d423433e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423392e28-true-d423433e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e318-true-d423462e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2667"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e318-true-d423462e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423133e318-true-d423462e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e329-true-d423485e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2666"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e329-true-d423485e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423133e329-true-d423485e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e351-true-d423521e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2665"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e351-true-d423521e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d423133e351-true-d423521e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423133e369-true-d423593e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.3/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2664"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423133e369-true-d423593e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d423133e369-true-d423593e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e47-true-d423665e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:MOP.1 | self::hl7v2:MOP.2 | self::hl7v2:MOP.3)]"
                 priority="2663"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e47-true-d423665e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOP.1 | hl7v2:MOP.2 | hl7v2:MOP.3 (rule-reference: d422835e47-true-d423665e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e58-true-d423694e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2662"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e58-true-d423694e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d422835e58-true-d423694e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e69-true-d423717e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2661"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e69-true-d423717e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d422835e69-true-d423717e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e80-true-d423761e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2660"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e80-true-d423761e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d422835e80-true-d423761e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e32-true-d423781e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2659"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e32-true-d423781e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d423733e32-true-d423781e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e123-true-d423859e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2658"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e123-true-d423859e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d423733e123-true-d423859e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e215-true-d423913e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2657"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e215-true-d423913e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d423733e215-true-d423913e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e275-true-d423952e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2656"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e275-true-d423952e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d423733e275-true-d423952e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e288-true-d423999e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2655"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e288-true-d423999e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d423733e288-true-d423999e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423992e17-true-d424010e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2654"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423992e17-true-d424010e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423992e17-true-d424010e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423992e28-true-d424033e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2653"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423992e28-true-d424033e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423992e28-true-d424033e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e318-true-d424062e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2652"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e318-true-d424062e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423733e318-true-d424062e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e329-true-d424085e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2651"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e329-true-d424085e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d423733e329-true-d424085e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e351-true-d424121e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2650"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e351-true-d424121e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d423733e351-true-d424121e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d423733e369-true-d424193e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.8/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2649"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d423733e369-true-d424193e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d423733e369-true-d424193e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e113-true-d424270e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:DTN.1 | self::hl7v2:DTN.2)]"
                 priority="2648"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e113-true-d424270e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DTN.1 | hl7v2:DTN.2 (rule-reference: d422835e113-true-d424270e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e125-true-d424297e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2647"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e125-true-d424297e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d422835e125-true-d424297e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e138-true-d424344e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2646"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e138-true-d424344e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d422835e138-true-d424344e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e149-true-d424388e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2645"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e149-true-d424388e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d422835e149-true-d424388e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e35-true-d424408e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2644"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e35-true-d424408e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d424360e35-true-d424408e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e127-true-d424486e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2643"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e127-true-d424486e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d424360e127-true-d424486e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e218-true-d424540e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2642"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e218-true-d424540e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d424360e218-true-d424540e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e278-true-d424579e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2641"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e278-true-d424579e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d424360e278-true-d424579e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e291-true-d424626e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2640"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e291-true-d424626e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d424360e291-true-d424626e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424619e17-true-d424637e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2639"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424619e17-true-d424637e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d424619e17-true-d424637e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424619e28-true-d424660e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2638"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424619e28-true-d424660e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d424619e28-true-d424660e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e322-true-d424689e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2637"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e322-true-d424689e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d424360e322-true-d424689e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e333-true-d424712e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2636"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e333-true-d424712e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d424360e333-true-d424712e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e355-true-d424748e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2635"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e355-true-d424748e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d424360e355-true-d424748e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d424360e372-true-d424820e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.14/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2634"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d424360e372-true-d424820e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d424360e372-true-d424820e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e173-true-d424901e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2633"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e173-true-d424901e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d422835e173-true-d424901e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e184-true-d424988e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2632"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e184-true-d424988e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d422835e184-true-d424988e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e197-true-d425039e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2631"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e197-true-d425039e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d422835e197-true-d425039e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e210-true-d425096e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2630"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e210-true-d425096e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d422835e210-true-d425096e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e221-true-d425180e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:ICD.1 | self::hl7v2:ICD.2 | self::hl7v2:ICD.3)]"
                 priority="2629"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e221-true-d425180e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ICD.1 | hl7v2:ICD.2 | hl7v2:ICD.3 (rule-reference: d422835e221-true-d425180e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425172e41-true-d425203e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.20/hl7v2:ICD.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2628"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425172e41-true-d425203e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425172e41-true-d425203e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d422835e281-true-d425271e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2627"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d422835e281-true-d425271e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d422835e281-true-d425271e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e35-true-d425291e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2626"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e35-true-d425291e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d425243e35-true-d425291e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e127-true-d425369e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2625"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e127-true-d425369e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d425243e127-true-d425369e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e218-true-d425423e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2624"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e218-true-d425423e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d425243e218-true-d425423e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e278-true-d425462e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2623"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e278-true-d425462e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425243e278-true-d425462e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e291-true-d425509e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2622"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e291-true-d425509e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d425243e291-true-d425509e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425502e17-true-d425520e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2621"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425502e17-true-d425520e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425502e17-true-d425520e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425502e28-true-d425543e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2620"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425502e28-true-d425543e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425502e28-true-d425543e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e322-true-d425572e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2619"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e322-true-d425572e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425243e322-true-d425572e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e333-true-d425595e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2618"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e333-true-d425595e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425243e333-true-d425595e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e355-true-d425631e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2617"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e355-true-d425631e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d425243e355-true-d425631e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425243e372-true-d425703e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:OML_O21.INSURANCE/hl7v2:IN3/hl7v2:IN3.25/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2616"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425243e372-true-d425703e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d425243e372-true-d425703e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3722-true-d425823e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/*[not(@xsi:nil = 'true')][not(self::hl7v2:GT1.1 | self::hl7v2:GT1.2 | self::hl7v2:GT1.3 | self::hl7v2:GT1.4 | self::hl7v2:GT1.5 | self::hl7v2:GT1.6 | self::hl7v2:GT1.7 | self::hl7v2:GT1.8 | self::hl7v2:GT1.9 | self::hl7v2:GT1.10 | self::hl7v2:GT1.11 | self::hl7v2:GT1.12 | self::hl7v2:GT1.13 | self::hl7v2:GT1.14 | self::hl7v2:GT1.15 | self::hl7v2:GT1.16 | self::hl7v2:GT1.17 | self::hl7v2:GT1.18 | self::hl7v2:GT1.19 | self::hl7v2:GT1.20 | self::hl7v2:GT1.21 | self::hl7v2:GT1.22 | self::hl7v2:GT1.23 | self::hl7v2:GT1.24 | self::hl7v2:GT1.25 | self::hl7v2:GT1.26 | self::hl7v2:GT1.27 | self::hl7v2:GT1.28 | self::hl7v2:GT1.29 | self::hl7v2:GT1.30 | self::hl7v2:GT1.31 | self::hl7v2:GT1.32 | self::hl7v2:GT1.33 | self::hl7v2:GT1.34 | self::hl7v2:GT1.35 | self::hl7v2:GT1.36 | self::hl7v2:GT1.37 | self::hl7v2:GT1.38 | self::hl7v2:GT1.39 | self::hl7v2:GT1.40 | self::hl7v2:GT1.41 | self::hl7v2:GT1.42 | self::hl7v2:GT1.43 | self::hl7v2:GT1.44 | self::hl7v2:GT1.45 | self::hl7v2:GT1.46 | self::hl7v2:GT1.47 | self::hl7v2:GT1.48 | self::hl7v2:GT1.49 | self::hl7v2:GT1.50 | self::hl7v2:GT1.51 | self::hl7v2:GT1.52 | self::hl7v2:GT1.53 | self::hl7v2:GT1.54 | self::hl7v2:GT1.55 | self::hl7v2:GT1.56 | self::hl7v2:GT1.57)]"
                 priority="2615"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3722-true-d425823e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:GT1.1 | hl7v2:GT1.2 | hl7v2:GT1.3 | hl7v2:GT1.4 | hl7v2:GT1.5 | hl7v2:GT1.6 | hl7v2:GT1.7 | hl7v2:GT1.8 | hl7v2:GT1.9 | hl7v2:GT1.10 | hl7v2:GT1.11 | hl7v2:GT1.12 | hl7v2:GT1.13 | hl7v2:GT1.14 | hl7v2:GT1.15 | hl7v2:GT1.16 | hl7v2:GT1.17 | hl7v2:GT1.18 | hl7v2:GT1.19 | hl7v2:GT1.20 | hl7v2:GT1.21 | hl7v2:GT1.22 | hl7v2:GT1.23 | hl7v2:GT1.24 | hl7v2:GT1.25 | hl7v2:GT1.26 | hl7v2:GT1.27 | hl7v2:GT1.28 | hl7v2:GT1.29 | hl7v2:GT1.30 | hl7v2:GT1.31 | hl7v2:GT1.32 | hl7v2:GT1.33 | hl7v2:GT1.34 | hl7v2:GT1.35 | hl7v2:GT1.36 | hl7v2:GT1.37 | hl7v2:GT1.38 | hl7v2:GT1.39 | hl7v2:GT1.40 | hl7v2:GT1.41 | hl7v2:GT1.42 | hl7v2:GT1.43 | hl7v2:GT1.44 | hl7v2:GT1.45 | hl7v2:GT1.46 | hl7v2:GT1.47 | hl7v2:GT1.48 | hl7v2:GT1.49 | hl7v2:GT1.50 | hl7v2:GT1.51 | hl7v2:GT1.52 | hl7v2:GT1.53 | hl7v2:GT1.54 | hl7v2:GT1.55 | hl7v2:GT1.56 | hl7v2:GT1.57 (rule-reference: d20e3722-true-d425823e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e12-true-d425848e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2614"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e12-true-d425848e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d425762e12-true-d425848e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425833e221-true-d425878e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2613"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425833e221-true-d425878e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d425833e221-true-d425878e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425833e263-true-d425914e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2612"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425833e263-true-d425914e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d425833e263-true-d425914e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425833e305-true-d425962e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2611"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425833e305-true-d425962e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d425833e305-true-d425962e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425833e334-true-d426034e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.2/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2610"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425833e334-true-d426034e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d425833e334-true-d426034e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e23-true-d426111e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2609"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e23-true-d426111e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d425762e23-true-d426111e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426092e15-true-d426125e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2608"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426092e15-true-d426125e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d426092e15-true-d426125e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426092e142-true-d426212e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2607"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426092e142-true-d426212e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d426092e142-true-d426212e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426092e155-true-d426259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2606"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426092e155-true-d426259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d426092e155-true-d426259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426252e17-true-d426270e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2605"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426252e17-true-d426270e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426252e17-true-d426270e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426252e28-true-d426293e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2604"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426252e28-true-d426293e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426252e28-true-d426293e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426092e186-true-d426322e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2603"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426092e186-true-d426322e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426092e186-true-d426322e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426092e197-true-d426345e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.3/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2602"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426092e197-true-d426345e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426092e197-true-d426345e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e34-true-d426386e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2601"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e34-true-d426386e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d425762e34-true-d426386e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426367e15-true-d426400e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2600"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426367e15-true-d426400e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d426367e15-true-d426400e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426367e142-true-d426487e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2599"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426367e142-true-d426487e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d426367e142-true-d426487e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426367e155-true-d426534e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2598"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426367e155-true-d426534e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d426367e155-true-d426534e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426527e17-true-d426545e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2597"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426527e17-true-d426545e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426527e17-true-d426545e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426527e28-true-d426568e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2596"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426527e28-true-d426568e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426527e28-true-d426568e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426367e186-true-d426597e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2595"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426367e186-true-d426597e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426367e186-true-d426597e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426367e197-true-d426620e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.4/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2594"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426367e197-true-d426620e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426367e197-true-d426620e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e45-true-d426661e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2593"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e45-true-d426661e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d425762e45-true-d426661e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426642e15-true-d426673e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2592"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426642e15-true-d426673e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d426642e15-true-d426673e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426642e189-true-d426762e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2591"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426642e189-true-d426762e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d426642e189-true-d426762e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426755e17-true-d426773e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2590"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426755e17-true-d426773e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426755e17-true-d426773e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426755e28-true-d426796e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2589"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426755e28-true-d426796e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426755e28-true-d426796e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426642e206-true-d426819e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2588"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426642e206-true-d426819e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426642e206-true-d426819e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d426642e217-true-d426842e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.5/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2587"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d426642e217-true-d426842e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d426642e217-true-d426842e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e56-true-d426875e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2586"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e56-true-d426875e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d425762e56-true-d426875e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e67-true-d426968e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2585"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e67-true-d426968e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d425762e67-true-d426968e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e78-true-d427051e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2584"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e78-true-d427051e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425762e78-true-d427051e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e115-true-d427090e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2583"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e115-true-d427090e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e115-true-d427090e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e173-true-d427173e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2582"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e173-true-d427173e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d425762e173-true-d427173e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427154e15-true-d427187e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2581"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427154e15-true-d427187e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d427154e15-true-d427187e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427154e142-true-d427274e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2580"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427154e142-true-d427274e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d427154e142-true-d427274e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427154e155-true-d427321e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2579"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427154e155-true-d427321e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d427154e155-true-d427321e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427314e17-true-d427332e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2578"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427314e17-true-d427332e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427314e17-true-d427332e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427314e28-true-d427355e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2577"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427314e28-true-d427355e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427314e28-true-d427355e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427154e186-true-d427384e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2576"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427154e186-true-d427384e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427154e186-true-d427384e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427154e197-true-d427407e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.16/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2575"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427154e197-true-d427407e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427154e197-true-d427407e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e184-true-d427448e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2574"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e184-true-d427448e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d425762e184-true-d427448e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427429e15-true-d427460e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2573"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427429e15-true-d427460e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d427429e15-true-d427460e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427429e189-true-d427549e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2572"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427429e189-true-d427549e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d427429e189-true-d427549e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427542e17-true-d427560e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2571"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427542e17-true-d427560e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427542e17-true-d427560e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427542e28-true-d427583e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2570"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427542e28-true-d427583e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427542e28-true-d427583e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427429e206-true-d427606e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2569"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427429e206-true-d427606e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427429e206-true-d427606e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427429e217-true-d427629e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.17/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2568"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427429e217-true-d427629e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d427429e217-true-d427629e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e195-true-d427662e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2567"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e195-true-d427662e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d425762e195-true-d427662e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e206-true-d427753e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2566"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e206-true-d427753e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d425762e206-true-d427753e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427738e221-true-d427783e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2565"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427738e221-true-d427783e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d427738e221-true-d427783e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427738e263-true-d427819e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2564"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427738e263-true-d427819e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d427738e263-true-d427819e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427738e305-true-d427867e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2563"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427738e305-true-d427867e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d427738e305-true-d427867e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d427738e334-true-d427939e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.19/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2562"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d427738e334-true-d427939e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d427738e334-true-d427939e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e230-true-d428018e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2561"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e230-true-d428018e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d425762e230-true-d428018e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428003e80-true-d428060e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2560"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428003e80-true-d428060e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d428003e80-true-d428060e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428003e119-true-d428096e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.21/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2559"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428003e119-true-d428096e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d428003e119-true-d428096e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e255-true-d428147e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2558"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e255-true-d428147e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e255-true-d428147e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e268-true-d428194e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.24/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2557"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e268-true-d428194e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d425762e268-true-d428194e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e292-true-d428227e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2556"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e292-true-d428227e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e292-true-d428227e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e305-true-d428278e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="2555"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e305-true-d428278e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d425762e305-true-d428278e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428267e15-true-d428289e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2554"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428267e15-true-d428289e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d428267e15-true-d428289e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428267e82-true-d428334e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.27/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2553"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428267e82-true-d428334e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d428267e82-true-d428334e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e327-true-d428401e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="2552"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e327-true-d428401e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d425762e327-true-d428401e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428386e221-true-d428431e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2551"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428386e221-true-d428431e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d428386e221-true-d428431e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428386e263-true-d428467e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2550"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428386e263-true-d428467e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d428386e263-true-d428467e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428386e305-true-d428515e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2549"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428386e305-true-d428515e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d428386e305-true-d428515e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428386e334-true-d428587e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.29/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2548"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428386e334-true-d428587e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d428386e334-true-d428587e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e338-true-d428656e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2547"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e338-true-d428656e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e338-true-d428656e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e400-true-d428731e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2546"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e400-true-d428731e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e400-true-d428731e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e413-true-d428782e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.36/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2545"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e413-true-d428782e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e413-true-d428782e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e439-true-d428839e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2544"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e439-true-d428839e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e439-true-d428839e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e478-true-d428902e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.41/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2543"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e478-true-d428902e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e478-true-d428902e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e491-true-d428961e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2542"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e491-true-d428961e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d425762e491-true-d428961e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428942e15-true-d428975e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2541"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428942e15-true-d428975e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d428942e15-true-d428975e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428942e142-true-d429062e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2540"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428942e142-true-d429062e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d428942e142-true-d429062e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428942e155-true-d429109e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2539"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428942e155-true-d429109e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d428942e155-true-d429109e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429102e17-true-d429120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2538"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429102e17-true-d429120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429102e17-true-d429120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429102e28-true-d429143e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2537"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429102e28-true-d429143e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429102e28-true-d429143e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428942e186-true-d429172e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2536"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428942e186-true-d429172e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d428942e186-true-d429172e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d428942e197-true-d429195e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.42/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2535"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d428942e197-true-d429195e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d428942e197-true-d429195e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e502-true-d429228e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2534"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e502-true-d429228e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e502-true-d429228e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e515-true-d429279e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2533"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e515-true-d429279e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e515-true-d429279e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e529-true-d429338e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2532"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e529-true-d429338e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d425762e529-true-d429338e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429319e15-true-d429352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2531"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429319e15-true-d429352e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d429319e15-true-d429352e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429319e142-true-d429439e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2530"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429319e142-true-d429439e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d429319e142-true-d429439e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429319e155-true-d429486e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2529"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429319e155-true-d429486e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d429319e155-true-d429486e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429479e17-true-d429497e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2528"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429479e17-true-d429497e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429479e17-true-d429497e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429479e28-true-d429520e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2527"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429479e28-true-d429520e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429479e28-true-d429520e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429319e186-true-d429549e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2526"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429319e186-true-d429549e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429319e186-true-d429549e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429319e197-true-d429572e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.45/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2525"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429319e197-true-d429572e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429319e197-true-d429572e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e540-true-d429611e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.46/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2524"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e540-true-d429611e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d425762e540-true-d429611e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e551-true-d429698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.47/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2523"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e551-true-d429698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e551-true-d429698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e588-true-d429758e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/*[not(@xsi:nil = 'true')][not(self::hl7v2:JCC.1 | self::hl7v2:JCC.2 | self::hl7v2:JCC.3)]"
                 priority="2522"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e588-true-d429758e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:JCC.1 | hl7v2:JCC.2 | hl7v2:JCC.3 (rule-reference: d425762e588-true-d429758e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429750e41-true-d429780e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2521"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429750e41-true-d429780e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d429750e41-true-d429780e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429774e11-true-d429790e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2520"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429774e11-true-d429790e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d429774e11-true-d429790e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429784e5-true-d429800e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.50/hl7v2:JCC.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2519"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429784e5-true-d429800e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d429784e5-true-d429800e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e599-true-d429823e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2518"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e599-true-d429823e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d425762e599-true-d429823e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429808e80-true-d429865e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2517"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429808e80-true-d429865e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d429808e80-true-d429865e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429808e119-true-d429901e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.51/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2516"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429808e119-true-d429901e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d429808e119-true-d429901e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e636-true-d429954e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/*[not(@xsi:nil = 'true')][not(self::hl7v2:FC.1 | self::hl7v2:FC.2)]"
                 priority="2515"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e636-true-d429954e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FC.1 | hl7v2:FC.2 (rule-reference: d425762e636-true-d429954e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d429947e28-true-d429971e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.54/hl7v2:FC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2514"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d429947e28-true-d429971e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d429947e28-true-d429971e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d425762e647-true-d429998e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:GT1/hl7v2:GT1.55/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2513"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d425762e647-true-d429998e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d425762e647-true-d429998e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3724-true-d430059e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/*[not(@xsi:nil = 'true')][not(self::hl7v2:AL1.1 | self::hl7v2:AL1.2 | self::hl7v2:AL1.3 | self::hl7v2:AL1.4)]"
                 priority="2512"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3724-true-d430059e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:AL1.1 | hl7v2:AL1.2 | hl7v2:AL1.3 | hl7v2:AL1.4 (rule-reference: d20e3724-true-d430059e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430051e15-true-d430080e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2511"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430051e15-true-d430080e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430051e15-true-d430080e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430051e28-true-d430131e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2510"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430051e28-true-d430131e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430051e28-true-d430131e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430051e39-true-d430182e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.PATIENT/hl7v2:AL1/hl7v2:AL1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2509"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430051e39-true-d430182e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430051e39-true-d430182e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3727-true-d430230e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/*[not(@xsi:nil = 'true')][not(self::hl7v2:ORC | self::hl7v2:OML_O21.TIMING_PRIOR | self::hl7v2:OML_O21.OBSERVATION_REQUEST | self::hl7v2:FT1 | self::hl7v2:CTI | self::hl7v2:BLG)]"
                 priority="2508"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3727-true-d430230e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC | hl7v2:OML_O21.TIMING_PRIOR | hl7v2:OML_O21.OBSERVATION_REQUEST | hl7v2:FT1 | hl7v2:CTI | hl7v2:BLG (rule-reference: d20e3727-true-d430230e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3729-true-d430269e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/*[not(@xsi:nil = 'true')][not(self::hl7v2:ORC.1 | self::hl7v2:ORC.2 | self::hl7v2:ORC.3 | self::hl7v2:ORC.4 | self::hl7v2:ORC.5 | self::hl7v2:ORC.6 | self::hl7v2:ORC.7 | self::hl7v2:ORC.8 | self::hl7v2:ORC.9 | self::hl7v2:ORC.10 | self::hl7v2:ORC.11 | self::hl7v2:ORC.12 | self::hl7v2:ORC.13 | self::hl7v2:ORC.14 | self::hl7v2:ORC.15 | self::hl7v2:ORC.16 | self::hl7v2:ORC.17 | self::hl7v2:ORC.18 | self::hl7v2:ORC.19 | self::hl7v2:ORC.20 | self::hl7v2:ORC.21 | self::hl7v2:ORC.22 | self::hl7v2:ORC.23 | self::hl7v2:ORC.24 | self::hl7v2:ORC.25 | self::hl7v2:ORC.26 | self::hl7v2:ORC.27 | self::hl7v2:ORC.28 | self::hl7v2:ORC.29 | self::hl7v2:ORC.30)]"
                 priority="2507"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3729-true-d430269e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC.1 | hl7v2:ORC.2 | hl7v2:ORC.3 | hl7v2:ORC.4 | hl7v2:ORC.5 | hl7v2:ORC.6 | hl7v2:ORC.7 | hl7v2:ORC.8 | hl7v2:ORC.9 | hl7v2:ORC.10 | hl7v2:ORC.11 | hl7v2:ORC.12 | hl7v2:ORC.13 | hl7v2:ORC.14 | hl7v2:ORC.15 | hl7v2:ORC.16 | hl7v2:ORC.17 | hl7v2:ORC.18 | hl7v2:ORC.19 | hl7v2:ORC.20 | hl7v2:ORC.21 | hl7v2:ORC.22 | hl7v2:ORC.23 | hl7v2:ORC.24 | hl7v2:ORC.25 | hl7v2:ORC.26 | hl7v2:ORC.27 | hl7v2:ORC.28 | hl7v2:ORC.29 | hl7v2:ORC.30 (rule-reference: d20e3729-true-d430269e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e102-true-d430288e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2506"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e102-true-d430288e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d430235e102-true-d430288e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e119-true-d430325e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2505"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e119-true-d430325e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d430235e119-true-d430325e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e143-true-d430362e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2504"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e143-true-d430362e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d430235e143-true-d430362e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e186-true-d430419e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="2503"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e186-true-d430419e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d430235e186-true-d430419e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e15-true-d430430e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2502"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e15-true-d430430e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d430402e15-true-d430430e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430423e31-true-d430451e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2501"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430423e31-true-d430451e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430423e31-true-d430451e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e35-true-d430498e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="2500"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e35-true-d430498e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d430402e35-true-d430498e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e189-true-d430527e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2499"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e189-true-d430527e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430402e189-true-d430527e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e206-true-d430550e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2498"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e206-true-d430550e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430402e206-true-d430550e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e461-true-d430584e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2497"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e461-true-d430584e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d430402e461-true-d430584e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430578e11-true-d430594e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2496"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430578e11-true-d430594e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d430578e11-true-d430594e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430588e5-true-d430604e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2495"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430588e5-true-d430604e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d430588e5-true-d430604e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e485-true-d430634e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="2494"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e485-true-d430634e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d430402e485-true-d430634e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430402e505-true-d430715e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2493"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430402e505-true-d430715e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430402e505-true-d430715e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e197-true-d430768e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="2492"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e197-true-d430768e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d430235e197-true-d430768e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430761e18-true-d430781e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2491"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430761e18-true-d430781e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d430761e18-true-d430781e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430761e47-true-d430818e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2490"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430761e47-true-d430818e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d430761e47-true-d430818e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e211-true-d430853e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2489"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e211-true-d430853e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430235e211-true-d430853e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e222-true-d430897e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2488"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e222-true-d430897e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d430235e222-true-d430897e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e32-true-d430917e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2487"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e32-true-d430917e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d430869e32-true-d430917e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e123-true-d430995e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2486"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e123-true-d430995e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d430869e123-true-d430995e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e215-true-d431049e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2485"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e215-true-d431049e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d430869e215-true-d431049e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e275-true-d431088e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2484"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e275-true-d431088e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430869e275-true-d431088e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e288-true-d431135e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2483"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e288-true-d431135e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d430869e288-true-d431135e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431128e17-true-d431146e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2482"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431128e17-true-d431146e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431128e17-true-d431146e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431128e28-true-d431169e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2481"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431128e28-true-d431169e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431128e28-true-d431169e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e318-true-d431198e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2480"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e318-true-d431198e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430869e318-true-d431198e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e329-true-d431221e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2479"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e329-true-d431221e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430869e329-true-d431221e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e351-true-d431257e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2478"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e351-true-d431257e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d430869e351-true-d431257e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430869e369-true-d431329e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2477"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430869e369-true-d431329e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d430869e369-true-d431329e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e233-true-d431415e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2476"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e233-true-d431415e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d430235e233-true-d431415e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e32-true-d431435e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2475"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e32-true-d431435e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d431387e32-true-d431435e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e123-true-d431513e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2474"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e123-true-d431513e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d431387e123-true-d431513e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e215-true-d431567e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2473"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e215-true-d431567e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d431387e215-true-d431567e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e275-true-d431606e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2472"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e275-true-d431606e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d431387e275-true-d431606e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e288-true-d431653e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2471"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e288-true-d431653e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d431387e288-true-d431653e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431646e17-true-d431664e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2470"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431646e17-true-d431664e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431646e17-true-d431664e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431646e28-true-d431687e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2469"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431646e28-true-d431687e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431646e28-true-d431687e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e318-true-d431716e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2468"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e318-true-d431716e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431387e318-true-d431716e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e329-true-d431739e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2467"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e329-true-d431739e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431387e329-true-d431739e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e351-true-d431775e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2466"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e351-true-d431775e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d431387e351-true-d431775e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431387e369-true-d431847e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2465"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431387e369-true-d431847e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d431387e369-true-d431847e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e245-true-d431933e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2464"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e245-true-d431933e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d430235e245-true-d431933e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e32-true-d431953e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2463"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e32-true-d431953e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d431905e32-true-d431953e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e123-true-d432031e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2462"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e123-true-d432031e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d431905e123-true-d432031e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e215-true-d432085e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2461"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e215-true-d432085e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d431905e215-true-d432085e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e275-true-d432124e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2460"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e275-true-d432124e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d431905e275-true-d432124e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e288-true-d432171e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2459"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e288-true-d432171e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d431905e288-true-d432171e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432164e17-true-d432182e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2458"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432164e17-true-d432182e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d432164e17-true-d432182e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432164e28-true-d432205e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2457"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432164e28-true-d432205e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d432164e28-true-d432205e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e318-true-d432234e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2456"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e318-true-d432234e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431905e318-true-d432234e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e329-true-d432257e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2455"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e329-true-d432257e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d431905e329-true-d432257e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e351-true-d432293e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2454"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e351-true-d432293e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d431905e351-true-d432293e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d431905e369-true-d432365e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2453"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d431905e369-true-d432365e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d431905e369-true-d432365e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e256-true-d432439e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="2452"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e256-true-d432439e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d430235e256-true-d432439e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432423e48-true-d432469e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2451"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432423e48-true-d432469e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d432423e48-true-d432469e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432423e125-true-d432530e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2450"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432423e125-true-d432530e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d432423e125-true-d432530e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432423e134-true-d432566e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2449"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432423e134-true-d432566e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d432423e134-true-d432566e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e267-true-d432605e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2448"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e267-true-d432605e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d430235e267-true-d432605e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e278-true-d432688e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2447"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e278-true-d432688e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430235e278-true-d432688e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e289-true-d432715e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2446"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e289-true-d432715e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430235e289-true-d432715e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e303-true-d432766e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2445"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e303-true-d432766e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430235e303-true-d432766e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e314-true-d432817e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2444"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e314-true-d432817e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430235e314-true-d432817e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e325-true-d432885e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2443"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e325-true-d432885e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d430235e325-true-d432885e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e32-true-d432905e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2442"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e32-true-d432905e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d432857e32-true-d432905e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e123-true-d432983e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2441"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e123-true-d432983e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d432857e123-true-d432983e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e215-true-d433037e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2440"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e215-true-d433037e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d432857e215-true-d433037e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e275-true-d433076e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2439"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e275-true-d433076e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d432857e275-true-d433076e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e288-true-d433123e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2438"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e288-true-d433123e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d432857e288-true-d433123e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433116e17-true-d433134e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2437"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433116e17-true-d433134e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433116e17-true-d433134e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433116e28-true-d433157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2436"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433116e28-true-d433157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433116e28-true-d433157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e318-true-d433186e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2435"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e318-true-d433186e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d432857e318-true-d433186e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e329-true-d433209e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2434"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e329-true-d433209e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d432857e329-true-d433209e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e351-true-d433245e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2433"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e351-true-d433245e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d432857e351-true-d433245e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d432857e369-true-d433317e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2432"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d432857e369-true-d433317e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d432857e369-true-d433317e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e336-true-d433386e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2431"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e336-true-d433386e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d430235e336-true-d433386e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e349-true-d433441e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="2430"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e349-true-d433441e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d430235e349-true-d433441e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433426e80-true-d433483e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2429"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433426e80-true-d433483e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d433426e80-true-d433483e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433426e119-true-d433519e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2428"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433426e119-true-d433519e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d433426e119-true-d433519e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e360-true-d433572e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2427"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e360-true-d433572e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d430235e360-true-d433572e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433553e15-true-d433584e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2426"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433553e15-true-d433584e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d433553e15-true-d433584e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433553e214-true-d433673e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2425"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433553e214-true-d433673e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d433553e214-true-d433673e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433666e23-true-d433684e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2424"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433666e23-true-d433684e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433666e23-true-d433684e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433666e34-true-d433707e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2423"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433666e34-true-d433707e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433666e34-true-d433707e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433553e234-true-d433730e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2422"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433553e234-true-d433730e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433553e234-true-d433730e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433553e248-true-d433753e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2421"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433553e248-true-d433753e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433553e248-true-d433753e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e372-true-d433786e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2420"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e372-true-d433786e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d430235e372-true-d433786e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e383-true-d433881e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2419"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e383-true-d433881e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d430235e383-true-d433881e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433862e15-true-d433893e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2418"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433862e15-true-d433893e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d433862e15-true-d433893e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433862e214-true-d433982e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2417"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433862e214-true-d433982e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d433862e214-true-d433982e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433975e23-true-d433993e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2416"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433975e23-true-d433993e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433975e23-true-d433993e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433975e34-true-d434016e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2415"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433975e34-true-d434016e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433975e34-true-d434016e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433862e234-true-d434039e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2414"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433862e234-true-d434039e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433862e234-true-d434039e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d433862e248-true-d434062e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2413"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d433862e248-true-d434062e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d433862e248-true-d434062e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e394-true-d434092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2412"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e394-true-d434092e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d430235e394-true-d434092e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e405-true-d434164e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2411"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e405-true-d434164e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d430235e405-true-d434164e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e418-true-d434229e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2410"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e418-true-d434229e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d430235e418-true-d434229e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e429-true-d434259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2409"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e429-true-d434259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d430235e429-true-d434259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e442-true-d434331e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2408"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e442-true-d434331e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d430235e442-true-d434331e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d430235e455-true-d434403e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:ORC/hl7v2:ORC.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNE.1 | self::hl7v2:CNE.2 | self::hl7v2:CNE.3 | self::hl7v2:CNE.4 | self::hl7v2:CNE.5 | self::hl7v2:CNE.6 | self::hl7v2:CNE.7 | self::hl7v2:CNE.8 | self::hl7v2:CNE.9)]"
                 priority="2407"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d430235e455-true-d434403e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNE.1 | hl7v2:CNE.2 | hl7v2:CNE.3 | hl7v2:CNE.4 | hl7v2:CNE.5 | hl7v2:CNE.6 | hl7v2:CNE.7 | hl7v2:CNE.8 | hl7v2:CNE.9 (rule-reference: d430235e455-true-d434403e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3731-true-d434465e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ1 | self::hl7v2:TQ2)]"
                 priority="2406"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3731-true-d434465e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1 | hl7v2:TQ2 (rule-reference: d20e3731-true-d434465e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3733-true-d434488e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ1.1 | self::hl7v2:TQ1.2 | self::hl7v2:TQ1.3 | self::hl7v2:TQ1.4 | self::hl7v2:TQ1.5 | self::hl7v2:TQ1.6 | self::hl7v2:TQ1.7 | self::hl7v2:TQ1.8 | self::hl7v2:TQ1.9 | self::hl7v2:TQ1.10 | self::hl7v2:TQ1.11 | self::hl7v2:TQ1.12 | self::hl7v2:TQ1.13 | self::hl7v2:TQ1.14)]"
                 priority="2405"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3733-true-d434488e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1.1 | hl7v2:TQ1.2 | hl7v2:TQ1.3 | hl7v2:TQ1.4 | hl7v2:TQ1.5 | hl7v2:TQ1.6 | hl7v2:TQ1.7 | hl7v2:TQ1.8 | hl7v2:TQ1.9 | hl7v2:TQ1.10 | hl7v2:TQ1.11 | hl7v2:TQ1.12 | hl7v2:TQ1.13 | hl7v2:TQ1.14 (rule-reference: d20e3733-true-d434488e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e15-true-d434505e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2404"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e15-true-d434505e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d434470e15-true-d434505e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434498e26-true-d434526e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2403"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434498e26-true-d434526e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d434498e26-true-d434526e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e26-true-d434582e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:RPT.1 | self::hl7v2:RPT.2 | self::hl7v2:RPT.3 | self::hl7v2:RPT.4 | self::hl7v2:RPT.5 | self::hl7v2:RPT.6 | self::hl7v2:RPT.7 | self::hl7v2:RPT.8 | self::hl7v2:RPT.9 | self::hl7v2:RPT.10 | self::hl7v2:RPT.11)]"
                 priority="2402"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e26-true-d434582e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RPT.1 | hl7v2:RPT.2 | hl7v2:RPT.3 | hl7v2:RPT.4 | hl7v2:RPT.5 | hl7v2:RPT.6 | hl7v2:RPT.7 | hl7v2:RPT.8 | hl7v2:RPT.9 | hl7v2:RPT.10 | hl7v2:RPT.11 (rule-reference: d434470e26-true-d434582e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434566e18-true-d434600e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2401"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434566e18-true-d434600e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d434566e18-true-d434600e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e50-true-d434731e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2400"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e50-true-d434731e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d434470e50-true-d434731e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434724e26-true-d434752e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2399"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434724e26-true-d434752e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d434724e26-true-d434752e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e61-true-d434799e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2398"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e61-true-d434799e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d434470e61-true-d434799e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434792e26-true-d434820e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2397"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434792e26-true-d434820e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d434792e26-true-d434820e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e72-true-d434867e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2396"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e72-true-d434867e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d434470e72-true-d434867e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e86-true-d434890e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2395"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e86-true-d434890e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d434470e86-true-d434890e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e100-true-d434920e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2394"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e100-true-d434920e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d434470e100-true-d434920e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e117-true-d434984e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2393"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e117-true-d434984e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d434470e117-true-d434984e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434978e15-true-d434994e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2392"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434978e15-true-d434994e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d434978e15-true-d434994e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434988e5-true-d435004e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2391"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434988e5-true-d435004e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d434988e5-true-d435004e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e128-true-d435018e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2390"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e128-true-d435018e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d434470e128-true-d435018e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435012e15-true-d435028e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2389"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435012e15-true-d435028e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d435012e15-true-d435028e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435022e5-true-d435038e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2388"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435022e5-true-d435038e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d435022e5-true-d435038e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d434470e153-true-d435059e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2387"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d434470e153-true-d435059e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d434470e153-true-d435059e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435052e26-true-d435080e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2386"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435052e26-true-d435080e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435052e26-true-d435080e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3735-true-d435141e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ2.1 | self::hl7v2:TQ2.2 | self::hl7v2:TQ2.3 | self::hl7v2:TQ2.4 | self::hl7v2:TQ2.5 | self::hl7v2:TQ2.6 | self::hl7v2:TQ2.7 | self::hl7v2:TQ2.8 | self::hl7v2:TQ2.9 | self::hl7v2:TQ2.10)]"
                 priority="2385"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3735-true-d435141e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ2.1 | hl7v2:TQ2.2 | hl7v2:TQ2.3 | hl7v2:TQ2.4 | hl7v2:TQ2.5 | hl7v2:TQ2.6 | hl7v2:TQ2.7 | hl7v2:TQ2.8 | hl7v2:TQ2.9 | hl7v2:TQ2.10 (rule-reference: d20e3735-true-d435141e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435127e25-true-d435166e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2384"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435127e25-true-d435166e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d435127e25-true-d435166e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435127e36-true-d435203e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2383"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435127e36-true-d435203e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d435127e36-true-d435203e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435127e47-true-d435240e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2382"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435127e47-true-d435240e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d435127e47-true-d435240e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435127e84-true-d435287e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2381"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435127e84-true-d435287e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d435127e84-true-d435287e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435280e26-true-d435308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2380"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435280e26-true-d435308e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435280e26-true-d435308e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3738-true-d435390e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBR | self::hl7v2:TCD | self::hl7v2:NTE | self::hl7v2:CTD | self::hl7v2:DG1 | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.OBSERVATION | self::hl7v2:OML_O21.SPECIMEN | self::hl7v2:OML_O21.PRIOR_RESULT)]"
                 priority="2379"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3738-true-d435390e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR | hl7v2:TCD | hl7v2:NTE | hl7v2:CTD | hl7v2:DG1 | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.OBSERVATION | hl7v2:OML_O21.SPECIMEN | hl7v2:OML_O21.PRIOR_RESULT (rule-reference: d20e3738-true-d435390e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3740-true-d435448e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBR.1 | self::hl7v2:OBR.2 | self::hl7v2:OBR.3 | self::hl7v2:OBR.4 | self::hl7v2:OBR.5 | self::hl7v2:OBR.6 | self::hl7v2:OBR.7 | self::hl7v2:OBR.8 | self::hl7v2:OBR.9 | self::hl7v2:OBR.10 | self::hl7v2:OBR.11 | self::hl7v2:OBR.12 | self::hl7v2:OBR.13 | self::hl7v2:OBR.14 | self::hl7v2:OBR.15 | self::hl7v2:OBR.16 | self::hl7v2:OBR.17 | self::hl7v2:OBR.18 | self::hl7v2:OBR.19 | self::hl7v2:OBR.20 | self::hl7v2:OBR.21 | self::hl7v2:OBR.22 | self::hl7v2:OBR.23 | self::hl7v2:OBR.24 | self::hl7v2:OBR.25 | self::hl7v2:OBR.26 | self::hl7v2:OBR.27 | self::hl7v2:OBR.28 | self::hl7v2:OBR.29 | self::hl7v2:OBR.30 | self::hl7v2:OBR.31 | self::hl7v2:OBR.32 | self::hl7v2:OBR.33 | self::hl7v2:OBR.34 | self::hl7v2:OBR.35 | self::hl7v2:OBR.36 | self::hl7v2:OBR.37 | self::hl7v2:OBR.38 | self::hl7v2:OBR.39 | self::hl7v2:OBR.40 | self::hl7v2:OBR.41 | self::hl7v2:OBR.42 | self::hl7v2:OBR.43 | self::hl7v2:OBR.44 | self::hl7v2:OBR.45 | self::hl7v2:OBR.46 | self::hl7v2:OBR.47 | self::hl7v2:OBR.48 | self::hl7v2:OBR.49)]"
                 priority="2378"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3740-true-d435448e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR.1 | hl7v2:OBR.2 | hl7v2:OBR.3 | hl7v2:OBR.4 | hl7v2:OBR.5 | hl7v2:OBR.6 | hl7v2:OBR.7 | hl7v2:OBR.8 | hl7v2:OBR.9 | hl7v2:OBR.10 | hl7v2:OBR.11 | hl7v2:OBR.12 | hl7v2:OBR.13 | hl7v2:OBR.14 | hl7v2:OBR.15 | hl7v2:OBR.16 | hl7v2:OBR.17 | hl7v2:OBR.18 | hl7v2:OBR.19 | hl7v2:OBR.20 | hl7v2:OBR.21 | hl7v2:OBR.22 | hl7v2:OBR.23 | hl7v2:OBR.24 | hl7v2:OBR.25 | hl7v2:OBR.26 | hl7v2:OBR.27 | hl7v2:OBR.28 | hl7v2:OBR.29 | hl7v2:OBR.30 | hl7v2:OBR.31 | hl7v2:OBR.32 | hl7v2:OBR.33 | hl7v2:OBR.34 | hl7v2:OBR.35 | hl7v2:OBR.36 | hl7v2:OBR.37 | hl7v2:OBR.38 | hl7v2:OBR.39 | hl7v2:OBR.40 | hl7v2:OBR.41 | hl7v2:OBR.42 | hl7v2:OBR.43 | hl7v2:OBR.44 | hl7v2:OBR.45 | hl7v2:OBR.46 | hl7v2:OBR.47 | hl7v2:OBR.48 | hl7v2:OBR.49 (rule-reference: d20e3740-true-d435448e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e15-true-d435467e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2377"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e15-true-d435467e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d435395e15-true-d435467e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e32-true-d435504e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2376"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e32-true-d435504e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d435395e32-true-d435504e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e49-true-d435543e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2375"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e49-true-d435543e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e49-true-d435543e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e95-true-d435596e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2374"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e95-true-d435596e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435395e95-true-d435596e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e115-true-d435619e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2373"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e115-true-d435619e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435395e115-true-d435619e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e126-true-d435642e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2372"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e126-true-d435642e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435395e126-true-d435642e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e137-true-d435665e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2371"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e137-true-d435665e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d435395e137-true-d435665e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435658e26-true-d435686e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2370"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435658e26-true-d435686e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435658e26-true-d435686e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e148-true-d435754e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2369"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e148-true-d435754e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d435395e148-true-d435754e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e32-true-d435774e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2368"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e32-true-d435774e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d435726e32-true-d435774e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e123-true-d435852e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2367"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e123-true-d435852e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d435726e123-true-d435852e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e215-true-d435906e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2366"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e215-true-d435906e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d435726e215-true-d435906e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e275-true-d435945e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2365"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e275-true-d435945e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435726e275-true-d435945e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e288-true-d435992e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2364"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e288-true-d435992e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d435726e288-true-d435992e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435985e17-true-d436003e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2363"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435985e17-true-d436003e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435985e17-true-d436003e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435985e28-true-d436026e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2362"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435985e28-true-d436026e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435985e28-true-d436026e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e318-true-d436055e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2361"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e318-true-d436055e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435726e318-true-d436055e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e329-true-d436078e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2360"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e329-true-d436078e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435726e329-true-d436078e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e351-true-d436114e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2359"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e351-true-d436114e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d435726e351-true-d436114e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435726e369-true-d436186e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2358"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435726e369-true-d436186e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d435726e369-true-d436186e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e173-true-d436261e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2357"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e173-true-d436261e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e173-true-d436261e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e195-true-d436314e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2356"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e195-true-d436314e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435395e195-true-d436314e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e227-true-d436342e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="2355"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e227-true-d436342e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d435395e227-true-d436342e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e24-true-d436360e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2354"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e24-true-d436360e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436330e24-true-d436360e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e53-true-d436432e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2353"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e53-true-d436432e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436330e53-true-d436432e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e66-true-d436496e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2352"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e66-true-d436496e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d436330e66-true-d436496e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436490e11-true-d436506e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2351"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436490e11-true-d436506e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d436490e11-true-d436506e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436500e5-true-d436516e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2350"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436500e5-true-d436516e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d436500e5-true-d436516e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e77-true-d436538e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2349"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e77-true-d436538e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436330e77-true-d436538e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e102-true-d436610e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2348"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e102-true-d436610e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436330e102-true-d436610e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e115-true-d436682e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2347"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e115-true-d436682e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436330e115-true-d436682e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436330e126-true-d436754e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2346"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436330e126-true-d436754e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436330e126-true-d436754e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e247-true-d436840e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2345"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e247-true-d436840e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d435395e247-true-d436840e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e32-true-d436860e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2344"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e32-true-d436860e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d436812e32-true-d436860e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e123-true-d436938e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2343"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e123-true-d436938e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d436812e123-true-d436938e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e215-true-d436992e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2342"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e215-true-d436992e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d436812e215-true-d436992e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e275-true-d437031e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2341"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e275-true-d437031e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d436812e275-true-d437031e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e288-true-d437078e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2340"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e288-true-d437078e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d436812e288-true-d437078e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437071e17-true-d437089e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2339"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437071e17-true-d437089e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d437071e17-true-d437089e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437071e28-true-d437112e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2338"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437071e28-true-d437112e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d437071e28-true-d437112e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e318-true-d437141e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2337"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e318-true-d437141e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d436812e318-true-d437141e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e329-true-d437164e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2336"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e329-true-d437164e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d436812e329-true-d437164e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e351-true-d437200e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2335"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e351-true-d437200e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436812e351-true-d437200e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d436812e369-true-d437272e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2334"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d436812e369-true-d437272e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d436812e369-true-d437272e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e258-true-d437347e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2333"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e258-true-d437347e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d435395e258-true-d437347e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e313-true-d437454e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2332"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e313-true-d437454e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435395e313-true-d437454e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e325-true-d437477e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:MOC.1 | self::hl7v2:MOC.2)]"
                 priority="2331"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e325-true-d437477e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOC.1 | hl7v2:MOC.2 (rule-reference: d435395e325-true-d437477e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437470e15-true-d437488e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2330"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437470e15-true-d437488e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d437470e15-true-d437488e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437470e26-true-d437515e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2329"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437470e26-true-d437515e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d437470e26-true-d437515e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e369-true-d437575e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:PRL.1 | self::hl7v2:PRL.2 | self::hl7v2:PRL.3)]"
                 priority="2328"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e369-true-d437575e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PRL.1 | hl7v2:PRL.2 | hl7v2:PRL.3 (rule-reference: d435395e369-true-d437575e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437567e45-true-d437590e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2327"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437567e45-true-d437590e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d437567e45-true-d437590e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437567e67-true-d437642e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2326"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437567e67-true-d437642e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d437567e67-true-d437642e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437636e17-true-d437652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2325"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437636e17-true-d437652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d437636e17-true-d437652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437646e5-true-d437662e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2324"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437646e5-true-d437662e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d437646e5-true-d437662e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e411-true-d437687e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="2323"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e411-true-d437687e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d435395e411-true-d437687e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e36-true-d437698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="2322"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e36-true-d437698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d437670e36-true-d437698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437691e31-true-d437719e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2321"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437691e31-true-d437719e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d437691e31-true-d437719e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e56-true-d437766e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="2320"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e56-true-d437766e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d437670e56-true-d437766e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e210-true-d437795e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2319"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e210-true-d437795e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d437670e210-true-d437795e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e227-true-d437818e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2318"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e227-true-d437818e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d437670e227-true-d437818e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e482-true-d437852e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2317"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e482-true-d437852e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d437670e482-true-d437852e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437846e11-true-d437862e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2316"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437846e11-true-d437862e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d437846e11-true-d437862e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437856e5-true-d437872e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2315"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437856e5-true-d437872e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d437856e5-true-d437872e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e507-true-d437902e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="2314"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e507-true-d437902e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d437670e507-true-d437902e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d437670e527-true-d437983e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2313"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d437670e527-true-d437983e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d437670e527-true-d437983e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e443-true-d438057e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2312"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e443-true-d438057e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d435395e443-true-d438057e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e32-true-d438077e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2311"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e32-true-d438077e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d438029e32-true-d438077e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e123-true-d438155e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2310"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e123-true-d438155e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d438029e123-true-d438155e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e215-true-d438209e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2309"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e215-true-d438209e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d438029e215-true-d438209e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e275-true-d438248e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2308"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e275-true-d438248e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d438029e275-true-d438248e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e288-true-d438295e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2307"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e288-true-d438295e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d438029e288-true-d438295e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438288e17-true-d438306e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2306"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438288e17-true-d438306e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438288e17-true-d438306e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438288e28-true-d438329e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2305"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438288e28-true-d438329e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438288e28-true-d438329e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e318-true-d438358e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2304"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e318-true-d438358e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438029e318-true-d438358e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e329-true-d438381e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2303"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e329-true-d438381e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438029e329-true-d438381e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e351-true-d438417e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2302"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e351-true-d438417e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d438029e351-true-d438417e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438029e369-true-d438489e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2301"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438029e369-true-d438489e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d438029e369-true-d438489e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e454-true-d438554e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="2300"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e454-true-d438554e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d435395e454-true-d438554e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438547e21-true-d438567e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2299"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438547e21-true-d438567e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d438547e21-true-d438567e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438547e50-true-d438604e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2298"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438547e50-true-d438604e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d438547e50-true-d438604e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e485-true-d438649e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.31/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2297"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e485-true-d438649e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e485-true-d438649e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e496-true-d438705e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="2296"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e496-true-d438705e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d435395e496-true-d438705e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438689e15-true-d438725e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="2295"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438689e15-true-d438725e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d438689e15-true-d438725e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438689e26-true-d438802e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2294"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438689e26-true-d438802e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438689e26-true-d438802e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438689e37-true-d438825e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2293"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438689e37-true-d438825e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438689e37-true-d438825e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438689e87-true-d438867e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2292"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438689e87-true-d438867e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d438689e87-true-d438867e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e507-true-d438929e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="2291"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e507-true-d438929e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d435395e507-true-d438929e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438913e15-true-d438949e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="2290"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438913e15-true-d438949e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d438913e15-true-d438949e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438913e26-true-d439026e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2289"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438913e26-true-d439026e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438913e26-true-d439026e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438913e37-true-d439049e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2288"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438913e37-true-d439049e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d438913e37-true-d439049e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d438913e87-true-d439091e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2287"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d438913e87-true-d439091e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d438913e87-true-d439091e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e519-true-d439153e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="2286"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e519-true-d439153e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d435395e519-true-d439153e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439137e15-true-d439173e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="2285"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439137e15-true-d439173e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d439137e15-true-d439173e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439137e26-true-d439250e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2284"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439137e26-true-d439250e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d439137e26-true-d439250e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439137e37-true-d439273e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2283"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439137e37-true-d439273e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d439137e37-true-d439273e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439137e87-true-d439315e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2282"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439137e87-true-d439315e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d439137e87-true-d439315e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e530-true-d439377e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="2281"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e530-true-d439377e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d435395e530-true-d439377e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439361e15-true-d439397e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="2280"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439361e15-true-d439397e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d439361e15-true-d439397e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439361e26-true-d439474e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2279"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439361e26-true-d439474e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d439361e26-true-d439474e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439361e37-true-d439497e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2278"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439361e37-true-d439497e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d439361e37-true-d439497e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d439361e87-true-d439539e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2277"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d439361e87-true-d439539e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d439361e87-true-d439539e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e541-true-d439592e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.36/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2276"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e541-true-d439592e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d435395e541-true-d439592e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e563-true-d439625e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2275"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e563-true-d439625e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e563-true-d439625e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e574-true-d439676e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2274"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e574-true-d439676e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e574-true-d439676e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e585-true-d439727e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2273"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e585-true-d439727e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e585-true-d439727e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e622-true-d439790e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2272"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e622-true-d439790e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e622-true-d439790e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e633-true-d439841e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2271"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e633-true-d439841e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e633-true-d439841e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e647-true-d439892e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2270"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e647-true-d439892e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e647-true-d439892e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e660-true-d439943e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.46/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2269"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e660-true-d439943e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e660-true-d439943e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e673-true-d439994e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.47/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2268"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e673-true-d439994e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d435395e673-true-d439994e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d435395e686-true-d440048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OBR/hl7v2:OBR.48/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2267"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d435395e686-true-d440048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d435395e686-true-d440048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3742-true-d440125e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/*[not(@xsi:nil = 'true')][not(self::hl7v2:TCD.1 | self::hl7v2:TCD.2 | self::hl7v2:TCD.3 | self::hl7v2:TCD.4 | self::hl7v2:TCD.5 | self::hl7v2:TCD.6 | self::hl7v2:TCD.7 | self::hl7v2:TCD.8)]"
                 priority="2266"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3742-true-d440125e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TCD.1 | hl7v2:TCD.2 | hl7v2:TCD.3 | hl7v2:TCD.4 | hl7v2:TCD.5 | hl7v2:TCD.6 | hl7v2:TCD.7 | hl7v2:TCD.8 (rule-reference: d20e3742-true-d440125e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440113e1-true-d440140e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2265"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440113e1-true-d440140e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d440113e1-true-d440140e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440113e12-true-d440189e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="2264"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440113e12-true-d440189e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d440113e12-true-d440189e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440113e23-true-d440226e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="2263"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440113e23-true-d440226e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d440113e23-true-d440226e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440113e34-true-d440263e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="2262"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440113e34-true-d440263e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d440113e34-true-d440263e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440113e45-true-d440300e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="2261"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440113e45-true-d440300e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d440113e45-true-d440300e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440113e82-true-d440351e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:TCD/hl7v2:TCD.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2260"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440113e82-true-d440351e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d440113e82-true-d440351e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3744-true-d440400e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="2259"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3744-true-d440400e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3744-true-d440400e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440392e110-true-d440422e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2258"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440392e110-true-d440422e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d440392e110-true-d440422e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440416e36-true-d440432e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2257"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440416e36-true-d440432e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d440416e36-true-d440432e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440426e5-true-d440442e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="2256"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440426e5-true-d440442e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d440426e5-true-d440442e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440392e142-true-d440461e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2255"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440392e142-true-d440461e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d440392e142-true-d440461e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3746-true-d440513e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/*[not(@xsi:nil = 'true')][not(self::hl7v2:CTD.1 | self::hl7v2:CTD.2 | self::hl7v2:CTD.3 | self::hl7v2:CTD.4 | self::hl7v2:CTD.5 | self::hl7v2:CTD.6 | self::hl7v2:CTD.7)]"
                 priority="2254"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3746-true-d440513e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CTD.1 | hl7v2:CTD.2 | hl7v2:CTD.3 | hl7v2:CTD.4 | hl7v2:CTD.5 | hl7v2:CTD.6 | hl7v2:CTD.7 (rule-reference: d20e3746-true-d440513e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e1-true-d440528e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2253"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e1-true-d440528e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d440502e1-true-d440528e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e14-true-d440587e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="2252"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e14-true-d440587e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d440502e14-true-d440587e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440568e15-true-d440601e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2251"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440568e15-true-d440601e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d440568e15-true-d440601e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440568e142-true-d440688e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2250"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440568e142-true-d440688e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d440568e142-true-d440688e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440568e155-true-d440735e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2249"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440568e155-true-d440735e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d440568e155-true-d440735e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440728e17-true-d440746e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2248"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440728e17-true-d440746e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440728e17-true-d440746e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440728e28-true-d440769e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2247"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440728e28-true-d440769e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440728e28-true-d440769e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440568e186-true-d440798e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2246"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440568e186-true-d440798e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440568e186-true-d440798e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440568e197-true-d440821e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.2/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2245"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440568e197-true-d440821e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440568e197-true-d440821e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e25-true-d440862e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="2244"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e25-true-d440862e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d440502e25-true-d440862e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440843e15-true-d440874e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="2243"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440843e15-true-d440874e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d440843e15-true-d440874e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440843e189-true-d440963e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2242"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440843e189-true-d440963e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d440843e189-true-d440963e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440956e17-true-d440974e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2241"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440956e17-true-d440974e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440956e17-true-d440974e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440956e28-true-d440997e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2240"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440956e28-true-d440997e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440956e28-true-d440997e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440843e206-true-d441020e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2239"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440843e206-true-d441020e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440843e206-true-d441020e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440843e217-true-d441043e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.3/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2238"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440843e217-true-d441043e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d440843e217-true-d441043e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e36-true-d441075e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="2237"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e36-true-d441075e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d440502e36-true-d441075e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441059e48-true-d441105e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2236"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441059e48-true-d441105e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d441059e48-true-d441105e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441059e125-true-d441166e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2235"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441059e125-true-d441166e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d441059e125-true-d441166e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441059e134-true-d441202e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.4/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2234"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441059e134-true-d441202e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d441059e134-true-d441202e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e47-true-d441241e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="2233"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e47-true-d441241e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d440502e47-true-d441241e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e58-true-d441328e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2232"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e58-true-d441328e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d440502e58-true-d441328e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d440502e71-true-d441377e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:CTD/hl7v2:CTD.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:PLN.1 | self::hl7v2:PLN.2 | self::hl7v2:PLN.3 | self::hl7v2:PLN.4)]"
                 priority="2231"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d440502e71-true-d441377e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PLN.1 | hl7v2:PLN.2 | hl7v2:PLN.3 | hl7v2:PLN.4 (rule-reference: d440502e71-true-d441377e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3748-true-d441431e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/*[not(@xsi:nil = 'true')][not(self::hl7v2:DG1.1 | self::hl7v2:DG1.2 | self::hl7v2:DG1.3 | self::hl7v2:DG1.4 | self::hl7v2:DG1.5 | self::hl7v2:DG1.6 | self::hl7v2:DG1.7 | self::hl7v2:DG1.8 | self::hl7v2:DG1.9 | self::hl7v2:DG1.10 | self::hl7v2:DG1.11 | self::hl7v2:DG1.12 | self::hl7v2:DG1.13 | self::hl7v2:DG1.14 | self::hl7v2:DG1.15 | self::hl7v2:DG1.16 | self::hl7v2:DG1.17 | self::hl7v2:DG1.18 | self::hl7v2:DG1.19 | self::hl7v2:DG1.20 | self::hl7v2:DG1.21)]"
                 priority="2230"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3748-true-d441431e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DG1.1 | hl7v2:DG1.2 | hl7v2:DG1.3 | hl7v2:DG1.4 | hl7v2:DG1.5 | hl7v2:DG1.6 | hl7v2:DG1.7 | hl7v2:DG1.8 | hl7v2:DG1.9 | hl7v2:DG1.10 | hl7v2:DG1.11 | hl7v2:DG1.12 | hl7v2:DG1.13 | hl7v2:DG1.14 | hl7v2:DG1.15 | hl7v2:DG1.16 | hl7v2:DG1.17 | hl7v2:DG1.18 | hl7v2:DG1.19 | hl7v2:DG1.20 | hl7v2:DG1.21 (rule-reference: d20e3748-true-d441431e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e25-true-d441458e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2229"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e25-true-d441458e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d441406e25-true-d441458e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e49-true-d441511e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2228"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e49-true-d441511e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d441406e49-true-d441511e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e73-true-d441544e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2227"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e73-true-d441544e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d441406e73-true-d441544e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e86-true-d441595e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2226"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e86-true-d441595e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d441406e86-true-d441595e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e125-true-d441658e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2225"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e125-true-d441658e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d441406e125-true-d441658e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e150-true-d441715e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="2224"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e150-true-d441715e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d441406e150-true-d441715e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441704e15-true-d441726e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="2223"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441704e15-true-d441726e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d441704e15-true-d441726e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441704e82-true-d441771e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.13/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2222"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441704e82-true-d441771e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d441704e82-true-d441771e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e185-true-d441857e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2221"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e185-true-d441857e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d441406e185-true-d441857e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e32-true-d441877e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2220"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e32-true-d441877e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d441829e32-true-d441877e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e123-true-d441955e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2219"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e123-true-d441955e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d441829e123-true-d441955e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e215-true-d442009e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2218"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e215-true-d442009e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d441829e215-true-d442009e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e275-true-d442048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2217"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e275-true-d442048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d441829e275-true-d442048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e288-true-d442095e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2216"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e288-true-d442095e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d441829e288-true-d442095e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442088e17-true-d442106e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2215"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442088e17-true-d442106e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442088e17-true-d442106e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442088e28-true-d442129e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2214"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442088e28-true-d442129e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442088e28-true-d442129e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e318-true-d442158e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2213"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e318-true-d442158e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d441829e318-true-d442158e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e329-true-d442181e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2212"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e329-true-d442181e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d441829e329-true-d442181e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e351-true-d442217e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2211"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e351-true-d442217e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d441829e351-true-d442217e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441829e369-true-d442289e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2210"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441829e369-true-d442289e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d441829e369-true-d442289e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e222-true-d442366e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2209"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e222-true-d442366e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d441406e222-true-d442366e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d441406e233-true-d442391e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:DG1/hl7v2:DG1.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2208"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d441406e233-true-d442391e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d441406e233-true-d442391e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3751-true-d442428e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2207"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3751-true-d442428e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3751-true-d442428e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3756-true-d442456e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2206"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3756-true-d442456e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3756-true-d442456e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e38-true-d442483e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2205"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e38-true-d442483e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d442433e38-true-d442483e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e83-true-d442546e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2204"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e83-true-d442546e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d442433e83-true-d442546e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e165-true-d442623e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2203"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e165-true-d442623e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442433e165-true-d442623e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e187-true-d442652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2202"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e187-true-d442652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442433e187-true-d442652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e198-true-d442679e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2201"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e198-true-d442679e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d442433e198-true-d442679e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e209-true-d442747e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2200"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e209-true-d442747e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d442433e209-true-d442747e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e32-true-d442767e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2199"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e32-true-d442767e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d442719e32-true-d442767e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e123-true-d442845e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2198"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e123-true-d442845e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d442719e123-true-d442845e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e215-true-d442899e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2197"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e215-true-d442899e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d442719e215-true-d442899e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e275-true-d442938e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2196"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e275-true-d442938e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d442719e275-true-d442938e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e288-true-d442985e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2195"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e288-true-d442985e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d442719e288-true-d442985e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442978e17-true-d442996e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2194"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442978e17-true-d442996e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442978e17-true-d442996e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442978e28-true-d443019e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2193"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442978e28-true-d443019e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442978e28-true-d443019e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e318-true-d443048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2192"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e318-true-d443048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442719e318-true-d443048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e329-true-d443071e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2191"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e329-true-d443071e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442719e329-true-d443071e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e351-true-d443107e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2190"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e351-true-d443107e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d442719e351-true-d443107e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442719e369-true-d443179e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2189"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442719e369-true-d443179e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d442719e369-true-d443179e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e220-true-d443248e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2188"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e220-true-d443248e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d442433e220-true-d443248e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e231-true-d443297e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2187"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e231-true-d443297e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d442433e231-true-d443297e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d442433e242-true-d443332e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2186"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d442433e242-true-d443332e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d442433e242-true-d443332e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3759-true-d443351e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2185"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3759-true-d443351e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3759-true-d443351e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3764-true-d443379e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2184"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3764-true-d443379e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3764-true-d443379e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e32-true-d443406e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2183"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e32-true-d443406e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d443356e32-true-d443406e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e77-true-d443469e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2182"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e77-true-d443469e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d443356e77-true-d443469e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e154-true-d443546e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2181"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e154-true-d443546e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443356e154-true-d443546e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e176-true-d443575e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2180"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e176-true-d443575e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443356e176-true-d443575e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e187-true-d443602e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2179"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e187-true-d443602e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d443356e187-true-d443602e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e198-true-d443670e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2178"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e198-true-d443670e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d443356e198-true-d443670e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e32-true-d443690e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2177"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e32-true-d443690e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d443642e32-true-d443690e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e123-true-d443768e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2176"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e123-true-d443768e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d443642e123-true-d443768e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e215-true-d443822e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2175"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e215-true-d443822e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d443642e215-true-d443822e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e275-true-d443861e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2174"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e275-true-d443861e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d443642e275-true-d443861e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e288-true-d443908e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2173"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e288-true-d443908e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d443642e288-true-d443908e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443901e17-true-d443919e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2172"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443901e17-true-d443919e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443901e17-true-d443919e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443901e28-true-d443942e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2171"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443901e28-true-d443942e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443901e28-true-d443942e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e318-true-d443971e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2170"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e318-true-d443971e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443642e318-true-d443971e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e329-true-d443994e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2169"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e329-true-d443994e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443642e329-true-d443994e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e351-true-d444030e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2168"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e351-true-d444030e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d443642e351-true-d444030e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443642e369-true-d444102e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2167"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443642e369-true-d444102e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d443642e369-true-d444102e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e209-true-d444171e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2166"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e209-true-d444171e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d443356e209-true-d444171e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e220-true-d444220e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2165"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e220-true-d444220e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d443356e220-true-d444220e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d443356e231-true-d444255e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2164"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d443356e231-true-d444255e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d443356e231-true-d444255e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3767-true-d444274e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2163"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3767-true-d444274e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3767-true-d444274e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3772-true-d444302e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2162"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3772-true-d444302e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3772-true-d444302e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e35-true-d444329e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2161"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e35-true-d444329e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d444279e35-true-d444329e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e80-true-d444392e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2160"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e80-true-d444392e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d444279e80-true-d444392e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e165-true-d444469e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2159"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e165-true-d444469e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444279e165-true-d444469e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e187-true-d444498e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2158"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e187-true-d444498e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444279e187-true-d444498e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e198-true-d444525e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2157"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e198-true-d444525e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d444279e198-true-d444525e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e209-true-d444593e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2156"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e209-true-d444593e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d444279e209-true-d444593e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e32-true-d444613e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2155"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e32-true-d444613e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d444565e32-true-d444613e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e123-true-d444691e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2154"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e123-true-d444691e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d444565e123-true-d444691e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e215-true-d444745e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2153"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e215-true-d444745e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d444565e215-true-d444745e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e275-true-d444784e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2152"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e275-true-d444784e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d444565e275-true-d444784e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e288-true-d444831e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2151"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e288-true-d444831e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d444565e288-true-d444831e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444824e17-true-d444842e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2150"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444824e17-true-d444842e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444824e17-true-d444842e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444824e28-true-d444865e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2149"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444824e28-true-d444865e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444824e28-true-d444865e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e318-true-d444894e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2148"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e318-true-d444894e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444565e318-true-d444894e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e329-true-d444917e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2147"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e329-true-d444917e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444565e329-true-d444917e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e351-true-d444953e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2146"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e351-true-d444953e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d444565e351-true-d444953e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444565e369-true-d445025e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2145"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444565e369-true-d445025e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d444565e369-true-d445025e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e220-true-d445094e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2144"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e220-true-d445094e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d444279e220-true-d445094e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e231-true-d445143e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2143"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e231-true-d445143e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d444279e231-true-d445143e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d444279e242-true-d445178e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2142"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d444279e242-true-d445178e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d444279e242-true-d445178e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3775-true-d445197e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2141"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3775-true-d445197e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3775-true-d445197e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3780-true-d445225e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2140"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3780-true-d445225e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3780-true-d445225e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e35-true-d445252e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2139"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e35-true-d445252e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d445202e35-true-d445252e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e80-true-d445315e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2138"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e80-true-d445315e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d445202e80-true-d445315e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e163-true-d445392e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2137"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e163-true-d445392e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445202e163-true-d445392e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e185-true-d445421e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2136"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e185-true-d445421e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445202e185-true-d445421e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e196-true-d445448e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2135"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e196-true-d445448e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d445202e196-true-d445448e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e207-true-d445516e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2134"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e207-true-d445516e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d445202e207-true-d445516e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e32-true-d445536e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2133"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e32-true-d445536e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d445488e32-true-d445536e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e123-true-d445614e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2132"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e123-true-d445614e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d445488e123-true-d445614e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e215-true-d445668e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2131"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e215-true-d445668e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d445488e215-true-d445668e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e275-true-d445707e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2130"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e275-true-d445707e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d445488e275-true-d445707e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e288-true-d445754e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2129"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e288-true-d445754e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d445488e288-true-d445754e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445747e17-true-d445765e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2128"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445747e17-true-d445765e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445747e17-true-d445765e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445747e28-true-d445788e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2127"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445747e28-true-d445788e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445747e28-true-d445788e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e318-true-d445817e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2126"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e318-true-d445817e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445488e318-true-d445817e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e329-true-d445840e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2125"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e329-true-d445840e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445488e329-true-d445840e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e351-true-d445876e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2124"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e351-true-d445876e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d445488e351-true-d445876e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445488e369-true-d445948e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2123"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445488e369-true-d445948e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d445488e369-true-d445948e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e218-true-d446017e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2122"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e218-true-d446017e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d445202e218-true-d446017e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e229-true-d446066e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2121"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e229-true-d446066e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d445202e229-true-d446066e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d445202e240-true-d446101e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2120"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d445202e240-true-d446101e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d445202e240-true-d446101e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3783-true-d446120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2119"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3783-true-d446120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3783-true-d446120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3788-true-d446148e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2118"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3788-true-d446148e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3788-true-d446148e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e35-true-d446175e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2117"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e35-true-d446175e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d446125e35-true-d446175e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e63-true-d446228e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2116"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e63-true-d446228e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446125e63-true-d446228e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e77-true-d446255e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2115"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e77-true-d446255e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d446125e77-true-d446255e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e154-true-d446332e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2114"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e154-true-d446332e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446125e154-true-d446332e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e176-true-d446361e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2113"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e176-true-d446361e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446125e176-true-d446361e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e187-true-d446388e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2112"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e187-true-d446388e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d446125e187-true-d446388e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e198-true-d446456e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2111"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e198-true-d446456e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d446125e198-true-d446456e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e32-true-d446476e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2110"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e32-true-d446476e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d446428e32-true-d446476e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e123-true-d446554e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2109"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e123-true-d446554e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d446428e123-true-d446554e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e215-true-d446608e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2108"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e215-true-d446608e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d446428e215-true-d446608e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e275-true-d446647e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2107"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e275-true-d446647e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d446428e275-true-d446647e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e288-true-d446694e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2106"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e288-true-d446694e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d446428e288-true-d446694e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446687e17-true-d446705e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2105"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446687e17-true-d446705e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446687e17-true-d446705e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446687e28-true-d446728e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2104"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446687e28-true-d446728e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446687e28-true-d446728e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e318-true-d446757e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2103"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e318-true-d446757e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446428e318-true-d446757e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e329-true-d446780e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2102"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e329-true-d446780e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446428e329-true-d446780e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e351-true-d446816e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2101"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e351-true-d446816e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d446428e351-true-d446816e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446428e369-true-d446888e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2100"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446428e369-true-d446888e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d446428e369-true-d446888e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e209-true-d446957e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2099"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e209-true-d446957e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d446125e209-true-d446957e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e220-true-d447006e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2098"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e220-true-d447006e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d446125e220-true-d447006e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d446125e231-true-d447041e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2097"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d446125e231-true-d447041e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d446125e231-true-d447041e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3791-true-d447060e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2096"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3791-true-d447060e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3791-true-d447060e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3796-true-d447088e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.11 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2095"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3796-true-d447088e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.11 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3796-true-d447088e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e35-true-d447115e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2094"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e35-true-d447115e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447065e35-true-d447115e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e91-true-d447184e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2093"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e91-true-d447184e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447065e91-true-d447184e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e151-true-d447255e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2092"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e151-true-d447255e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447065e151-true-d447255e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e173-true-d447284e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2091"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e173-true-d447284e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447065e173-true-d447284e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e184-true-d447311e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2090"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e184-true-d447311e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447065e184-true-d447311e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e195-true-d447379e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2089"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e195-true-d447379e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d447065e195-true-d447379e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e32-true-d447399e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2088"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e32-true-d447399e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d447351e32-true-d447399e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e123-true-d447477e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2087"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e123-true-d447477e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d447351e123-true-d447477e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e215-true-d447531e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2086"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e215-true-d447531e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d447351e215-true-d447531e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e275-true-d447570e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2085"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e275-true-d447570e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447351e275-true-d447570e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e288-true-d447617e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2084"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e288-true-d447617e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d447351e288-true-d447617e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447610e17-true-d447628e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2083"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447610e17-true-d447628e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447610e17-true-d447628e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447610e28-true-d447651e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2082"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447610e28-true-d447651e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447610e28-true-d447651e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e318-true-d447680e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2081"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e318-true-d447680e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447351e318-true-d447680e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e329-true-d447703e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2080"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e329-true-d447703e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447351e329-true-d447703e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e351-true-d447739e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2079"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e351-true-d447739e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d447351e351-true-d447739e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447351e369-true-d447811e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2078"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447351e369-true-d447811e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d447351e369-true-d447811e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e206-true-d447880e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2077"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e206-true-d447880e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447065e206-true-d447880e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e217-true-d447929e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2076"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e217-true-d447929e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d447065e217-true-d447929e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447065e228-true-d447964e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2075"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447065e228-true-d447964e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447065e228-true-d447964e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3800-true-d447983e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2074"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3800-true-d447983e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3800-true-d447983e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3805-true-d448011e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2073"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3805-true-d448011e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3805-true-d448011e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e35-true-d448038e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2072"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e35-true-d448038e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447988e35-true-d448038e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e87-true-d448101e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2071"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e87-true-d448101e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447988e87-true-d448101e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e164-true-d448178e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2070"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e164-true-d448178e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447988e164-true-d448178e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e186-true-d448207e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2069"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e186-true-d448207e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447988e186-true-d448207e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e197-true-d448234e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2068"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e197-true-d448234e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447988e197-true-d448234e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e208-true-d448302e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2067"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e208-true-d448302e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d447988e208-true-d448302e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e32-true-d448322e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2066"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e32-true-d448322e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d448274e32-true-d448322e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e123-true-d448400e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2065"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e123-true-d448400e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d448274e123-true-d448400e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e215-true-d448454e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2064"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e215-true-d448454e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d448274e215-true-d448454e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e275-true-d448493e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2063"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e275-true-d448493e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d448274e275-true-d448493e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e288-true-d448540e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2062"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e288-true-d448540e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d448274e288-true-d448540e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448533e17-true-d448551e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2061"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448533e17-true-d448551e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448533e17-true-d448551e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448533e28-true-d448574e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2060"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448533e28-true-d448574e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448533e28-true-d448574e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e318-true-d448603e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2059"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e318-true-d448603e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448274e318-true-d448603e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e329-true-d448626e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2058"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e329-true-d448626e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448274e329-true-d448626e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e351-true-d448662e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2057"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e351-true-d448662e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d448274e351-true-d448662e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448274e369-true-d448734e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2056"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448274e369-true-d448734e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d448274e369-true-d448734e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e219-true-d448803e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2055"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e219-true-d448803e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d447988e219-true-d448803e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e230-true-d448852e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2054"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e230-true-d448852e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d447988e230-true-d448852e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d447988e241-true-d448887e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2053"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d447988e241-true-d448887e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d447988e241-true-d448887e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3808-true-d448906e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2052"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3808-true-d448906e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3808-true-d448906e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3813-true-d448934e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2051"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3813-true-d448934e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3813-true-d448934e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e35-true-d448961e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2050"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e35-true-d448961e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d448911e35-true-d448961e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e84-true-d449024e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2049"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e84-true-d449024e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d448911e84-true-d449024e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e161-true-d449101e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2048"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e161-true-d449101e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448911e161-true-d449101e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e183-true-d449130e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2047"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e183-true-d449130e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448911e183-true-d449130e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e194-true-d449157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2046"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e194-true-d449157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d448911e194-true-d449157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e205-true-d449225e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2045"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e205-true-d449225e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d448911e205-true-d449225e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e32-true-d449245e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2044"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e32-true-d449245e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d449197e32-true-d449245e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e123-true-d449323e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2043"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e123-true-d449323e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d449197e123-true-d449323e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e215-true-d449377e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2042"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e215-true-d449377e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d449197e215-true-d449377e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e275-true-d449416e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2041"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e275-true-d449416e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d449197e275-true-d449416e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e288-true-d449463e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2040"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e288-true-d449463e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d449197e288-true-d449463e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449456e17-true-d449474e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2039"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449456e17-true-d449474e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449456e17-true-d449474e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449456e28-true-d449497e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2038"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449456e28-true-d449497e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449456e28-true-d449497e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e318-true-d449526e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2037"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e318-true-d449526e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449197e318-true-d449526e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e329-true-d449549e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2036"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e329-true-d449549e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449197e329-true-d449549e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e351-true-d449585e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2035"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e351-true-d449585e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d449197e351-true-d449585e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449197e369-true-d449657e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2034"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449197e369-true-d449657e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d449197e369-true-d449657e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e216-true-d449726e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2033"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e216-true-d449726e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d448911e216-true-d449726e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e227-true-d449775e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2032"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e227-true-d449775e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d448911e227-true-d449775e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d448911e238-true-d449810e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2031"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d448911e238-true-d449810e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d448911e238-true-d449810e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3816-true-d449829e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2030"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3816-true-d449829e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3816-true-d449829e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3821-true-d449857e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2029"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3821-true-d449857e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3821-true-d449857e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e35-true-d449884e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2028"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e35-true-d449884e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d449834e35-true-d449884e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e84-true-d449947e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2027"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e84-true-d449947e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d449834e84-true-d449947e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e161-true-d450024e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2026"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e161-true-d450024e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449834e161-true-d450024e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e183-true-d450053e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2025"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e183-true-d450053e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449834e183-true-d450053e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e194-true-d450080e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2024"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e194-true-d450080e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d449834e194-true-d450080e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e205-true-d450148e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2023"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e205-true-d450148e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d449834e205-true-d450148e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e32-true-d450168e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="2022"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e32-true-d450168e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d450120e32-true-d450168e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e123-true-d450246e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2021"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e123-true-d450246e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d450120e123-true-d450246e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e215-true-d450300e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="2020"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e215-true-d450300e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d450120e215-true-d450300e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e275-true-d450339e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2019"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e275-true-d450339e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d450120e275-true-d450339e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e288-true-d450386e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="2018"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e288-true-d450386e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d450120e288-true-d450386e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450379e17-true-d450397e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2017"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450379e17-true-d450397e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450379e17-true-d450397e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450379e28-true-d450420e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2016"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450379e28-true-d450420e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450379e28-true-d450420e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e318-true-d450449e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2015"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e318-true-d450449e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450120e318-true-d450449e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e329-true-d450472e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2014"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e329-true-d450472e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450120e329-true-d450472e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e351-true-d450508e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2013"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e351-true-d450508e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d450120e351-true-d450508e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450120e369-true-d450580e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="2012"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450120e369-true-d450580e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d450120e369-true-d450580e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e216-true-d450649e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2011"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e216-true-d450649e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d449834e216-true-d450649e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e227-true-d450698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="2010"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e227-true-d450698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d449834e227-true-d450698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d449834e238-true-d450733e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2009"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d449834e238-true-d450733e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d449834e238-true-d450733e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3824-true-d450752e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="2008"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3824-true-d450752e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3824-true-d450752e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3829-true-d450780e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="2007"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3829-true-d450780e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3829-true-d450780e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e35-true-d450807e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2006"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e35-true-d450807e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d450757e35-true-d450807e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e66-true-d450860e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2005"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e66-true-d450860e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450757e66-true-d450860e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e84-true-d450887e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2004"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e84-true-d450887e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d450757e84-true-d450887e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e161-true-d450964e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2003"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e161-true-d450964e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450757e161-true-d450964e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e183-true-d450993e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="2002"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e183-true-d450993e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450757e183-true-d450993e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e194-true-d451020e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="2001"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e194-true-d451020e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d450757e194-true-d451020e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e205-true-d451088e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="2000"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e205-true-d451088e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d450757e205-true-d451088e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e32-true-d451108e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1999"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e32-true-d451108e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d451060e32-true-d451108e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e123-true-d451186e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1998"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e123-true-d451186e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d451060e123-true-d451186e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e215-true-d451240e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1997"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e215-true-d451240e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d451060e215-true-d451240e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e275-true-d451279e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1996"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e275-true-d451279e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d451060e275-true-d451279e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e288-true-d451326e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1995"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e288-true-d451326e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d451060e288-true-d451326e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451319e17-true-d451337e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1994"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451319e17-true-d451337e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451319e17-true-d451337e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451319e28-true-d451360e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1993"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451319e28-true-d451360e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451319e28-true-d451360e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e318-true-d451389e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1992"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e318-true-d451389e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451060e318-true-d451389e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e329-true-d451412e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1991"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e329-true-d451412e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451060e329-true-d451412e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e351-true-d451448e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1990"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e351-true-d451448e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d451060e351-true-d451448e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451060e369-true-d451520e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1989"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451060e369-true-d451520e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d451060e369-true-d451520e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e216-true-d451589e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1988"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e216-true-d451589e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d450757e216-true-d451589e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e227-true-d451638e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1987"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e227-true-d451638e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d450757e227-true-d451638e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d450757e238-true-d451673e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1986"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d450757e238-true-d451673e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d450757e238-true-d451673e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3832-true-d451692e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1985"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3832-true-d451692e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3832-true-d451692e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3837-true-d451720e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1984"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3837-true-d451720e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3837-true-d451720e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e35-true-d451747e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1983"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e35-true-d451747e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d451697e35-true-d451747e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e74-true-d451810e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1982"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e74-true-d451810e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d451697e74-true-d451810e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e157-true-d451887e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1981"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e157-true-d451887e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451697e157-true-d451887e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e179-true-d451916e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1980"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e179-true-d451916e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451697e179-true-d451916e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e190-true-d451943e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1979"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e190-true-d451943e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d451697e190-true-d451943e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e201-true-d452011e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1978"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e201-true-d452011e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d451697e201-true-d452011e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e32-true-d452031e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1977"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e32-true-d452031e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d451983e32-true-d452031e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e123-true-d452109e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1976"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e123-true-d452109e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d451983e123-true-d452109e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e215-true-d452163e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1975"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e215-true-d452163e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d451983e215-true-d452163e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e275-true-d452202e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1974"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e275-true-d452202e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d451983e275-true-d452202e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e288-true-d452249e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1973"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e288-true-d452249e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d451983e288-true-d452249e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452242e17-true-d452260e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1972"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452242e17-true-d452260e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452242e17-true-d452260e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452242e28-true-d452283e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1971"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452242e28-true-d452283e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452242e28-true-d452283e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e318-true-d452312e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1970"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e318-true-d452312e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451983e318-true-d452312e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e329-true-d452335e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1969"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e329-true-d452335e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451983e329-true-d452335e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e351-true-d452371e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1968"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e351-true-d452371e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d451983e351-true-d452371e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451983e369-true-d452443e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1967"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451983e369-true-d452443e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d451983e369-true-d452443e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e212-true-d452512e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1966"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e212-true-d452512e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d451697e212-true-d452512e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e223-true-d452561e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1965"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e223-true-d452561e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d451697e223-true-d452561e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d451697e234-true-d452596e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1964"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d451697e234-true-d452596e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d451697e234-true-d452596e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3840-true-d452615e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1963"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3840-true-d452615e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3840-true-d452615e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3845-true-d452643e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1962"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3845-true-d452643e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3845-true-d452643e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e35-true-d452670e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1961"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e35-true-d452670e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d452620e35-true-d452670e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e88-true-d452733e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1960"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e88-true-d452733e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d452620e88-true-d452733e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e165-true-d452810e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1959"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e165-true-d452810e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452620e165-true-d452810e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e187-true-d452839e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1958"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e187-true-d452839e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452620e187-true-d452839e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e198-true-d452866e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1957"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e198-true-d452866e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d452620e198-true-d452866e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e209-true-d452934e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1956"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e209-true-d452934e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d452620e209-true-d452934e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e32-true-d452954e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1955"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e32-true-d452954e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d452906e32-true-d452954e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e123-true-d453032e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1954"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e123-true-d453032e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d452906e123-true-d453032e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e215-true-d453086e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1953"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e215-true-d453086e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d452906e215-true-d453086e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e275-true-d453125e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1952"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e275-true-d453125e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d452906e275-true-d453125e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e288-true-d453172e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1951"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e288-true-d453172e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d452906e288-true-d453172e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453165e17-true-d453183e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1950"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453165e17-true-d453183e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453165e17-true-d453183e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453165e28-true-d453206e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1949"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453165e28-true-d453206e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453165e28-true-d453206e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e318-true-d453235e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1948"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e318-true-d453235e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452906e318-true-d453235e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e329-true-d453258e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1947"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e329-true-d453258e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452906e329-true-d453258e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e351-true-d453294e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1946"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e351-true-d453294e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d452906e351-true-d453294e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452906e369-true-d453366e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1945"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452906e369-true-d453366e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d452906e369-true-d453366e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e220-true-d453435e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1944"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e220-true-d453435e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d452620e220-true-d453435e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e231-true-d453484e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1943"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e231-true-d453484e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d452620e231-true-d453484e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d452620e242-true-d453519e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1942"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d452620e242-true-d453519e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d452620e242-true-d453519e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3849-true-d453538e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1941"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3849-true-d453538e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3849-true-d453538e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3854-true-d453566e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1940"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3854-true-d453566e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3854-true-d453566e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e35-true-d453593e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1939"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e35-true-d453593e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d453543e35-true-d453593e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e84-true-d453656e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1938"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e84-true-d453656e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d453543e84-true-d453656e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e161-true-d453733e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1937"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e161-true-d453733e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453543e161-true-d453733e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e183-true-d453762e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1936"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e183-true-d453762e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453543e183-true-d453762e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e194-true-d453789e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1935"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e194-true-d453789e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d453543e194-true-d453789e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e205-true-d453857e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1934"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e205-true-d453857e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d453543e205-true-d453857e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e32-true-d453877e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1933"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e32-true-d453877e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d453829e32-true-d453877e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e123-true-d453955e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1932"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e123-true-d453955e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d453829e123-true-d453955e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e215-true-d454009e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1931"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e215-true-d454009e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d453829e215-true-d454009e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e275-true-d454048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1930"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e275-true-d454048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d453829e275-true-d454048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e288-true-d454095e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1929"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e288-true-d454095e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d453829e288-true-d454095e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454088e17-true-d454106e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1928"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454088e17-true-d454106e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454088e17-true-d454106e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454088e28-true-d454129e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1927"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454088e28-true-d454129e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454088e28-true-d454129e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e318-true-d454158e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1926"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e318-true-d454158e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453829e318-true-d454158e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e329-true-d454181e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1925"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e329-true-d454181e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453829e329-true-d454181e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e351-true-d454217e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1924"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e351-true-d454217e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d453829e351-true-d454217e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453829e369-true-d454289e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1923"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453829e369-true-d454289e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d453829e369-true-d454289e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e216-true-d454358e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1922"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e216-true-d454358e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d453543e216-true-d454358e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e227-true-d454407e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1921"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e227-true-d454407e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d453543e227-true-d454407e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d453543e238-true-d454442e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1920"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d453543e238-true-d454442e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d453543e238-true-d454442e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3857-true-d454461e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1919"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3857-true-d454461e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3857-true-d454461e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3862-true-d454489e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1918"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3862-true-d454489e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3862-true-d454489e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e35-true-d454516e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1917"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e35-true-d454516e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d454466e35-true-d454516e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e69-true-d454569e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1916"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e69-true-d454569e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454466e69-true-d454569e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e83-true-d454596e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1915"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e83-true-d454596e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d454466e83-true-d454596e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e160-true-d454673e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1914"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e160-true-d454673e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454466e160-true-d454673e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e182-true-d454702e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1913"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e182-true-d454702e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454466e182-true-d454702e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e193-true-d454729e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1912"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e193-true-d454729e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d454466e193-true-d454729e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e204-true-d454797e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1911"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e204-true-d454797e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d454466e204-true-d454797e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e32-true-d454817e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1910"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e32-true-d454817e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d454769e32-true-d454817e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e123-true-d454895e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1909"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e123-true-d454895e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d454769e123-true-d454895e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e215-true-d454949e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1908"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e215-true-d454949e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d454769e215-true-d454949e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e275-true-d454988e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1907"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e275-true-d454988e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d454769e275-true-d454988e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e288-true-d455035e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1906"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e288-true-d455035e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d454769e288-true-d455035e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455028e17-true-d455046e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1905"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455028e17-true-d455046e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455028e17-true-d455046e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455028e28-true-d455069e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1904"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455028e28-true-d455069e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455028e28-true-d455069e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e318-true-d455098e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1903"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e318-true-d455098e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454769e318-true-d455098e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e329-true-d455121e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1902"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e329-true-d455121e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454769e329-true-d455121e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e351-true-d455157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1901"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e351-true-d455157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d454769e351-true-d455157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454769e369-true-d455229e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1900"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454769e369-true-d455229e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d454769e369-true-d455229e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e215-true-d455298e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1899"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e215-true-d455298e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d454466e215-true-d455298e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e226-true-d455347e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1898"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e226-true-d455347e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d454466e226-true-d455347e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d454466e237-true-d455382e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1897"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d454466e237-true-d455382e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d454466e237-true-d455382e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3865-true-d455401e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1896"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3865-true-d455401e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3865-true-d455401e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3870-true-d455429e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1895"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3870-true-d455429e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3870-true-d455429e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e35-true-d455456e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1894"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e35-true-d455456e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d455406e35-true-d455456e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e66-true-d455509e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1893"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e66-true-d455509e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455406e66-true-d455509e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e80-true-d455536e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1892"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e80-true-d455536e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d455406e80-true-d455536e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e157-true-d455613e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1891"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e157-true-d455613e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455406e157-true-d455613e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e179-true-d455642e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1890"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e179-true-d455642e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455406e179-true-d455642e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e190-true-d455669e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1889"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e190-true-d455669e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d455406e190-true-d455669e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e201-true-d455737e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1888"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e201-true-d455737e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d455406e201-true-d455737e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e32-true-d455757e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1887"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e32-true-d455757e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d455709e32-true-d455757e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e123-true-d455835e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1886"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e123-true-d455835e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d455709e123-true-d455835e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e215-true-d455889e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1885"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e215-true-d455889e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d455709e215-true-d455889e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e275-true-d455928e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1884"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e275-true-d455928e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d455709e275-true-d455928e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e288-true-d455975e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1883"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e288-true-d455975e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d455709e288-true-d455975e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455968e17-true-d455986e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1882"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455968e17-true-d455986e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455968e17-true-d455986e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455968e28-true-d456009e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1881"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455968e28-true-d456009e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455968e28-true-d456009e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e318-true-d456038e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1880"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e318-true-d456038e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455709e318-true-d456038e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e329-true-d456061e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1879"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e329-true-d456061e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455709e329-true-d456061e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e351-true-d456097e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1878"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e351-true-d456097e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d455709e351-true-d456097e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455709e369-true-d456169e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1877"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455709e369-true-d456169e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d455709e369-true-d456169e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e212-true-d456238e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1876"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e212-true-d456238e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d455406e212-true-d456238e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e223-true-d456287e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1875"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e223-true-d456287e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d455406e223-true-d456287e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d455406e234-true-d456322e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1874"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d455406e234-true-d456322e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d455406e234-true-d456322e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3873-true-d456341e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1873"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3873-true-d456341e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3873-true-d456341e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3878-true-d456369e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1872"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3878-true-d456369e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3878-true-d456369e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e32-true-d456396e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1871"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e32-true-d456396e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d456346e32-true-d456396e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e74-true-d456459e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1870"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e74-true-d456459e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d456346e74-true-d456459e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e151-true-d456536e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1869"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e151-true-d456536e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456346e151-true-d456536e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e173-true-d456565e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1868"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e173-true-d456565e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456346e173-true-d456565e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e184-true-d456592e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1867"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e184-true-d456592e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d456346e184-true-d456592e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e195-true-d456660e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1866"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e195-true-d456660e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d456346e195-true-d456660e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e32-true-d456680e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1865"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e32-true-d456680e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d456632e32-true-d456680e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e123-true-d456758e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1864"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e123-true-d456758e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d456632e123-true-d456758e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e215-true-d456812e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1863"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e215-true-d456812e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d456632e215-true-d456812e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e275-true-d456851e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1862"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e275-true-d456851e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d456632e275-true-d456851e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e288-true-d456898e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1861"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e288-true-d456898e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d456632e288-true-d456898e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456891e17-true-d456909e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1860"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456891e17-true-d456909e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456891e17-true-d456909e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456891e28-true-d456932e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1859"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456891e28-true-d456932e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456891e28-true-d456932e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e318-true-d456961e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1858"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e318-true-d456961e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456632e318-true-d456961e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e329-true-d456984e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1857"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e329-true-d456984e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456632e329-true-d456984e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e351-true-d457020e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1856"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e351-true-d457020e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d456632e351-true-d457020e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456632e369-true-d457092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1855"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456632e369-true-d457092e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d456632e369-true-d457092e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e206-true-d457161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1854"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e206-true-d457161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d456346e206-true-d457161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e217-true-d457210e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1853"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e217-true-d457210e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d456346e217-true-d457210e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d456346e228-true-d457245e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1852"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d456346e228-true-d457245e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d456346e228-true-d457245e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3881-true-d457264e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1851"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3881-true-d457264e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3881-true-d457264e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3886-true-d457292e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1850"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3886-true-d457292e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3886-true-d457292e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e32-true-d457319e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1849"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e32-true-d457319e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d457269e32-true-d457319e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e71-true-d457382e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1848"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e71-true-d457382e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d457269e71-true-d457382e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e148-true-d457459e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1847"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e148-true-d457459e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457269e148-true-d457459e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e170-true-d457488e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1846"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e170-true-d457488e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457269e170-true-d457488e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e181-true-d457515e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1845"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e181-true-d457515e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d457269e181-true-d457515e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e192-true-d457583e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1844"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e192-true-d457583e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d457269e192-true-d457583e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e32-true-d457603e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1843"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e32-true-d457603e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d457555e32-true-d457603e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e123-true-d457681e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1842"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e123-true-d457681e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d457555e123-true-d457681e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e215-true-d457735e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1841"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e215-true-d457735e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d457555e215-true-d457735e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e275-true-d457774e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1840"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e275-true-d457774e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d457555e275-true-d457774e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e288-true-d457821e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1839"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e288-true-d457821e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d457555e288-true-d457821e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457814e17-true-d457832e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1838"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457814e17-true-d457832e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457814e17-true-d457832e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457814e28-true-d457855e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1837"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457814e28-true-d457855e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457814e28-true-d457855e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e318-true-d457884e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1836"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e318-true-d457884e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457555e318-true-d457884e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e329-true-d457907e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1835"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e329-true-d457907e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457555e329-true-d457907e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e351-true-d457943e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1834"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e351-true-d457943e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d457555e351-true-d457943e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457555e369-true-d458015e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1833"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457555e369-true-d458015e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d457555e369-true-d458015e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e203-true-d458084e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1832"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e203-true-d458084e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d457269e203-true-d458084e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e214-true-d458133e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1831"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e214-true-d458133e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d457269e214-true-d458133e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d457269e225-true-d458168e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1830"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d457269e225-true-d458168e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d457269e225-true-d458168e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3889-true-d458188e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX | self::hl7v2:NTE)]"
                 priority="1829"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3889-true-d458188e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX | hl7v2:NTE (rule-reference: d20e3889-true-d458188e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3894-true-d458216e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1828"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3894-true-d458216e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3894-true-d458216e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e35-true-d458243e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1827"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e35-true-d458243e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d458193e35-true-d458243e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e74-true-d458306e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1826"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e74-true-d458306e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d458193e74-true-d458306e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e151-true-d458383e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1825"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e151-true-d458383e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458193e151-true-d458383e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e173-true-d458412e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1824"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e173-true-d458412e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458193e173-true-d458412e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e184-true-d458439e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1823"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e184-true-d458439e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d458193e184-true-d458439e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e195-true-d458507e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1822"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e195-true-d458507e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d458193e195-true-d458507e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e32-true-d458527e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1821"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e32-true-d458527e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d458479e32-true-d458527e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e123-true-d458605e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1820"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e123-true-d458605e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d458479e123-true-d458605e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e215-true-d458659e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1819"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e215-true-d458659e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d458479e215-true-d458659e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e275-true-d458698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1818"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e275-true-d458698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d458479e275-true-d458698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e288-true-d458745e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1817"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e288-true-d458745e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d458479e288-true-d458745e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458738e17-true-d458756e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1816"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458738e17-true-d458756e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458738e17-true-d458756e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458738e28-true-d458779e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1815"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458738e28-true-d458779e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458738e28-true-d458779e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e318-true-d458808e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1814"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e318-true-d458808e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458479e318-true-d458808e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e329-true-d458831e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1813"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e329-true-d458831e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458479e329-true-d458831e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e351-true-d458867e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1812"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e351-true-d458867e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d458479e351-true-d458867e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458479e369-true-d458939e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1811"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458479e369-true-d458939e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d458479e369-true-d458939e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e206-true-d459008e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1810"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e206-true-d459008e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d458193e206-true-d459008e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e217-true-d459057e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1809"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e217-true-d459057e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d458193e217-true-d459057e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d458193e228-true-d459092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1808"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d458193e228-true-d459092e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d458193e228-true-d459092e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3896-true-d459117e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1807"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3896-true-d459117e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3896-true-d459117e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459109e28-true-d459139e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1806"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459109e28-true-d459139e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d459109e28-true-d459139e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459133e18-true-d459149e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1805"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459133e18-true-d459149e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d459133e18-true-d459149e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459143e5-true-d459159e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1804"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459143e5-true-d459159e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d459143e5-true-d459159e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459109e42-true-d459178e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1803"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459109e42-true-d459178e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d459109e42-true-d459178e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3900-true-d459221e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1802"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3900-true-d459221e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3900-true-d459221e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3905-true-d459249e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1801"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3905-true-d459249e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3905-true-d459249e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e35-true-d459276e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1800"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e35-true-d459276e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d459226e35-true-d459276e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e77-true-d459339e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1799"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e77-true-d459339e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d459226e77-true-d459339e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e154-true-d459416e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1798"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e154-true-d459416e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459226e154-true-d459416e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e176-true-d459445e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1797"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e176-true-d459445e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459226e176-true-d459445e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e187-true-d459472e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1796"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e187-true-d459472e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d459226e187-true-d459472e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e198-true-d459540e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1795"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e198-true-d459540e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d459226e198-true-d459540e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e32-true-d459560e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1794"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e32-true-d459560e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d459512e32-true-d459560e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e123-true-d459638e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1793"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e123-true-d459638e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d459512e123-true-d459638e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e215-true-d459692e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1792"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e215-true-d459692e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d459512e215-true-d459692e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e275-true-d459731e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1791"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e275-true-d459731e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d459512e275-true-d459731e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e288-true-d459778e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1790"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e288-true-d459778e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d459512e288-true-d459778e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459771e17-true-d459789e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1789"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459771e17-true-d459789e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459771e17-true-d459789e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459771e28-true-d459812e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1788"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459771e28-true-d459812e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459771e28-true-d459812e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e318-true-d459841e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1787"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e318-true-d459841e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459512e318-true-d459841e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e329-true-d459864e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1786"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e329-true-d459864e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459512e329-true-d459864e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e351-true-d459900e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1785"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e351-true-d459900e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d459512e351-true-d459900e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459512e369-true-d459972e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1784"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459512e369-true-d459972e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d459512e369-true-d459972e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e209-true-d460041e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1783"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e209-true-d460041e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d459226e209-true-d460041e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e220-true-d460090e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1782"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e220-true-d460090e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d459226e220-true-d460090e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d459226e231-true-d460125e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1781"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d459226e231-true-d460125e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d459226e231-true-d460125e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3908-true-d460144e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX)]"
                 priority="1780"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3908-true-d460144e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX (rule-reference: d20e3908-true-d460144e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3913-true-d460172e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1779"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3913-true-d460172e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3913-true-d460172e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e32-true-d460199e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1778"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e32-true-d460199e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d460149e32-true-d460199e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e71-true-d460262e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1777"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e71-true-d460262e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d460149e71-true-d460262e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e148-true-d460339e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1776"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e148-true-d460339e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460149e148-true-d460339e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e170-true-d460368e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1775"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e170-true-d460368e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460149e170-true-d460368e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e181-true-d460395e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1774"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e181-true-d460395e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d460149e181-true-d460395e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e192-true-d460463e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1773"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e192-true-d460463e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d460149e192-true-d460463e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e32-true-d460483e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1772"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e32-true-d460483e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d460435e32-true-d460483e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e123-true-d460561e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1771"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e123-true-d460561e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d460435e123-true-d460561e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e215-true-d460615e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1770"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e215-true-d460615e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d460435e215-true-d460615e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e275-true-d460654e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1769"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e275-true-d460654e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d460435e275-true-d460654e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e288-true-d460701e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1768"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e288-true-d460701e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d460435e288-true-d460701e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460694e17-true-d460712e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1767"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460694e17-true-d460712e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460694e17-true-d460712e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460694e28-true-d460735e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1766"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460694e28-true-d460735e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460694e28-true-d460735e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e318-true-d460764e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1765"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e318-true-d460764e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460435e318-true-d460764e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e329-true-d460787e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1764"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e329-true-d460787e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460435e329-true-d460787e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e351-true-d460823e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1763"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e351-true-d460823e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d460435e351-true-d460823e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460435e369-true-d460895e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1762"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460435e369-true-d460895e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d460435e369-true-d460895e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e203-true-d460964e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1761"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e203-true-d460964e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d460149e203-true-d460964e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e214-true-d461013e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1760"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e214-true-d461013e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d460149e214-true-d461013e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d460149e225-true-d461048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1759"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d460149e225-true-d461048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d460149e225-true-d461048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3916-true-d461069e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX | self::hl7v2:TCD | self::hl7v2:NTE)]"
                 priority="1758"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3916-true-d461069e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX | hl7v2:TCD | hl7v2:NTE (rule-reference: d20e3916-true-d461069e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3921-true-d461097e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1757"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3921-true-d461097e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3921-true-d461097e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e32-true-d461124e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1756"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e32-true-d461124e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461074e32-true-d461124e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e71-true-d461187e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1755"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e71-true-d461187e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461074e71-true-d461187e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e148-true-d461264e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1754"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e148-true-d461264e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461074e148-true-d461264e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e170-true-d461293e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1753"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e170-true-d461293e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461074e170-true-d461293e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e181-true-d461320e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1752"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e181-true-d461320e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461074e181-true-d461320e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e192-true-d461388e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1751"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e192-true-d461388e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d461074e192-true-d461388e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e32-true-d461408e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1750"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e32-true-d461408e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d461360e32-true-d461408e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e123-true-d461486e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1749"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e123-true-d461486e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d461360e123-true-d461486e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e215-true-d461540e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1748"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e215-true-d461540e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d461360e215-true-d461540e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e275-true-d461579e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1747"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e275-true-d461579e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461360e275-true-d461579e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e288-true-d461626e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1746"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e288-true-d461626e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d461360e288-true-d461626e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461619e17-true-d461637e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1745"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461619e17-true-d461637e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461619e17-true-d461637e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461619e28-true-d461660e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1744"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461619e28-true-d461660e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461619e28-true-d461660e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e318-true-d461689e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1743"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e318-true-d461689e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461360e318-true-d461689e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e329-true-d461712e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1742"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e329-true-d461712e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461360e329-true-d461712e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e351-true-d461748e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1741"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e351-true-d461748e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d461360e351-true-d461748e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461360e369-true-d461820e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1740"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461360e369-true-d461820e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d461360e369-true-d461820e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e203-true-d461889e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1739"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e203-true-d461889e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461074e203-true-d461889e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e214-true-d461938e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1738"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e214-true-d461938e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d461074e214-true-d461938e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461074e225-true-d461973e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1737"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461074e225-true-d461973e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d461074e225-true-d461973e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3923-true-d462002e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/*[not(@xsi:nil = 'true')][not(self::hl7v2:TCD.1 | self::hl7v2:TCD.2 | self::hl7v2:TCD.3 | self::hl7v2:TCD.4 | self::hl7v2:TCD.5 | self::hl7v2:TCD.6 | self::hl7v2:TCD.7 | self::hl7v2:TCD.8)]"
                 priority="1736"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3923-true-d462002e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TCD.1 | hl7v2:TCD.2 | hl7v2:TCD.3 | hl7v2:TCD.4 | hl7v2:TCD.5 | hl7v2:TCD.6 | hl7v2:TCD.7 | hl7v2:TCD.8 (rule-reference: d20e3923-true-d462002e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461990e1-true-d462017e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1735"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461990e1-true-d462017e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461990e1-true-d462017e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461990e12-true-d462066e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1734"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461990e12-true-d462066e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d461990e12-true-d462066e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461990e23-true-d462103e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1733"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461990e23-true-d462103e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d461990e23-true-d462103e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461990e34-true-d462140e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1732"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461990e34-true-d462140e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d461990e34-true-d462140e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461990e45-true-d462177e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1731"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461990e45-true-d462177e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d461990e45-true-d462177e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d461990e82-true-d462228e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:TCD/hl7v2:TCD.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1730"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d461990e82-true-d462228e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d461990e82-true-d462228e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3925-true-d462277e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1729"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3925-true-d462277e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3925-true-d462277e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462269e110-true-d462299e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1728"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462269e110-true-d462299e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d462269e110-true-d462299e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462293e36-true-d462309e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1727"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462293e36-true-d462309e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d462293e36-true-d462309e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462303e5-true-d462319e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1726"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462303e5-true-d462319e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d462303e5-true-d462319e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462269e142-true-d462338e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.OBSERVATION/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1725"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462269e142-true-d462338e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d462269e142-true-d462338e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3928-true-d462383e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/*[not(@xsi:nil = 'true')][not(self::hl7v2:SPM | self::hl7v2:OBX | self::hl7v2:OML_O21.CONTAINER)]"
                 priority="1724"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3928-true-d462383e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPM | hl7v2:OBX | hl7v2:OML_O21.CONTAINER (rule-reference: d20e3928-true-d462383e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3930-true-d462421e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/*[not(@xsi:nil = 'true')][not(self::hl7v2:SPM.1 | self::hl7v2:SPM.2 | self::hl7v2:SPM.3 | self::hl7v2:SPM.4 | self::hl7v2:SPM.5 | self::hl7v2:SPM.6 | self::hl7v2:SPM.7 | self::hl7v2:SPM.8 | self::hl7v2:SPM.9 | self::hl7v2:SPM.10 | self::hl7v2:SPM.11 | self::hl7v2:SPM.12 | self::hl7v2:SPM.13 | self::hl7v2:SPM.14 | self::hl7v2:SPM.15 | self::hl7v2:SPM.16 | self::hl7v2:SPM.17 | self::hl7v2:SPM.18 | self::hl7v2:SPM.19 | self::hl7v2:SPM.20 | self::hl7v2:SPM.21 | self::hl7v2:SPM.22 | self::hl7v2:SPM.23 | self::hl7v2:SPM.24 | self::hl7v2:SPM.25 | self::hl7v2:SPM.26 | self::hl7v2:SPM.27 | self::hl7v2:SPM.28 | self::hl7v2:SPM.29)]"
                 priority="1723"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3930-true-d462421e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPM.1 | hl7v2:SPM.2 | hl7v2:SPM.3 | hl7v2:SPM.4 | hl7v2:SPM.5 | hl7v2:SPM.6 | hl7v2:SPM.7 | hl7v2:SPM.8 | hl7v2:SPM.9 | hl7v2:SPM.10 | hl7v2:SPM.11 | hl7v2:SPM.12 | hl7v2:SPM.13 | hl7v2:SPM.14 | hl7v2:SPM.15 | hl7v2:SPM.16 | hl7v2:SPM.17 | hl7v2:SPM.18 | hl7v2:SPM.19 | hl7v2:SPM.20 | hl7v2:SPM.21 | hl7v2:SPM.22 | hl7v2:SPM.23 | hl7v2:SPM.24 | hl7v2:SPM.25 | hl7v2:SPM.26 | hl7v2:SPM.27 | hl7v2:SPM.28 | hl7v2:SPM.29 (rule-reference: d20e3930-true-d462421e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e15-true-d462438e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1722"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e15-true-d462438e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d462388e15-true-d462438e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462431e18-true-d462451e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1721"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462431e18-true-d462451e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d462431e18-true-d462451e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462431e47-true-d462488e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.2/hl7v2:EIP.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1720"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462431e47-true-d462488e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d462431e47-true-d462488e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e29-true-d462523e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1719"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e29-true-d462523e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d462388e29-true-d462523e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462516e39-true-d462536e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1718"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462516e39-true-d462536e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d462516e39-true-d462536e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462516e68-true-d462573e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.3/hl7v2:EIP.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1717"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462516e68-true-d462573e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d462516e68-true-d462573e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e65-true-d462615e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1716"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e65-true-d462615e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e65-true-d462615e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e91-true-d462687e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1715"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e91-true-d462687e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e91-true-d462687e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e114-true-d462759e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1714"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e114-true-d462759e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e114-true-d462759e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e127-true-d462831e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1713"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e127-true-d462831e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e127-true-d462831e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e153-true-d462903e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1712"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e153-true-d462903e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e153-true-d462903e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e177-true-d462975e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1711"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e177-true-d462975e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e177-true-d462975e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e190-true-d463047e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1710"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e190-true-d463047e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e190-true-d463047e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e213-true-d463119e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1709"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e213-true-d463119e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e213-true-d463119e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e227-true-d463184e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1708"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e227-true-d463184e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d462388e227-true-d463184e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d463177e35-true-d463205e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.12/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1707"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d463177e35-true-d463205e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d463177e35-true-d463205e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e270-true-d463271e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1706"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e270-true-d463271e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e270-true-d463271e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e283-true-d463343e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1705"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e283-true-d463343e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e283-true-d463343e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e296-true-d463408e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1704"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e296-true-d463408e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d462388e296-true-d463408e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d463401e21-true-d463419e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1703"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d463401e21-true-d463419e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d463401e21-true-d463419e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d463401e32-true-d463442e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1702"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d463401e32-true-d463442e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d463401e32-true-d463442e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e314-true-d463465e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1701"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e314-true-d463465e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d462388e314-true-d463465e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e328-true-d463488e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1700"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e328-true-d463488e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d462388e328-true-d463488e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e352-true-d463524e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1699"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e352-true-d463524e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e352-true-d463524e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e365-true-d463596e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1698"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e365-true-d463596e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e365-true-d463596e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e379-true-d463668e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1697"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e379-true-d463668e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e379-true-d463668e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e392-true-d463740e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.24/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1696"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e392-true-d463740e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e392-true-d463740e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e405-true-d463805e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1695"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e405-true-d463805e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d462388e405-true-d463805e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d463798e26-true-d463826e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.25/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1694"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d463798e26-true-d463826e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d463798e26-true-d463826e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e427-true-d463886e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1693"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e427-true-d463886e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e427-true-d463886e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e438-true-d463958e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1692"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e438-true-d463958e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e438-true-d463958e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d462388e451-true-d464030e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:SPM/hl7v2:SPM.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1691"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d462388e451-true-d464030e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d462388e451-true-d464030e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3934-true-d464112e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1690"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3934-true-d464112e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3934-true-d464112e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e35-true-d464139e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1689"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e35-true-d464139e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d464089e35-true-d464139e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e74-true-d464202e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1688"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e74-true-d464202e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d464089e74-true-d464202e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e151-true-d464279e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1687"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e151-true-d464279e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464089e151-true-d464279e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e173-true-d464308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1686"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e173-true-d464308e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464089e173-true-d464308e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e184-true-d464335e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1685"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e184-true-d464335e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d464089e184-true-d464335e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e195-true-d464403e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1684"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e195-true-d464403e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d464089e195-true-d464403e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e32-true-d464423e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1683"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e32-true-d464423e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d464375e32-true-d464423e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e123-true-d464501e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1682"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e123-true-d464501e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d464375e123-true-d464501e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e215-true-d464555e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1681"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e215-true-d464555e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d464375e215-true-d464555e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e275-true-d464594e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1680"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e275-true-d464594e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d464375e275-true-d464594e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e288-true-d464641e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1679"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e288-true-d464641e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d464375e288-true-d464641e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464634e17-true-d464652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1678"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464634e17-true-d464652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464634e17-true-d464652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464634e28-true-d464675e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1677"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464634e28-true-d464675e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464634e28-true-d464675e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e318-true-d464704e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1676"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e318-true-d464704e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464375e318-true-d464704e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e329-true-d464727e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1675"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e329-true-d464727e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464375e329-true-d464727e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e351-true-d464763e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1674"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e351-true-d464763e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d464375e351-true-d464763e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464375e369-true-d464835e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1673"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464375e369-true-d464835e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d464375e369-true-d464835e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e206-true-d464904e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1672"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e206-true-d464904e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d464089e206-true-d464904e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e217-true-d464953e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1671"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e217-true-d464953e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d464089e217-true-d464953e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d464089e228-true-d464988e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1670"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d464089e228-true-d464988e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d464089e228-true-d464988e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3936-true-d465008e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAC | self::hl7v2:OBX)]"
                 priority="1669"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3936-true-d465008e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAC | hl7v2:OBX (rule-reference: d20e3936-true-d465008e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3938-true-d465061e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAC.1 | self::hl7v2:SAC.2 | self::hl7v2:SAC.3 | self::hl7v2:SAC.4 | self::hl7v2:SAC.5 | self::hl7v2:SAC.6 | self::hl7v2:SAC.7 | self::hl7v2:SAC.8 | self::hl7v2:SAC.9 | self::hl7v2:SAC.10 | self::hl7v2:SAC.11 | self::hl7v2:SAC.12 | self::hl7v2:SAC.13 | self::hl7v2:SAC.14 | self::hl7v2:SAC.15 | self::hl7v2:SAC.16 | self::hl7v2:SAC.17 | self::hl7v2:SAC.18 | self::hl7v2:SAC.19 | self::hl7v2:SAC.20 | self::hl7v2:SAC.21 | self::hl7v2:SAC.22 | self::hl7v2:SAC.23 | self::hl7v2:SAC.24 | self::hl7v2:SAC.25 | self::hl7v2:SAC.26 | self::hl7v2:SAC.27 | self::hl7v2:SAC.28 | self::hl7v2:SAC.29 | self::hl7v2:SAC.30 | self::hl7v2:SAC.31 | self::hl7v2:SAC.32 | self::hl7v2:SAC.33 | self::hl7v2:SAC.34 | self::hl7v2:SAC.35 | self::hl7v2:SAC.36 | self::hl7v2:SAC.37 | self::hl7v2:SAC.38 | self::hl7v2:SAC.39 | self::hl7v2:SAC.40 | self::hl7v2:SAC.41 | self::hl7v2:SAC.42 | self::hl7v2:SAC.43 | self::hl7v2:SAC.44)]"
                 priority="1668"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3938-true-d465061e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAC.1 | hl7v2:SAC.2 | hl7v2:SAC.3 | hl7v2:SAC.4 | hl7v2:SAC.5 | hl7v2:SAC.6 | hl7v2:SAC.7 | hl7v2:SAC.8 | hl7v2:SAC.9 | hl7v2:SAC.10 | hl7v2:SAC.11 | hl7v2:SAC.12 | hl7v2:SAC.13 | hl7v2:SAC.14 | hl7v2:SAC.15 | hl7v2:SAC.16 | hl7v2:SAC.17 | hl7v2:SAC.18 | hl7v2:SAC.19 | hl7v2:SAC.20 | hl7v2:SAC.21 | hl7v2:SAC.22 | hl7v2:SAC.23 | hl7v2:SAC.24 | hl7v2:SAC.25 | hl7v2:SAC.26 | hl7v2:SAC.27 | hl7v2:SAC.28 | hl7v2:SAC.29 | hl7v2:SAC.30 | hl7v2:SAC.31 | hl7v2:SAC.32 | hl7v2:SAC.33 | hl7v2:SAC.34 | hl7v2:SAC.35 | hl7v2:SAC.36 | hl7v2:SAC.37 | hl7v2:SAC.38 | hl7v2:SAC.39 | hl7v2:SAC.40 | hl7v2:SAC.41 | hl7v2:SAC.42 | hl7v2:SAC.43 | hl7v2:SAC.44 (rule-reference: d20e3938-true-d465061e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e1-true-d465074e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1667"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e1-true-d465074e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e1-true-d465074e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e12-true-d465111e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1666"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e12-true-d465111e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e12-true-d465111e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e23-true-d465148e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1665"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e23-true-d465148e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e23-true-d465148e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e34-true-d465185e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1664"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e34-true-d465185e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e34-true-d465185e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e45-true-d465222e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1663"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e45-true-d465222e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e45-true-d465222e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e56-true-d465262e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="1662"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e56-true-d465262e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d465013e56-true-d465262e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e15-true-d465280e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1661"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e15-true-d465280e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465250e15-true-d465280e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e44-true-d465352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1660"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e44-true-d465352e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465250e44-true-d465352e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e57-true-d465416e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1659"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e57-true-d465416e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d465250e57-true-d465416e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465410e11-true-d465426e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1658"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465410e11-true-d465426e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d465410e11-true-d465426e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465420e5-true-d465436e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1657"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465420e5-true-d465436e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d465420e5-true-d465436e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e68-true-d465458e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1656"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e68-true-d465458e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465250e68-true-d465458e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e93-true-d465530e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1655"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e93-true-d465530e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465250e93-true-d465530e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e106-true-d465602e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1654"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e106-true-d465602e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465250e106-true-d465602e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465250e117-true-d465674e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.6/hl7v2:SPS.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1653"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465250e117-true-d465674e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465250e117-true-d465674e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e67-true-d465739e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1652"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e67-true-d465739e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d465013e67-true-d465739e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e78-true-d465766e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1651"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e78-true-d465766e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e78-true-d465766e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e91-true-d465817e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1650"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e91-true-d465817e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e91-true-d465817e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e104-true-d465866e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1649"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e104-true-d465866e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e104-true-d465866e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e115-true-d465903e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:NA.1 | self::hl7v2:NA.2 | self::hl7v2:NA.3 | self::hl7v2:NA.4)]"
                 priority="1648"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e115-true-d465903e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NA.1 | hl7v2:NA.2 | hl7v2:NA.3 | hl7v2:NA.4 (rule-reference: d465013e115-true-d465903e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e127-true-d465942e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1647"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e127-true-d465942e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e127-true-d465942e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e140-true-d465991e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1646"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e140-true-d465991e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d465013e140-true-d465991e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e151-true-d466028e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:NA.1 | self::hl7v2:NA.2 | self::hl7v2:NA.3 | self::hl7v2:NA.4)]"
                 priority="1645"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e151-true-d466028e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NA.1 | hl7v2:NA.2 | hl7v2:NA.3 | hl7v2:NA.4 (rule-reference: d465013e151-true-d466028e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e162-true-d466067e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1644"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e162-true-d466067e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e162-true-d466067e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e217-true-d466142e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1643"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e217-true-d466142e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e217-true-d466142e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e262-true-d466211e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.24/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1642"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e262-true-d466211e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e262-true-d466211e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e273-true-d466262e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1641"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e273-true-d466262e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e273-true-d466262e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e286-true-d466313e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1640"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e286-true-d466313e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e286-true-d466313e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e299-true-d466367e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1639"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e299-true-d466367e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465013e299-true-d466367e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e312-true-d466436e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1638"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e312-true-d466436e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e312-true-d466436e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e323-true-d466485e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1637"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e323-true-d466485e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d465013e323-true-d466485e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e334-true-d466524e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1636"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e334-true-d466524e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e334-true-d466524e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e347-true-d466573e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.31/*[not(@xsi:nil = 'true')][not(self::hl7v2:SN.1 | self::hl7v2:SN.2 | self::hl7v2:SN.3 | self::hl7v2:SN.4)]"
                 priority="1635"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e347-true-d466573e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SN.1 | hl7v2:SN.2 | hl7v2:SN.3 | hl7v2:SN.4 (rule-reference: d465013e347-true-d466573e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e369-true-d466618e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1634"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e369-true-d466618e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e369-true-d466618e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e392-true-d466675e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1633"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e392-true-d466675e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e392-true-d466675e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e414-true-d466732e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.37/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1632"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e414-true-d466732e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e414-true-d466732e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e436-true-d466789e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1631"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e436-true-d466789e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e436-true-d466789e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e447-true-d466840e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1630"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e447-true-d466840e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e447-true-d466840e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e460-true-d466891e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.41/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1629"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e460-true-d466891e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e460-true-d466891e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e473-true-d466942e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1628"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e473-true-d466942e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e473-true-d466942e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e486-true-d466996e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1627"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e486-true-d466996e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d465013e486-true-d466996e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d465013e499-true-d467065e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:SAC/hl7v2:SAC.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1626"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d465013e499-true-d467065e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d465013e499-true-d467065e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3940-true-d467129e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1625"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3940-true-d467129e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3940-true-d467129e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e74-true-d467156e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1624"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e74-true-d467156e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d467106e74-true-d467156e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e164-true-d467219e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1623"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e164-true-d467219e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d467106e164-true-d467219e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e287-true-d467296e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1622"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e287-true-d467296e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467106e287-true-d467296e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e309-true-d467325e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1621"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e309-true-d467325e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467106e309-true-d467325e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e327-true-d467352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1620"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e327-true-d467352e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d467106e327-true-d467352e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e338-true-d467420e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1619"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e338-true-d467420e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d467106e338-true-d467420e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e32-true-d467440e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1618"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e32-true-d467440e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d467392e32-true-d467440e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e123-true-d467518e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1617"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e123-true-d467518e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d467392e123-true-d467518e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e215-true-d467572e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1616"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e215-true-d467572e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d467392e215-true-d467572e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e275-true-d467611e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1615"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e275-true-d467611e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d467392e275-true-d467611e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e288-true-d467658e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1614"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e288-true-d467658e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d467392e288-true-d467658e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467651e17-true-d467669e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1613"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467651e17-true-d467669e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467651e17-true-d467669e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467651e28-true-d467692e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1612"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467651e28-true-d467692e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467651e28-true-d467692e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e318-true-d467721e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1611"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e318-true-d467721e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467392e318-true-d467721e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e329-true-d467744e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1610"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e329-true-d467744e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467392e329-true-d467744e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e351-true-d467780e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1609"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e351-true-d467780e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d467392e351-true-d467780e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467392e369-true-d467852e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1608"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467392e369-true-d467852e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d467392e369-true-d467852e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e349-true-d467921e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1607"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e349-true-d467921e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d467106e349-true-d467921e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e360-true-d467970e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1606"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e360-true-d467970e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d467106e360-true-d467970e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d467106e371-true-d468005e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.SPECIMEN/hl7v2:OML_O21.CONTAINER/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1605"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d467106e371-true-d468005e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d467106e371-true-d468005e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3944-true-d468027e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/*[not(@xsi:nil = 'true')][not(self::hl7v2:OML_O21.PATIENT_PRIOR | self::hl7v2:OML_O21.PATIENT_VISIT_PRIOR | self::hl7v2:AL1 | self::hl7v2:OML_O21.ORDER_PRIOR)]"
                 priority="1604"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3944-true-d468027e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OML_O21.PATIENT_PRIOR | hl7v2:OML_O21.PATIENT_VISIT_PRIOR | hl7v2:AL1 | hl7v2:OML_O21.ORDER_PRIOR (rule-reference: d20e3944-true-d468027e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3954-true-d468036e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/*[not(@xsi:nil = 'true')][not(self::hl7v2:PID | self::hl7v2:PD1)]"
                 priority="1603"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3954-true-d468036e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID | hl7v2:PD1 (rule-reference: d20e3954-true-d468036e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3956-true-d468084e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/*[not(@xsi:nil = 'true')][not(self::hl7v2:PID.1 | self::hl7v2:PID.2 | self::hl7v2:PID.3 | self::hl7v2:PID.4 | self::hl7v2:PID.5 | self::hl7v2:PID.6 | self::hl7v2:PID.7 | self::hl7v2:PID.8 | self::hl7v2:PID.9 | self::hl7v2:PID.10 | self::hl7v2:PID.11 | self::hl7v2:PID.12 | self::hl7v2:PID.13 | self::hl7v2:PID.14 | self::hl7v2:PID.15 | self::hl7v2:PID.16 | self::hl7v2:PID.17 | self::hl7v2:PID.18 | self::hl7v2:PID.19 | self::hl7v2:PID.20 | self::hl7v2:PID.21 | self::hl7v2:PID.22 | self::hl7v2:PID.23 | self::hl7v2:PID.24 | self::hl7v2:PID.25 | self::hl7v2:PID.26 | self::hl7v2:PID.27 | self::hl7v2:PID.28 | self::hl7v2:PID.29 | self::hl7v2:PID.30 | self::hl7v2:PID.31 | self::hl7v2:PID.32 | self::hl7v2:PID.33 | self::hl7v2:PID.34 | self::hl7v2:PID.35 | self::hl7v2:PID.36 | self::hl7v2:PID.37 | self::hl7v2:PID.38 | self::hl7v2:PID.39)]"
                 priority="1602"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3956-true-d468084e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PID.1 | hl7v2:PID.2 | hl7v2:PID.3 | hl7v2:PID.4 | hl7v2:PID.5 | hl7v2:PID.6 | hl7v2:PID.7 | hl7v2:PID.8 | hl7v2:PID.9 | hl7v2:PID.10 | hl7v2:PID.11 | hl7v2:PID.12 | hl7v2:PID.13 | hl7v2:PID.14 | hl7v2:PID.15 | hl7v2:PID.16 | hl7v2:PID.17 | hl7v2:PID.18 | hl7v2:PID.19 | hl7v2:PID.20 | hl7v2:PID.21 | hl7v2:PID.22 | hl7v2:PID.23 | hl7v2:PID.24 | hl7v2:PID.25 | hl7v2:PID.26 | hl7v2:PID.27 | hl7v2:PID.28 | hl7v2:PID.29 | hl7v2:PID.30 | hl7v2:PID.31 | hl7v2:PID.32 | hl7v2:PID.33 | hl7v2:PID.34 | hl7v2:PID.35 | hl7v2:PID.36 | hl7v2:PID.37 | hl7v2:PID.38 | hl7v2:PID.39 (rule-reference: d20e3956-true-d468084e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e15-true-d468109e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1601"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e15-true-d468109e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d468041e15-true-d468109e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468094e221-true-d468139e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1600"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468094e221-true-d468139e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468094e221-true-d468139e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468094e263-true-d468175e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1599"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468094e263-true-d468175e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468094e263-true-d468175e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468094e305-true-d468223e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1598"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468094e305-true-d468223e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468094e305-true-d468223e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468094e334-true-d468295e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.2/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1597"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468094e334-true-d468295e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468094e334-true-d468295e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e26-true-d468368e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1596"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e26-true-d468368e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d468041e26-true-d468368e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468353e248-true-d468398e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1595"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468353e248-true-d468398e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468353e248-true-d468398e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468353e290-true-d468434e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1594"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468353e290-true-d468434e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468353e290-true-d468434e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468353e332-true-d468482e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1593"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468353e332-true-d468482e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468353e332-true-d468482e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468353e361-true-d468554e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.3/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1592"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468353e361-true-d468554e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468353e361-true-d468554e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e64-true-d468627e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1591"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e64-true-d468627e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d468041e64-true-d468627e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468612e221-true-d468657e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1590"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468612e221-true-d468657e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468612e221-true-d468657e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468612e263-true-d468693e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1589"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468612e263-true-d468693e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468612e263-true-d468693e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468612e305-true-d468741e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1588"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468612e305-true-d468741e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468612e305-true-d468741e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468612e334-true-d468813e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.4/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1587"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468612e334-true-d468813e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468612e334-true-d468813e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e75-true-d468890e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1586"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e75-true-d468890e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d468041e75-true-d468890e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468871e26-true-d468904e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1585"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468871e26-true-d468904e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d468871e26-true-d468904e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468871e154-true-d468991e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1584"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468871e154-true-d468991e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468871e154-true-d468991e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468871e167-true-d469038e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1583"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468871e167-true-d469038e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d468871e167-true-d469038e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469031e17-true-d469049e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1582"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469031e17-true-d469049e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469031e17-true-d469049e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469031e28-true-d469072e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1581"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469031e28-true-d469072e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469031e28-true-d469072e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468871e197-true-d469101e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1580"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468871e197-true-d469101e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d468871e197-true-d469101e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468871e208-true-d469124e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.5/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1579"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468871e208-true-d469124e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d468871e208-true-d469124e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e98-true-d469165e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1578"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e98-true-d469165e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d468041e98-true-d469165e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469146e15-true-d469179e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1577"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469146e15-true-d469179e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d469146e15-true-d469179e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469146e142-true-d469266e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1576"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469146e142-true-d469266e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d469146e142-true-d469266e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469146e155-true-d469313e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1575"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469146e155-true-d469313e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d469146e155-true-d469313e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469306e17-true-d469324e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1574"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469306e17-true-d469324e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469306e17-true-d469324e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469306e28-true-d469347e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1573"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469306e28-true-d469347e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469306e28-true-d469347e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469146e186-true-d469376e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1572"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469146e186-true-d469376e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469146e186-true-d469376e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469146e197-true-d469399e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.6/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1571"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469146e197-true-d469399e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469146e197-true-d469399e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e109-true-d469428e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1570"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e109-true-d469428e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d468041e109-true-d469428e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e163-true-d469469e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:XPN.1 | self::hl7v2:XPN.2 | self::hl7v2:XPN.3 | self::hl7v2:XPN.4 | self::hl7v2:XPN.5 | self::hl7v2:XPN.6 | self::hl7v2:XPN.7 | self::hl7v2:XPN.8 | self::hl7v2:XPN.9 | self::hl7v2:XPN.10 | self::hl7v2:XPN.11 | self::hl7v2:XPN.12 | self::hl7v2:XPN.13 | self::hl7v2:XPN.14)]"
                 priority="1569"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e163-true-d469469e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XPN.1 | hl7v2:XPN.2 | hl7v2:XPN.3 | hl7v2:XPN.4 | hl7v2:XPN.5 | hl7v2:XPN.6 | hl7v2:XPN.7 | hl7v2:XPN.8 | hl7v2:XPN.9 | hl7v2:XPN.10 | hl7v2:XPN.11 | hl7v2:XPN.12 | hl7v2:XPN.13 | hl7v2:XPN.14 (rule-reference: d468041e163-true-d469469e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469450e15-true-d469483e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1568"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469450e15-true-d469483e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d469450e15-true-d469483e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469450e142-true-d469570e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1567"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469450e142-true-d469570e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d469450e142-true-d469570e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469450e155-true-d469617e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1566"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469450e155-true-d469617e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d469450e155-true-d469617e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469610e17-true-d469628e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1565"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469610e17-true-d469628e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469610e17-true-d469628e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469610e28-true-d469651e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.10/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1564"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469610e28-true-d469651e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469610e28-true-d469651e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469450e186-true-d469680e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1563"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469450e186-true-d469680e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469450e186-true-d469680e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469450e197-true-d469703e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.9/hl7v2:XPN.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1562"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469450e197-true-d469703e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469450e197-true-d469703e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e174-true-d469736e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1561"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e174-true-d469736e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e174-true-d469736e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e187-true-d469795e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1560"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e187-true-d469795e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d468041e187-true-d469795e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469776e32-true-d469807e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1559"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469776e32-true-d469807e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d469776e32-true-d469807e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469776e231-true-d469896e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1558"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469776e231-true-d469896e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d469776e231-true-d469896e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469889e23-true-d469907e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1557"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469889e23-true-d469907e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469889e23-true-d469907e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469889e34-true-d469930e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1556"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469889e34-true-d469930e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469889e34-true-d469930e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469776e252-true-d469953e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1555"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469776e252-true-d469953e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469776e252-true-d469953e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d469776e266-true-d469976e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.11/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1554"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d469776e266-true-d469976e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d469776e266-true-d469976e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e230-true-d470015e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1553"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e230-true-d470015e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d468041e230-true-d470015e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e244-true-d470108e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1552"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e244-true-d470108e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d468041e244-true-d470108e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e258-true-d470195e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1551"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e258-true-d470195e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e258-true-d470195e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e271-true-d470246e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1550"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e271-true-d470246e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e271-true-d470246e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e288-true-d470297e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1549"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e288-true-d470297e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e288-true-d470297e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e301-true-d470352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1548"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e301-true-d470352e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d468041e301-true-d470352e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470337e221-true-d470382e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1547"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470337e221-true-d470382e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d470337e221-true-d470382e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470337e263-true-d470418e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1546"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470337e263-true-d470418e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d470337e263-true-d470418e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470337e305-true-d470466e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1545"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470337e305-true-d470466e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d470337e305-true-d470466e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470337e334-true-d470538e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.18/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1544"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470337e334-true-d470538e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d470337e334-true-d470538e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e323-true-d470610e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:DLN.1 | self::hl7v2:DLN.2 | self::hl7v2:DLN.3)]"
                 priority="1543"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e323-true-d470610e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLN.1 | hl7v2:DLN.2 | hl7v2:DLN.3 (rule-reference: d468041e323-true-d470610e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e334-true-d470647e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1542"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e334-true-d470647e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d468041e334-true-d470647e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470632e221-true-d470677e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1541"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470632e221-true-d470677e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d470632e221-true-d470677e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470632e263-true-d470713e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1540"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470632e263-true-d470713e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d470632e263-true-d470713e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470632e305-true-d470761e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1539"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470632e305-true-d470761e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d470632e305-true-d470761e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d470632e334-true-d470833e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.21/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1538"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d470632e334-true-d470833e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d470632e334-true-d470833e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e345-true-d470902e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1537"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e345-true-d470902e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e345-true-d470902e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e404-true-d470971e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1536"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e404-true-d470971e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e404-true-d470971e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e417-true-d471022e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1535"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e417-true-d471022e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e417-true-d471022e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e430-true-d471073e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1534"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e430-true-d471073e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e430-true-d471073e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e443-true-d471120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1533"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e443-true-d471120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d468041e443-true-d471120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e493-true-d471161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1532"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e493-true-d471161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d468041e493-true-d471161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e505-true-d471185e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.34/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1531"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e505-true-d471185e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d468041e505-true-d471185e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e516-true-d471218e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1530"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e516-true-d471218e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e516-true-d471218e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e529-true-d471269e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.36/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1529"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e529-true-d471269e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e529-true-d471269e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e553-true-d471326e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1528"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e553-true-d471326e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d468041e553-true-d471326e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d468041e566-true-d471380e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PID/hl7v2:PID.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1527"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d468041e566-true-d471380e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d468041e566-true-d471380e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3958-true-d471464e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/*[not(@xsi:nil = 'true')][not(self::hl7v2:PD1.1 | self::hl7v2:PD1.2 | self::hl7v2:PD1.3 | self::hl7v2:PD1.4 | self::hl7v2:PD1.5 | self::hl7v2:PD1.6 | self::hl7v2:PD1.7 | self::hl7v2:PD1.8 | self::hl7v2:PD1.9 | self::hl7v2:PD1.10 | self::hl7v2:PD1.11 | self::hl7v2:PD1.12 | self::hl7v2:PD1.13 | self::hl7v2:PD1.14 | self::hl7v2:PD1.15 | self::hl7v2:PD1.16 | self::hl7v2:PD1.17 | self::hl7v2:PD1.18 | self::hl7v2:PD1.19 | self::hl7v2:PD1.20 | self::hl7v2:PD1.21)]"
                 priority="1526"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3958-true-d471464e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PD1.1 | hl7v2:PD1.2 | hl7v2:PD1.3 | hl7v2:PD1.4 | hl7v2:PD1.5 | hl7v2:PD1.6 | hl7v2:PD1.7 | hl7v2:PD1.8 | hl7v2:PD1.9 | hl7v2:PD1.10 | hl7v2:PD1.11 | hl7v2:PD1.12 | hl7v2:PD1.13 | hl7v2:PD1.14 | hl7v2:PD1.15 | hl7v2:PD1.16 | hl7v2:PD1.17 | hl7v2:PD1.18 | hl7v2:PD1.19 | hl7v2:PD1.20 | hl7v2:PD1.21 (rule-reference: d20e3958-true-d471464e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471439e27-true-d471495e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1525"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471439e27-true-d471495e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d471439e27-true-d471495e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471480e80-true-d471537e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1524"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471480e80-true-d471537e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d471480e80-true-d471537e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471480e119-true-d471573e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.3/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1523"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471480e119-true-d471573e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d471480e119-true-d471573e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471439e38-true-d471635e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1522"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471439e38-true-d471635e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d471439e38-true-d471635e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e32-true-d471655e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1521"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e32-true-d471655e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d471607e32-true-d471655e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e123-true-d471733e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1520"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e123-true-d471733e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d471607e123-true-d471733e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e215-true-d471787e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1519"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e215-true-d471787e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d471607e215-true-d471787e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e275-true-d471826e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1518"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e275-true-d471826e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d471607e275-true-d471826e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e288-true-d471873e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1517"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e288-true-d471873e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d471607e288-true-d471873e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471866e17-true-d471884e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1516"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471866e17-true-d471884e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d471866e17-true-d471884e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471866e28-true-d471907e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1515"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471866e28-true-d471907e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d471866e28-true-d471907e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e318-true-d471936e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1514"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e318-true-d471936e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d471607e318-true-d471936e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e329-true-d471959e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1513"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e329-true-d471959e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d471607e329-true-d471959e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e351-true-d471995e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1512"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e351-true-d471995e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d471607e351-true-d471995e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471607e369-true-d472067e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.4/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1511"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471607e369-true-d472067e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d471607e369-true-d472067e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471439e114-true-d472170e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1510"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471439e114-true-d472170e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d471439e114-true-d472170e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472155e221-true-d472200e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1509"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472155e221-true-d472200e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472155e221-true-d472200e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472155e263-true-d472236e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1508"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472155e263-true-d472236e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472155e263-true-d472236e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472155e305-true-d472284e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1507"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472155e305-true-d472284e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d472155e305-true-d472284e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472155e334-true-d472356e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.10/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1506"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472155e334-true-d472356e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d472155e334-true-d472356e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471439e125-true-d472425e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1505"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471439e125-true-d472425e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d471439e125-true-d472425e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471439e163-true-d472492e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1504"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471439e163-true-d472492e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d471439e163-true-d472492e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472477e80-true-d472534e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1503"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472477e80-true-d472534e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472477e80-true-d472534e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472477e119-true-d472570e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.14/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1502"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472477e119-true-d472570e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472477e119-true-d472570e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d471439e174-true-d472615e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_PRIOR/hl7v2:PD1/hl7v2:PD1.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1501"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d471439e174-true-d472615e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d471439e174-true-d472615e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3961-true-d472695e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/*[not(@xsi:nil = 'true')][not(self::hl7v2:PV1 | self::hl7v2:PV2)]"
                 priority="1500"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3961-true-d472695e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV1 | hl7v2:PV2 (rule-reference: d20e3961-true-d472695e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3963-true-d472756e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/*[not(@xsi:nil = 'true')][not(self::hl7v2:PV1.1 | self::hl7v2:PV1.2 | self::hl7v2:PV1.3 | self::hl7v2:PV1.4 | self::hl7v2:PV1.5 | self::hl7v2:PV1.6 | self::hl7v2:PV1.7 | self::hl7v2:PV1.8 | self::hl7v2:PV1.9 | self::hl7v2:PV1.10 | self::hl7v2:PV1.11 | self::hl7v2:PV1.12 | self::hl7v2:PV1.13 | self::hl7v2:PV1.14 | self::hl7v2:PV1.15 | self::hl7v2:PV1.16 | self::hl7v2:PV1.17 | self::hl7v2:PV1.18 | self::hl7v2:PV1.19 | self::hl7v2:PV1.20 | self::hl7v2:PV1.21 | self::hl7v2:PV1.22 | self::hl7v2:PV1.23 | self::hl7v2:PV1.24 | self::hl7v2:PV1.25 | self::hl7v2:PV1.26 | self::hl7v2:PV1.27 | self::hl7v2:PV1.28 | self::hl7v2:PV1.29 | self::hl7v2:PV1.30 | self::hl7v2:PV1.31 | self::hl7v2:PV1.32 | self::hl7v2:PV1.33 | self::hl7v2:PV1.34 | self::hl7v2:PV1.35 | self::hl7v2:PV1.36 | self::hl7v2:PV1.37 | self::hl7v2:PV1.38 | self::hl7v2:PV1.39 | self::hl7v2:PV1.40 | self::hl7v2:PV1.41 | self::hl7v2:PV1.42 | self::hl7v2:PV1.43 | self::hl7v2:PV1.44 | self::hl7v2:PV1.45 | self::hl7v2:PV1.46 | self::hl7v2:PV1.47 | self::hl7v2:PV1.48 | self::hl7v2:PV1.49 | self::hl7v2:PV1.50 | self::hl7v2:PV1.51 | self::hl7v2:PV1.52)]"
                 priority="1499"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3963-true-d472756e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV1.1 | hl7v2:PV1.2 | hl7v2:PV1.3 | hl7v2:PV1.4 | hl7v2:PV1.5 | hl7v2:PV1.6 | hl7v2:PV1.7 | hl7v2:PV1.8 | hl7v2:PV1.9 | hl7v2:PV1.10 | hl7v2:PV1.11 | hl7v2:PV1.12 | hl7v2:PV1.13 | hl7v2:PV1.14 | hl7v2:PV1.15 | hl7v2:PV1.16 | hl7v2:PV1.17 | hl7v2:PV1.18 | hl7v2:PV1.19 | hl7v2:PV1.20 | hl7v2:PV1.21 | hl7v2:PV1.22 | hl7v2:PV1.23 | hl7v2:PV1.24 | hl7v2:PV1.25 | hl7v2:PV1.26 | hl7v2:PV1.27 | hl7v2:PV1.28 | hl7v2:PV1.29 | hl7v2:PV1.30 | hl7v2:PV1.31 | hl7v2:PV1.32 | hl7v2:PV1.33 | hl7v2:PV1.34 | hl7v2:PV1.35 | hl7v2:PV1.36 | hl7v2:PV1.37 | hl7v2:PV1.38 | hl7v2:PV1.39 | hl7v2:PV1.40 | hl7v2:PV1.41 | hl7v2:PV1.42 | hl7v2:PV1.43 | hl7v2:PV1.44 | hl7v2:PV1.45 | hl7v2:PV1.46 | hl7v2:PV1.47 | hl7v2:PV1.48 | hl7v2:PV1.49 | hl7v2:PV1.50 | hl7v2:PV1.51 | hl7v2:PV1.52 (rule-reference: d20e3963-true-d472756e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e25-true-d472788e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1498"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e25-true-d472788e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d472700e25-true-d472788e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472772e48-true-d472818e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1497"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472772e48-true-d472818e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472772e48-true-d472818e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472772e125-true-d472879e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1496"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472772e125-true-d472879e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d472772e125-true-d472879e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472772e134-true-d472915e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.3/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1495"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472772e134-true-d472915e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472772e134-true-d472915e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e49-true-d472958e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1494"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e49-true-d472958e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d472700e49-true-d472958e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472943e221-true-d472988e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1493"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472943e221-true-d472988e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472943e221-true-d472988e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472943e263-true-d473024e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1492"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472943e263-true-d473024e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d472943e263-true-d473024e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472943e305-true-d473072e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1491"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472943e305-true-d473072e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d472943e305-true-d473072e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472943e334-true-d473144e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.5/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1490"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472943e334-true-d473144e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d472943e334-true-d473144e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e60-true-d473218e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1489"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e60-true-d473218e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d472700e60-true-d473218e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473202e48-true-d473248e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1488"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473202e48-true-d473248e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d473202e48-true-d473248e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473202e125-true-d473309e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1487"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473202e125-true-d473309e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d473202e125-true-d473309e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473202e134-true-d473345e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.6/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1486"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473202e134-true-d473345e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d473202e134-true-d473345e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e71-true-d473395e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1485"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e71-true-d473395e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d472700e71-true-d473395e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e35-true-d473415e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1484"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e35-true-d473415e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d473367e35-true-d473415e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e127-true-d473493e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1483"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e127-true-d473493e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d473367e127-true-d473493e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e218-true-d473547e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1482"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e218-true-d473547e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d473367e218-true-d473547e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e278-true-d473586e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1481"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e278-true-d473586e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d473367e278-true-d473586e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e291-true-d473633e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1480"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e291-true-d473633e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d473367e291-true-d473633e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473626e17-true-d473644e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1479"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473626e17-true-d473644e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d473626e17-true-d473644e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473626e28-true-d473667e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1478"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473626e28-true-d473667e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d473626e28-true-d473667e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e322-true-d473696e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1477"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e322-true-d473696e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d473367e322-true-d473696e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e333-true-d473719e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1476"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e333-true-d473719e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d473367e333-true-d473719e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e355-true-d473755e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1475"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e355-true-d473755e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d473367e355-true-d473755e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473367e372-true-d473827e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.7/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1474"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473367e372-true-d473827e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d473367e372-true-d473827e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e84-true-d473913e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1473"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e84-true-d473913e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d472700e84-true-d473913e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e35-true-d473933e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1472"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e35-true-d473933e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d473885e35-true-d473933e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e127-true-d474011e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1471"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e127-true-d474011e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d473885e127-true-d474011e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e218-true-d474065e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1470"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e218-true-d474065e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d473885e218-true-d474065e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e278-true-d474104e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1469"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e278-true-d474104e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d473885e278-true-d474104e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e291-true-d474151e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1468"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e291-true-d474151e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d473885e291-true-d474151e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474144e17-true-d474162e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1467"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474144e17-true-d474162e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d474144e17-true-d474162e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474144e28-true-d474185e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1466"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474144e28-true-d474185e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d474144e28-true-d474185e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e322-true-d474214e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1465"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e322-true-d474214e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d473885e322-true-d474214e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e333-true-d474237e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1464"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e333-true-d474237e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d473885e333-true-d474237e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e355-true-d474273e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1463"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e355-true-d474273e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d473885e355-true-d474273e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d473885e372-true-d474345e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.8/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1462"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d473885e372-true-d474345e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d473885e372-true-d474345e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e97-true-d474431e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1461"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e97-true-d474431e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d472700e97-true-d474431e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e35-true-d474451e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1460"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e35-true-d474451e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d474403e35-true-d474451e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e127-true-d474529e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1459"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e127-true-d474529e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d474403e127-true-d474529e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e218-true-d474583e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1458"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e218-true-d474583e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d474403e218-true-d474583e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e278-true-d474622e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1457"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e278-true-d474622e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d474403e278-true-d474622e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e291-true-d474669e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1456"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e291-true-d474669e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d474403e291-true-d474669e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474662e17-true-d474680e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1455"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474662e17-true-d474680e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d474662e17-true-d474680e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474662e28-true-d474703e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1454"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474662e28-true-d474703e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d474662e28-true-d474703e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e322-true-d474732e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1453"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e322-true-d474732e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d474403e322-true-d474732e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e333-true-d474755e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1452"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e333-true-d474755e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d474403e333-true-d474755e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e355-true-d474791e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1451"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e355-true-d474791e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d474403e355-true-d474791e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474403e372-true-d474863e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.9/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1450"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474403e372-true-d474863e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d474403e372-true-d474863e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e123-true-d474943e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1449"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e123-true-d474943e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d472700e123-true-d474943e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474927e48-true-d474973e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1448"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474927e48-true-d474973e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d474927e48-true-d474973e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474927e125-true-d475034e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1447"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474927e125-true-d475034e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d474927e125-true-d475034e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d474927e134-true-d475070e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.11/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1446"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d474927e134-true-d475070e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d474927e134-true-d475070e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e200-true-d475150e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1445"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e200-true-d475150e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d472700e200-true-d475150e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e35-true-d475170e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1444"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e35-true-d475170e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d475122e35-true-d475170e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e127-true-d475248e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1443"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e127-true-d475248e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d475122e127-true-d475248e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e218-true-d475302e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1442"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e218-true-d475302e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d475122e218-true-d475302e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e278-true-d475341e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1441"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e278-true-d475341e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d475122e278-true-d475341e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e291-true-d475388e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1440"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e291-true-d475388e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d475122e291-true-d475388e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475381e17-true-d475399e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1439"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475381e17-true-d475399e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d475381e17-true-d475399e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475381e28-true-d475422e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1438"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475381e28-true-d475422e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d475381e28-true-d475422e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e322-true-d475451e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1437"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e322-true-d475451e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d475122e322-true-d475451e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e333-true-d475474e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1436"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e333-true-d475474e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d475122e333-true-d475474e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e355-true-d475510e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1435"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e355-true-d475510e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d475122e355-true-d475510e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475122e372-true-d475582e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.17/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1434"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475122e372-true-d475582e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d475122e372-true-d475582e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e226-true-d475661e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1433"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e226-true-d475661e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d472700e226-true-d475661e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475646e221-true-d475691e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1432"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475646e221-true-d475691e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d475646e221-true-d475691e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475646e263-true-d475727e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1431"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475646e263-true-d475727e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d475646e263-true-d475727e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475646e305-true-d475775e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1430"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475646e305-true-d475775e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d475646e305-true-d475775e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475646e334-true-d475847e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.19/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1429"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475646e334-true-d475847e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d475646e334-true-d475847e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e237-true-d475912e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:FC.1 | self::hl7v2:FC.2)]"
                 priority="1428"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e237-true-d475912e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FC.1 | hl7v2:FC.2 (rule-reference: d472700e237-true-d475912e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d475905e31-true-d475929e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.20/hl7v2:FC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1427"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d475905e31-true-d475929e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d475905e31-true-d475929e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e446-true-d476048e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/*[not(@xsi:nil = 'true')][not(self::hl7v2:DLD.1 | self::hl7v2:DLD.2)]"
                 priority="1426"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e446-true-d476048e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DLD.1 | hl7v2:DLD.2 (rule-reference: d472700e446-true-d476048e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476041e31-true-d476065e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.37/hl7v2:DLD.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1425"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476041e31-true-d476065e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d476041e31-true-d476065e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e459-true-d476092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1424"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e459-true-d476092e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d472700e459-true-d476092e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e511-true-d476166e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1423"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e511-true-d476166e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d472700e511-true-d476166e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476150e48-true-d476196e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1422"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476150e48-true-d476196e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476150e48-true-d476196e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476150e125-true-d476257e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1421"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476150e125-true-d476257e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d476150e125-true-d476257e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476150e134-true-d476293e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.42/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1420"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476150e134-true-d476293e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476150e134-true-d476293e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e522-true-d476331e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1419"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e522-true-d476331e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d472700e522-true-d476331e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476315e48-true-d476361e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1418"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476315e48-true-d476361e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476315e48-true-d476361e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476315e125-true-d476422e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1417"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476315e125-true-d476422e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d476315e125-true-d476422e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476315e134-true-d476458e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.43/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1416"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476315e134-true-d476458e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476315e134-true-d476458e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e533-true-d476487e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1415"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e533-true-d476487e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d472700e533-true-d476487e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e545-true-d476510e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1414"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e545-true-d476510e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d472700e545-true-d476510e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e600-true-d476565e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1413"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e600-true-d476565e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d472700e600-true-d476565e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476550e224-true-d476595e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1412"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476550e224-true-d476595e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476550e224-true-d476595e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476550e266-true-d476631e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1411"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476550e266-true-d476631e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476550e266-true-d476631e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476550e309-true-d476679e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1410"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476550e309-true-d476679e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d476550e309-true-d476679e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476550e338-true-d476751e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.50/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1409"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476550e338-true-d476751e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d476550e338-true-d476751e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d472700e626-true-d476843e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1408"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d472700e626-true-d476843e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d472700e626-true-d476843e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e35-true-d476863e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1407"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e35-true-d476863e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d476815e35-true-d476863e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e127-true-d476941e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1406"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e127-true-d476941e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476815e127-true-d476941e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e218-true-d476995e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1405"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e218-true-d476995e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d476815e218-true-d476995e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e278-true-d477034e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1404"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e278-true-d477034e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d476815e278-true-d477034e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e291-true-d477081e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1403"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e291-true-d477081e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d476815e291-true-d477081e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477074e17-true-d477092e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1402"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477074e17-true-d477092e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477074e17-true-d477092e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477074e28-true-d477115e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1401"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477074e28-true-d477115e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477074e28-true-d477115e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e322-true-d477144e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1400"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e322-true-d477144e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d476815e322-true-d477144e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e333-true-d477167e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1399"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e333-true-d477167e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d476815e333-true-d477167e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e355-true-d477203e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1398"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e355-true-d477203e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d476815e355-true-d477203e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d476815e372-true-d477275e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV1/hl7v2:PV1.52/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1397"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d476815e372-true-d477275e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d476815e372-true-d477275e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3965-true-d477387e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/*[not(@xsi:nil = 'true')][not(self::hl7v2:PV2.1 | self::hl7v2:PV2.2 | self::hl7v2:PV2.3 | self::hl7v2:PV2.4 | self::hl7v2:PV2.5 | self::hl7v2:PV2.6 | self::hl7v2:PV2.7 | self::hl7v2:PV2.8 | self::hl7v2:PV2.9 | self::hl7v2:PV2.10 | self::hl7v2:PV2.11 | self::hl7v2:PV2.12 | self::hl7v2:PV2.13 | self::hl7v2:PV2.14 | self::hl7v2:PV2.15 | self::hl7v2:PV2.16 | self::hl7v2:PV2.17 | self::hl7v2:PV2.18 | self::hl7v2:PV2.19 | self::hl7v2:PV2.20 | self::hl7v2:PV2.21 | self::hl7v2:PV2.22 | self::hl7v2:PV2.23 | self::hl7v2:PV2.24 | self::hl7v2:PV2.25 | self::hl7v2:PV2.26 | self::hl7v2:PV2.27 | self::hl7v2:PV2.28 | self::hl7v2:PV2.29 | self::hl7v2:PV2.30 | self::hl7v2:PV2.31 | self::hl7v2:PV2.32 | self::hl7v2:PV2.33 | self::hl7v2:PV2.34 | self::hl7v2:PV2.35 | self::hl7v2:PV2.36 | self::hl7v2:PV2.37 | self::hl7v2:PV2.38 | self::hl7v2:PV2.39 | self::hl7v2:PV2.40 | self::hl7v2:PV2.41 | self::hl7v2:PV2.42 | self::hl7v2:PV2.43 | self::hl7v2:PV2.44 | self::hl7v2:PV2.45 | self::hl7v2:PV2.46 | self::hl7v2:PV2.47 | self::hl7v2:PV2.48 | self::hl7v2:PV2.49)]"
                 priority="1396"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3965-true-d477387e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PV2.1 | hl7v2:PV2.2 | hl7v2:PV2.3 | hl7v2:PV2.4 | hl7v2:PV2.5 | hl7v2:PV2.6 | hl7v2:PV2.7 | hl7v2:PV2.8 | hl7v2:PV2.9 | hl7v2:PV2.10 | hl7v2:PV2.11 | hl7v2:PV2.12 | hl7v2:PV2.13 | hl7v2:PV2.14 | hl7v2:PV2.15 | hl7v2:PV2.16 | hl7v2:PV2.17 | hl7v2:PV2.18 | hl7v2:PV2.19 | hl7v2:PV2.20 | hl7v2:PV2.21 | hl7v2:PV2.22 | hl7v2:PV2.23 | hl7v2:PV2.24 | hl7v2:PV2.25 | hl7v2:PV2.26 | hl7v2:PV2.27 | hl7v2:PV2.28 | hl7v2:PV2.29 | hl7v2:PV2.30 | hl7v2:PV2.31 | hl7v2:PV2.32 | hl7v2:PV2.33 | hl7v2:PV2.34 | hl7v2:PV2.35 | hl7v2:PV2.36 | hl7v2:PV2.37 | hl7v2:PV2.38 | hl7v2:PV2.39 | hl7v2:PV2.40 | hl7v2:PV2.41 | hl7v2:PV2.42 | hl7v2:PV2.43 | hl7v2:PV2.44 | hl7v2:PV2.45 | hl7v2:PV2.46 | hl7v2:PV2.47 | hl7v2:PV2.48 | hl7v2:PV2.49 (rule-reference: d20e3965-true-d477387e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e1-true-d477407e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1395"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e1-true-d477407e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d477334e1-true-d477407e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477391e48-true-d477437e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1394"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477391e48-true-d477437e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d477391e48-true-d477437e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477391e125-true-d477498e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1393"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477391e125-true-d477498e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d477391e125-true-d477498e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477391e134-true-d477534e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.1/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1392"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477391e134-true-d477534e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d477391e134-true-d477534e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e12-true-d477567e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1391"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e12-true-d477567e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e12-true-d477567e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e25-true-d477618e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1390"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e25-true-d477618e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e25-true-d477618e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e36-true-d477669e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1389"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e36-true-d477669e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e36-true-d477669e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e82-true-d477734e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1388"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e82-true-d477734e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477334e82-true-d477734e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e93-true-d477757e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1387"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e93-true-d477757e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477334e93-true-d477757e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e138-true-d477819e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1386"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e138-true-d477819e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d477334e138-true-d477819e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e32-true-d477839e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1385"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e32-true-d477839e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d477791e32-true-d477839e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e123-true-d477917e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1384"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e123-true-d477917e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d477791e123-true-d477917e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e215-true-d477971e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1383"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e215-true-d477971e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d477791e215-true-d477971e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e275-true-d478010e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1382"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e275-true-d478010e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477791e275-true-d478010e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e288-true-d478057e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1381"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e288-true-d478057e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d477791e288-true-d478057e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d478050e17-true-d478068e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1380"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d478050e17-true-d478068e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d478050e17-true-d478068e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d478050e28-true-d478091e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1379"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d478050e28-true-d478091e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d478050e28-true-d478091e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e318-true-d478120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1378"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e318-true-d478120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477791e318-true-d478120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e329-true-d478143e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1377"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e329-true-d478143e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477791e329-true-d478143e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e351-true-d478179e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1376"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e351-true-d478179e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d477791e351-true-d478179e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477791e369-true-d478251e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.13/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1375"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477791e369-true-d478251e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d477791e369-true-d478251e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e261-true-d478378e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1374"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e261-true-d478378e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d477334e261-true-d478378e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d478363e80-true-d478420e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1373"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d478363e80-true-d478420e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d478363e80-true-d478420e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d478363e119-true-d478456e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.23/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1372"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d478363e119-true-d478456e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d478363e119-true-d478456e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e344-true-d478537e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1371"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e344-true-d478537e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e344-true-d478537e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e383-true-d478596e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1370"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e383-true-d478596e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477334e383-true-d478596e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e447-true-d478647e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1369"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e447-true-d478647e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e447-true-d478647e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e460-true-d478698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1368"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e460-true-d478698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e460-true-d478698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e473-true-d478749e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1367"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e473-true-d478749e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e473-true-d478749e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e486-true-d478800e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.41/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1366"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e486-true-d478800e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e486-true-d478800e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e499-true-d478851e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.42/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1365"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e499-true-d478851e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e499-true-d478851e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e539-true-d478914e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1364"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e539-true-d478914e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d477334e539-true-d478914e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e563-true-d478967e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.47/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1363"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e563-true-d478967e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477334e563-true-d478967e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d477334e574-true-d478990e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.PATIENT_VISIT_PRIOR/hl7v2:PV2/hl7v2:PV2.48/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1362"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d477334e574-true-d478990e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d477334e574-true-d478990e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3968-true-d479023e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/*[not(@xsi:nil = 'true')][not(self::hl7v2:AL1.1 | self::hl7v2:AL1.2 | self::hl7v2:AL1.3 | self::hl7v2:AL1.4 | self::hl7v2:AL1.5 | self::hl7v2:AL1.6)]"
                 priority="1361"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3968-true-d479023e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:AL1.1 | hl7v2:AL1.2 | hl7v2:AL1.3 | hl7v2:AL1.4 | hl7v2:AL1.5 | hl7v2:AL1.6 (rule-reference: d20e3968-true-d479023e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479013e12-true-d479044e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1360"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479013e12-true-d479044e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479013e12-true-d479044e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479013e25-true-d479095e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1359"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479013e25-true-d479095e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479013e25-true-d479095e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479013e36-true-d479146e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:AL1/hl7v2:AL1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1358"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479013e36-true-d479146e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479013e36-true-d479146e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3971-true-d479205e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/*[not(@xsi:nil = 'true')][not(self::hl7v2:ORC | self::hl7v2:OBR | self::hl7v2:NTE | self::hl7v2:OML_O21.TIMING_PRIOR | self::hl7v2:OML_O21.OBSERVATION_PRIOR)]"
                 priority="1357"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3971-true-d479205e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC | hl7v2:OBR | hl7v2:NTE | hl7v2:OML_O21.TIMING_PRIOR | hl7v2:OML_O21.OBSERVATION_PRIOR (rule-reference: d20e3971-true-d479205e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3973-true-d479244e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/*[not(@xsi:nil = 'true')][not(self::hl7v2:ORC.1 | self::hl7v2:ORC.2 | self::hl7v2:ORC.3 | self::hl7v2:ORC.4 | self::hl7v2:ORC.5 | self::hl7v2:ORC.6 | self::hl7v2:ORC.7 | self::hl7v2:ORC.8 | self::hl7v2:ORC.9 | self::hl7v2:ORC.10 | self::hl7v2:ORC.11 | self::hl7v2:ORC.12 | self::hl7v2:ORC.13 | self::hl7v2:ORC.14 | self::hl7v2:ORC.15 | self::hl7v2:ORC.16 | self::hl7v2:ORC.17 | self::hl7v2:ORC.18 | self::hl7v2:ORC.19 | self::hl7v2:ORC.20 | self::hl7v2:ORC.21 | self::hl7v2:ORC.22 | self::hl7v2:ORC.23 | self::hl7v2:ORC.24 | self::hl7v2:ORC.25 | self::hl7v2:ORC.26 | self::hl7v2:ORC.27 | self::hl7v2:ORC.28 | self::hl7v2:ORC.29 | self::hl7v2:ORC.30)]"
                 priority="1356"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3973-true-d479244e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:ORC.1 | hl7v2:ORC.2 | hl7v2:ORC.3 | hl7v2:ORC.4 | hl7v2:ORC.5 | hl7v2:ORC.6 | hl7v2:ORC.7 | hl7v2:ORC.8 | hl7v2:ORC.9 | hl7v2:ORC.10 | hl7v2:ORC.11 | hl7v2:ORC.12 | hl7v2:ORC.13 | hl7v2:ORC.14 | hl7v2:ORC.15 | hl7v2:ORC.16 | hl7v2:ORC.17 | hl7v2:ORC.18 | hl7v2:ORC.19 | hl7v2:ORC.20 | hl7v2:ORC.21 | hl7v2:ORC.22 | hl7v2:ORC.23 | hl7v2:ORC.24 | hl7v2:ORC.25 | hl7v2:ORC.26 | hl7v2:ORC.27 | hl7v2:ORC.28 | hl7v2:ORC.29 | hl7v2:ORC.30 (rule-reference: d20e3973-true-d479244e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e102-true-d479263e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1355"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e102-true-d479263e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d479210e102-true-d479263e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e119-true-d479300e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1354"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e119-true-d479300e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d479210e119-true-d479300e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e143-true-d479337e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1353"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e143-true-d479337e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d479210e143-true-d479337e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e186-true-d479394e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1352"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e186-true-d479394e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d479210e186-true-d479394e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e15-true-d479405e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1351"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e15-true-d479405e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d479377e15-true-d479405e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479398e31-true-d479426e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.1/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1350"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479398e31-true-d479426e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479398e31-true-d479426e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e35-true-d479473e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1349"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e35-true-d479473e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d479377e35-true-d479473e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e189-true-d479502e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1348"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e189-true-d479502e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479377e189-true-d479502e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e206-true-d479525e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1347"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e206-true-d479525e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479377e206-true-d479525e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e461-true-d479559e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1346"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e461-true-d479559e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d479377e461-true-d479559e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479553e11-true-d479569e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1345"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479553e11-true-d479569e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d479553e11-true-d479569e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479563e5-true-d479579e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1344"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479563e5-true-d479579e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d479563e5-true-d479579e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e485-true-d479609e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1343"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e485-true-d479609e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d479377e485-true-d479609e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479377e505-true-d479690e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.7/hl7v2:TQ.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1342"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479377e505-true-d479690e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479377e505-true-d479690e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e197-true-d479743e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1341"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e197-true-d479743e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d479210e197-true-d479743e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479736e18-true-d479756e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1340"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479736e18-true-d479756e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d479736e18-true-d479756e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479736e47-true-d479793e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.8/hl7v2:EIP.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1339"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479736e47-true-d479793e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d479736e47-true-d479793e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e211-true-d479828e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1338"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e211-true-d479828e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479210e211-true-d479828e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e222-true-d479872e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1337"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e222-true-d479872e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d479210e222-true-d479872e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e32-true-d479892e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1336"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e32-true-d479892e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d479844e32-true-d479892e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e123-true-d479970e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1335"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e123-true-d479970e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d479844e123-true-d479970e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e215-true-d480024e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1334"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e215-true-d480024e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d479844e215-true-d480024e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e275-true-d480063e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1333"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e275-true-d480063e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479844e275-true-d480063e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e288-true-d480110e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1332"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e288-true-d480110e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d479844e288-true-d480110e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480103e17-true-d480121e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1331"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480103e17-true-d480121e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480103e17-true-d480121e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480103e28-true-d480144e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1330"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480103e28-true-d480144e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480103e28-true-d480144e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e318-true-d480173e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1329"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e318-true-d480173e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479844e318-true-d480173e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e329-true-d480196e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1328"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e329-true-d480196e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479844e329-true-d480196e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e351-true-d480232e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1327"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e351-true-d480232e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d479844e351-true-d480232e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479844e369-true-d480304e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.10/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1326"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479844e369-true-d480304e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d479844e369-true-d480304e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e233-true-d480390e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1325"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e233-true-d480390e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d479210e233-true-d480390e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e32-true-d480410e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1324"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e32-true-d480410e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d480362e32-true-d480410e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e123-true-d480488e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1323"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e123-true-d480488e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d480362e123-true-d480488e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e215-true-d480542e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1322"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e215-true-d480542e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d480362e215-true-d480542e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e275-true-d480581e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1321"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e275-true-d480581e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d480362e275-true-d480581e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e288-true-d480628e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1320"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e288-true-d480628e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d480362e288-true-d480628e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480621e17-true-d480639e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1319"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480621e17-true-d480639e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480621e17-true-d480639e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480621e28-true-d480662e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1318"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480621e28-true-d480662e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480621e28-true-d480662e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e318-true-d480691e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1317"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e318-true-d480691e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480362e318-true-d480691e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e329-true-d480714e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1316"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e329-true-d480714e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480362e329-true-d480714e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e351-true-d480750e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1315"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e351-true-d480750e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d480362e351-true-d480750e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480362e369-true-d480822e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.11/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1314"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480362e369-true-d480822e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d480362e369-true-d480822e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e245-true-d480908e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1313"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e245-true-d480908e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d479210e245-true-d480908e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e32-true-d480928e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1312"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e32-true-d480928e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d480880e32-true-d480928e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e123-true-d481006e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1311"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e123-true-d481006e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d480880e123-true-d481006e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e215-true-d481060e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1310"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e215-true-d481060e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d480880e215-true-d481060e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e275-true-d481099e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1309"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e275-true-d481099e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d480880e275-true-d481099e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e288-true-d481146e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1308"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e288-true-d481146e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d480880e288-true-d481146e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481139e17-true-d481157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1307"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481139e17-true-d481157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d481139e17-true-d481157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481139e28-true-d481180e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1306"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481139e28-true-d481180e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d481139e28-true-d481180e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e318-true-d481209e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1305"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e318-true-d481209e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480880e318-true-d481209e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e329-true-d481232e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1304"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e329-true-d481232e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d480880e329-true-d481232e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e351-true-d481268e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1303"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e351-true-d481268e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d480880e351-true-d481268e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d480880e369-true-d481340e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.12/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1302"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d480880e369-true-d481340e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d480880e369-true-d481340e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e256-true-d481414e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1301"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e256-true-d481414e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d479210e256-true-d481414e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481398e48-true-d481444e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1300"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481398e48-true-d481444e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d481398e48-true-d481444e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481398e125-true-d481505e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1299"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481398e125-true-d481505e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d481398e125-true-d481505e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481398e134-true-d481541e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.13/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1298"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481398e134-true-d481541e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d481398e134-true-d481541e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e267-true-d481580e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1297"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e267-true-d481580e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d479210e267-true-d481580e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e278-true-d481663e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1296"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e278-true-d481663e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479210e278-true-d481663e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e289-true-d481690e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1295"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e289-true-d481690e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479210e289-true-d481690e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e303-true-d481741e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1294"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e303-true-d481741e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479210e303-true-d481741e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e314-true-d481792e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1293"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e314-true-d481792e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479210e314-true-d481792e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e325-true-d481860e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1292"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e325-true-d481860e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d479210e325-true-d481860e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e32-true-d481880e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1291"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e32-true-d481880e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d481832e32-true-d481880e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e123-true-d481958e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1290"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e123-true-d481958e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d481832e123-true-d481958e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e215-true-d482012e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1289"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e215-true-d482012e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d481832e215-true-d482012e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e275-true-d482051e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1288"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e275-true-d482051e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d481832e275-true-d482051e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e288-true-d482098e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1287"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e288-true-d482098e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d481832e288-true-d482098e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482091e17-true-d482109e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1286"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482091e17-true-d482109e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482091e17-true-d482109e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482091e28-true-d482132e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1285"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482091e28-true-d482132e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482091e28-true-d482132e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e318-true-d482161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1284"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e318-true-d482161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d481832e318-true-d482161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e329-true-d482184e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1283"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e329-true-d482184e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d481832e329-true-d482184e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e351-true-d482220e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1282"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e351-true-d482220e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d481832e351-true-d482220e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d481832e369-true-d482292e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.19/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1281"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d481832e369-true-d482292e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d481832e369-true-d482292e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e336-true-d482361e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1280"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e336-true-d482361e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d479210e336-true-d482361e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e349-true-d482416e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:XON.1 | self::hl7v2:XON.2 | self::hl7v2:XON.3 | self::hl7v2:XON.4 | self::hl7v2:XON.5 | self::hl7v2:XON.6 | self::hl7v2:XON.7 | self::hl7v2:XON.8 | self::hl7v2:XON.9 | self::hl7v2:XON.10)]"
                 priority="1279"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e349-true-d482416e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XON.1 | hl7v2:XON.2 | hl7v2:XON.3 | hl7v2:XON.4 | hl7v2:XON.5 | hl7v2:XON.6 | hl7v2:XON.7 | hl7v2:XON.8 | hl7v2:XON.9 | hl7v2:XON.10 (rule-reference: d479210e349-true-d482416e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482401e80-true-d482458e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1278"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482401e80-true-d482458e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d482401e80-true-d482458e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482401e119-true-d482494e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.21/hl7v2:XON.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1277"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482401e119-true-d482494e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d482401e119-true-d482494e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e360-true-d482547e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1276"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e360-true-d482547e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d479210e360-true-d482547e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482528e15-true-d482559e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1275"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482528e15-true-d482559e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d482528e15-true-d482559e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482528e214-true-d482648e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1274"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482528e214-true-d482648e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d482528e214-true-d482648e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482641e23-true-d482659e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1273"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482641e23-true-d482659e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482641e23-true-d482659e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482641e34-true-d482682e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1272"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482641e34-true-d482682e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482641e34-true-d482682e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482528e234-true-d482705e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1271"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482528e234-true-d482705e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482528e234-true-d482705e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482528e248-true-d482728e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.22/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1270"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482528e248-true-d482728e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482528e248-true-d482728e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e372-true-d482761e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1269"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e372-true-d482761e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d479210e372-true-d482761e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e383-true-d482856e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/*[not(@xsi:nil = 'true')][not(self::hl7v2:XAD.1 | self::hl7v2:XAD.2 | self::hl7v2:XAD.3 | self::hl7v2:XAD.4 | self::hl7v2:XAD.5 | self::hl7v2:XAD.6 | self::hl7v2:XAD.7 | self::hl7v2:XAD.8 | self::hl7v2:XAD.9 | self::hl7v2:XAD.10 | self::hl7v2:XAD.11 | self::hl7v2:XAD.12 | self::hl7v2:XAD.13 | self::hl7v2:XAD.14)]"
                 priority="1268"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e383-true-d482856e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XAD.1 | hl7v2:XAD.2 | hl7v2:XAD.3 | hl7v2:XAD.4 | hl7v2:XAD.5 | hl7v2:XAD.6 | hl7v2:XAD.7 | hl7v2:XAD.8 | hl7v2:XAD.9 | hl7v2:XAD.10 | hl7v2:XAD.11 | hl7v2:XAD.12 | hl7v2:XAD.13 | hl7v2:XAD.14 (rule-reference: d479210e383-true-d482856e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482837e15-true-d482868e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:SAD.1 | self::hl7v2:SAD.2 | self::hl7v2:SAD.3)]"
                 priority="1267"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482837e15-true-d482868e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SAD.1 | hl7v2:SAD.2 | hl7v2:SAD.3 (rule-reference: d482837e15-true-d482868e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482837e214-true-d482957e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1266"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482837e214-true-d482957e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d482837e214-true-d482957e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482950e23-true-d482968e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1265"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482950e23-true-d482968e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482950e23-true-d482968e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482950e34-true-d482991e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.12/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1264"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482950e34-true-d482991e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482950e34-true-d482991e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482837e234-true-d483014e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1263"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482837e234-true-d483014e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482837e234-true-d483014e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d482837e248-true-d483037e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.24/hl7v2:XAD.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1262"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d482837e248-true-d483037e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d482837e248-true-d483037e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e394-true-d483067e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1261"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e394-true-d483067e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d479210e394-true-d483067e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e405-true-d483139e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1260"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e405-true-d483139e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d479210e405-true-d483139e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e418-true-d483204e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1259"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e418-true-d483204e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d479210e418-true-d483204e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e429-true-d483234e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1258"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e429-true-d483234e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d479210e429-true-d483234e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e442-true-d483306e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1257"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e442-true-d483306e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d479210e442-true-d483306e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d479210e455-true-d483378e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:ORC/hl7v2:ORC.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNE.1 | self::hl7v2:CNE.2 | self::hl7v2:CNE.3 | self::hl7v2:CNE.4 | self::hl7v2:CNE.5 | self::hl7v2:CNE.6 | self::hl7v2:CNE.7 | self::hl7v2:CNE.8 | self::hl7v2:CNE.9)]"
                 priority="1256"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d479210e455-true-d483378e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNE.1 | hl7v2:CNE.2 | hl7v2:CNE.3 | hl7v2:CNE.4 | hl7v2:CNE.5 | hl7v2:CNE.6 | hl7v2:CNE.7 | hl7v2:CNE.8 | hl7v2:CNE.9 (rule-reference: d479210e455-true-d483378e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3975-true-d483490e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBR.1 | self::hl7v2:OBR.2 | self::hl7v2:OBR.3 | self::hl7v2:OBR.4 | self::hl7v2:OBR.5 | self::hl7v2:OBR.6 | self::hl7v2:OBR.7 | self::hl7v2:OBR.8 | self::hl7v2:OBR.9 | self::hl7v2:OBR.10 | self::hl7v2:OBR.11 | self::hl7v2:OBR.12 | self::hl7v2:OBR.13 | self::hl7v2:OBR.14 | self::hl7v2:OBR.15 | self::hl7v2:OBR.16 | self::hl7v2:OBR.17 | self::hl7v2:OBR.18 | self::hl7v2:OBR.19 | self::hl7v2:OBR.20 | self::hl7v2:OBR.21 | self::hl7v2:OBR.22 | self::hl7v2:OBR.23 | self::hl7v2:OBR.24 | self::hl7v2:OBR.25 | self::hl7v2:OBR.26 | self::hl7v2:OBR.27 | self::hl7v2:OBR.28 | self::hl7v2:OBR.29 | self::hl7v2:OBR.30 | self::hl7v2:OBR.31 | self::hl7v2:OBR.32 | self::hl7v2:OBR.33 | self::hl7v2:OBR.34 | self::hl7v2:OBR.35 | self::hl7v2:OBR.36 | self::hl7v2:OBR.37 | self::hl7v2:OBR.38 | self::hl7v2:OBR.39 | self::hl7v2:OBR.40 | self::hl7v2:OBR.41 | self::hl7v2:OBR.42 | self::hl7v2:OBR.43 | self::hl7v2:OBR.44 | self::hl7v2:OBR.45 | self::hl7v2:OBR.46 | self::hl7v2:OBR.47 | self::hl7v2:OBR.48 | self::hl7v2:OBR.49)]"
                 priority="1255"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3975-true-d483490e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBR.1 | hl7v2:OBR.2 | hl7v2:OBR.3 | hl7v2:OBR.4 | hl7v2:OBR.5 | hl7v2:OBR.6 | hl7v2:OBR.7 | hl7v2:OBR.8 | hl7v2:OBR.9 | hl7v2:OBR.10 | hl7v2:OBR.11 | hl7v2:OBR.12 | hl7v2:OBR.13 | hl7v2:OBR.14 | hl7v2:OBR.15 | hl7v2:OBR.16 | hl7v2:OBR.17 | hl7v2:OBR.18 | hl7v2:OBR.19 | hl7v2:OBR.20 | hl7v2:OBR.21 | hl7v2:OBR.22 | hl7v2:OBR.23 | hl7v2:OBR.24 | hl7v2:OBR.25 | hl7v2:OBR.26 | hl7v2:OBR.27 | hl7v2:OBR.28 | hl7v2:OBR.29 | hl7v2:OBR.30 | hl7v2:OBR.31 | hl7v2:OBR.32 | hl7v2:OBR.33 | hl7v2:OBR.34 | hl7v2:OBR.35 | hl7v2:OBR.36 | hl7v2:OBR.37 | hl7v2:OBR.38 | hl7v2:OBR.39 | hl7v2:OBR.40 | hl7v2:OBR.41 | hl7v2:OBR.42 | hl7v2:OBR.43 | hl7v2:OBR.44 | hl7v2:OBR.45 | hl7v2:OBR.46 | hl7v2:OBR.47 | hl7v2:OBR.48 | hl7v2:OBR.49 (rule-reference: d20e3975-true-d483490e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e15-true-d483509e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1254"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e15-true-d483509e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d483437e15-true-d483509e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e32-true-d483546e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1253"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e32-true-d483546e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d483437e32-true-d483546e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e49-true-d483585e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1252"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e49-true-d483585e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e49-true-d483585e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e95-true-d483638e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1251"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e95-true-d483638e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483437e95-true-d483638e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e115-true-d483661e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1250"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e115-true-d483661e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483437e115-true-d483661e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e126-true-d483684e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1249"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e126-true-d483684e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483437e126-true-d483684e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e137-true-d483707e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1248"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e137-true-d483707e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d483437e137-true-d483707e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483700e26-true-d483728e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.9/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1247"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483700e26-true-d483728e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483700e26-true-d483728e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e148-true-d483796e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1246"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e148-true-d483796e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d483437e148-true-d483796e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e32-true-d483816e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1245"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e32-true-d483816e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d483768e32-true-d483816e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e123-true-d483894e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1244"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e123-true-d483894e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d483768e123-true-d483894e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e215-true-d483948e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1243"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e215-true-d483948e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d483768e215-true-d483948e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e275-true-d483987e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1242"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e275-true-d483987e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483768e275-true-d483987e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e288-true-d484034e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1241"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e288-true-d484034e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d483768e288-true-d484034e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484027e17-true-d484045e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1240"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484027e17-true-d484045e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d484027e17-true-d484045e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484027e28-true-d484068e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1239"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484027e28-true-d484068e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d484027e28-true-d484068e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e318-true-d484097e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1238"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e318-true-d484097e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483768e318-true-d484097e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e329-true-d484120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1237"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e329-true-d484120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483768e329-true-d484120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e351-true-d484156e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1236"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e351-true-d484156e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d483768e351-true-d484156e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483768e369-true-d484228e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.10/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1235"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483768e369-true-d484228e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d483768e369-true-d484228e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e173-true-d484303e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1234"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e173-true-d484303e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e173-true-d484303e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e195-true-d484356e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1233"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e195-true-d484356e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483437e195-true-d484356e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e227-true-d484384e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:SPS.1 | self::hl7v2:SPS.2 | self::hl7v2:SPS.3 | self::hl7v2:SPS.4 | self::hl7v2:SPS.5 | self::hl7v2:SPS.6 | self::hl7v2:SPS.7)]"
                 priority="1232"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e227-true-d484384e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:SPS.1 | hl7v2:SPS.2 | hl7v2:SPS.3 | hl7v2:SPS.4 | hl7v2:SPS.5 | hl7v2:SPS.6 | hl7v2:SPS.7 (rule-reference: d483437e227-true-d484384e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e24-true-d484402e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1231"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e24-true-d484402e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484372e24-true-d484402e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e53-true-d484474e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1230"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e53-true-d484474e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484372e53-true-d484474e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e66-true-d484538e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1229"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e66-true-d484538e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d484372e66-true-d484538e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484532e11-true-d484548e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1228"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484532e11-true-d484548e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d484532e11-true-d484548e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484542e5-true-d484558e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1227"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484542e5-true-d484558e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d484542e5-true-d484558e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e77-true-d484580e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1226"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e77-true-d484580e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484372e77-true-d484580e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e102-true-d484652e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1225"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e102-true-d484652e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484372e102-true-d484652e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e115-true-d484724e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1224"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e115-true-d484724e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484372e115-true-d484724e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484372e126-true-d484796e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.15/hl7v2:SPS.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1223"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484372e126-true-d484796e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484372e126-true-d484796e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e247-true-d484882e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1222"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e247-true-d484882e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d483437e247-true-d484882e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e32-true-d484902e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1221"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e32-true-d484902e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d484854e32-true-d484902e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e123-true-d484980e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1220"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e123-true-d484980e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d484854e123-true-d484980e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e215-true-d485034e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1219"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e215-true-d485034e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d484854e215-true-d485034e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e275-true-d485073e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1218"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e275-true-d485073e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d484854e275-true-d485073e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e288-true-d485120e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1217"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e288-true-d485120e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d484854e288-true-d485120e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485113e17-true-d485131e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1216"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485113e17-true-d485131e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d485113e17-true-d485131e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485113e28-true-d485154e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1215"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485113e28-true-d485154e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d485113e28-true-d485154e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e318-true-d485183e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1214"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e318-true-d485183e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d484854e318-true-d485183e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e329-true-d485206e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1213"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e329-true-d485206e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d484854e329-true-d485206e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e351-true-d485242e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1212"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e351-true-d485242e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484854e351-true-d485242e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d484854e369-true-d485314e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1211"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d484854e369-true-d485314e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d484854e369-true-d485314e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e258-true-d485389e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:XTN.1 | self::hl7v2:XTN.2 | self::hl7v2:XTN.3 | self::hl7v2:XTN.4 | self::hl7v2:XTN.5 | self::hl7v2:XTN.6 | self::hl7v2:XTN.7 | self::hl7v2:XTN.8 | self::hl7v2:XTN.9 | self::hl7v2:XTN.10 | self::hl7v2:XTN.11 | self::hl7v2:XTN.12)]"
                 priority="1210"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e258-true-d485389e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XTN.1 | hl7v2:XTN.2 | hl7v2:XTN.3 | hl7v2:XTN.4 | hl7v2:XTN.5 | hl7v2:XTN.6 | hl7v2:XTN.7 | hl7v2:XTN.8 | hl7v2:XTN.9 | hl7v2:XTN.10 | hl7v2:XTN.11 | hl7v2:XTN.12 (rule-reference: d483437e258-true-d485389e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e313-true-d485496e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1209"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e313-true-d485496e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483437e313-true-d485496e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e325-true-d485519e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:MOC.1 | self::hl7v2:MOC.2)]"
                 priority="1208"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e325-true-d485519e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MOC.1 | hl7v2:MOC.2 (rule-reference: d483437e325-true-d485519e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485512e15-true-d485530e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1207"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485512e15-true-d485530e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d485512e15-true-d485530e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485512e26-true-d485557e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.23/hl7v2:MOC.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1206"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485512e26-true-d485557e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d485512e26-true-d485557e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e369-true-d485617e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:PRL.1 | self::hl7v2:PRL.2 | self::hl7v2:PRL.3)]"
                 priority="1205"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e369-true-d485617e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PRL.1 | hl7v2:PRL.2 | hl7v2:PRL.3 (rule-reference: d483437e369-true-d485617e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485609e45-true-d485632e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1204"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485609e45-true-d485632e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d485609e45-true-d485632e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485609e67-true-d485684e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1203"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485609e67-true-d485684e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d485609e67-true-d485684e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485678e17-true-d485694e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1202"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485678e17-true-d485694e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d485678e17-true-d485694e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485688e5-true-d485704e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.26/hl7v2:PRL.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1201"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485688e5-true-d485704e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d485688e5-true-d485704e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e411-true-d485729e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ.1 | self::hl7v2:TQ.2 | self::hl7v2:TQ.3 | self::hl7v2:TQ.4 | self::hl7v2:TQ.5 | self::hl7v2:TQ.6 | self::hl7v2:TQ.7 | self::hl7v2:TQ.8 | self::hl7v2:TQ.9 | self::hl7v2:TQ.10 | self::hl7v2:TQ.11 | self::hl7v2:TQ.12)]"
                 priority="1200"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e411-true-d485729e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ.1 | hl7v2:TQ.2 | hl7v2:TQ.3 | hl7v2:TQ.4 | hl7v2:TQ.5 | hl7v2:TQ.6 | hl7v2:TQ.7 | hl7v2:TQ.8 | hl7v2:TQ.9 | hl7v2:TQ.10 | hl7v2:TQ.11 | hl7v2:TQ.12 (rule-reference: d483437e411-true-d485729e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e36-true-d485740e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1199"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e36-true-d485740e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d485712e36-true-d485740e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485733e31-true-d485761e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.1/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1198"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485733e31-true-d485761e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d485733e31-true-d485761e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e56-true-d485808e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:RI.1 | self::hl7v2:RI.2)]"
                 priority="1197"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e56-true-d485808e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RI.1 | hl7v2:RI.2 (rule-reference: d485712e56-true-d485808e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e210-true-d485837e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1196"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e210-true-d485837e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d485712e210-true-d485837e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e227-true-d485860e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1195"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e227-true-d485860e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d485712e227-true-d485860e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e482-true-d485894e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1194"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e482-true-d485894e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d485712e482-true-d485894e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485888e11-true-d485904e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1193"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485888e11-true-d485904e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d485888e11-true-d485904e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485898e5-true-d485914e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.8/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1192"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485898e5-true-d485914e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d485898e5-true-d485914e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e507-true-d485944e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:OSD.1 | self::hl7v2:OSD.2 | self::hl7v2:OSD.3 | self::hl7v2:OSD.4 | self::hl7v2:OSD.5 | self::hl7v2:OSD.6 | self::hl7v2:OSD.7 | self::hl7v2:OSD.8 | self::hl7v2:OSD.9 | self::hl7v2:OSD.10 | self::hl7v2:OSD.11)]"
                 priority="1191"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e507-true-d485944e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OSD.1 | hl7v2:OSD.2 | hl7v2:OSD.3 | hl7v2:OSD.4 | hl7v2:OSD.5 | hl7v2:OSD.6 | hl7v2:OSD.7 | hl7v2:OSD.8 | hl7v2:OSD.9 | hl7v2:OSD.10 | hl7v2:OSD.11 (rule-reference: d485712e507-true-d485944e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d485712e527-true-d486025e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.27/hl7v2:TQ.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1190"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d485712e527-true-d486025e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d485712e527-true-d486025e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e443-true-d486099e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1189"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e443-true-d486099e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d483437e443-true-d486099e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e32-true-d486119e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1188"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e32-true-d486119e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d486071e32-true-d486119e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e123-true-d486197e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1187"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e123-true-d486197e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d486071e123-true-d486197e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e215-true-d486251e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1186"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e215-true-d486251e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d486071e215-true-d486251e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e275-true-d486290e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1185"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e275-true-d486290e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d486071e275-true-d486290e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e288-true-d486337e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1184"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e288-true-d486337e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d486071e288-true-d486337e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486330e17-true-d486348e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1183"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486330e17-true-d486348e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486330e17-true-d486348e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486330e28-true-d486371e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1182"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486330e28-true-d486371e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486330e28-true-d486371e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e318-true-d486400e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1181"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e318-true-d486400e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486071e318-true-d486400e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e329-true-d486423e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1180"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e329-true-d486423e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486071e329-true-d486423e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e351-true-d486459e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1179"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e351-true-d486459e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d486071e351-true-d486459e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486071e369-true-d486531e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.28/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1178"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486071e369-true-d486531e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d486071e369-true-d486531e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e454-true-d486596e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:EIP.1 | self::hl7v2:EIP.2)]"
                 priority="1177"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e454-true-d486596e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EIP.1 | hl7v2:EIP.2 (rule-reference: d483437e454-true-d486596e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486589e21-true-d486609e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1176"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486589e21-true-d486609e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d486589e21-true-d486609e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486589e50-true-d486646e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.29/hl7v2:EIP.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1175"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486589e50-true-d486646e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d486589e50-true-d486646e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e485-true-d486691e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.31/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1174"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e485-true-d486691e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e485-true-d486691e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e496-true-d486747e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1173"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e496-true-d486747e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d483437e496-true-d486747e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486731e15-true-d486767e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1172"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486731e15-true-d486767e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d486731e15-true-d486767e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486731e26-true-d486844e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1171"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486731e26-true-d486844e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486731e26-true-d486844e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486731e37-true-d486867e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1170"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486731e37-true-d486867e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486731e37-true-d486867e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486731e87-true-d486909e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.32/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1169"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486731e87-true-d486909e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d486731e87-true-d486909e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e507-true-d486971e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1168"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e507-true-d486971e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d483437e507-true-d486971e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486955e15-true-d486991e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1167"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486955e15-true-d486991e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d486955e15-true-d486991e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486955e26-true-d487068e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1166"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486955e26-true-d487068e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486955e26-true-d487068e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486955e37-true-d487091e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1165"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486955e37-true-d487091e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d486955e37-true-d487091e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d486955e87-true-d487133e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.33/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1164"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d486955e87-true-d487133e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d486955e87-true-d487133e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e519-true-d487195e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1163"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e519-true-d487195e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d483437e519-true-d487195e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487179e15-true-d487215e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1162"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487179e15-true-d487215e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d487179e15-true-d487215e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487179e26-true-d487292e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1161"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487179e26-true-d487292e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d487179e26-true-d487292e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487179e37-true-d487315e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1160"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487179e37-true-d487315e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d487179e37-true-d487315e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487179e87-true-d487357e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.34/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1159"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487179e87-true-d487357e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d487179e87-true-d487357e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e530-true-d487419e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/*[not(@xsi:nil = 'true')][not(self::hl7v2:NDL.1 | self::hl7v2:NDL.2 | self::hl7v2:NDL.3 | self::hl7v2:NDL.4 | self::hl7v2:NDL.5 | self::hl7v2:NDL.6 | self::hl7v2:NDL.7 | self::hl7v2:NDL.8 | self::hl7v2:NDL.9 | self::hl7v2:NDL.10 | self::hl7v2:NDL.11)]"
                 priority="1158"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e530-true-d487419e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NDL.1 | hl7v2:NDL.2 | hl7v2:NDL.3 | hl7v2:NDL.4 | hl7v2:NDL.5 | hl7v2:NDL.6 | hl7v2:NDL.7 | hl7v2:NDL.8 | hl7v2:NDL.9 | hl7v2:NDL.10 | hl7v2:NDL.11 (rule-reference: d483437e530-true-d487419e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487403e15-true-d487439e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNN.1 | self::hl7v2:CNN.2 | self::hl7v2:CNN.3 | self::hl7v2:CNN.4 | self::hl7v2:CNN.5 | self::hl7v2:CNN.6 | self::hl7v2:CNN.7 | self::hl7v2:CNN.8 | self::hl7v2:CNN.9 | self::hl7v2:CNN.10 | self::hl7v2:CNN.11)]"
                 priority="1157"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487403e15-true-d487439e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNN.1 | hl7v2:CNN.2 | hl7v2:CNN.3 | hl7v2:CNN.4 | hl7v2:CNN.5 | hl7v2:CNN.6 | hl7v2:CNN.7 | hl7v2:CNN.8 | hl7v2:CNN.9 | hl7v2:CNN.10 | hl7v2:CNN.11 (rule-reference: d487403e15-true-d487439e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487403e26-true-d487516e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1156"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487403e26-true-d487516e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d487403e26-true-d487516e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487403e37-true-d487539e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1155"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487403e37-true-d487539e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d487403e37-true-d487539e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d487403e87-true-d487581e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.35/hl7v2:NDL.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1154"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d487403e87-true-d487581e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d487403e87-true-d487581e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e541-true-d487634e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.36/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1153"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e541-true-d487634e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d483437e541-true-d487634e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e563-true-d487667e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.38/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1152"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e563-true-d487667e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e563-true-d487667e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e574-true-d487718e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.39/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1151"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e574-true-d487718e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e574-true-d487718e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e585-true-d487769e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.40/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1150"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e585-true-d487769e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e585-true-d487769e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e622-true-d487832e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.43/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1149"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e622-true-d487832e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e622-true-d487832e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e633-true-d487883e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.44/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1148"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e633-true-d487883e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e633-true-d487883e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e647-true-d487934e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.45/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1147"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e647-true-d487934e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e647-true-d487934e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e660-true-d487985e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.46/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1146"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e660-true-d487985e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e660-true-d487985e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e673-true-d488036e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.47/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1145"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e673-true-d488036e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d483437e673-true-d488036e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d483437e686-true-d488090e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OBR/hl7v2:OBR.48/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1144"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d483437e686-true-d488090e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d483437e686-true-d488090e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3977-true-d488163e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1143"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3977-true-d488163e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3977-true-d488163e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488155e110-true-d488185e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1142"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488155e110-true-d488185e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488155e110-true-d488185e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488179e36-true-d488195e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1141"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488179e36-true-d488195e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488179e36-true-d488195e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488189e5-true-d488205e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1140"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488189e5-true-d488205e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488189e5-true-d488205e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488155e142-true-d488224e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1139"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488155e142-true-d488224e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d488155e142-true-d488224e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3979-true-d488268e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ1 | self::hl7v2:TQ2)]"
                 priority="1138"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3979-true-d488268e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1 | hl7v2:TQ2 (rule-reference: d20e3979-true-d488268e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3981-true-d488291e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ1.1 | self::hl7v2:TQ1.2 | self::hl7v2:TQ1.3 | self::hl7v2:TQ1.4 | self::hl7v2:TQ1.5 | self::hl7v2:TQ1.6 | self::hl7v2:TQ1.7 | self::hl7v2:TQ1.8 | self::hl7v2:TQ1.9 | self::hl7v2:TQ1.10 | self::hl7v2:TQ1.11 | self::hl7v2:TQ1.12 | self::hl7v2:TQ1.13 | self::hl7v2:TQ1.14)]"
                 priority="1137"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3981-true-d488291e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ1.1 | hl7v2:TQ1.2 | hl7v2:TQ1.3 | hl7v2:TQ1.4 | hl7v2:TQ1.5 | hl7v2:TQ1.6 | hl7v2:TQ1.7 | hl7v2:TQ1.8 | hl7v2:TQ1.9 | hl7v2:TQ1.10 | hl7v2:TQ1.11 | hl7v2:TQ1.12 | hl7v2:TQ1.13 | hl7v2:TQ1.14 (rule-reference: d20e3981-true-d488291e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e15-true-d488308e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1136"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e15-true-d488308e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d488273e15-true-d488308e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488301e26-true-d488329e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.2/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1135"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488301e26-true-d488329e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d488301e26-true-d488329e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e26-true-d488385e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:RPT.1 | self::hl7v2:RPT.2 | self::hl7v2:RPT.3 | self::hl7v2:RPT.4 | self::hl7v2:RPT.5 | self::hl7v2:RPT.6 | self::hl7v2:RPT.7 | self::hl7v2:RPT.8 | self::hl7v2:RPT.9 | self::hl7v2:RPT.10 | self::hl7v2:RPT.11)]"
                 priority="1134"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e26-true-d488385e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:RPT.1 | hl7v2:RPT.2 | hl7v2:RPT.3 | hl7v2:RPT.4 | hl7v2:RPT.5 | hl7v2:RPT.6 | hl7v2:RPT.7 | hl7v2:RPT.8 | hl7v2:RPT.9 | hl7v2:RPT.10 | hl7v2:RPT.11 (rule-reference: d488273e26-true-d488385e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488369e18-true-d488403e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.3/hl7v2:RPT.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1133"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488369e18-true-d488403e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d488369e18-true-d488403e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e50-true-d488534e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1132"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e50-true-d488534e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d488273e50-true-d488534e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488527e26-true-d488555e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.5/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1131"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488527e26-true-d488555e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d488527e26-true-d488555e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e61-true-d488602e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1130"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e61-true-d488602e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d488273e61-true-d488602e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488595e26-true-d488623e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.6/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1129"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488595e26-true-d488623e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d488595e26-true-d488623e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e72-true-d488670e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1128"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e72-true-d488670e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d488273e72-true-d488670e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e86-true-d488693e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1127"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e86-true-d488693e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d488273e86-true-d488693e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e100-true-d488723e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1126"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e100-true-d488723e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d488273e100-true-d488723e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e117-true-d488787e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1125"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e117-true-d488787e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488273e117-true-d488787e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488781e15-true-d488797e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1124"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488781e15-true-d488797e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488781e15-true-d488797e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488791e5-true-d488807e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.10/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1123"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488791e5-true-d488807e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488791e5-true-d488807e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e128-true-d488821e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1122"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e128-true-d488821e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488273e128-true-d488821e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488815e15-true-d488831e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1121"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488815e15-true-d488831e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488815e15-true-d488831e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488825e5-true-d488841e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.11/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1120"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488825e5-true-d488841e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d488825e5-true-d488841e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488273e153-true-d488862e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1119"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488273e153-true-d488862e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d488273e153-true-d488862e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488855e26-true-d488883e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ1/hl7v2:TQ1.13/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1118"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488855e26-true-d488883e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d488855e26-true-d488883e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3983-true-d488944e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TQ2.1 | self::hl7v2:TQ2.2 | self::hl7v2:TQ2.3 | self::hl7v2:TQ2.4 | self::hl7v2:TQ2.5 | self::hl7v2:TQ2.6 | self::hl7v2:TQ2.7 | self::hl7v2:TQ2.8 | self::hl7v2:TQ2.9 | self::hl7v2:TQ2.10)]"
                 priority="1117"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3983-true-d488944e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TQ2.1 | hl7v2:TQ2.2 | hl7v2:TQ2.3 | hl7v2:TQ2.4 | hl7v2:TQ2.5 | hl7v2:TQ2.6 | hl7v2:TQ2.7 | hl7v2:TQ2.8 | hl7v2:TQ2.9 | hl7v2:TQ2.10 (rule-reference: d20e3983-true-d488944e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488930e25-true-d488969e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1116"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488930e25-true-d488969e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d488930e25-true-d488969e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488930e36-true-d489006e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1115"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488930e36-true-d489006e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d488930e36-true-d489006e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488930e47-true-d489043e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1114"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488930e47-true-d489043e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d488930e47-true-d489043e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d488930e84-true-d489090e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/*[not(@xsi:nil = 'true')][not(self::hl7v2:CQ.1 | self::hl7v2:CQ.2)]"
                 priority="1113"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d488930e84-true-d489090e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CQ.1 | hl7v2:CQ.2 (rule-reference: d488930e84-true-d489090e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489083e26-true-d489111e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.TIMING_PRIOR/hl7v2:TQ2/hl7v2:TQ2.8/hl7v2:CQ.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1112"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489083e26-true-d489111e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d489083e26-true-d489111e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3986-true-d489167e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX | self::hl7v2:NTE)]"
                 priority="1111"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3986-true-d489167e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX | hl7v2:NTE (rule-reference: d20e3986-true-d489167e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3988-true-d489195e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/*[not(@xsi:nil = 'true')][not(self::hl7v2:OBX.1 | self::hl7v2:OBX.2 | self::hl7v2:OBX.3 | self::hl7v2:OBX.4 | self::hl7v2:OBX.5 | self::hl7v2:OBX.6 | self::hl7v2:OBX.7 | self::hl7v2:OBX.8 | self::hl7v2:OBX.9 | self::hl7v2:OBX.10 | self::hl7v2:OBX.11 | self::hl7v2:OBX.12 | self::hl7v2:OBX.13 | self::hl7v2:OBX.14 | self::hl7v2:OBX.15 | self::hl7v2:OBX.16 | self::hl7v2:OBX.17 | self::hl7v2:OBX.18 | self::hl7v2:OBX.19)]"
                 priority="1110"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3988-true-d489195e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:OBX.1 | hl7v2:OBX.2 | hl7v2:OBX.3 | hl7v2:OBX.4 | hl7v2:OBX.5 | hl7v2:OBX.6 | hl7v2:OBX.7 | hl7v2:OBX.8 | hl7v2:OBX.9 | hl7v2:OBX.10 | hl7v2:OBX.11 | hl7v2:OBX.12 | hl7v2:OBX.13 | hl7v2:OBX.14 | hl7v2:OBX.15 | hl7v2:OBX.16 | hl7v2:OBX.17 | hl7v2:OBX.18 | hl7v2:OBX.19 (rule-reference: d20e3988-true-d489195e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e74-true-d489222e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1109"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e74-true-d489222e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d489172e74-true-d489222e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e164-true-d489285e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1108"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e164-true-d489285e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d489172e164-true-d489285e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e287-true-d489362e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1107"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e287-true-d489362e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489172e287-true-d489362e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e309-true-d489391e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1106"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e309-true-d489391e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489172e309-true-d489391e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e327-true-d489418e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1105"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e327-true-d489418e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d489172e327-true-d489418e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e338-true-d489486e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1104"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e338-true-d489486e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d489172e338-true-d489486e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e32-true-d489506e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1103"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e32-true-d489506e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d489458e32-true-d489506e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e123-true-d489584e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1102"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e123-true-d489584e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d489458e123-true-d489584e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e215-true-d489638e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1101"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e215-true-d489638e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d489458e215-true-d489638e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e275-true-d489677e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1100"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e275-true-d489677e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d489458e275-true-d489677e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e288-true-d489724e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1099"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e288-true-d489724e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d489458e288-true-d489724e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489717e17-true-d489735e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1098"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489717e17-true-d489735e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489717e17-true-d489735e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489717e28-true-d489758e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1097"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489717e28-true-d489758e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489717e28-true-d489758e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e318-true-d489787e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1096"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e318-true-d489787e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489458e318-true-d489787e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e329-true-d489810e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1095"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e329-true-d489810e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489458e329-true-d489810e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e351-true-d489846e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1094"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e351-true-d489846e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d489458e351-true-d489846e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489458e369-true-d489918e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.16/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1093"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489458e369-true-d489918e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d489458e369-true-d489918e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e349-true-d489987e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1092"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e349-true-d489987e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d489172e349-true-d489987e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e360-true-d490036e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.18/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1091"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e360-true-d490036e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d489172e360-true-d490036e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d489172e371-true-d490071e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:OBX/hl7v2:OBX.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1090"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d489172e371-true-d490071e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d489172e371-true-d490071e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3990-true-d490096e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/*[not(@xsi:nil = 'true')][not(self::hl7v2:NTE.1 | self::hl7v2:NTE.2 | self::hl7v2:NTE.3 | self::hl7v2:NTE.4)]"
                 priority="1089"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3990-true-d490096e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:NTE.1 | hl7v2:NTE.2 | hl7v2:NTE.3 | hl7v2:NTE.4 (rule-reference: d20e3990-true-d490096e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490088e110-true-d490118e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1088"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490088e110-true-d490118e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d490088e110-true-d490118e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490112e36-true-d490128e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1087"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490112e36-true-d490128e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d490112e36-true-d490128e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490122e5-true-d490138e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.3/hl7v2:escape/hl7v2:escape/*[not(@xsi:nil = 'true')][not(self::hl7v2:escape)]"
                 priority="1086"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490122e5-true-d490138e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:escape (rule-reference: d490122e5-true-d490138e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490088e142-true-d490157e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:OML_O21.OBSERVATION_REQUEST/hl7v2:OML_O21.PRIOR_RESULT/hl7v2:OML_O21.ORDER_PRIOR/hl7v2:OML_O21.OBSERVATION_PRIOR/hl7v2:NTE/hl7v2:NTE.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1085"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490088e142-true-d490157e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490088e142-true-d490157e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3996-true-d490233e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/*[not(@xsi:nil = 'true')][not(self::hl7v2:FT1.1 | self::hl7v2:FT1.2 | self::hl7v2:FT1.3 | self::hl7v2:FT1.4 | self::hl7v2:FT1.5 | self::hl7v2:FT1.6 | self::hl7v2:FT1.7 | self::hl7v2:FT1.8 | self::hl7v2:FT1.9 | self::hl7v2:FT1.10 | self::hl7v2:FT1.11 | self::hl7v2:FT1.12 | self::hl7v2:FT1.13 | self::hl7v2:FT1.14 | self::hl7v2:FT1.15 | self::hl7v2:FT1.16 | self::hl7v2:FT1.17 | self::hl7v2:FT1.18 | self::hl7v2:FT1.19 | self::hl7v2:FT1.20 | self::hl7v2:FT1.21 | self::hl7v2:FT1.22 | self::hl7v2:FT1.23 | self::hl7v2:FT1.24 | self::hl7v2:FT1.25 | self::hl7v2:FT1.26 | self::hl7v2:FT1.27 | self::hl7v2:FT1.28 | self::hl7v2:FT1.29 | self::hl7v2:FT1.30 | self::hl7v2:FT1.31)]"
                 priority="1084"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3996-true-d490233e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FT1.1 | hl7v2:FT1.2 | hl7v2:FT1.3 | hl7v2:FT1.4 | hl7v2:FT1.5 | hl7v2:FT1.6 | hl7v2:FT1.7 | hl7v2:FT1.8 | hl7v2:FT1.9 | hl7v2:FT1.10 | hl7v2:FT1.11 | hl7v2:FT1.12 | hl7v2:FT1.13 | hl7v2:FT1.14 | hl7v2:FT1.15 | hl7v2:FT1.16 | hl7v2:FT1.17 | hl7v2:FT1.18 | hl7v2:FT1.19 | hl7v2:FT1.20 | hl7v2:FT1.21 | hl7v2:FT1.22 | hl7v2:FT1.23 | hl7v2:FT1.24 | hl7v2:FT1.25 | hl7v2:FT1.26 | hl7v2:FT1.27 | hl7v2:FT1.28 | hl7v2:FT1.29 | hl7v2:FT1.30 | hl7v2:FT1.31 (rule-reference: d20e3996-true-d490233e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e34-true-d490262e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1083"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e34-true-d490262e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d490198e34-true-d490262e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490255e15-true-d490273e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1082"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490255e15-true-d490273e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d490255e15-true-d490273e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490255e26-true-d490296e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.4/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1081"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490255e26-true-d490296e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d490255e26-true-d490296e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e45-true-d490319e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1080"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e45-true-d490319e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d490198e45-true-d490319e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e69-true-d490352e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.7/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1079"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e69-true-d490352e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e69-true-d490352e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e115-true-d490421e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="1078"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e115-true-d490421e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d490198e115-true-d490421e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490410e15-true-d490432e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1077"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490410e15-true-d490432e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d490410e15-true-d490432e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490410e82-true-d490477e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.11/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1076"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490410e82-true-d490477e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490410e82-true-d490477e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e127-true-d490534e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="1075"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e127-true-d490534e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d490198e127-true-d490534e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490523e15-true-d490545e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1074"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490523e15-true-d490545e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d490523e15-true-d490545e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490523e82-true-d490590e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.12/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1073"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490523e82-true-d490590e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490523e82-true-d490590e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e138-true-d490647e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.13/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1072"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e138-true-d490647e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e138-true-d490647e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e151-true-d490698e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1071"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e151-true-d490698e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e151-true-d490698e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e164-true-d490749e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="1070"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e164-true-d490749e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d490198e164-true-d490749e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490738e15-true-d490760e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1069"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490738e15-true-d490760e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d490738e15-true-d490760e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490738e82-true-d490805e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.15/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1068"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490738e82-true-d490805e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490738e82-true-d490805e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e175-true-d490867e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:PL.1 | self::hl7v2:PL.2 | self::hl7v2:PL.3 | self::hl7v2:PL.4 | self::hl7v2:PL.5 | self::hl7v2:PL.6 | self::hl7v2:PL.7 | self::hl7v2:PL.8 | self::hl7v2:PL.9 | self::hl7v2:PL.10 | self::hl7v2:PL.11)]"
                 priority="1067"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e175-true-d490867e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:PL.1 | hl7v2:PL.2 | hl7v2:PL.3 | hl7v2:PL.4 | hl7v2:PL.5 | hl7v2:PL.6 | hl7v2:PL.7 | hl7v2:PL.8 | hl7v2:PL.9 | hl7v2:PL.10 | hl7v2:PL.11 (rule-reference: d490198e175-true-d490867e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490851e48-true-d490897e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1066"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490851e48-true-d490897e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d490851e48-true-d490897e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490851e125-true-d490958e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1065"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490851e125-true-d490958e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d490851e125-true-d490958e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490851e134-true-d490994e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.16/hl7v2:PL.11/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1064"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490851e134-true-d490994e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d490851e134-true-d490994e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e212-true-d491039e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1063"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e212-true-d491039e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e212-true-d491039e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e225-true-d491107e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1062"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e225-true-d491107e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d490198e225-true-d491107e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e35-true-d491127e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1061"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e35-true-d491127e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d491079e35-true-d491127e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e127-true-d491205e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1060"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e127-true-d491205e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d491079e127-true-d491205e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e218-true-d491259e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1059"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e218-true-d491259e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d491079e218-true-d491259e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e278-true-d491298e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1058"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e278-true-d491298e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d491079e278-true-d491298e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e291-true-d491345e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1057"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e291-true-d491345e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d491079e291-true-d491345e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491338e17-true-d491356e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1056"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491338e17-true-d491356e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491338e17-true-d491356e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491338e28-true-d491379e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1055"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491338e28-true-d491379e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491338e28-true-d491379e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e322-true-d491408e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1054"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e322-true-d491408e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491079e322-true-d491408e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e333-true-d491431e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1053"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e333-true-d491431e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491079e333-true-d491431e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e355-true-d491467e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1052"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e355-true-d491467e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d491079e355-true-d491467e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491079e372-true-d491539e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.20/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1051"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491079e372-true-d491539e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d491079e372-true-d491539e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e238-true-d491625e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1050"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e238-true-d491625e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d490198e238-true-d491625e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e32-true-d491645e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1049"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e32-true-d491645e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d491597e32-true-d491645e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e123-true-d491723e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1048"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e123-true-d491723e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d491597e123-true-d491723e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e215-true-d491777e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1047"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e215-true-d491777e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d491597e215-true-d491777e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e275-true-d491816e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1046"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e275-true-d491816e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d491597e275-true-d491816e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e288-true-d491863e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1045"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e288-true-d491863e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d491597e288-true-d491863e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491856e17-true-d491874e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1044"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491856e17-true-d491874e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491856e17-true-d491874e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491856e28-true-d491897e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1043"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491856e28-true-d491897e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491856e28-true-d491897e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e318-true-d491926e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1042"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e318-true-d491926e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491597e318-true-d491926e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e329-true-d491949e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1041"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e329-true-d491949e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d491597e329-true-d491949e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e351-true-d491985e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1040"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e351-true-d491985e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d491597e351-true-d491985e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d491597e369-true-d492057e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.21/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1039"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d491597e369-true-d492057e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d491597e369-true-d492057e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e249-true-d492126e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CP.1 | self::hl7v2:CP.2 | self::hl7v2:CP.3 | self::hl7v2:CP.4 | self::hl7v2:CP.5 | self::hl7v2:CP.6)]"
                 priority="1038"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e249-true-d492126e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CP.1 | hl7v2:CP.2 | hl7v2:CP.3 | hl7v2:CP.4 | hl7v2:CP.5 | hl7v2:CP.6 (rule-reference: d490198e249-true-d492126e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492115e15-true-d492137e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:MO.1 | self::hl7v2:MO.2)]"
                 priority="1037"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492115e15-true-d492137e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:MO.1 | hl7v2:MO.2 (rule-reference: d492115e15-true-d492137e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492115e82-true-d492182e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.22/hl7v2:CP.5/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1036"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492115e82-true-d492182e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d492115e82-true-d492182e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e261-true-d492237e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1035"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e261-true-d492237e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d490198e261-true-d492237e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e272-true-d492293e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/*[not(@xsi:nil = 'true')][not(self::hl7v2:XCN.1 | self::hl7v2:XCN.2 | self::hl7v2:XCN.3 | self::hl7v2:XCN.4 | self::hl7v2:XCN.5 | self::hl7v2:XCN.6 | self::hl7v2:XCN.7 | self::hl7v2:XCN.8 | self::hl7v2:XCN.9 | self::hl7v2:XCN.10 | self::hl7v2:XCN.11 | self::hl7v2:XCN.12 | self::hl7v2:XCN.13 | self::hl7v2:XCN.14 | self::hl7v2:XCN.15 | self::hl7v2:XCN.16 | self::hl7v2:XCN.17 | self::hl7v2:XCN.18 | self::hl7v2:XCN.19 | self::hl7v2:XCN.20 | self::hl7v2:XCN.21 | self::hl7v2:XCN.22 | self::hl7v2:XCN.23)]"
                 priority="1034"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e272-true-d492293e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:XCN.1 | hl7v2:XCN.2 | hl7v2:XCN.3 | hl7v2:XCN.4 | hl7v2:XCN.5 | hl7v2:XCN.6 | hl7v2:XCN.7 | hl7v2:XCN.8 | hl7v2:XCN.9 | hl7v2:XCN.10 | hl7v2:XCN.11 | hl7v2:XCN.12 | hl7v2:XCN.13 | hl7v2:XCN.14 | hl7v2:XCN.15 | hl7v2:XCN.16 | hl7v2:XCN.17 | hl7v2:XCN.18 | hl7v2:XCN.19 | hl7v2:XCN.20 | hl7v2:XCN.21 | hl7v2:XCN.22 | hl7v2:XCN.23 (rule-reference: d490198e272-true-d492293e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e32-true-d492313e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:FN.1 | self::hl7v2:FN.2 | self::hl7v2:FN.3 | self::hl7v2:FN.4 | self::hl7v2:FN.5)]"
                 priority="1033"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e32-true-d492313e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:FN.1 | hl7v2:FN.2 | hl7v2:FN.3 | hl7v2:FN.4 | hl7v2:FN.5 (rule-reference: d492265e32-true-d492313e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e123-true-d492391e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1032"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e123-true-d492391e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d492265e123-true-d492391e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e215-true-d492445e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.14/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1031"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e215-true-d492445e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d492265e215-true-d492445e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e275-true-d492484e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.16/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1030"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e275-true-d492484e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d492265e275-true-d492484e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e288-true-d492531e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/*[not(@xsi:nil = 'true')][not(self::hl7v2:DR.1 | self::hl7v2:DR.2)]"
                 priority="1029"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e288-true-d492531e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:DR.1 | hl7v2:DR.2 (rule-reference: d492265e288-true-d492531e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492524e17-true-d492542e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1028"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492524e17-true-d492542e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d492524e17-true-d492542e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492524e28-true-d492565e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.17/hl7v2:DR.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1027"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492524e28-true-d492565e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d492524e28-true-d492565e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e318-true-d492594e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.19/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1026"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e318-true-d492594e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d492265e318-true-d492594e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e329-true-d492617e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.20/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1025"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e329-true-d492617e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d492265e329-true-d492617e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e351-true-d492653e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.22/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1024"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e351-true-d492653e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d492265e351-true-d492653e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d492265e369-true-d492725e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.24/hl7v2:XCN.23/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1023"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d492265e369-true-d492725e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d492265e369-true-d492725e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e283-true-d492794e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.25/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1022"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e283-true-d492794e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e283-true-d492794e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e296-true-d492845e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.26/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1021"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e296-true-d492845e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e296-true-d492845e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e309-true-d492896e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.27/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1020"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e309-true-d492896e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d490198e309-true-d492896e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e322-true-d492950e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.28/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1019"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e322-true-d492950e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d490198e322-true-d492950e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e335-true-d493022e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.29/*[not(@xsi:nil = 'true')][not(self::hl7v2:CNE.1 | self::hl7v2:CNE.2 | self::hl7v2:CNE.3 | self::hl7v2:CNE.4 | self::hl7v2:CNE.5 | self::hl7v2:CNE.6 | self::hl7v2:CNE.7 | self::hl7v2:CNE.8 | self::hl7v2:CNE.9)]"
                 priority="1018"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e335-true-d493022e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CNE.1 | hl7v2:CNE.2 | hl7v2:CNE.3 | hl7v2:CNE.4 | hl7v2:CNE.5 | hl7v2:CNE.6 | hl7v2:CNE.7 | hl7v2:CNE.8 | hl7v2:CNE.9 (rule-reference: d490198e335-true-d493022e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d490198e348-true-d493095e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1017"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d490198e348-true-d493095e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d490198e348-true-d493095e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493080e221-true-d493125e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1016"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493080e221-true-d493125e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d493080e221-true-d493125e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493080e263-true-d493161e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1015"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493080e263-true-d493161e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d493080e263-true-d493161e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493080e305-true-d493209e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1014"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493080e305-true-d493209e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d493080e305-true-d493209e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493080e334-true-d493281e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:FT1/hl7v2:FT1.30/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1013"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493080e334-true-d493281e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d493080e334-true-d493281e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e3998-true-d493353e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/*[not(@xsi:nil = 'true')][not(self::hl7v2:CTI.1 | self::hl7v2:CTI.2 | self::hl7v2:CTI.3)]"
                 priority="1012"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e3998-true-d493353e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CTI.1 | hl7v2:CTI.2 | hl7v2:CTI.3 (rule-reference: d20e3998-true-d493353e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493346e1-true-d493366e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:EI.1 | self::hl7v2:EI.2 | self::hl7v2:EI.3 | self::hl7v2:EI.4)]"
                 priority="1011"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493346e1-true-d493366e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:EI.1 | hl7v2:EI.2 | hl7v2:EI.3 | hl7v2:EI.4 (rule-reference: d493346e1-true-d493366e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493346e12-true-d493405e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1010"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493346e12-true-d493405e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d493346e12-true-d493405e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493346e23-true-d493456e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:CTI/hl7v2:CTI.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CE.1 | self::hl7v2:CE.2 | self::hl7v2:CE.3 | self::hl7v2:CE.4 | self::hl7v2:CE.5 | self::hl7v2:CE.6)]"
                 priority="1009"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493346e23-true-d493456e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CE.1 | hl7v2:CE.2 | hl7v2:CE.3 | hl7v2:CE.4 | hl7v2:CE.5 | hl7v2:CE.6 (rule-reference: d493346e23-true-d493456e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d20e4001-true-d493505e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/*[not(@xsi:nil = 'true')][not(self::hl7v2:BLG.1 | self::hl7v2:BLG.2 | self::hl7v2:BLG.3 | self::hl7v2:BLG.4)]"
                 priority="1008"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d20e4001-true-d493505e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:BLG.1 | hl7v2:BLG.2 | hl7v2:BLG.3 | hl7v2:BLG.4 (rule-reference: d20e4001-true-d493505e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493497e1-true-d493516e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/*[not(@xsi:nil = 'true')][not(self::hl7v2:CCD.1 | self::hl7v2:CCD.2)]"
                 priority="1007"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493497e1-true-d493516e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CCD.1 | hl7v2:CCD.2 (rule-reference: d493497e1-true-d493516e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493509e31-true-d493533e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.1/hl7v2:CCD.2/*[not(@xsi:nil = 'true')][not(self::hl7v2:TS.1 | self::hl7v2:TS.2)]"
                 priority="1006"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493509e31-true-d493533e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:TS.1 | hl7v2:TS.2 (rule-reference: d493509e31-true-d493533e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493497e27-true-d493570e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/*[not(@xsi:nil = 'true')][not(self::hl7v2:CX.1 | self::hl7v2:CX.2 | self::hl7v2:CX.3 | self::hl7v2:CX.4 | self::hl7v2:CX.5 | self::hl7v2:CX.6 | self::hl7v2:CX.7 | self::hl7v2:CX.8 | self::hl7v2:CX.9 | self::hl7v2:CX.10)]"
                 priority="1005"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493497e27-true-d493570e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CX.1 | hl7v2:CX.2 | hl7v2:CX.3 | hl7v2:CX.4 | hl7v2:CX.5 | hl7v2:CX.6 | hl7v2:CX.7 | hl7v2:CX.8 | hl7v2:CX.9 | hl7v2:CX.10 (rule-reference: d493497e27-true-d493570e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493555e221-true-d493600e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1004"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493555e221-true-d493600e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d493555e221-true-d493600e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493555e263-true-d493636e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.6/*[not(@xsi:nil = 'true')][not(self::hl7v2:HD.1 | self::hl7v2:HD.2 | self::hl7v2:HD.3)]"
                 priority="1003"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493555e263-true-d493636e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:HD.1 | hl7v2:HD.2 | hl7v2:HD.3 (rule-reference: d493555e263-true-d493636e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493555e305-true-d493684e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.9/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1002"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493555e305-true-d493684e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d493555e305-true-d493684e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493555e334-true-d493756e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.3/hl7v2:CX.10/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1001"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493555e334-true-d493756e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d493555e334-true-d493756e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>

	  <!--RULE d493497e38-true-d493828e0-->
   <xsl:template match="/hl7v2:OML_O21/hl7v2:OML_O21.ORDER/hl7v2:BLG/hl7v2:BLG.4/*[not(@xsi:nil = 'true')][not(self::hl7v2:CWE.1 | self::hl7v2:CWE.2 | self::hl7v2:CWE.3 | self::hl7v2:CWE.4 | self::hl7v2:CWE.5 | self::hl7v2:CWE.6 | self::hl7v2:CWE.7 | self::hl7v2:CWE.8 | self::hl7v2:CWE.9)]"
                 priority="1000"
                 mode="M15">

		<!--ASSERT warning-->
      <xsl:choose>
         <xsl:when test="not(.)"/>
         <xsl:otherwise>
            <xsl:message>(OML_O21_Lab2Lab)/d493497e38-true-d493828e0: dit element '<xsl:text/>
               <xsl:value-of select="name(.)"/>
               <xsl:text/>' is niet gedefinieerd, of niet gedefinieerd met deze inhoud. Mogelijk betreft dit het templateId, code, of id. Verwacht in deze context: hl7v2:CWE.1 | hl7v2:CWE.2 | hl7v2:CWE.3 | hl7v2:CWE.4 | hl7v2:CWE.5 | hl7v2:CWE.6 | hl7v2:CWE.7 | hl7v2:CWE.8 | hl7v2:CWE.9 (rule-reference: d493497e38-true-d493828e0) (not(.) / warning / <xsl:apply-templates select="." mode="schematron-select-full-path"/> / http://decor.nictiz.nl/pub/labuitwisseling/lu-html-20191213T103632/tmp-2.16.840.1.113883.2.4.3.11.60.25.10.1-2015-07-21T113502.html)</xsl:message>
         </xsl:otherwise>
      </xsl:choose>
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
   <xsl:template match="text()" priority="-1" mode="M15"/>
   <xsl:template match="@*|node()" priority="-2" mode="M15">
      <xsl:apply-templates select="*" mode="M15"/>
   </xsl:template>
</xsl:stylesheet>
